#
# spec file for package kernel-default
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# This makes the OBS store the project cert as %_sourcedir/_projectcert.crt
# needssslcertforbuild

%define srcversion 3.12
%define patchversion 3.12.55
%define variant %{nil}
%define vanilla_only 0

%include %_sourcedir/kernel-spec-macros

%define build_flavor	default
%define build_default	("%build_flavor" == "default")
%define build_xen	("%build_flavor" == "xen" || "%build_flavor" == "ec2")
%define build_vanilla	("%build_flavor" == "vanilla")

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,find-provides,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SPLIT_PACKAGE CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_base (%CONFIG_SPLIT_PACKAGE == "y")
%define split_extra (%CONFIG_SPLIT_PACKAGE == "y" && %CONFIG_SUSE_KERNEL_SUPPORTED == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-default
Summary:        The Standard Kernel
License:        GPL-2.0
Group:          System/Kernel
Version:        3.12.55
%if 0%{?is_kotd}
Release:        52.42.1.g4354e1d
%else
Release:        52.42.1
%endif
Url:            http://www.kernel.org/
BuildRequires:  bc
BuildRequires:  coreutils
BuildRequires:  fdupes
%if 0%{?suse_version} > 1310
BuildRequires:  hmaccalc
%endif
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%release
Provides:       multiversion(kernel)
%if %split_base
Provides:       kernel-base = %version-%source_rel
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# END COMMON DEPS
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools m4 udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
%if %build_xen
#!BuildIgnore:  xen
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
Provides:       kernel = %version-%source_rel
%ifarch s390x
Provides:       kernel-trace = 3.13
Obsoletes:      kernel-trace <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-smp = 2.6.17
Obsoletes:      kernel-smp <= 2.6.17
Provides:       kernel-trace = 3.13
Obsoletes:      kernel-trace <= 3.13
%endif
%ifarch s390x
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%obsolete_rebuilds %name
Source0:        http://www.kernel.org/pub/linux/kernel/v3.x/linux-%srcversion.tar.xz
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source44:       find-provides
Source45:       split-modules
Source46:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source90:       SLES-UEFI-SIGN-Certificate-2048.crt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source107:      patches.xen.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source112:      patches.trace.tar.bz2
Source113:      patches.kabi.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
Source122:      modprobe-xen.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 ppc64le s390x x86_64
%define kmp_target_cpu %_target_cpu

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       8
NoSource:       9
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       39
NoSource:       40
NoSource:       44
NoSource:       45
NoSource:       46
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       90
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       107
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       112
NoSource:       113
NoSource:       120
NoSource:       121
NoSource:       122

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp   wacom 0.8.1_3
%obsolete_kmp   btrfs 0_3
%obsolete_kmp   brocade-bna 2.1.0.0_3
%obsolete_kmp   hyper-v 0_3
%obsolete_kmp   intel-e1000e 2.2.14
%obsolete_kmp   drm 3.7_3.1
Obsoletes:      firewire <= 3.0
Provides:       firewire = 3.0
%obsolete_kmp   firewire 3.0
%obsolete_kmp   iwlagn 3.0
Obsoletes:      compat-ath9k <= 3.0
Provides:       compat-ath9k = 3.0
%obsolete_kmp   compat-ath9k 3.0
%obsolete_kmp   realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp   realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp   rt3090 2.4.0.4_3
%obsolete_kmp   rt3592 2.4.1.1_3
%obsolete_kmp   rt5390 2.4.0.4_3
%obsolete_kmp   ath3k 1.0_3
Obsoletes:      ath3k-firmware <= 1.0
Provides:       ath3k-firmware = 1.0
%obsolete_kmp	compat-wireless 3.12
%obsolete_kmp	rts5229 1.08
%obsolete_kmp	rts_pstor 1.11

# Provide the exported symbols as "ksym(symbol) = hash"
%define __find_provides %_sourcedir/find-provides %name

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
The standard kernel for both uniprocessor and multiprocessor systems.


%source_timestamp
%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 107 -a 108 -a 109 -a 110 -a 111 -a 112 -a 113 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/^\+(base|yes) / {
		print $(NF);
		next;
	}
	/^\+external / {
		print $(NF) " external";
		next;
	}
	/^[-+]/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
%_sourcedir/guards --default=0 base < %_sourcedir/supported.conf | \
	sed 's,.*/,,; s,\.ko$,,' | sort -u >%kernel_build_dir/Module.base

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

cp %my_builddir/config/%cpu_arch_flavor .config
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi
../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO \
	--disable  CONFIG_DEBUG_INFO_REDUCED
%else
	--disable CONFIG_DEBUG_INFO
%endif

MAKE_ARGS="$MAKE_ARGS %{?_smp_mflags} -C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS
else
    cp .config .config.orig
    make silentoldconfig $MAKE_ARGS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d -printf '%%P\n' > %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy optional module signing files:
# *.x509, *.crt
#  - certificates with pubkeys used to verify module and firmware signatures
#    at runtime. *.crt files assumed to be in the PEM format.
# signing_key.priv
#  - unencrypted private key used to sign modules and firmware during build
# x509.genkey
#  - openssl req config to generate a new signing_key.{x509,priv} pair for the
#    build
for f in %_sourcedir/*.x509 %_sourcedir/{signing_key.priv,x509.genkey}; do
    if test -e "$f"; then
        cp "$f" .
    fi
done
for f in %_sourcedir/*.crt; do
    if ! test -e "$f"; then
        continue
    fi
    out=${f##*/}
    out=${out%.crt}.x509
    openssl x509 -inform PEM -in "$f" -outform DER -out "$out"
done
# Convince kernel/Makefile not to generate a new keypair
touch x509.genkey
touch signing_key.x509
%if %build_vanilla
    # workaround for the 3.12 vanilla kernel which does not have
    #   f0e6d22 ("KEYS: Load *.x509 files into kernel keyring)
    # but supports an "extra_certificates" file instead
    for f in *.x509; do
        if test ! -e "$f" -o "$f" = "signing_key.x509"; then
            continue
        fi
        cat "$f" >>extra_certificates
    done
%endif


MAKE_ARGS="$MAKE_ARGS %{?_smp_mflags}"

%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

while true; do
    make all $MAKE_ARGS 2>&1 \
        | tee buildlog
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver buildlog; then
        echo "Retrying make"
    else
        exit 1
    fi
done

%install

# sign the modules, firmware and possibly the kernel in the buildservice
export BRP_PESIGN_FILES="*.ko"
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES /boot/vmlinuz-%kernelrelease-%build_flavor"
%endif

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.gz
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
%if %build_xen
    test -f arch/x86/boot/$image || image=vmlinuz
%endif
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
    image=vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    image=zImage
    cp -p arch/arm/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    image=Image
    cp -p arch/arm64/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/$image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in *.x509; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform DER -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            cp "$f" %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

# Install the frontend driver selector file for xen/ec2
%if %build_xen
mkdir -p %buildroot/etc/modprobe.d
cp %_sourcedir/modprobe-xen.conf %buildroot/etc/modprobe.d/50-xen.conf
%endif

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base' | '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        if test %build_flavor = "zfcpdump"; then
            : >%my_builddir/$script$sub.sh
            continue
        fi
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_xen || %build_vanilla
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot/lib/modules/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

%if %split_base
    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir/Module.base \
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i
%endif
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    dd if=/dev/zero of=%buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep ibs=`stat -c%s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep` count=1

%else
    (   cd %buildroot
	find lib/modules/%kernelrelease-%build_flavor -type f -name '*.ko' -printf '/%%p\n'
    ) > %my_builddir/base-modules
%endif

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # arch/powerpc/lib/crtsavres.o is required for building external
    # modules on powerpc
    if [ -f %kernel_build_dir/arch/powerpc/lib/crtsavres.o ]; then
	echo arch/powerpc/lib/crtsavres.o >> %my_builddir/obj-files
    fi

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Recreate the generated Makefile with correct path
    sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
        %rpm_install_dir/%cpu_arch_flavor \
        $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
fi

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/symtypes* %buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    for f in boot/*; do
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.gz)
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                echo "%%ghost /$f"
                continue
            fi
            ;;
        boot/symtypes*)
            continue
            ;;
        esac
        echo "%%attr(0644, root, root) /$f"
    done

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -type f -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    # optional per-kernel-release module config workarounds
    if test -d etc/modprobe.d; then
        find etc/modprobe.d -type f -printf '%%%%config(noreplace) /%%p\n'
    fi
    test -d lib/firmware/%kernelrelease-%build_flavor && \
    find lib/firmware/%kernelrelease-%build_flavor \
	-type d -o \
	-printf '/%%p\n'
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

%if %split_base
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules} \
	> %my_builddir/kernel-main.files
%endif
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%endif

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%if %split_base

%files -f kernel-main.files
%defattr(-, root, root)
%else

%files -f kernel-base.files
%defattr(-, root, root)
%endif

%package base
Summary:        The Standard Kernel - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%release
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%ifarch s390x
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%obsolete_rebuilds %name-base

%description base
The standard kernel for both uniprocessor and multiprocessor systems.

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%if %split_base

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        The Standard Kernel - Unsupported kernel modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%release
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%release
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch s390x
Provides:       kernel-trace-extra = 3.13
Obsoletes:      kernel-trace-extra <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-extra = 3.13
Obsoletes:      kernel-trace-extra <= 3.13
%endif
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SUSE_SLED):%{name}_%_target_cpu)

%description extra
The standard kernel for both uniprocessor and multiprocessor systems.

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script.
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla
Requires:       kernel-devel%variant = %version-%source_rel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%ifarch s390x
Provides:       kernel-trace-devel = 3.13
Obsoletes:      kernel-trace-devel <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-devel = 3.13
Obsoletes:      kernel-trace-devel <= 3.13
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp
%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%if %kmp_target_cpu != %cpu_arch
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif
%endif

%changelog
* Thu Mar  3 2016 mmarek@suse.cz
- kabi: Preserve checksum of kvm_x86_ops (bsc#969112).
- commit 4354e1d
* Wed Mar  2 2016 mmarek@suse.com
- Add /etc/modprobe.d/50-xen.conf selecting Xen frontend driver implementation
  (bsc#957986, bsc#956084, bsc#961658).
- commit f454f9f
* Wed Mar  2 2016 jbeulich@suse.com
- Update Xen config files (enable upstream block frontend).
- commit 4e2afd4
* Wed Mar  2 2016 jbeulich@suse.com
- xen-blkfront: allow building in our Xen environment (bsc#957986
  fate#320625).
- supported.conf: Add xen-blkfront.
- commit f9b2d40
* Wed Mar  2 2016 jbeulich@suse.com
- xen/blkfront: Fix crash if backend doesn't follow the right
  states (bsc#957986 fate#320625).
- drivers: xen-blkfront: only talk_to_blkback() when in
  XenbusStateInitialising (bsc#957986 fate#320625).
- driver: xen-blkfront: move talk_to_blkback to a more suitable
  place (bsc#957986 fate#320625).
- xen-blkfront: fix accounting of reqs when migrating (bsc#957986
  fate#320625).
- xen/blkfront: remove redundant flush_op (bsc#957986
  fate#320625).
- xen/blkfront: improve protection against issuing unsupported
  REQ_FUA (bsc#957986 fate#320625).
- xen, blkfront: factor out flush-related checks from
  do_blkif_request() (bsc#957986 fate#320625).
- xen-blkfront: remove type check from blkfront_setup_discard
  (bsc#957986 fate#320625).
- block: xen-blkfront: Fix possible NULL ptr dereference
  (bsc#957986 fate#320625).
- xen-blkfront: Silence pfn maybe-uninitialized warning
  (bsc#957986 fate#320625).
- xen-blkfront: improve aproximation of required grants per
  request (bsc#957986 fate#320625).
- commit b9f43ee
* Wed Mar  2 2016 mmarek@suse.com
- Remove superfluous Git-commit header
  from patches.fixes/0001-namespaces-Re-introduce-task_nsproxy-helper.patch.
- commit 878d0de
* Wed Mar  2 2016 dbueso@suse.de
- namespaces: Re-introduce task_nsproxy() helper (bug#963960).
- commit 611a9b7
* Tue Mar  1 2016 mmarek@suse.com
- kabi/severities: Fail on changes in kvm_x86_ops, needed by lttng-modules
- commit bb67694
* Tue Mar  1 2016 mmarek@suse.com
- rpm/kernel-module-subpackage: Fix obsoleting dropped flavors (bsc#968253)
- commit 73352e3
* Tue Mar  1 2016 mkubecek@suse.cz
- net: core: Correct an over-stringent device loop detection
  (bsc#945219).
- commit b4e4e5a
* Tue Mar  1 2016 mkubecek@suse.cz
- series.conf: add section comments
- commit 702e302
* Mon Feb 29 2016 jbeulich@suse.com
- pciback: Check PF instead of VF for PCI_COMMAND_MEMORY.
- pciback: Save the number of MSI-X entries to be copied later.
- commit 3520b84
* Sun Feb 28 2016 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8391-fix-invalid-page-accesses-in-extent_same-dedup.patch.
- commit a4dccec
* Fri Feb 26 2016 mfasheh@suse.de
- btrfs: qgroup: Fix a rebase bug which will cause qgroup double
  free (bsc#963193).
- btrfs: qgroup: Fix a race in delayed_ref which leads to abort
  trans (bsc#963193).
- btrfs: qgroup: Check if qgroup reserved space leaked
  (bsc#963193).
- btrfs: qgroup: Avoid calling btrfs_free_reserved_data_space
  in clear_bit_hook (bsc#963193).
- btrfs: fallocate: Add support to accurate qgroup reserve
  (bsc#963193).
- btrfs: qgroup: Add new trace point for qgroup data reserve
  (bsc#963193).
- btrfs: Add handler for invalidate page (bsc#963193).
- btrfs: qgroup: Add handler for NOCOW and inline (bsc#963193).
- btrfs: qgroup: Cleanup old inaccurate facilities (bsc#963193).
- btrfs: extent-tree: Switch to new delalloc space reserve and
  release (bsc#963193).
- btrfs: extent-tree: Add new version of
  btrfs_delalloc_reserve/release_space (bsc#963193).
- btrfs: extent-tree: Switch to new check_data_free_space and
  free_reserved_data_space (bsc#963193).
- btrfs: extent-tree: Add new version of
  btrfs_check_data_free_space and btrfs_free_reserved_data_space
  (bsc#963193).
- btrfs: qgroup: Use new metadata reservation (bsc#963193).
- btrfs: qgroup: Introduce new functions to reserve/free metadata
  (bsc#963193).
- btrfs: delayed_ref: release and free qgroup reserved at proper
  timing (bsc#963193).
- btrfs: delayed_ref: Add new function to record reserved space
  into delayed ref (bsc#963193).
- btrfs: qgroup: Introduce functions to release/free qgroup
  reserve data space (bsc#963193).
- btrfs: qgroup: Introduce btrfs_qgroup_reserve_data function
  (bsc#963193).
- btrfs: extent_io: Introduce new function
  clear_record_extent_bits() (bsc#963193).
- btrfs: extent_io: Introduce new function set_record_extent_bits
  (bsc#963193).
- btrfs: extent_io: Introduce needed structure for recoding
  set/clear bits (bsc#963193).
- commit a8f0163
* Fri Feb 26 2016 mmarek@suse.com
- supported.conf: Add tulip to -base for Hyper-V (bsc#968234)
- commit 058b6ae
* Fri Feb 26 2016 tiwai@suse.de
- ALSA: seq: Fix leak of pool buffer at concurrent writes
  (bsc#968018).
- ALSA: rawmidi: Make snd_rawmidi_transmit() race-free
  (bsc#968018).
- commit dec36cd
* Thu Feb 25 2016 mmarek@suse.com
- supported.conf: Add more qemu device driver (bsc#968234)
- commit b8868fa
* Thu Feb 25 2016 fdmanana@suse.com
- Btrfs: fix page reading in extent_same ioctl leading to csum
  errors (bnc#968230).
- Btrfs: fix invalid page accesses in extent_same (dedup) ioctl
  (bnc#968230).
- commit edf4a2a
* Thu Feb 25 2016 mmarek@suse.com
- supported.conf: Add mptspi and mptsas to -base (bsc#968206)
- commit 6a9bf47
* Thu Feb 25 2016 jbeulich@suse.com
- patches.xen/xen-vscsi-large-requests: Fix resource collision for
  racing request maps and unmaps (bsc#966094).
- commit f3b3596
* Wed Feb 24 2016 mmarek@suse.cz
- supported.conf: Add e1000e (emulated by VMware) to -base (bsc#968074)
- commit 3747199
* Wed Feb 24 2016 dbueso@suse.de
- namespaces: Use task_lock and not rcu to protect nsproxy
  (bug#963960).
- commit 7ea3f5e
* Wed Feb 24 2016 dbueso@suse.de
- fs/proc_namespace.c: simplify testing nsp and nsp->mnt_ns
  (bug#963960).
- commit 302b7c5
* Wed Feb 24 2016 dbueso@suse.de
- futex: Drop refcount if requeue_pi() acquired the rtmutex
  (bug#960174).
- commit 78af7bf
* Wed Feb 24 2016 jslaby@suse.cz
- Linux 3.12.55 (CVE-2015-8785 CVE-2016-0723 CVE-2016-2384 bnc#961500
  bnc#961588 bsc#944749 bsc#949752 bsc#959257 bsc#961516 bsc#963765
  bsc#966693 bsc#965199 bug#960174 bnc#964730).
- proc: Fix ptrace-based permission checks for accessing task
  maps.
- kABI: protect struct af_alg_type.
- kABI: protect struct crypto_ahash.
- Refresh
  patches.arch/0002-x86-mm-pageattr-Lookup-address-in-an-arbitrary-PGD.patch.
- Refresh
  patches.drivers/0001-SCSI-sd-Add-error-handling-during-flushing-caches.patch.
- Refresh patches.fixes/ptrace-in-namespace-perm-check.fix.
- Refresh
  patches.fixes/scsi_sysfs-Implement-is_visible-callback.patch.
- Refresh
  patches.fixes/xfs-Use-defines-for-CRC-offsets-in-all-cases.patch.
- Delete
  patches.drivers/ALSA-usb-audio-avoid-freeing-umidi-object-twice.
- Delete
  patches.fixes/0001-dcache-use-IS_ROOT-to-decide-where-dentry-is-hashed.patch.
- Delete
  patches.fixes/0001-futex-Drop-refcount-if-requeue_pi-acquired-the-rtmut.patch.
- Delete
  patches.fixes/0001-tty-Fix-unsafe-ldisc-reference-via-ioctl-TIOCGETD.patch.
- Delete
  patches.fixes/fuse-break-infinite-loop-in-fuse_fill_write_pages.patch.
- Delete
  patches.fixes/jbd2-Fix-unreclaimed-pages-after-truncate-in-data-jo.patch.
- Delete
  patches.fixes/scsi-fix-soft-lockup-in-scsi_remove_target-on-module-removal.patch.
- Delete
  patches.fixes/scsi-restart-list-search-after-unlock-in-scsi_remove_target.patch.
- Delete
  patches.suse/mm-memory_hotplug.c-check-for-missing-sections-in-test_pages_in_a_zone.patch.
- commit 690f537
* Tue Feb 23 2016 neilb@suse.com
- tcp: Restore RFC5961-compliant behavior for SYN packets
  (bsc#966864).
- commit 79f4e34
* Tue Feb 23 2016 mmarek@suse.cz
- supported.conf: Add the qemu scsi driver (sym53c8xx) to -base (bsc#967802)
- commit b86f069
* Tue Feb 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Sync the main and -base package dependencies
  (bsc#965830#c51).
- commit 02459bc
* Fri Feb 19 2016 jroedel@suse.de
- kvm: x86: Check dest_map->vector to match eoi signals for rtc
  (bsc#966471).
- kvm: x86: Track irq vectors in ioapic->rtc_status.dest_map
  (bsc#966471).
- kvm: x86: Convert ioapic->rtc_status.dest_map to a struct
  (bsc#966471).
- KVM: x86: store IOAPIC-handled vectors in each VCPU
  (bsc#966471).
- commit c6567ce
* Fri Feb 19 2016 mmarek@suse.com
- kabi: Workaround spurious kabi change in kernel/ptrace.c
  (bsc#959709, CVE-2015-8709, bsc#960561).
- commit d36cb71
* Fri Feb 19 2016 hare@suse.de
- pci: Blacklist vpd access for buggy devices (bsc#959146).
- pci: Determine actual VPD size on first access (bsc#959146).
- pci: Update VPD definitions (bsc#959146).
- pci: allow access to VPD attributes with size '0' (bsc#959146).
- Delete
  patches.fixes/pci-Update-VPD-size-with-correct-length.patch.
- commit 0685b37
* Fri Feb 19 2016 neilb@suse.com
- Fix handling of re-write-before-commit for mmapped NFS pages
  (bsc#964201).
- commit 1db6d87
* Thu Feb 18 2016 neilb@suse.com
- ptrace: being capable wrt a process requires mapped uids/gids
  (bsc#959709 bsc#960561 CVE-2015-8709).
- commit aefdacd
* Wed Feb 17 2016 mmarek@suse.com
- supported.conf: Add Hyper-V modules to -base (bsc#965830)
- commit 14ea8e7
* Tue Feb 16 2016 fdmanana@suse.com
- Btrfs: check prepare_uptodate_page() error code earlier
  (bnc#966910).
- commit e081f8f
* Tue Feb 16 2016 oneukum@suse.com
- usb: Quiet down false peer failure messages (bnc#960629).
- commit 1e59f5b
* Tue Feb 16 2016 jthumshirn@suse.de
- scsi: fix soft lockup in scsi_remove_target() on module removal
  (bsc#965199).
- commit ede2bcb
* Mon Feb 15 2016 tiwai@suse.de
- ALSA: usb-audio: avoid freeing umidi object twice
  (CVE-2016-2384,bsc#966693).
- commit 4b26484
* Mon Feb 15 2016 hare@suse.de
- scsi_dh_alua: Do not block request queue if workqueue is active
  (bsc#960458).
- commit 9bf5ce3
* Fri Feb 12 2016 bp@suse.de
- iw_cxgb3: Fix incorrectly returning error on success
  (bsc#966437, CVE-2015-8812).
- commit b874ac7
* Fri Feb 12 2016 jslaby@suse.cz
- Linux 3.12.54 (bnc#959463).
- Revert "ipv6: tcp: add rcu locking in tcp_v6_send_synack()"
  (bnc#961257).
- Delete
  patches.drivers/0008-RDMA-cxgb4-Fix-gcc-warning-on-32-bit-arch.patch.
- Delete
  patches.fixes/Revert-workqueue-make-sure-delayed-work-run-in-local-cpu.patch.
- Delete
  patches.fixes/vmstat-explicitly-schedule-per-cpu-work-on-the-CPU-we-need-it-to-run-on.patch.
- commit ad1d663
* Fri Feb 12 2016 neilb@suse.com
- dcache: use IS_ROOT to decide where dentry is hashed
  (bsc#949752).
- commit aeba1c4
* Thu Feb 11 2016 mmarek@suse.cz
- supported.conf: Add xfs to -base (bsc#965891)
- commit 55d413f
* Thu Feb 11 2016 fdmanana@suse.com
- Btrfs: fix warning in backref walking (bnc#966278).
- commit 25fa867
* Thu Feb 11 2016 jdelvare@suse.de
- supported.conf: Fix usb-common path
  usb-common moved to its own subdirectory in kernel v3.16, and we
  backported that change to SLE12.
- commit 038c934
* Thu Feb 11 2016 neilb@suse.com
- NFS: Background flush should not be low priority (bsc#955308).
- NFS: don't use STABLE writes during writeback (bnc#816099).
- commit db2146a
* Wed Feb 10 2016 mmarek@suse.com
- supported.conf: Add virtio-rng (bsc#966026)
- commit 1b5d6e6
* Wed Feb 10 2016 rgoldwyn@suse.com
- Update
  patches.fixes/fuse-break-infinite-loop-in-fuse_fill_write_pages.patch
  (bsc#963765, CVE-2015-8785).
- commit 046b0cc
* Wed Feb 10 2016 mmarek@suse.com
- supported.conf: Add more QEMU and VMware drivers to -base (bsc#965840).
- commit 89b150e
* Wed Feb 10 2016 rgoldwyn@suse.com
- fuse: break infinite loop in fuse_fill_write_pages()
  (bsc#963765).
- commit 66f5b73
* Tue Feb  9 2016 jbeulich@suse.com
- driver core: Add BUS_NOTIFY_REMOVED_DEVICE event (bnc#962965).
- xen/x86/mm: Add barriers and document switch_mm()-vs-flush
  synchronization (bnc#963767, CVE-2016-2069).
- Refresh patches.xen/xen3-patch-3.9 (don't subvert NX protection
  during 1:1 mapping setup).
- Refresh other Xen patches.
- commit cbb9fce
* Mon Feb  8 2016 jdelvare@suse.de
- Update s390x/vanilla config file: CONFIG_ENCLOSURE_SERVICES
  Per bsc#884701, CONFIG_ENCLOSURE_SERVICES isn't needed on S/390. It
  was already disabled in the default config, so disable it in vanilla
  too.
- commit 659728a
* Mon Feb  8 2016 mgalbraith@suse.de
- Revert 874bbfe60 workqueue: make sure delayed work run in local cpu
  1. Without 22b886dd, 874bbfe60 leads to timer corruption.
  2. With 22b886dd applied, victim of 1 reports performance regression
    (1,2 https://lkml.org/lkml/2016/2/4/618)
  3. Leads to scheduling work to offlined CPU (bnc#959463).
  SLERT:
  4. NO_HZ_FULL regressession, unbound delayed work timer is no longer deflected to a housekeeper CPU.
- Replace with 176bed1d vmstat: explicitly schedule per-cpu work on the CPU we need it to run on
- commit 3abab80
* Fri Feb  5 2016 fdmanana@suse.com
- Btrfs: fix deadlock between direct IO write and defrag/readpages
  (bnc#965344).
- commit 9803667
* Thu Feb  4 2016 mmarek@suse.cz
- Update kabi files and start tracking ec2
- commit d3b68a1
* Thu Feb  4 2016 ddiss@suse.de
- libceph: fix scatterlist last_piece calculation (bsc#963746).
- commit aeeaf2d
* Wed Feb  3 2016 mmarek@suse.cz
- supported.conf: Add netfilter modules to base (bsc#950292)
- commit a0a8134
* Tue Feb  2 2016 ptesarik@suse.cz
- Refresh patches.fixes/kexec-contiguous-ELF-notes.patch with the final
  upstream version.
- Refresh patches.xen/xen3-fixup-common.
- commit a470009
* Mon Feb  1 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.52-53 (FATE#315482
  CVE-2015-7550 CVE-2015-7799 CVE-2015-8767 bnc#956703 bnc#956708
  bnc#956711 bnc#958951 boo#958504 bsc#758040 bsc#902606
  bsc#949936 bsc#951199 bsc#951392 bsc#955224 bsc#956047
  bsc#959364 bsc#961509).
  Cleanup references (remove deadwood).
- commit dc54bb0
* Mon Feb  1 2016 jslaby@suse.cz
- Refresh
  patches.fixes/0001-tty-Fix-unsafe-ldisc-reference-via-ioctl-TIOCGETD.patch.
- Refresh
  patches.fixes/0002-n_tty-Fix-unsafe-reference-to-other-ldisc.patch.
  Upstream status.
- commit 835c34a
* Sat Jan 30 2016 mmarek@suse.cz
- Move nfsd patch to the right section
- commit c63b0e4
* Fri Jan 29 2016 neilb@suse.com
- NFSD: Don't start lockd when only NFSv4 is running
  (fate#316311).
- Improve fairness when locking the per-superblock s_anon list
  (bsc#957525, bsc#941363).
- commit d64a9c9
* Thu Jan 28 2016 mmarek@suse.cz
- Update patches.kernel.org/patch-3.12.45-46: Add CVE-2015-5707 / bsc#940338.
- commit 0a3bc5c
* Thu Jan 28 2016 mhocko@suse.cz
- x86/mm: Add barriers and document switch_mm()-vs-flush
  synchronization (bnc#963767, CVE-2016-2069).
- commit c720d45
* Thu Jan 28 2016 fdmanana@suse.com
- Btrfs: skip locking when searching commit root (bnc#963825).
- commit 8494e2b
* Thu Jan 28 2016 jslaby@suse.cz
- kgr: do not use WQ_MEM_RECLAIM workqueue (bnc#963572).
- commit 7c7470e
* Thu Jan 28 2016 jslaby@suse.cz
- kgr: log when modifying kernel (fate#317827).
- commit 360b3d1
* Wed Jan 27 2016 mmarek@suse.cz
- supported.conf: Add nls_iso8859-1 and nls_cp437 to -base (bsc#950292)
- commit 5a9b3e0
* Wed Jan 27 2016 jack@suse.cz
- jbd2: Fix unreclaimed pages after truncate in data=journal mode
  (bsc#961516).
- commit e7d03c1
* Wed Jan 27 2016 alnovak@suse.cz
- supported.conf: drop +external from ghash-clmulni-intel
  It was agreed that it doesn't make sense to maintain "external" for
  this specific module. Furthermore it causes problems in rather ordinary
  VMware environments. (bsc#961971)
- commit afde151
* Wed Jan 27 2016 mmarek@suse.com
- supported.conf: Also add virtio_pci to kernel-default-base (bsc#950292).
- commit 6128afb
* Wed Jan 27 2016 mmarek@suse.com
- supported.conf: Add virtio_{blk,net,scsi} to kernel-default-base (bsc#950292)
- commit e47811e
* Tue Jan 26 2016 jslaby@suse.cz
- n_tty: Fix unsafe reference to "other" ldisc (bnc#961500
  CVE-2016-0723).
- tty: Fix unsafe ldisc reference via ioctl(TIOCGETD) (bnc#961500
  CVE-2016-0723).
- commit d27f560
* Tue Jan 26 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Do not modify the release string in PTFs (bsc#963449)
- commit dc2b096
* Mon Jan 25 2016 jslaby@suse.cz
- Linux 3.12.53 ((FATE#315482) Automatic Balancing
  CVE-2015-7550 CVE-2015-7799 CVE-2015-8767
  NUMA bnc#956703 bnc#956708 bnc#956711 bnc#958951
  boo#958504 bsc#758040 bsc#902606 bsc#949936 bsc#951199
  bsc#951392 bsc#955224 bsc#956047 bsc#959364 bsc#961509
  http://article.gmane.org/gmane.comp.security.oss.general/17908).
- kABI: reintroduce blk_rq_check_limits.
- Refresh
  patches.arch/0010-x86-efi-Runtime-services-virtual-mapping.patch.
- Refresh
  patches.arch/ppc64le-kvm-0033-kvm-powerpc-Add-kvmppc_ops-callback.patch.
- Refresh patches.arch/x86-efi-fix-32-bit-fallout.patch.
- Refresh
  patches.arch/x86-efi-make-efi-virtual-runtime-map-passing-more-robust.patch.
- Delete
  patches.drivers/0001-Input-aiptek-fix-crash-on-detecting-device-without-e.patch.
- Delete patches.drivers/PCI-Drop-setting-latency-timer-messages.
- Delete
  patches.drivers/drm-i915-Fix-SRC_COPY-width-on-830-845g.patch.
- Delete
  patches.drivers/hda-0055-Fix-noise-problems-on-Thinkpad-T440s.
- Delete
  patches.drivers/lpfc-Fix-null-ndlp-dereference-in-target_reset_handler.patch.
- Delete
  patches.fixes/0001-KEYS-Fix-keyring-ref-leak-in-join_session_keyring.patch.
- Delete
  patches.fixes/0001-ring-buffer-Always-run-per-cpu-ring-buffer-resize-wi.patch.
- Delete
  patches.fixes/SUNRPC-Fix-oops-when-trace-sunrpc_task-events-in-nfs.patch.
- Delete
  patches.fixes/block-Always-check-queue-limits-for-cloned-requests.patch.
- Delete patches.fixes/dlm-make-posix-locks-interruptible.patch.
- Delete
  patches.fixes/ipv4-Don-t-increase-PMTU-with-Datagram-Too-Big-messa.patch.
- Delete
  patches.fixes/isdn_ppp-add-checks-for-allocation-failure-in-isdn_p.patch.
- Delete
  patches.fixes/ppp-slip-validate-vj-compression-slot-parameters-com.patch.
- Delete
  patches.fixes/route-Use-ipv4_mtu-instead-of-raw-rt_pmtu.patch.
- Delete
  patches.fixes/sctp-Prevent-soft-lockup-when-sctp_accept-is-called-.patch.
- Delete
  patches.fixes/udp-properly-support-MSG_PEEK-with-truncated-buffers.patch.
- Delete
  patches.suse/0001-KEYS-Fix-race-between-read-and-revoke.patch.
- Delete
  patches.suse/m32r-fix-potential-NULL-pointer-dereference.patch.
- commit 3e46b49
* Mon Jan 25 2016 mmarek@suse.com
- supported.conf: Add vfat to -base to be able to mount the ESP (bsc#950292).
- commit bbfdaa4
* Mon Jan 25 2016 mgalbraith@suse.de
- sched/fair: Disable tg load_avg/runnable_avg update for
  root_task_group (bnc#960227).
- sched/fair: Move cache hot load_avg/runnable_avg into separate
  cacheline (bnc#960227).
- commit f61b328
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-source.spec.in: Install kernel-macros for kernel-source-vanilla
  (bsc#959090)
- commit cd33617
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix paths in kernel-vanilla-devel (bsc#959090).
- commit 2d2ec7f
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix kernel-vanilla-devel dependency (bsc#959090)
- commit fbbc989
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use bzip compression to speed up build (bsc#962356)
- commit e8f8f54
* Fri Jan 22 2016 trenn@suse.com
- Do not modify perf bias performance setting by default at boot
  (bnc#812259,bsc#959629).
- commit 862abf8
* Thu Jan 21 2016 dvaleev@suse.com
- Add sd_mod to initrd modules
  For some reason PowerVM backend can't work without sd_mod
- commit 7c2bd21
* Thu Jan 21 2016 mmarek@suse.com
- rpm/package-descriptions: Add kernel-zfcpdump and drop -desktop
- commit 54e8f7c
* Wed Jan 20 2016 mbenes@suse.cz
- module: keep percpu symbols in module's symtab (bsc#962788).
- commit 6f57a44
* Wed Jan 20 2016 mkubecek@suse.cz
- Update patches.kernel.org/patch-3.12.51-52 references
  (add CVE-2013-7446 bsc#917648 bsc#955654).
- commit b550781
* Tue Jan 19 2016 mgorman@suse.com
- mm/memory_hotplug.c: check for missing sections in test_pages_in_a_zone()
  (VM Functionality, bnc#961588).
- commit 4121eb3
* Tue Jan 19 2016 jbeulich@suse.com
- backends: guarantee one time reads of shared ring contents
  (bsc#957988 CVE-2015-8550 XSA-155).
- netback: don't use last request to determine minimum Tx credit
  (bsc#957988 CVE-2015-8550 XSA-155).
- nmi: provide the option to issue an NMI back trace to every
  cpu but current (bsc#940946, bsc#937444).
- x86/nmi: Save regs in crash dump on external NMI (bsc#940946,
  bsc#937444).
- xen: Linux 3.12.52.
- Refresh patches.xen/xen3-patch-3.9 (bsc#951155).
- Refresh other Xen patches.- Delete
  patches.xen/xen3-do-not-reserve-crashkernel-high-memory-if-crashkernel-low-memory-reserving-failed.
- commit 898f1eb
* Mon Jan 18 2016 jslaby@suse.cz
- kgr: mark some more missed kthreads (bnc#962336).
- commit b92bf04
* Mon Jan 18 2016 mkubecek@suse.cz
- sctp: Prevent soft lockup when sctp_accept() is called during
  a timeout event (CVE-2015-8767 bsc#961509).
- commit 040dad6
* Mon Jan 18 2016 jthumshirn@suse.de
- scsi: restart list search after unlock in scsi_remove_target
  (bsc#944749, bsc#959257).
- Delete
  patches.fixes/0001-SCSI-Fix-hard-lockup-in-scsi_remove_target.patch.
- commit 2490876
* Mon Jan 18 2016 jslaby@suse.cz
- kgr: usb/storage: do not emit thread awakened (bnc#899908).
- commit 1b0c65e
* Mon Jan 18 2016 jdelvare@suse.de
- megaraid_sas: Chip reset if driver fails to get IOC ready
  (bsc#922071).
  Refresh the patch based on the actual upstream commit, and add
  the commit ID.
- commit 5f293b0
* Sun Jan 17 2016 mgorman@suse.com
- Refresh
  patches.suse/mm-mempolicy-c-convert-the-shared_policy-lock-to-a-rwlock.patch.
- commit 3600a6d
* Fri Jan 15 2016 mmarek@suse.com
- KEYS: Fix keyring ref leak in join_session_keyring() (bsc#962075, CVE-2016-0728).
- commit 918e576
* Thu Jan 14 2016 jslaby@suse.cz
- kgr: do not print error for !abort_if_missing symbols
  (bnc#943989).
- commit 12d1e5f
* Thu Jan 14 2016 duwe@suse.de
- Refresh patches.suse/s390-hwrng-enable -- add commit ID.
- commit 11d7b05
* Thu Jan 14 2016 dchang@suse.com
- be2net: fix some log messages (bnc#855062 FATE#315961,
  bnc#867583).
- Delete
  patches.drivers/be2net-0010-be2net-Removed-unecessary-log-for-uknown-grp5-event.patch.
  Fix tag, subject and align to upstrem commit.
- commit c3df167
* Wed Jan 13 2016 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8224-don-t-initialize-a-space-info-as-full-to-preve.patch.
- commit 096d37c
* Wed Jan 13 2016 neilb@suse.com
- NFSv4: Recovery of recalled read delegations is broken
  (bsc#956514).
- commit 968c3b9
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix build if no UEFI certs are installed
- commit ef1b7d3
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Install libopenssl-devel for newer sign-file
- commit fbdf0b8
* Tue Jan 12 2016 mmarek@suse.com
- Run refresh_patch.sh on patches that need to be ported to SP2
  No code changes.
- commit 61961c4
* Mon Jan 11 2016 mmarek@suse.cz
- rpm/constraints.in: Bump disk space requirements up a bit
  Require 10GB on s390x, 20GB elsewhere.
- commit 558b7b3
* Sat Jan  9 2016 jslaby@suse.cz
- Refresh
  patches.drivers/hda-0055-Fix-noise-problems-on-Thinkpad-T440s.
  It's upstream -> fix tags.
- commit bdae4e2
* Sat Jan  9 2016 jslaby@suse.cz
- Linux 3.12.52 (CVE-2015-8543 CVE-2015-8569 CVE-2015-8575
  bnc#814440 bsc#939145 bsc#952579 bsc#955422 bsc#958886
  bsc#959190 bsc#959399).
- Revert "ipv6: add complete rcu protection around np->opt"
  (bnc#961257).
- Refresh
  patches.fixes/ktime-add-ktime_after-and-ktime_before-helper.patch.
- Refresh
  patches.suse/btrfs-0253-don-t-use-ram_bytes-for-uncompressed-inline-it.patch.
- Delete
  patches.drivers/hda-0054-Disable-64bit-address-for-Creative-HDA-cont.
- Delete
  patches.drivers/target-stat-print-full-t10_wwn.model-buffer.patch.
- Delete
  patches.fixes/bluetooth-validate-socket-address-length-in-sco_sock_bind.patch.
- Delete
  patches.fixes/do-not-reserve-crashkernel-high-memory-if-crashkernel-low-memory-reserving-failed.
- Delete
  patches.fixes/ipv6-distinguish-frag-queues-by-device-for-multicast.patch.
- Delete patches.fixes/ipv6-fix-tunnel-error-handling.patch.
- Delete
  patches.fixes/net-add-validation-for-the-socket-syscall-protocol-a.patch.
- Delete
  patches.fixes/pptp-verify-sockaddr_len-in-pptp_bind-and-pptp_connect.patch.
- Delete
  patches.fixes/rds-fix-race-condition-when-sending-a-message.patch.
- commit 6f55ce7
* Wed Jan  6 2016 bp@suse.de
- kernel: Provide READ_ONCE and ASSIGN_ONCE (bsc#940946,
  bsc#937444).
- kernel: Change ASSIGN_ONCE(val, x) to WRITE_ONCE(x, val)
  (bsc#940946, bsc#937444).
- nmi: provide the option to issue an NMI back trace to every
  cpu but current (bsc#940946, bsc#937444).
- kernel/watchdog.c: perform all-CPU backtrace in case of hard
  lockup (bsc#940946, bsc#937444).
- panic, x86: Fix re-entrance problem due to panic on NMI
  (bsc#940946, bsc#937444).
- panic, x86: Allow CPUs to save registers even if looping in
  NMI context (bsc#940946, bsc#937444).
- kexec: Fix race between panic() and crash_kexec() (bsc#940946,
  bsc#937444).
- x86/apic: Introduce apic_extnmi command line parameter
  (bsc#940946, bsc#937444).
- x86/nmi: Save regs in crash dump on external NMI (bsc#940946,
  bsc#937444).
- Documentation: Document kernel.panic_on_io_nmi sysctl
  (bsc#940946, bsc#937444).
- Refresh patches.xen/pci-guestdev.
- Refresh patches.xen/xen-x86-panic-no-reboot.
- Refresh patches.xen/xen3-patch-2.6.32.
- Refresh patches.xen/xen3-patch-3.2.
- commit 901aeff
* Tue Jan  5 2016 vbabka@suse.cz
- Refresh
  patches.suse/mm-mempolicy-c-convert-the-shared_policy-lock-to-a-rwlock.patch.
- commit 0414e89
* Tue Jan  5 2016 mkubecek@suse.cz
- udp: properly support MSG_PEEK with truncated buffers
  (bsc#951199 bsc#959364).
- commit 94a277b
* Tue Jan  5 2016 jlee@suse.com
- ACPICA: Correctly cleanup after a ACPI table load failure
  (bnc#937261).
- commit 9ab7d78
* Mon Jan  4 2016 oneukum@suse.com
- Input: aiptek - fix crash on detecting device without endpoints
  (bnc#956708).
- commit 347fde1
* Wed Dec 30 2015 bpoirier@suse.com
- e1000e: Fix msi-x interrupt automask (bsc#924919).
- e1000e: Do not write lsc to ics in msi-x mode (bsc#924919).
- e1000e: Do not read ICR in Other interrupt (bsc#924919).
- e1000e: Remove unreachable code (bsc#924919).
- commit 59dc1ab
* Wed Dec 30 2015 jlee@suse.com
- KEYS: Fix race between read and revoke (bnc#958951,
  CVE-2015-7550).
- commit 7c3a0e1
* Mon Dec 28 2015 fdmanana@suse.com
- btrfs: qgroup: fix quota disable during rescan (bnc#960300).
- Btrfs: fix sleeping inside atomic context in qgroup rescan
  worker (bnc#960300).
- Btrfs: fix race waiting for qgroup rescan worker (bnc#960300).
- btrfs: qgroup: exit the rescan worker during umount
  (bnc#960300).
- btrfs: qgroup: Don't copy extent buffer to do qgroup rescan
  (bnc#960300).
- btrfs: qgroup: clear STATUS_FLAG_ON in disabling quota
  (bnc#960300).
- btrfs: Update btrfs qgroup status item when rescan is done
  (bnc#960300).
- commit d8381f5
* Mon Dec 21 2015 bp@suse.de
- pptp: verify sockaddr_len in pptp_bind() and pptp_connect()
  (bsc#959190, CVE-2015-8569).
- commit 6a55448
* Mon Dec 21 2015 vbabka@suse.cz
- mm/mempolicy.c: convert the shared_policy lock to a rwlock
  (VM Performance, bnc#959436).
- commit 7968d7b
* Mon Dec 21 2015 jlee@suse.com
- KEYS: Fix handling of stored error in a negatively instantiated
  user key (bnc#958463, CVE-2015-8539).
- commit 96706a0
* Fri Dec 18 2015 bp@suse.de
- bluetooth: Validate socket address length in sco_sock_bind()
  (bsc#959399, CVE-2015-8575).
- commit d0a709d
* Fri Dec 18 2015 jbohac@suse.cz
- net: add validation for the socket syscall protocol argument
  (bsc#958886, CVE-2015-8543).
- commit 789251c
* Fri Dec 18 2015 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.12.46-47 (bsc#959705).
- commit 8309622
* Fri Dec 18 2015 mkubecek@suse.cz
- ipv6: fix tunnel error handling (bsc#952579).
- commit 17599a3
* Fri Dec 18 2015 mkubecek@suse.cz
- Update patches.kernel.org/patch-3.12.50-51 references (add CVE-2015-8215 bsc#955354).
- commit b24d184
* Fri Dec 18 2015 jbeulich@suse.com
- xen/pciback: Don't allow MSI-X ops if PCI_COMMAND_MEMORY is
  not set (bsc#957990 XSA-157).
- xen/pciback: For XEN_PCI_OP_disable_msi[|x] only disable
  if device has MSI(X) enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msix when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- xen/pciback: Return error on XEN_PCI_OP_enable_msi when
  device has MSI or MSI-X enabled (bsc#957990 CVE-2015-8551
  CVE-2015-8552 XSA-157).
- commit afe8b08
* Fri Dec 18 2015 jbeulich@suse.com
- guarantee one time reads of shared ring contents (bsc#957988
  CVE-2015-8550 XSA-155).
- commit 82dc91c
* Fri Dec 18 2015 hare@suse.de
- block: Always check queue limits for cloned requests
  (bsc#902606).
- commit fc0dd99
* Thu Dec 17 2015 mfasheh@suse.de
- Refresh patches.suse/btrfs-8367-fix-qgroup-sanity-tests.patch.
- Refresh
  patches.suse/btrfs-8368-fix-regression-when-running-delayed-references.patch.
- Refresh
  patches.suse/btrfs-8369-fix-regression-running-delayed-references-when.patch.
- commit 777b459
* Tue Dec 15 2015 jbeulich@suse.com
- Refresh
  patches.xen/xen3-do-not-reserve-crashkernel-high-memory-if-crashkernel-low-memory-reserving-failed.
- commit e8ff414
* Tue Dec 15 2015 duwe@suse.de
- Refresh patches.fixes/fix-stop-machine.
- Refresh patches.fixes/flush-call-function-queue.
- commit 3d7490b
* Tue Dec 15 2015 jbeulich@suse.com
- blktap: also call blkif_disconnect() when frontend switched
  to closed (bsc#952976).
- blktap: refine mm tracking (bsc#952976).
- xen: Linux 3.12.51.
- Refresh patches.xen/xen3-patch-3.9 (bsc#951155).
- Refresh other Xen patches.xen.
- commit 0368e67
* Tue Dec 15 2015 mmarek@suse.com
- Remove Git-repo headers pointing back to our repository
- commit feb0a13
* Tue Dec 15 2015 mmarek@suse.com
- rpm/compute-PATCHVERSION.sh: Skip stale directories in the package dir
- commit 014bd26
* Mon Dec 14 2015 jthumshirn@suse.de
- lpfc: Fix null ndlp dereference in target_reset_handler
  (bsc#951392).
- commit 1fcbd42
* Mon Dec 14 2015 jroedel@suse.de
- Refresh
  patches.fixes/kvm-irqchip-break-up-high-order-allocations-of-kvm_irq_routing_table.
- commit 1c60eb9
* Fri Dec 11 2015 jthumshirn@suse.de
- bcache: backing device set to clean after finishing detach
  (bsc#951638).
- commit 30e89cd
* Thu Dec 10 2015 fdmanana@suse.com
- Btrfs: fix the number of transaction units needed to remove
  a block group (bsc#958647).
- Btrfs: use global reserve when deleting unused block group
  after ENOSPC (bsc#958647).
- btrfs: Set relative data on clear
  btrfs_block_group_cache->pinned (bsc#958647).
- btrfs: Adjust commit-transaction condition to avoid NO_SPACE
  more (bsc#958647).
- btrfs: Fix tail space processing in find_free_dev_extent()
  (bsc#958647).
- btrfs: fix condition of commit transaction (bsc#958647).
- btrfs: cleanup: remove no-used alloc_chunk in
  btrfs_check_data_free_space() (bsc#958647).
- btrfs: Fix out-of-space bug (bsc#958647).
- commit 332aec5
* Thu Dec 10 2015 mmarek@suse.com
- genksyms: Handle string literals with spaces in reference files (bsc#958510).
- commit 0fb9109
* Wed Dec  9 2015 tiwai@suse.de
- ALSA: hda - Fix noise problems on Thinkpad T440s (boo#958504).
- commit 4c530de
* Tue Dec  8 2015 neilb@suse.com
- Update Patch-mainline
- Refresh
  patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch.
- Refresh patches.suse/01a-md-failfast-metadata.
- commit d03582b
* Tue Dec  8 2015 neilb@suse.com
- Update some commit-ids
- Refresh
  patches.suse/0018-autofs4-make-autofs4_can_expire-idempotent.patch.
- commit 357ca36
* Thu Dec  3 2015 eich@suse.de
- drm/i915: Fix SRC_COPY width on 830/845g (bsc#758040).
- commit 89cd16f
* Thu Dec  3 2015 tonyj@suse.de
- Fix commit-id in
  patches.fixes/audit-do-not-reject-all-audit_inode-filter-types.patch.
- commit 3ac974d
* Thu Dec  3 2015 jeffm@suse.com
- patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops: Update patch tags.
- commit 7e8dd81
* Thu Dec  3 2015 jack@suse.cz
- Update tags
  patches.fixes/xfs-catch-buffers-written-without-verifiers-attached.patch.
- commit 1960ab2
* Thu Dec  3 2015 oneukum@suse.com
- Refresh
  patches.drivers/0001-USB-ehci-fsl-Remove-casting-the-return-value-which-i.patch.
- Refresh
  patches.drivers/0001-USB-see-if-URB-comes-from-a-completion-handler.patch.
- Refresh
  patches.drivers/0001-usb-storage-support-for-more-than-8-LUNs.patch.
- Refresh
  patches.drivers/0001-usbcore-fix-incorrect-type-in-assignment-in-usb_set_.patch.
- Refresh
  patches.drivers/0002-USB-EHCI-code-rearrangement-in-iso_stream_schedule.patch.
- Refresh
  patches.drivers/0002-storage-accept-some-UAS-devices-if-streams-are-unava.patch.
- Refresh
  patches.drivers/0002-usb-core-Make-usb_free_streams-return-an-error.patch.
- Refresh
  patches.drivers/0002-usb-wusbcore-rename-urb-to-tr_urb-in-struct-wa_seg.patch.
- Refresh
  patches.drivers/0003-USB-EHCI-handle-isochronous-underruns-with-tasklets.patch.
- Refresh
  patches.drivers/0003-usb-wusbcore-rename-fields-in-struct-wahc.patch.
- Refresh
  patches.drivers/0004-usb-wusbcore-allow-wa_xfer_destroy-to-clean-up-parti.patch.
- Refresh
  patches.drivers/0005-usb-wusbcore-resource-cleanup-fix-in-__wa_xfer_setup.patch.
- Refresh
  patches.drivers/0006-usb-wusbcore-clean-up-the-sg-list-that-was-created-f.patch.
- Refresh
  patches.drivers/0007-usb-wusbcore-set-pointers-to-NULL-after-freeing-in-e.patch.
- Refresh
  patches.drivers/0008-usb-wusbcore-fix-endianess-issues-when-using-dwTrans.patch.
- Refresh
  patches.drivers/0009-usb-wusbcore-include-the-xfer_id-in-debug-prints.patch.
- Refresh
  patches.drivers/0010-usb-wusbcore-clean-up-urb-dequeue-process.patch.
- Refresh
  patches.drivers/0011-usb-wusbcore-fix-build-warning-on-64-bit-builds.patch.
- Refresh
  patches.drivers/0012-usb-wusbcore-avoid-stack-overflow-in-URB-enqueue-err.patch.
- Refresh
  patches.drivers/0013-usb-wusbcore-implement-hwahc_op_get_frame_number.patch.
- Refresh
  patches.drivers/0014-usb-wusbcore-set-the-RPIPE-bOverTheAirInterval-for-i.patch.
- Refresh
  patches.drivers/0015-usb-wusbcore-add-support-for-isoc-out-transfers.patch.
- Refresh
  patches.drivers/0016-usb-wusbcore-fix-string-formatting-warnings-on-64-bi.patch.
- Refresh
  patches.drivers/0017-usb-wusbcore-serialize-access-to-the-HWA-data-out-en.patch.
- Refresh
  patches.drivers/0018-usb-wusbcore-preserve-endianness-of-cached-descripto.patch.
- Refresh
  patches.drivers/0019-USB-wusbcore-fix-usb_dev-leaks.patch.
- Refresh
  patches.drivers/0021-usb-wusbcore-combine-multiple-isoc-frames-in-a-singl.patch.
- Refresh
  patches.drivers/0022-usb-wusbcore-add-a-quirk-for-Alereon-HWA-device-isoc.patch.
- Refresh
  patches.drivers/0024-usb-wusbcore-Add-isoc-transfer-type-enum-and-packet-.patch.
- Refresh
  patches.suse/0010-UAS-fixup-for-remaining-use-of-dead_list.patch.
- commit 1e74543
* Wed Dec  2 2015 jkosina@suse.cz
- Refresh
  patches.drivers/0001-Input-synaptics-split-synaptics_resolution-query-fir.patch.
- Refresh
  patches.drivers/0002-Input-synaptics-log-queried-and-quirked-dimension-va.patch.
- Refresh
  patches.drivers/0003-Input-synaptics-query-min-dimensions-for-fw-v8.1.patch.
- Refresh
  patches.drivers/0004-Input-synaptics-remove-obsolete-min-max-quirk-for-X2.patch.
- Refresh
  patches.drivers/0005-Input-synaptics-support-min-max-board-id-in-min_max_.patch.
- Refresh
  patches.drivers/0006-Input-synaptics-skip-quirks-when-post-2013-dimension.patch.
- Refresh
  patches.drivers/0009-Input-synaptics-do-not-retrieve-the-board-id-on-old-.patch.
- Refresh
  patches.drivers/0012-Input-synaptics-re-route-tracksticks-buttons-on-the-.patch.
- Refresh
  patches.drivers/0013-Input-synaptics-remove-X1-Carbon-3rd-gen-from-the-to.patch.
- Refresh
  patches.drivers/0014-Input-synaptics-remove-X250-from-the-topbuttonpad-li.patch.
  Fix metadata regarding upstream commit references.
- commit 331128b
* Wed Dec  2 2015 mgorman@suse.com
- Refresh patches.suse/memory-hotplug-add-zone_for_memory-for-selecting-zone-for-new-memory.patch. patches.suse/memory-hotplug-ia64-suitable-memory-should-go-to-zone_movable.patch. patches.suse/memory-hotplug-ppc-suitable-memory-should-go-to-zone_movable.patch. patches.suse/memory-hotplug-sh-suitable-memory-should-go-to-zone_movable.patch. patches.suse/memory-hotplug-x86_32-suitable-memory-should-go-to-zone_movable.patch. patches.suse/memory-hotplug-x86_64-suitable-memory-should-go-to-zone_movable.patch. patches.suse/sched-numa-Always-try-to-migrate-to-preferred-node-at-task_numa_placement-time.patch. patches.suse/sched-numa-Ensure-task_numa_migrate-checks-the-preferred-node.patch. patches.suse/sched-numa-examine-a-task-move-when-examining-a-task-swap.patch. patches.suse/sched-numa-move-power-adjustment-into-load_too_imbalanced.patch. patches.suse/sched-numa-rework-best-node-setting-in-task_numa_migrate.patch. patches.suse/sched-numa-simplify-task_numa_compare.patch. (Git commit ID updates)
- commit ed38fed
* Wed Dec  2 2015 mhocko@suse.cz
- Refresh patch header
  patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
- commit 36e5ba5
* Wed Dec  2 2015 oneukum@suse.com
- xhci: Workaround to get Intel xHCI reset working more reliably
  (bnc#957546).
- commit 35c8c0e
* Wed Dec  2 2015 mmarek@suse.com
- Fix broken Git-commit headers in SLE12 patches
- commit c0effa6
* Wed Dec  2 2015 mfleming@suse.de
- cpusets, isolcpus: exclude isolcpus from load balancing in
  cpusets (bsc#957395).
- sched, isolcpu: make cpu_isolated_map visible outside scheduler
  (bsc#957395).
- commit 0bccd4d
* Tue Dec  1 2015 jthumshirn@suse.de
- bcache: Fix sysfs splat on shutdown with flash only devs
  (bsc#951638).
- commit 2a9107d
* Tue Dec  1 2015 eich@suse.de
- drm: Fix KABI of 'struct drm_file' (bsc#956876, bsc#956801).
- commit 2e4c789
* Mon Nov 30 2015 eich@suse.de
- drm: Allocate new master object when client becomes master
  (bsc#956876, bsc#956801).
- commit ea95aa3
* Mon Nov 30 2015 dvaleev@suse.com
- Add RHEL to kernel-obs-build
- commit a010d5e
* Mon Nov 30 2015 jthumshirn@suse.de
- bcache: Fix more early shutdown bugs (bsc#951638).
- bcache: Fix a bug when detaching (bsc#951638).
- bcache: Fix a shutdown bug (bsc#951638).
- commit 6144aaf
* Mon Nov 30 2015 jthumshirn@suse.de
- cache: Fix sysfs splat on shutdown with flash only devs
  (bsc#951638).
- commit 0e91c1a
* Wed Nov 25 2015 rgoldwyn@suse.com
- Get cephfs to compile
- Re-add copy_page_vector_to_user()
- Refresh
  patches.drivers/0190-libceph-specify-position-of-extent-operation.patch.
- Refresh
  patches.drivers/libceph-support-bidirectional-requests.patch.
- commit 3c5f859
* Wed Nov 25 2015 mfleming@suse.de
- ring-buffer: Always run per-cpu ring buffer resize with
  schedule_work_on() (bnc#956711).
- commit 224f436
* Wed Nov 25 2015 mfleming@suse.de
- SUNRPC: Fix oops when trace sunrpc_task events in nfs client
  (bnc#956703).
- commit 48cbdd9
* Wed Nov 25 2015 hare@suse.de
- target: Send UA upon LUN RESET tmr completion (bsc#933514).
- target: use 'se_dev_entry' when allocating UAs (bsc#933514).
- commit 36bde12
* Wed Nov 25 2015 jslaby@suse.cz
- Refresh
  patches.arch/kvm-nvmx-add-support-for-activity-state-hlt.patch.
- Refresh
  patches.arch/kvm-nvmx-add-tracepoints-for-nested_vmexit-and-nested_vmexit_inject.patch.
- Refresh
  patches.arch/kvm-nvmx-amend-nested_run_pending-logic.patch.
- Refresh
  patches.arch/kvm-nvmx-check-all-exceptions-for-intercept-during-delivery-to-l2.patch.
- Refresh
  patches.arch/kvm-nvmx-clean-up-handling-of-vmx-related-msrs.patch.
- Refresh
  patches.arch/kvm-nvmx-do-not-generate-df-if-pf-happens-during-exception-delivery-into-l2.patch.
- Refresh
  patches.arch/kvm-nvmx-do-not-inject-nmi-vmexits-when-l2-has-a-pending-interrupt.patch.
- Refresh
  patches.arch/kvm-nvmx-do-not-put-exception-that-caused-vmexit-to-idt_vectoring_info.patch.
- Refresh
  patches.arch/kvm-nvmx-do-not-set-identity-page-map-for-l2.patch.
- Refresh
  patches.arch/kvm-nvmx-enable-unrestricted-guest-mode-support.patch.
- Refresh
  patches.arch/kvm-nvmx-fix-nested_run_pending-on-activity-state-hlt.patch.
- Refresh
  patches.arch/kvm-nvmx-fully-emulate-preemption-timer.patch.
- Refresh
  patches.arch/kvm-nvmx-fully-support-nested-vmx-preemption-timer.patch.
- Refresh
  patches.arch/kvm-nvmx-implement-support-for-efer-saving-on-vm-exit.patch.
- Refresh
  patches.arch/kvm-nvmx-leave-vmx-mode-on-clearing-of-feature-control-msr.patch.
- Refresh
  patches.arch/kvm-nvmx-pass-vmexit-parameters-to-nested_vmx_vmexit.patch.
- Refresh
  patches.arch/kvm-nvmx-replace-kvm_set_cr0-with-vmx_set_cr0-in-load_vmcs12_host_state.patch.
- Refresh
  patches.arch/kvm-nvmx-report-2mb-ept-pages-as-supported.patch.
- Refresh
  patches.arch/kvm-nvmx-rework-interception-of-irqs-and-nmis.patch.
- Refresh
  patches.arch/kvm-nvmx-support-direct-apic-access-from-l2.patch.
- Refresh
  patches.arch/kvm-nvmx-update-guest-activity-state-field-on-l2-exits.patch.
- Refresh
  patches.arch/kvm-vmx-disable-apic-virtualization-in-nested-guests.patch.
- Refresh patches.arch/kvm-vmx-fix-lazy-fpu-on-nested-guest.patch.
- Refresh
  patches.arch/kvm-vmx-really-fix-lazy-fpu-on-nested-guest.patch.
- Refresh
  patches.arch/kvm-vmx-shadow-vm_entry_exit_controls-vmcs-field.patch.
- Refresh
  patches.arch/kvm-x86-fix-kvm_set_xcrs-for-cpus-that-do-not-support-xsave.patch.
- Refresh patches.arch/kvm-x86-fix-kvm_set_xcrs-loop.patch.
- Refresh patches.arch/kvm-x86-fix-xsave-cpuid-exposing-bug.patch.
- Refresh
  patches.arch/kvm-x86-mask-unsupported-xsave-entries-from-leaf-0dh-index-0.patch.
- Refresh
  patches.arch/kvm-x86-only-copy-xsave-state-for-the-supported-features.patch.
- Refresh
  patches.arch/kvm-x86-prevent-setting-unsupported-xsave-states.patch.
- Refresh
  patches.arch/kvm-x86-remove-return-code-from-enable_irq-nmi_window.patch.
- Refresh patches.arch/nvmx-fix-pick-up-of-uninjected-nmis.patch.
- Refresh
  patches.arch/nvmx-report-cpu_based_virtual_nmi_pending-as-supported.patch.
- Refresh
  patches.arch/x86-cpufeature-define-the-intel-mpx-feature-flag.patch.
  Remove bogus 'Git-repo: git://kernel.suse.com/kernel.git'.
  Cc: Bruce Rogers <brogers@suse.com>
- commit e567f27
* Wed Nov 25 2015 jslaby@suse.cz
- Linux 3.12.51 (CVE-2014-3647 CVE-2015-0272 CVE-2015-5156
  CVE-2015-5307 CVE-2015-6937 CVE-2015-7872 CVE-2015-8104
  bnc#899192 bnc#900270 bnc#951165 bnc#955148 bsc#935083
  bsc#940776 bsc#944296 bsc#945825 bsc#950013 bsc#951110
  bsc#951440 bsc#953527 bsc#954404).
- kABI: protect struct ahci_host_priv.
- Refresh
  patches.arch/kvm-x86-remove-return-code-from-enable_irq-nmi_window.patch.
- Refresh
  patches.drivers/0015-rbd-add-support-for-single-major-device-number-allocation-scheme.
- Refresh
  patches.drivers/0016-rbd-enable-extended-devt-in-single-major-mode.
- Refresh
  patches.drivers/0017-rbd-introduce-rbd_dev_header_unwatch_sync-and-switch-to-it.
- Refresh patches.drivers/0043-iwlwifi-Support-7265-devices.
- Refresh patches.drivers/0066-iwlwifi-add-new-HW-7265-series.
- Refresh
  patches.drivers/0142-rbd-split-rbd_dev_spec_update-into-two-functions.patch.
- Refresh
  patches.drivers/0145-rbd-do-not-read-in-parent-info-before-snap-context.patch.
- Refresh
  patches.drivers/0163-rbd-initial-discard-bits-from-Guangliang-Zhao.patch.
- Refresh
  patches.drivers/0170-rbd-set-the-remaining-discard-properties-to-enable-s.patch.
- Refresh
  patches.drivers/0201-rbd-be-more-informative-on-ENOENT-failures.patch.
- Refresh
  patches.drivers/osd_client-rbd-update-event-interface-for-watch-noti.patch.
- Refresh
  patches.fixes/net-Explicitly-initialize-u64_stats_sync-structures-.patch.
- Delete
  patches.arch/kvm-x86-use-new-is_noncanonical_address-in-linearize.patch.
- Delete
  patches.arch/x86-mm-hotplug-modify-pgd-entry-when-removing-memory.patch.
- Delete
  patches.arch/x86-mm-hotplug-pass-sync_global_pgds-a-correct-argument-in-remove_pagetable.patch.
- Delete
  patches.drivers/0001-xhci-Add-spurious-wakeup-quirk-for-LynxPoint-LP-cont.patch.
- Delete
  patches.fixes/audit-correctly-record-file-names-with-different-path-name-types.
- Delete
  patches.fixes/audit-create-private-file-name-copies-when-auditing-inodes.
- Delete patches.fixes/fix-regression-in-nfsrdma-server.
- Delete
  patches.fixes/ipv6-addrconf-validate-new-MTU-before-applying-it.patch.
- Delete patches.fixes/kvm-svm-unconditionally-intercept-db.
- Delete
  patches.fixes/kvm-x86-work-around-infinite-loop-in-microcode-when-ac-is-delivered.
- Delete
  patches.fixes/net-socket-set-msg_namelen-to-0-if-msg_name-is-passe.patch.
- Delete
  patches.fixes/netfilter-xt_NFQUEUE-fix-queue-bypass-regression.patch.
- Delete
  patches.fixes/rds-verify-the-underlying-transport-exists-before-creating-a-connection.patch.
- Delete patches.fixes/virtio-net-drop-netif_f_fraglist.patch.
- Delete
  patches.suse/0001-KEYS-Fix-race-between-key-destruction-and-finding-a-.patch.
- Delete
  patches.suse/0002-KEYS-Fix-crash-when-attempt-to-garbage-collect-an-un.patch.
- commit bdb2402
* Wed Nov 25 2015 mkubecek@suse.cz
- Delete patches.fixes/bridge-module-get-put.patch.
  As discussed in
  http://mailman.suse.de/mlarch/SuSE/kernel/2015/kernel.2015.11/msg00097.html
- commit 9baadf0
* Wed Nov 25 2015 mkubecek@suse.cz
- ipv6: distinguish frag queues by device for multicast and
  link-local packets (bsc#955422).
- commit 096713f
* Wed Nov 25 2015 mkubecek@suse.cz
- route: Use ipv4_mtu instead of raw rt_pmtu (bsc#955224).
- ipv4: Don't increase PMTU with Datagram Too Big message
  (bsc#955224).
- commit 4dba66b
* Mon Nov 23 2015 mmarek@suse.com
- Update kabi files with sbc_parse_cdb symbol change (bsc#954635).
- commit d933be3
* Fri Nov 20 2015 bpoirier@suse.com
- Driver: Vmxnet3: Fix ethtool -S to return correct rx queue stats
  (bsc#950750).
- vmxnet3: adjust ring sizes when interface is down (bsc#950750).
- commit 638127c
* Fri Nov 20 2015 fdmanana@suse.com
- Btrfs: fix truncation of compressed and inlined extents
  (bnc#956053).
- Btrfs: fix file corruption and data loss after cloning inline
  extents (bnc#956053).
- commit f49784b
* Fri Nov 20 2015 tiwai@suse.de
- PCI: Drop "setting latency timer" messages (bsc#956047).
- commit 5fa5ece
* Thu Nov 19 2015 ddiss@suse.de
- kabi: Restore kabi in struct se_subsystem_api (bsc#954635).
- commit 3e6d127
* Thu Nov 19 2015 jslaby@suse.cz
- Refresh
  patches.fixes/0001-sunrpc-cache-make-cache-flushing-more-reliable.patch.
- Refresh
  patches.fixes/kvm-x86-work-around-infinite-loop-in-microcode-when-ac-is-delivered.
- Refresh patches.fixes/virtio-net-drop-netif_f_fraglist.patch.
- Refresh
  patches.suse/0001-KEYS-Fix-termination-condition-in-assoc-array-garbag.patch.
- Refresh
  patches.suse/0001-KEYS-Make-the-keyring-cycle-detector-ignore-other-ke.patch.
- Refresh
  patches.suse/0002-KEYS-Fix-crash-when-attempt-to-garbage-collect-an-un.patch.
- Refresh
  patches.suse/0003-KEYS-Don-t-permit-request_key-to-construct-a-new-key.patch.
  Update upstream status & add 'for-stable: no' for those with CVE, but
  which I should skip for the stable tree, because are 'later' fixes.
- commit 4bc342c
* Thu Nov 19 2015 jroedel@suse.de
- cpu: Defer smpboot kthread unparking until CPU known to
  scheduler (bsc#936773).
- Delete
  patches.fixes/x86-smpboot-Check-for-cpu_active-on-cpu-initializati.patch.
- commit 547e444
* Thu Nov 19 2015 mmarek@suse.com
- Refresh patches.drivers/0001-Add-PCI-IDs-of-Intel-Sunrise-Point-H-SATA-Controller.patch
- commit 15508e0
* Wed Nov 18 2015 mmarek@suse.com
- Revert ceph / target kabi updates.
- commit f5ef369
* Wed Nov 18 2015 jack@suse.cz
- Refresh patches.fixes/xfs-dquot-recovery-needs-verifiers.patch.
- commit e312652
* Wed Nov 18 2015 jack@suse.cz
- fanotify: fix notification of groups with inode & mount marks
  (bsc#955533).
- commit 5604acd
* Wed Nov 18 2015 mmarek@suse.com
- kabi: Restore kabi in struct se_cmd (bsc#954635).
- kabi: Restore kabi in struct iscsi_tpg_attrib (bsc#954635).
- commit 80fff47
* Wed Nov 18 2015 vbabka@suse.cz
- x86/mm/hotplug: Modify PGD entry when removing memory (VM
  Functionality, bnc#955148).
- x86/mm/hotplug: Pass sync_global_pgds() a correct argument in
  remove_pagetable() (VM Functionality, bnc#955148).
- commit 3287e3d
* Tue Nov 17 2015 mfasheh@suse.de
- xfs: recovery of XLOG_UNMOUNT_TRANS leaks memory (bsc#947953).
- commit 5440adc
* Mon Nov 16 2015 zren@suse.com
- dlm: make posix locks interruptible, (bsc#947241).
- commit dfb2f17
* Sun Nov 15 2015 jslaby@suse.cz
- Update config files. (bnc#955644)
- Refresh patches.suse/crasher-26.diff.
  Make crasher 'depends on m' and enable for s390x/default to be the
  same as in other configs.
- commit 27422d4
* Fri Nov 13 2015 jbohac@suse.cz
- ppp, slip: Validate VJ compression slot parameters completely
  (bsc#949936, CVE-2015-7799).
- isdn_ppp: Add checks for allocation failure in isdn_ppp_open()
  (bsc#949936, CVE-2015-7799).
- commit 77f49c2
* Fri Nov 13 2015 oneukum@suse.com
- usbvision fix overflow of interfaces array (bnc#950998).
- commit c49e871
* Thu Nov 12 2015 jthumshirn@suse.de
- bcache: Fix a lockdep splat in an error path (bnc#951638).
- bcache: kill closure locking usage (bnc#951638).
- bcache: Convert bucket_wait to wait_queue_head_t (bnc#951638).
- bcache: Convert try_wait to wait_queue_head_t (bnc#951638).
- bcache: Use blkdev_issue_discard() (bnc#951638).
- bcache: Refactor journalling flow control (bnc#951638).
- bcache: Refactor request_write() (bnc#951638).
- bcache: Clean up keylist code (bnc#951638).
- bcache: Add explicit keylist arg to btree_insert() (bnc#951638).
- bcache: Convert btree_insert_check_key() to btree_insert_node()
  (bnc#951638).
- bcache: Insert multiple keys at a time (bnc#951638).
- bcache: Add btree_insert_node() (bnc#951638).
- bcache: Explicitly track btree node's parent (bnc#951638).
- commit d4949b7
* Wed Nov 11 2015 mfasheh@suse.de
- xfs: fix double free in xlog_recover_commit_trans (bsc#947953).
- xfs: add a few more verifier tests (bsc#947953).
- commit a3cbbf1
* Wed Nov 11 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.48-49 (CVE-2015-5283
  bnc#942509 bsc#939834 bsc#947155 bsc#939716 bsc#926238
  CVE-2015-2925).
  Fix typo: s/CVS/CVE/
- commit 6f71aa0
* Wed Nov 11 2015 jroedel@suse.de
- KVM: svm: unconditionally intercept #DB (CVE-2015-8104
  bsc#954404).
- KVM: x86: work around infinite loop in microcode when #AC is
  delivered (CVE-2015-5307 bsc#953527).
- commit 7953c0a
* Tue Nov 10 2015 jbeulich@suse.com
- x86/evtchn: make use of PHYSDEVOP_map_pirq.
- Refresh patches.xen/1282-usbback-limit-copying.patch (bsc#941202).
- Update Xen patches to 3.12.50.
- commit 72c3e3f
* Tue Nov 10 2015 jeffm@suse.com
- Fix regression in NFSRDMA server (bsc#951110).
- commit 1401636
* Mon Nov  9 2015 mfasheh@suse.de
- Refresh
  patches.suse/btrfs-8363-btrfs-qgroup-account-shared-subtree-during-snapshot-.patch.
- commit ce43330
* Fri Nov  6 2015 jeffm@suse.com
- apparmor: allow SYS_CAP_RESOURCE to be sufficient to prlimit
  another task (bsc#921949).
- commit 8402467
* Fri Nov  6 2015 eich@suse.de
- drm/i915: add hotplug activation period to hotplug update mask
  (bsc#953980).
- commit 168910e
* Fri Nov  6 2015 mmarek@suse.com
- Add PCI IDs of Intel Sunrise Point-H SATA Controller S232/236 (bsc#953796).
- commit 29b9ad9
* Fri Nov  6 2015 jlee@suse.com
- rcu: Eliminate deadlock between CPU hotplug and expedited
  grace periods (bsc#949706).
- commit d1811e3
* Thu Nov  5 2015 jbohac@suse.cz
- RDS: fix race condition when sending a message on unbound socket
  (bsc#952384, CVE-2015-7990).
- commit e6b2c58
* Thu Nov  5 2015 jroedel@suse.de
- Refresh
  patches.fixes/do-not-reserve-crashkernel-high-memory-if-crashkernel-low-memory-reserving-failed.
  Add upstream commit-id and Patch-mainline information.
- commit 1115a10
* Tue Nov  3 2015 dvaleev@suse.com
- patches.arch/powerpc-Fix-endianness-of-flash_block_list-in-rtas_flash.patch:
  (bsc#952758).
- commit 7f31c81
* Tue Nov  3 2015 schwab@suse.de
- group-source-files: mark module.lds as devel file
  ld: cannot open linker script file /usr/src/linux-4.2.5-1/arch/arm/kernel/module.lds: No such file or directory
- commit ec6d351
* Fri Oct 30 2015 mfasheh@suse.de
- Btrfs: fix order by which delayed references are run
  (bnc#949440).
- btrfs: qgroup: account shared subtree during snapshot delete
  (bnc#935087, bnc#945649).
- btrfs: Add qgroup tracing (bnc#935087, bnc#945649).
- Btrfs: keep dropped roots in cache until transaction commit
  (bnc#935087, bnc#945649).
- Btrfs: use btrfs_get_fs_root in resolve_indirect_ref
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Fix a regression in qgroup reserved space
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Make snapshot accounting work with new
  extent-oriented qgroup (bnc#935087, bnc#945649).
- btrfs: qgroup: Add the ability to skip given qgroup for
  old/new_roots (bnc#935087, bnc#945649).
- btrfs: ulist: Add ulist_del() function (bnc#935087, bnc#945649).
- btrfs: qgroup: Cleanup the old ref_node-oriented mechanism
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Switch self test to extent-oriented qgroup
  mechanism (bnc#935087, bnc#945649).
- btrfs: qgroup: Switch to new extent-oriented qgroup mechanism
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Switch rescan to new mechanism (bnc#935087,
  bnc#945649).
- btrfs: qgroup: Add new qgroup calculation function
  btrfs_qgroup_account_extents() (bnc#935087, bnc#945649).
- btrfs: backref: Add special time_seq == (u64)-1 case for
  btrfs_find_all_roots() (bnc#935087, bnc#945649).
- btrfs: qgroup: Add new function to record old_roots (bnc#935087,
  bnc#945649).
- btrfs: qgroup: Record possible quota-related extent for qgroup
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Add function qgroup_update_counters()
  (bnc#935087, bnc#945649).
- btrfs: qgroup: Add function qgroup_update_refcnt() (bnc#935087,
  bnc#945649).
- btrfs: extent-tree: Use ref_node to replace unneeded parameters
  in __inc_extent_ref() and __free_extent() (bnc#935087,
  bnc#945649).
- btrfs: qgroup: Cleanup open-coded old/new_refcnt update and read
  (bnc#935087, bnc#945649).
- btrfs: delayed-ref: Cleanup the unneeded functions (bnc#935087,
  bnc#945649).
- btrfs: delayed-ref: Use list to replace the ref_root in ref_head
  (bnc#935087, bnc#945649).
- btrfs: backref: Don't merge refs which are not for same block
  (bnc#935087, bnc#945649).
- Btrfs: remove transaction from send (bnc#935087, bnc#945649).
- btrfs: qgroup: move WARN_ON() to the correct location
  (bnc#935087, bnc#945649).
- btrfs: fix leak in qgroup_subtree_accounting() error path
  (bnc#935087, bnc#945649).
- Btrfs: fix comp_oper to get right order (bnc#935087,
  bnc#945649).
- commit 13016a8
* Thu Oct 29 2015 jack@suse.com
- dmapi: Fix xfs dmapi to not unlock & lock XFS_ILOCK_EXCL
  (bsc#949744).
- commit 6069ac1
* Thu Oct 29 2015 ddiss@suse.de
- target/pr: fix core_scsi3_pr_seq_non_holder() caller
  (bnc#952666).
- commit b954f92
* Wed Oct 28 2015 jslaby@suse.cz
- rpm/kernel-binary.spec.in: really pass down %%{?_smp_mflags}
- commit 273a7fb
* Wed Oct 28 2015 jslaby@suse.cz
- Linux 3.12.50 (CVE-2015-7613 LTC#129509 bnc#853495 bnc#932348
  bnc#938024 bnc#941908 bnc#943476 bnc#944028 bnc#946906
  bnc#949463 bsc#931538 bsc#947537 bsc#948256 bsc#948536
  bsc#951199 bnc#942204).
- Refresh
  patches.drivers/0001-xhci-Blacklist-using-streams-on-the-Etron-EJ168-cont.patch.
- Refresh
  patches.drivers/0002-xhci-Rename-Asrock-P67-pci-product-id-to-EJ168.patch.
- Refresh
  patches.drivers/0013-USB-core-correct-spelling-mistakes-in-comments-and-w.patch.
- Refresh
  patches.drivers/0040-usb-xhci-change-enumeration-scheme-to-new-scheme-by-.patch.
- Refresh
  patches.drivers/0049-usb-rename-usb_port-device-objects.patch.
- Refresh
  patches.suse/btrfs-0146-replace-path-slots-0-with-otherwise-unused-var.patch.
- Refresh
  patches.suse/btrfs-0177-move-the-extent-buffer-radix-tree-into-the-fs_.patch.
- Refresh
  patches.suse/btrfs-8089-be-aware-of-btree-inode-write-errors-to-avoid-.patch.
- Refresh
  patches.suse/intel-tsx-0012-tools-perf-add-support-for-record-transaction-flags.patch.
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh patches.suse/kgr-0048-kgr-mark-even-more-kthreads.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Delete
  patches.arch/0001-x86-kvm-svm-Use-WARN_ON_ONCE-for-missing-X86_FEATURE_NRIPS.patch.
- Delete patches.arch/s390-sles12-3270-reconnect.patch.
- Delete
  patches.drivers/0001-usb-core-Fix-USB-3.0-devices-lost-in-NOTATTACHED-sta.patch.
- Delete
  patches.drivers/0001-usb-core-implement-AMD-remote-wakeup-quirk.patch.
- Delete
  patches.drivers/0001-xhci-Workaround-for-PME-stuck-issues-in-Intel-xhci.patch.
- Delete
  patches.drivers/0001-xhci-change-xhci-1.0-only-restrictions-to-support-xh.patch.
- Delete
  patches.drivers/0002-xhci-rework-cycle-bit-checking-for-new-dequeue-point.patch.
- Delete
  patches.fixes/0001-Initialize-msg-shm-IPC-objects-before-doing-ipc_addi.patch.
- Delete
  patches.fixes/cifs-client-should-ignore-non-zero-challengelenght.patch.
- Delete
  patches.fixes/iommu-amd-handle-integer-overflow-in-dma_ops_area_alloc.
- Delete
  patches.fixes/net-add-length-argument-to-skb_copy_and_csum_datagra.patch.
- Delete
  patches.fixes/rcu-Reject-memory-order-induced-stall-warning-false-positives.patch.
- Delete
  patches.fixes/scsi-fix-scsi_error_handler-vs.-scsi_host_dev_releas.patch.
- Delete
  patches.suse/arch-Clean-up-asm-barrier.h-implementations-using-asm-generic-barrier.h.patch.
- Delete
  patches.suse/btrfs-8226-fix-read-corruption-of-compressed-and-shared-e.patch.
- Delete
  patches.suse/btrfs-8241-update-fix-for-read-corruption-of-compressed-a.patch.
- commit c164191
* Wed Oct 28 2015 tiwai@suse.de
- ALSA: hda - Disable 64bit address for Creative HDA controllers
  (bnc#814440).
- commit 9abb1bc
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use parallel make in all invocations
  Also, remove the lengthy comment, since we are using a standard rpm
  macro now.
- commit 4d6ba88
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Delete one more DEBUG_SECTION_MISMATCH assignment
- commit fce45dc
* Mon Oct 26 2015 fdmanana@suse.com
- Btrfs: fix regression running delayed references when using
  qgroups (bnc#951615).
- Btrfs: fix regression when running delayed references
  (bnc#951615).
- Btrfs: fix qgroup sanity tests (bnc#951615).
- commit e8fd512
* Mon Oct 26 2015 fdmanana@suse.com
- Update
  patches.suse/btrfs-8361-Btrfs-keep-dropped-roots-in-cache-until-transaction-.patch
  (bnc#935087, bnc#945649, bnc#951615).
- commit 6900ddd
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not explicitly set DEBUG_SECTION_MISMATCH
  CONFIG_DEBUG_SECTION_MISMATCH is a selectable Kconfig option since
  2.6.39 and is enabled in our configs.
- commit 15aa4f8
* Mon Oct 26 2015 mmarek@suse.com
- kabi: Hide rt6_* types from genksyms on ppc64le (bsc#951546).
- commit c2df391
* Mon Oct 26 2015 mmarek@suse.com
- Disable some ppc64le netfilter modules to restore the kabi (bsc#951546)
- commit bdf30fb
* Fri Oct 23 2015 jlee@suse.com
- KEYS: Don't permit request_key() to construct a new keyring
  (CVE-2015-7872 bsc#951440).
- KEYS: Fix crash when attempt to garbage collect an
  uninstantiated keyring (CVE-2015-7872 bsc#951440).
- KEYS: Fix race between key destruction and finding a keyring
  by name (bsc#951440).
- commit b7988a2
* Fri Oct 23 2015 mmarek@suse.cz
- Move ktime_after patch to the networking section
- commit a2ac8c6
* Fri Oct 23 2015 mkubecek@suse.cz
- net: add length argument to skb_copy_and_csum_datagram_iovec
  (bsc#951199).
- kabi: protect skb_copy_and_csum_datagram_iovec() signature
  (bsc#951199).
- Delete
  patches.fixes/net-handle-null-iovec-pointer-in-skb_copy_and_csum_d.patch.
- commit f4acdf4
* Fri Oct 23 2015 mmarek@suse.com
- Sync ppc64le netfilter config options with other archs (bnc#951546)
- commit dbc49a6
* Fri Oct 23 2015 hare@suse.de
- pci: Update VPD size with correct length (bsc#924493).
- commit c671286
* Fri Oct 23 2015 jroedel@suse.de
- Revert "- sched: Fix cpu_active_mask/cpu_online_mask race (bsc#936773)."
  This reverts commit cb14f5b018016d54479e9d741266a72c5364e85d.
  The upstream fix does not fix the problem, so revert it and
  put my old fix back in place.
- commit 904e863
* Fri Oct 23 2015 mkubecek@suse.cz
- Fix commit message
  patches.fixes/net-handle-null-iovec-pointer-in-skb_copy_and_csum_d.patch.
- commit ebe910d
* Fri Oct 23 2015 mkubecek@suse.cz
- net: handle null iovec pointer in
  skb_copy_and_csum_datagram_iovec() (bsc#951199).
- commit 60ae8c7
* Thu Oct 22 2015 neilb@suse.com
- dm-snap: avoid deadock on s->lock when a read is split
  (bsc#939826).
- commit 2debeed
* Thu Oct 22 2015 tonyj@suse.de
- audit: create private file name copies when auditing inodes
  (bsc#950013).
- audit: correctly record file names with different path name
  types (bsc#950013).
- commit 423848b
* Wed Oct 21 2015 ohering@suse.de
- Drivers: hv: vss: run only on supported host versions
  (bnc#949504).
- commit cdff98c
* Wed Oct 21 2015 jack@suse.com
- xfs: DIO needs an ioend for writes (bsc#949744).
- xfs: DIO write completion size updates race (bsc#949744).
- xfs: DIO writes within EOF don't need an ioend (bsc#949744).
- xfs: always drain dio before extending aio write submission
  (bsc#949744).
- xfs: direct IO EOF zeroing needs to drain AIO (bsc#949744).
- xfs: don't allocate an ioend for direct I/O completions
  (bsc#949744).
- xfs: factor DIO write mapping from get_blocks (bsc#949744).
- xfs: handle DIO overwrite EOF update completion correctly
  (bsc#949744).
- xfs: move DIO mapping size calculation (bsc#949744).
- xfs: using generic_file_direct_write() is unnecessary
  (bsc#949744).
- Refresh
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit 3f08a8e
* Wed Oct 21 2015 mhocko@suse.cz
- Refresh
  patches.fixes/scsi-fix-scsi_error_handler-vs.-scsi_host_dev_releas.patch.
  update reference as the patch was merged
- commit 0c6dcc0
* Tue Oct 20 2015 jlee@suse.com
- x86/efi: Fix boot crash by mapping EFI memmap entries bottom-up
  at runtime, instead of top-down (bsc#940853).
- commit 38b041c
* Tue Oct 20 2015 hare@suse.de
- dm: impose configurable deadline for dm_request_fn's merge
  heuristic (bsc#904348).
- dm: don't start current request if it would've merged with
  the previous (bsc#904348).
- dm sysfs: introduce ability to add writable attributes
  (bsc#904348).
- ktime: add ktime_after and ktime_before helper (bsc#904348).
- commit d0ebdc9
* Tue Oct 20 2015 oneukum@suse.com
- xhci: Add spurious wakeup quirk for LynxPoint-LP controllers
  (bnc#951165).
- commit 2c8a8f0
* Mon Oct 19 2015 lduncan@suse.com
- SCSI: hosts: update to use ida_simple for host_no (bsc#939926)
- commit 36bbed4
* Sat Oct 17 2015 dmueller@suse.com
- KVM: x86: call irq notifiers with directed EOI (bsc#950862).
- commit ec0dbab
* Fri Oct 16 2015 mmarek@suse.com
- Delete unused rpm/config-subst.
- commit ff78db3
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-source.rpmlintrc: Update the filters
- commit e26b4cc
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use upstream script to support config.addon
- commit e8739f8
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Drop the %%build_src_dir macro
  It is the parent directory of the O= directory.
- commit 2ed0dbe
* Thu Oct 15 2015 neilb@suse.com
- sunrpc/cache: make cache flushing more reliable (bsc#947478).
- commit 6f43976
* Thu Oct 15 2015 mgalbraith@suse.de
- Refresh patches.fixes/sched-core-Fix-task-and-run-queue-sched_info-run_delay-inconsistencies.patch.
- commit bdd4847
* Thu Oct 15 2015 mgalbraith@suse.de
- Refresh patches.fixes/sched-core-Fix-task-and-run-queue-sched_info-run_delay-inconsistencies.patch.
- commit d375351
* Thu Oct 15 2015 mgalbraith@suse.de
- sched/core: Fix task and run queue sched_info::run_delay inconsistencies (bnc#949100).
- Refresh patches.fixes/sched-Consider-pi-boosting-in-setscheduler.patch.
- commit acb3293
* Wed Oct 14 2015 neilb@suse.com
- Update patches.kernel.org/patch-3.12.48-49 (CVE-2015-5283
  bnc#942509 bsc#939834 bsc#947155 bsc#939716 bsc#926238
  CVS-2015-2925).
  As this -stable release fixes bsc#926238, update the References line.
- commit 2e5c96f
* Mon Oct 12 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8241-update-fix-for-read-corruption-of-compressed-a.patch.
- commit 6d8479e
* Mon Oct 12 2015 mmarek@suse.com
- rpm/kernel-obs-build.spec.in: Add virtio_rng to the initrd
  This allows to feed some randomness to the OBS workers.
- commit fbb0589
* Fri Oct  9 2015 mkubecek@suse.cz
- macvlan: Support bonding events (bsc#948521).
- commit fbf4a48
* Thu Oct  8 2015 jbohac@suse.cz
- ipvs: drop first packet to dead server (bsc#946078).
- commit 3088523
* Thu Oct  8 2015 oneukum@suse.com
- xhci: change xhci 1.0 only restrictions to support xhci 1.1
  (bnc#949463).
- commit d775f48
* Wed Oct  7 2015 mbenes@suse.cz
- With fake signal, CPU-bound stack-inspection-based optimization is
  redundant. CPU-bound tasks get migrated on their return to userspace
  from IPI handling. The optimization is based on fragile stack heuristic.
  So drop it. (bsc#948685)
- Refresh patches.suse/kgr-0039-kgr-fix-ugly-race.patch.
- Refresh
  patches.suse/kgr-0072-kgr-use-for_each_process_thread.patch.
- Refresh
  patches.suse/kgr-0079-kgr-fix-migration-of-kthreads-to-the-new-universe.patch.
- Delete
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Delete
  patches.suse/kgr-0104-fix-unwinder-and-user-addresses.patch.
- commit 47b0870
* Wed Oct  7 2015 jdelvare@suse.de
- supported.conf: Fix dependencies on ppc64le
  of_mdio needed by mdio-gpio
- commit c0993a7
* Tue Oct  6 2015 jslaby@suse.cz
- Refresh
  patches.arch/0001-x86-kvm-svm-Use-WARN_ON_ONCE-for-missing-X86_FEATURE_NRIPS.patch.
  Upstream status.
- commit 02a0a90
* Tue Oct  6 2015 ddiss@suse.de
- target/rbd: fix PR info memory leaks (bnc#948831).
- target/rbd: fix COMPARE AND WRITE page vector leak (bnc#948831).
- commit 0e96e3b
* Tue Oct  6 2015 jslaby@suse.cz
- kgr: wake up kthreads periodically (fate#313296).
- kgr: fix migration of kthreads to the new universe
  (fate#313296).
- commit 63b337b
* Tue Oct  6 2015 mkubecek@suse.cz
- ipv6: addrconf: validate new MTU before applying it (bsc#944296
  CVE-2015-0272).
- commit 9bf46cc
* Tue Oct  6 2015 mkubecek@suse.cz
- Update mainline reference
  patches.fixes/netfilter-nf_conntrack_proto_sctp-minimal-multihomin.patch.
- commit 0bff168
* Mon Oct  5 2015 jslaby@suse.cz
- Linux 3.12.49 (CVE-2015-5283 bnc#942509 bsc#939834 bsc#947155
  bsc#939716).
- Refresh
  patches.fixes/0001-md-split-detach-operation-out-from-stop.patch.
- Refresh
  patches.fixes/0003-md-protect-pers-changes-with-mddev-lock.patch.
- Delete
  patches.fixes/Input-evdev-do-not-report-errors-form-flush.
- Delete patches.fixes/nfsv4-dont-set-for-O_RDONLY.
- Delete
  patches.fixes/sctp-fix-race-on-protocol-netns-initialization.patch.
- Delete
  patches.suse/btrfs-8217-check-if-previous-transaction-aborted-to-avoid.patch.
- Update config files.
  CONFIG_ARM64_ERRATUM_843419 is not set
  If anybody needs that, they should create a bnc or fate.
- commit 3ced81a
* Mon Oct  5 2015 mmarek@suse.com
- Initialize msg/shm IPC objects before doing ipc_addid()
  (bsc#948536, CVE-2015-7613).
- commit 314f0e3
* Mon Oct  5 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8239-fix-stale-dir-entries-after-unlink-inode-evict.patch.
- Refresh
  patches.suse/btrfs-8240-fix-stale-dir-entries-after-removing-a-link-an.patch.
  Commented some lines in the commit message of the patch files, because
  those lines confuse gnu's 'patch' and make it fail as reported by
  Jean Delvare.
- commit bf98106
* Fri Oct  2 2015 bp@suse.de
- rtc: cmos: Revert "rtc-cmos: Add an alarm disable quirk"
  (bsc#930145).
- rtc: cmos: Cancel alarm timer if alarm time is equal to now+1
  seconds (bsc#930145).
- Refresh patches.xen/xen-x86-EFI.
- commit 5c9ab22
* Fri Oct  2 2015 mkubecek@suse.cz
- ipv6: Check RTF_LOCAL on rt->rt6i_flags instead of rt->dst.flags
  (bsc#947321).
- kABI: protect struct rt6_info changes from bsc#947321 changes
  (bsc#947321).
- ipv6: Stop rt6_info from using inet_peer's metrics (bsc#947321).
- ipv6: Stop /128 route from disappearing after pmtu update
  (bsc#947321).
- ipv6: Extend the route lookups to low priority metrics
  (bsc#947321).
- ipv6: Consider RTF_CACHE when searching the fib6 tree
  (bsc#947321).
- commit b8374dd
* Fri Oct  2 2015 jthumshirn@suse.de
- SCSI: Fix hard lockup in scsi_remove_target() (bsc#944749).
- commit 6739364
* Fri Oct  2 2015 tiwai@suse.de
- apparmor: temporary work around for bug while unloading policy
  (boo#941867).
- commit 2c81711
* Fri Oct  2 2015 jdelvare@suse.de
- supported.conf: Add missing dependencies of supported modules
  hwmon_vid needed by nct6775
  hwmon_vid needed by w83627ehf
  reed_solomon needed by ramoops
- commit c057de8
* Thu Oct  1 2015 jroedel@suse.de
- genirq: Make sure irq descriptors really exist when
  __irq_alloc_descs returns (bsc#945626).
- commit 9b067e5
* Thu Oct  1 2015 dmueller@suse.com
- Use WARN_ON_ONCE for missing X86_FEATURE_NRIPS (bsc#947537).
- commit fe3a97e
* Thu Oct  1 2015 jthumshirn@suse.de
- NVMe: Mismatched host/device page size support (bsc#935961).
- commit 6ad7736
* Wed Sep 30 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8226-fix-read-corruption-of-compressed-and-shared-e.patch.
- commit ff65eec
* Wed Sep 30 2015 fdmanana@suse.com
- Btrfs: update fix for read corruption of compressed and shared
  extents (bsc#948256).
- commit 8f10ebd
* Wed Sep 30 2015 jbohac@suse.cz
- Update patches.kernel.org/patch-3.12.39-40 (FATE#315482
  LTC#111793 CVE-2015-2666 FATE#316038 bnc#883741 bnc#892612
  bnc#907969 bnc#914726 bnc#920262 bsc#921313 bsc#921990
  bsc#922944 bnc#854993 FATE#315929 bnc#877098 LTC#110078
  bsc#919463 CVE-2015-2150 XSA-120 bnc#927257 CVE-2015-3331
  bsc#869564 CVE-2014-2568).
  Update References to include bsc#869564/CVE-2014-2568.
- commit cd8b05d
* Wed Sep 30 2015 eich@suse.de
- Refresh
  patches.drivers/drm-i915-Avoid-race-of-intel_crt_detect_hotplug-with-HPD-interrupt-v2.patch.
- drm/i915: Avoid race of intel_crt_detect_hotplug() with HPD
  interrupt, v2 (bsc#942938).
- Delete
  patches.drivers/drm-i915-Avoid-race-of-intel_crt_detect_hotplug-with-HPD-interrupt.patch.
- commit fca6378
* Tue Sep 29 2015 fdmanana@suse.com
- Btrfs: fix stale dir entries after removing a link and fsync
  (bnc#942925).
- Btrfs: fix stale dir entries after unlink, inode eviction and
  fsync (bnc#942925).
- Btrfs: fill ->last_trans for delayed inode in btrfs_fill_inode
  (bnc#942925).
- Btrfs: fix stale directory entries after fsync log replay
  (bnc#942925).
- Btrfs: fix metadata inconsistencies after directory fsync
  (bnc#942925).
- Btrfs: make btrfs_search_forward return with nodes unlocked
  (bnc#942925).
- commit d2d6134
* Fri Sep 25 2015 jbohac@suse.cz
- sctp: fix race on protocol/netns initialization (bsc#947155,
  CVE-2015-5283).
- commit e0b2806
* Fri Sep 25 2015 bp@suse.de
- RDS: verify the underlying transport exists before creating
  a connection (bsc#945825, CVE-2015-6937).
- commit cbfd50e
* Thu Sep 24 2015 oneukum@suse.com
- xhci: rework cycle bit checking for new dequeue pointers
  (bnc#944028).
- xhci: Workaround for PME stuck issues in Intel xhci
  (bnc#944028).
- commit 1a49ced
* Thu Sep 24 2015 neilb@suse.com
- BTRFS: support NFSv2 export (bnc#929871).
- commit e41cbad
* Wed Sep 23 2015 mhocko@suse.cz
- sched, numa: do not hint for NUMA balancing on VM_MIXEDMAP
  mappings (bnc#943573).
- mm: numa: disable change protection for vma(VM_HUGETLB)
  (bnc#943573).
- commit 6f4b412
* Wed Sep 23 2015 fdmanana@suse.com
- Btrfs: fix incorrect compression ratio detection (fate#316463).
- Btrfs: incremental send, fix clone operations for compressed
  extents (fate#316463).
- Btrfs: use right clone root offset for compressed extents
  (fate#316463).
- btrfs: zero out left over bytes after processing compression
  streams (fate#316463).
- btrfs compression: merge inflate and deflate z_streams
  (fate#316463).
- btrfs: use E2BIG instead of EIO if compression does not help
  (fate#316463).
- btrfs: return errno instead of -1 from compression
  (fate#316463).
- btrfs: fix inline compressed read err corruption (fate#316463).
- commit cffac10
* Tue Sep 22 2015 jroedel@suse.de
- sched: Fix cpu_active_mask/cpu_online_mask race (bsc#936773).
- Delete
  patches.fixes/x86-smpboot-Check-for-cpu_active-on-cpu-initializati.patch.
- commit cb14f5b
* Tue Sep 22 2015 jroedel@suse.de
- PCI: Set MPS to match upstream bridge (bsc#943313).
- PCI: Move MPS configuration check to pci_configure_device()
  (bsc#943313).
- commit d3b9a59
* Tue Sep 22 2015 fdmanana@suse.com
- Btrfs: fix read corruption of compressed and shared extents
  (bnc#946906).
- Btrfs: fix file read corruption after extent cloning and fsync
  (bnc#946902).
- commit 2770f49
* Tue Sep 22 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8217-check-if-previous-transaction-aborted-to-avoid.patch.
- commit bfccc69
* Tue Sep 22 2015 neilb@suse.com
- Make sure XPRT_CONNECTING gets cleared when needed (bsc#946309).
- commit 66ed2f8
* Mon Sep 21 2015 dchang@suse.com
- net/mlx4_en: Use PTYS register to set ethtool settings (Speed)
  (bsc#945710).
- net/mlx4_en: Use PTYS register to query ethtool settings
  (bsc#945710).
- ethtool, net/mlx4_en: Add 100M, 20G, 56G speeds ethtool
  reporting support (bsc#945710).
- net/mlx4_core: Add ethernet backplane autoneg device capability
  (bsc#945710).
- net/mlx4_core: Introduce ACCESS_REG CMD and eth_prot_ctrl dev
  cap (bsc#945710).
- commit f86875f
* Mon Sep 21 2015 mgalbraith@suse.de
- rcu: Reject memory-order-induced stall-warning false positives (bnc#941908).
- commit 9c8a9fc
* Fri Sep 18 2015 ddiss@suse.de
- kabi: fix ppc64le and s390x symvers and symtypes
  They don't build with Ceph support, but are still affected by the
  related LIO target changes.
- commit 699c4b2
* Fri Sep 18 2015 ddiss@suse.de
- config: disable CONFIG_TCM_RBD on ppc64le and s390x
- commit 034de30
* Fri Sep 18 2015 ddiss@suse.de
- Update libceph, rbd and target kabi files
  To reflect changes for the new target_core_rbd module.
  s390x and ppc64le aren't configured to build ceph, so can be ignored.
- commit 6ca3632
* Fri Sep 18 2015 neilb@suse.com
- md: move GET_BITMAP_FILE ioctl out from mddev_lock (bsc#943270).
- md: tidy up set_bitmap_file (bsc#943270).
- md: remove unnecessary 'buf' from get_bitmap_file (bsc#943270).
- md/bitmap: don't abuse i_writecount for bitmap files
  (bsc#943270).
- commit 80760f7
* Thu Sep 17 2015 brogers@suse.com
- virtio-net: drop NETIF_F_FRAGLIST (bsc#940776 CVE-2015-5156).
- commit 0fac6b1
* Thu Sep 17 2015 ohering@suse.de
- Renumber hv patches, no source change.
  The tool which extracts backport candidates missed new
  files after upstream commit af170c5.
- commit 2b94429
* Thu Sep 17 2015 ddiss@suse.de
- target/stat: print full t10_wwn.model buffer (fate#318836).
- target: remove hardcoded T10 Vendor ID in INQUIRY response
  (fate#318836).
- target/configfs: add device vendor_id attribute (fate#318836).
- target/rbd: handle SCSI2 reservation release on reset
  (fate#318836).
- target/rbd: implement SCSI2 reservation handling (fate#318836).
- target/rbd: add SCSI2 reservation entry to PR info
  (fate#318836).
- target/rbd: SCSI3 check conflict support (fate#318836).
- target/rbd: add stubbed out pr_read_full_status (fate#318836).
- target/rbd: add pr_report_capabilities support (fate#318836).
- target/rbd: add stubbed out pr_register_and_move (fate#318836).
- target/rbd: add pr_preempt support (fate#318836).
- target/rbd: add pr_clear support (fate#318836).
- target/rbd: add pr_read_reservation support (fate#318836).
- target/rbd: add pr_release support (fate#318836).
- target/rbd: add pr_reserve support (fate#318836).
- target/rbd: add support for PR register & read keys
  (fate#318836).
- target/pr: add backend API for reservation handling
  (fate#318836).
- commit 37d76d5
* Thu Sep 17 2015 ohering@suse.de
- Correct an hv patch which modifies our disabled vmbus_exit
  function to make further backports easier
- commit ec8ce3e
* Thu Sep 17 2015 mgorman@suse.com
- sched,numa: limit amount of virtual memory scanned in task_numa_work
  (Automatic NUMA Balancing (fate#315482)).
- commit 1fdf05c
* Wed Sep 16 2015 jeffm@suse.com
- btrfs: advertise which crc32c implementation is being used on
  mount (bsc#946057).
- commit 6e6685c
* Tue Sep 15 2015 jslaby@suse.cz
- Linux 3.12.48 (FATE#315962 bnc#898159 bnc#941332 bsc#908950
  bsc#942307 bsc#942707 bsc#943378).
- Refresh
  patches.drivers/bonding-make-bond_for_each_slave-use-lower-neighbour.patch.
- Refresh
  patches.drivers/bonding-remove-the-no-effect-lock-for-bond_select_ac.patch.
- Refresh
  patches.drivers/rtnetlink-provide-api-for-getting-and-setting-slave-.patch.
- Refresh
  patches.fixes/block-modify-__bio_add_page-check-to-accept-pages-th.patch.
- Refresh
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- Refresh
  patches.suse/0072-tipc-aggregate-port-structure-into-socket-structure.patch.
- Refresh
  patches.suse/0075-tipc-align-usage-of-variable-names-and-macros-in-soc.patch.
- Refresh patches.suse/kgr-0048-kgr-mark-even-more-kthreads.patch.
- Delete
  patches.drivers/drm-radeon-fix-hotplug-race-at-startup.patch.
- Delete patches.drivers/lpfc-Fix-scsi-prep-dma-buf-error.patch.
- Delete
  patches.drivers/mtip32xx-dynamically-allocate-buffer-in-debugfs-func.patch.
- Delete
  patches.fixes/0001-cifs-Send-a-logoff-request-before-removing-a-smb-ses.patch.
- Delete patches.fixes/aio-fix-reqs_available-handling.patch.
- Delete
  patches.fixes/dm-cache-mq-fix-memory-allocation-failure-for-large-cache-devices.patch.
- Delete
  patches.fixes/mfd-lpc_ich-Assign-subdevice-ids-automatically.
- commit 3d4cccc
* Tue Sep 15 2015 jdelvare@suse.de
- supported.conf: Add encrypted-keys as supported
  ecryptfs depends on it, and it is supported.
- commit 2fa43fe
* Tue Sep 15 2015 mgalbraith@suse.de
- Cherry pick SLE12-SP1:f2179c151a6e56f4914664f0548826cc631076e1
- cpufreq: intel_pstate: Add CPU ID for Braswell processor (fate#318533).
- intel_pstate: Add CPU IDs for Broadwell processors (fate#318532).
- intel_pstate: Add CPUID for BDW-H CPU (fate#318532).
- intel_pstate: Add support for SkyLake (fate#318533).
- intel_pstate: Correct BYT VID values (bnc#907973, FATE#316038).
- intel_pstate: Remove periodic P state boost (bnc#907973, FATE#316038).
- intel_pstate: add sample time scaling (bnc#907973, FATE#316038, bnc#924722, bnc#916543).
- intel_pstate: don't touch turbo bit if turbo disabled or unavailable (bnc#907973, FATE#316038).
- intel_pstate: remove setting P state to MAX on init (bnc#907973, FATE#316038).
- intel_pstate: remove unneeded sample buffers (bnc#907973, FATE#316038).
- intel_pstate: set BYT MSR with wrmsrl_on_cpu() (bnc#907973, FATE#316038).
- Refresh patches.drivers/intel_pstate-Add-setting-voltage-value-for-baytrail-P-states.patch.
- Refresh patches.drivers/intel_pstate-Add-support-for-Baytrail-turbo-P-states.patch.
- Refresh patches.drivers/intel_pstate-Fix-BYT-frequency-reporting.patch.
- Refresh patches.drivers/intel_pstate-Fix-setting-VID.patch.
- Refresh patches.drivers/intel_pstate-Set-turbo-VID-for-BayTrail.patch.
- Refresh patches.drivers/intel_pstate-Use-LFM-bus-ratio-as-min-ratio-P-state.patch.
- commit 5631966
* Tue Sep 15 2015 jdelvare@suse.de
- supported.conf: Mark csiostor driver as unsupported
  We only support the csiostor driver starting with SLE12 SP1.
- commit ec23e09
* Mon Sep 14 2015 jdelvare@suse.de
- config/arm64: Disable CONFIG_HW_RANDOM_TIMERIOMEM
  It's disabled in all other configuration files and also in SLE12 SP1.
- commit 2022b63
* Mon Sep 14 2015 jdelvare@suse.de
- supported.conf: Drop removed modules
  We no longer ship these modules so they do not need to be listed in
  supported.conf.
- commit c5ecb4f
* Mon Sep 14 2015 ohering@suse.de
- Add mainline tag for kexec_in_progress patch
- commit 0ebe066
* Mon Sep 14 2015 ohering@suse.de
- Update headers in some hv patches
- commit d58aed1
* Sun Sep 13 2015 tiwai@suse.de
- Input: evdev - do not report errors form flush() (bsc#939834).
- commit e050571
* Fri Sep 11 2015 mmarek@suse.cz
- series.conf: Whitespace cleanup
- commit d79bf5b
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-spec-macros: Include the version string in the Obsoletes line
- commit 083cdb4
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Obsolete previous builds of the same package (boo#867595)
- commit ffb73eb
* Wed Sep  9 2015 mmarek@suse.com
- Remove symbol from s390x kabi files that is not present in this update
- commit f93b1bb
* Tue Sep  8 2015 mmarek@suse.com
- Build against SUSE:SLE-12:Update in the OBS
- commit ee72011
* Mon Sep  7 2015 fdmanana@suse.com
- Btrfs: don't initialize a space info as full to prevent ENOSPC
  (bnc#944001).
- commit 94c1028
* Fri Sep  4 2015 ohering@suse.de
- hv: fcopy: add memory barrier to propagate state (bnc#943529).
- commit f586c39
* Fri Sep  4 2015 tiwai@suse.de
- Remove I915 driver caps for SKL & BSA (bsc#944502).
- commit 7594a02
* Thu Sep  3 2015 jslaby@suse.cz
- kgr: add kgraft annotation to hwrng kthread (fate#313296).
- commit d02e6ac
* Wed Sep  2 2015 mhocko@suse.cz
- mm: remove PG_waiters from PAGE_FLAGS_CHECK_AT_FREE
  (bnc#943959).
- commit 74430dd
* Wed Sep  2 2015 jslaby@suse.cz
- Refresh patches.drivers/lpfc-Fix-scsi-prep-dma-buf-error.patch.
  Format commit SHA properly.
- commit 88556fd
* Wed Sep  2 2015 jbeulich@suse.com
- Update Xen patches to 3.12.47.
- Refresh patches.xen/xen-blkfront-indirect (bsc#935678).
- Refresh other Xen patches.
- commit 66de05c
* Wed Sep  2 2015 dmueller@suse.com
- config/arm64/default: Set CONFIG_BLK_DEV_RBD=m
  This is needed for SES2 on aarch64 (fate#318836)
- commit 37ad30d
* Tue Sep  1 2015 dmueller@suse.com
- config/aarch64: set CONFIG_TCM_RBD=m
  Enable the LIO clustered RBD backend (fate#318836).
- commit 79bdd6f
* Tue Sep  1 2015 mhocko@suse.cz
- pm, hinernate: use put_page in release_swap_writer (bnc#943959).
- commit 21c10c4
* Mon Aug 31 2015 eich@suse.de
- drm/i915: Only print hotplug event message when hotplug bit
  is set (bsc#942938).
- drm/i915: Use an interrupt save spinlock in
  intel_hpd_irq_handler() (bsc#942938).
- drm/i915: Queue reenable timer also when
  enable_hotplug_processing is false (bsc#942938).
- drm/i915: Avoid race of intel_crt_detect_hotplug() with HPD
  interrupt (bsc#942938).
- drm/i915: Make hpd arrays big enough to avoid out of bounds
  access (bsc#942938).
- commit 0f0e346
* Mon Aug 31 2015 jslaby@suse.cz
- Refresh patches.kabi/kabi-protect-struct-mm_context_t.patch.
  Fix the ldt interface removal comment. Thx to jbeulich.
- commit 44132d1
* Mon Aug 31 2015 jack@suse.com
- xfs: Fix file type directory corruption for btree directories
  (bsc#941305).
- commit fc4872d
* Fri Aug 28 2015 eich@suse.de
- drm/radeon: fix hotplug race at startup (bsc#942307).
- commit 9a3e78f
* Fri Aug 28 2015 jjolly@suse.de
- kernel: do full redraw of the 3270 screen on reconnect
  (bnc#943476, LTC#129509).
- commit 2dfdd72
* Fri Aug 28 2015 mhocko@suse.cz
- scsi: fix scsi_error_handler vs. scsi_host_dev_release race
  (bnc#942204).
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- commit a2f8077
* Fri Aug 28 2015 mmarek@suse.com
- series.conf: Comment cleanup
- commit 98b904e
* Fri Aug 28 2015 ddiss@suse.de
- target/pr: split out and export core_scsi3_pr_seq_non_holder()
  (fate#318836).
- commit 92ebbd2
* Thu Aug 27 2015 hare@suse.de
- block: blk-merge: fix blk_recount_segments() (bnc#934430).
- blk-merge: recaculate segment if it isn't less than max segments
  (bnc#934430).
- blk-merge: don't compute bi_phys_segments from bi_vcnt for
  cloned bio (bnc#934430).
- blk-merge: fix blk_recount_segments (bnc#934430).
- block: add queue flag for disabling SG merging (bnc#934430).
- commit b577263
* Thu Aug 27 2015 jack@suse.com
- inotify: Fix nested sleeps in inotify_read() (bsc#940925).
- commit 8e70bfa
* Thu Aug 27 2015 mgorman@suse.com
- mm: filemap: Avoid unnecessary barriers and waitqueue lookups -fix
  (VM/FS Performance (bnc#941951)).
- commit 1f4a409
* Thu Aug 27 2015 jack@suse.com
- aio: fix reqs_available handling ((bsc#943378).
- commit e32ca1b
* Wed Aug 26 2015 mmarek@suse.com
- rpm/constraints.in: Require 14GB worth of disk space on POWER
  The builds started to fail randomly due to ENOSPC errors.
- commit 9012f40
* Wed Aug 26 2015 ddiss@suse.de
- rbd: add getxattr device attribute for debugging (fate#318836).
- rbd: add rbd_dev_getxattr() helper (fate#318836).
- ceph/osd_client: add support for CEPH_OSD_OP_GETXATTR
  (fate#318836).
- rbd: add cmpsetattr device attribute for debugging
  (fate#318836).
- rbd: add rbd_dev_cmpsetxattr helper (fate#318836).
- rbd: add setxattr device attribute for debugging (fate#318836).
- rbd: add rbd_dev_setxattr() helper (fate#318836).
- osd_client: send watch ping messages (fate#318836).
- osd_client: add support for notify payloads via notify event
  (fate#318836).
- osd_client, rbd: update event interface for watch/notify2
  (fate#318836).
- ceph/rbd: update watch-notify ceph_osd_op (fate#318836).
- ceph/rbd: add support for header version 2 and 3 (fate#318836).
- ceph/rbd: add support for watch notify payloads (fate#318836).
- commit cde9ca0
* Wed Aug 26 2015 jbeulich@suse.com
- x86/asm/entry/64: Remove pointless jump to irq_return
  (bsc#938706, CVE-2015-5157).
- x86/ldt: Make modify_ldt synchronous (bsc#938706,
  CVE-2015-5157).
- Do not reserve crashkernel high memory if crashkernel low
  memoryreserving failed (bsc#939145).
- x86/smpboot: Check for cpu_active on cpu initialization
  (bsc#932285).
- Update Xen patches to 3.12.46.
- Refresh patches.xen/xen3-patch-2.6.29 (bsc#942160).
- commit 9aef364
* Wed Aug 26 2015 jthumshirn@suse.de
- dm cache mq: fix memory allocation failure for large cache
  devices (bsc#942707).
- commit 345da98
* Mon Aug 24 2015 jslaby@suse.cz
- Linux 3.12.47 (CVE-2015-5157 CVE-2015-6252 bcn#851603 bsc#936875
  bsc#938706 bsc#939994 bsc#942367).
- kABI: protect struct mm_context_t.
- Refresh
  patches.drivers/0050-target-iscsi-Remove-macros-that-contain-typecasts.patch.
- Refresh
  patches.drivers/0163-rbd-initial-discard-bits-from-Guangliang-Zhao.patch.
- Refresh
  patches.drivers/0169-rbd-use-helpers-to-handle-discard-for-layered-images.patch.
- Refresh
  patches.fixes/futex-avoid-race-between-requeue-and-wake.patch.
- Refresh patches.kabi/kabi-protect-struct-iscsi_conn.patch.
- Refresh
  patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch.
- Refresh
  patches.suse/arch-Clean-up-asm-barrier.h-implementations-using-asm-generic-barrier.h.patch.
- Refresh
  patches.xen/xen3-08-x86-ldt-make-modify_ldt-synchronous.patch.
- Delete
  patches.arch/01-x86-asm-entry-64-fold-the-test_in_nmi-macro-into-its-only-user.patch.
- Delete
  patches.arch/02-x86-asm-entry-64-remove-a-redundant-jump.patch.
- Delete
  patches.arch/03-x86-asm-entry-64-remove-pointless-jump-to-irq_return.patch.
- Delete
  patches.arch/04-x86-nmi-enable-nested-do_nmi-handling-for-64-bit-kernels.patch.
- Delete
  patches.arch/05-x86-nmi-64-remove-asm-code-that-saves-cr2.patch.
- Delete
  patches.arch/06-x86-nmi-64-switch-stacks-on-userspace-nmi-entry.patch.
- Delete
  patches.arch/07-rcu-move-lockless_dereference-out-of-rcupdate-h.patch.
- Delete
  patches.arch/08-x86-ldt-make-modify_ldt-synchronous.patch.
- Delete patches.arch/ipr-Fix-incorrect-trace-indexing.patch.
- Delete
  patches.arch/ipr-Fix-invalid-array-indexing-for-HRRQ.patch.
- Delete
  patches.drivers/vhost-actually-track-log-eventfd-file.patch.
- Delete
  patches.fixes/0001-md-use-kzalloc-when-bitmap-is-disabled.patch.
- Delete patches.fixes/0001-st-null-pointer-deref-panic.patch.
- Delete
  patches.fixes/futex-Fix-a-race-condition-between-REQUEUE_PI-and-task-death.patch.
- Delete
  patches.suse/arch-Introduce-smp_load_acquire-smp_store_release.patch.
- Delete
  patches.xen/xen3-03-x86-asm-entry-64-remove-pointless-jump-to-irq_return.patch.
- commit 7fa26d2
* Mon Aug 24 2015 oneukum@suse.com
- supported.conf: support UAS to let all storage devices work without kernel-extra
- commit c8843c5
* Mon Aug 24 2015 oneukum@suse.com
- uas: Set max_sectors_240 quirk for ASM1053 devices (bnc#934942).
- uas: Add US_FL_MAX_SECTORS_240 flag (bnc#934942).
- uas: Reduce number of function arguments for uas_alloc_foo
  functions (bnc#934942).
- USB: storage: use %%*ph specifier to dump small buffers
  (bnc#934942).
- uas: Add response iu handling (bnc#934942).
- uas: Log error codes when logging errors (bnc#934942).
- uas: Cleanup uas_log_cmd_state usage (bnc#934942).
- uas: Remove support for old sense ui as used in pre-production
  hardware (bnc#934942).
- uas: Drop COMMAND_COMPLETED flag (bnc#934942).
- uas: Use scsi_print_command (bnc#934942).
- uas: Do not log urb status error on cancellation (bnc#934942).
- uas: pre_reset and suspend: Fix a few races (bnc#934942).
- uas: Fix memleak of non-submitted urbs (bnc#934942).
- uas: Drop all references to a scsi_cmnd once it has been aborted
  (bnc#934942).
- uas: Remove cmnd reference from the cmd urb (bnc#934942).
- uas: Drop inflight list (bnc#934942).
- uas: zap_pending: data urbs should have completed at this time
  (bnc#934942).
- UAS: fixup for remaining use of dead_list (bnc#934942).
- uas: Simplify reset / disconnect handling (bnc#934942).
- uas: Free data urbs on completion (bnc#934942).
- uas: Simplify unlink of data urbs on error (bnc#934942).
- uas: Check against unexpected completions (bnc#934942).
- uas: Do not use scsi_host_find_tag (bnc#934942).
- uas: Add uas_get_tag() helper function (bnc#934942).
- uas: Fix resetting flag handling (bnc#934942).
- uas: Remove task-management / abort error handling code
  (bnc#934942).
- uas: Do not log urb status error on cancellation (bnc#934942).
- commit eda04d9
* Fri Aug 21 2015 mhocko@suse.cz
- mm: make page pfmemalloc check more robust (bnc#920016).
- kabi:
  patches.fixes/mm-make-page-pfmemalloc-check-more-robust.patch
  (bnc#920016).
- Refresh
  patches.suse/mm-implement-split-page-table-lock-for-PMD-level.patch.
- Refresh
  patches.suse/mm-place-page-pmd_huge_pte-to-right-union.patch.
- commit 5417818
* Fri Aug 21 2015 bp@suse.com
- vhost: actually track log eventfd file (bsc#942367, CVE-2015-6252).
- commit 143c442
* Fri Aug 21 2015 fdmanana@suse.com
- Btrfs: fix hang when failing to submit bio of directIO
  (bnc#942685).
- Btrfs: fix memory corruption on failure to submit bio for
  direct IO (bnc#942685).
- Btrfs: fix put dio bio twice when we submit dio bio fail
  (bnc#942685).
- commit 566ea57
* Fri Aug 21 2015 mkubecek@suse.cz
- netfilter: nf_conntrack_proto_sctp: minimal multihoming support
  (bsc#932350).
- commit 3ba33c9
* Thu Aug 20 2015 fdmanana@suse.com
- Btrfs: fix file corruption after cloning inline extents
  (bnc#942512).
- Btrfs: fix uninit variable in clone ioctl (bnc#942511).
- Btrfs: fix range cloning when same inode used as source and
  destination (bnc#942511).
- Btrfs: check if previous transaction aborted to avoid fs
  corruption (bnc#942509).
- commit b666fce
* Wed Aug 19 2015 tonyj@suse.de
- audit: don't generate loginuid log when audit disabled
  (bsc#941098).
  Eliminate duplicate audit sections in series.conf (no
  code changes)
- commit 3be96b5
* Wed Aug 19 2015 hare@suse.de
- lpfc: Fix scsi prep dma buf error (bsc#908950).
- commit 2439d05
* Tue Aug 18 2015 mmarek@suse.com
- kconfig: Do not print status messages in make -s mode (bnc#942160).
- commit 9e2e20f
* Tue Aug 18 2015 jjolly@suse.de
- s390/dasd: fix kernel panic when alias is set offline
  (bnc#940965, LTC#128595).
- commit c0d279c
* Tue Aug 18 2015 noel.power@suse.com
- cifs: Send a logoff request before removing a smb session
  (bnc#941332).
- commit eb3c189
* Tue Aug 18 2015 jslaby@suse.cz
- Refresh
  patches.arch/08-x86-ldt-make-modify_ldt-synchronous.patch.
  Update upstream status.
- commit 0c3e7a7
* Tue Aug 18 2015 neilb@suse.com
- Move kabi fix to patches.kabi
- KABI fix - cannot add vs_rpcb_optnl field (fate#316311).
- Renamed from
  patches.fixes/0001-SUNRPC-NFSD-Support-a-new-option-for-ignoring-the-re.kabi-fix.
- commit eafdf36
* Mon Aug 17 2015 mmarek@suse.com
- series.conf: Delete stale comments
- commit cc40b91
* Mon Aug 17 2015 oneukum@suse.com
- Refresh
  patches.drivers/0001-xhci-Blacklist-using-streams-on-the-Etron-EJ168-cont.patch.
- Refresh
  patches.drivers/0002-xhci-Rename-Asrock-P67-pci-product-id-to-EJ168.patch.
- Refresh
  patches.drivers/usbcore-Fix-wrong-device-in-an-error-message-in-hub_.
- Delete
  patches.drivers/0044-xhci-Prevent-runtime-pm-from-autosuspending-during-i.patch.
  (bnc#940295)
- commit 555738d
* Mon Aug 17 2015 neilb@suse.com
- KABI fix - cannot add vs_rpcb_optnl field (fate#316311).
- commit d6e6930
* Mon Aug 17 2015 neilb@suse.com
- SUNRPC/NFSD: Support a new option for ignoring the result of
  svc_register (fate#316311).
- commit 0e00ce2
* Fri Aug 14 2015 dvaleev@suse.com
- ipr: Fix incorrect trace indexing (bsc#940912).
- ipr: Fix invalid array indexing for HRRQ (bsc#940912).
- commit f09f991
* Fri Aug 14 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.38-39 (bnc#904177
  bnc#909309 bnc#915200 bsc#918620 bnc#922275 FATE#306586
  bnc#915322 CVE-2014-7822).
- Delete patches.fixes/splice-add-generic_write_checks.patch.
  Remove duplicated check.
- commit d594094
* Thu Aug 13 2015 jjolly@suse.de
- Removed redundant s390 patches
  - Delete patches.arch/s390-sles12-08-02-smp-detect-possible-cpus.
  - Delete patches.arch/s390-sles12-16-03-00-revert-smp-detect-possible-cpus.patch.
- commit aee809d
* Wed Aug 12 2015 ddiss@suse.de
- Fix patch headers for 0061-net-remove-unnecessary-return-s.patch
- commit 369809b
* Wed Aug 12 2015 mgalbraith@suse.de
- hrtimer: prevent timer interrupt DoS (bnc#886785).
- commit 4c02b31
* Wed Aug 12 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8208-fix-list-transaction-pending_ordered-corruptio.patch.
- commit 3b94c2b
* Wed Aug 12 2015 ddiss@suse.de
- supported: add target_core_rbd
  Ship LIO rbd backend module (fate#318836).
- commit da71c21
* Wed Aug 12 2015 jslaby@suse.cz
- Refresh
  patches.drivers/uas-replace-WARN_ON_ONCE-with-lockdep_assert_held.patch.
  Make it clear it is a partial upstream commit.
- commit 1910b5d
* Wed Aug 12 2015 ddiss@suse.de
- config/x86_64: set CONFIG_TCM_RBD=m
  Enable the LIO clustered RBD backend (fate#318836).
- commit 47a1fee
* Tue Aug 11 2015 ddiss@suse.de
- target: add lio rbd to makefile/Kconfig (fate#318836).
- target: add rbd backend (fate#318836).
- rbd: move structs used by lio rbd to new header (fate#318836).
- rbd: export some functions used by lio rbd backend
  (fate#318836).
- libceph: fix pr_fmt compile issues (fate#318836).
- target: add COMPARE_AND_WRITE sg creation helper (fate#318836).
- target: compare and write backend driver sense handling
  (fate#318836).
- target: add compare and write callback (fate#318836).
- rbd: add support for writesame requests (fate#318836).
- libceph: add support for write same requests (fate#318836).
- rbd: add support for COMPARE_AND_WRITE/CMPEXT (fate#318836).
- rbd: add num ops calculator helper (fate#318836).
- rbd: add write test helper (fate#318836).
- libceph: add support for CMPEXT compare extent requests
  (fate#318836).
- libceph: support bidirectional requests (fate#318836).
- rbd: add lio specific data area (fate#318836).
- rbd: add support for scatterlist obj_request_type (fate#318836).
- libceph: add scatterlist messenger data type (fate#318836).
- iscsi-target: Add tpg_enabled_sendtargets for disabled discovery
  (fate#318836).
- target/configfs: handle match_int() errors (fate#318836).
- target: Remove set-but-not-used-variables (fate#318836).
- commit 7eca887
* Tue Aug 11 2015 ddiss@suse.de
- target: correctly handle match_int errors in FILEIO + PSCSI
  (fate#318836).
- commit da54421
* Tue Aug 11 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.21-22 (bnc#855126
  bnc#868315 bnc#870618 bnc#873061 bnc#879452 bnc#880613).
- Update patches.kernel.org/patch-3.12.22-23 (CVE-2014-0131
  CVE-2014-3917 bnc#867723 bnc#879258 bnc#880484 bnc#881535).
- Update patches.kernel.org/patch-3.12.3-4 (fate#315482
  bnc#844513).
- Update patches.kernel.org/patch-3.12.6-7 (fate#315482
  bnc#833097).
  Cleanup References tag.
- commit 6f2292e
* Mon Aug 10 2015 mmarek@suse.com
- Fix headers in patches.fixes/dlm-fix-missing-endian-conversion-of-rcom_status-fla.patch
- commit 13bfed3
* Fri Aug  7 2015 rgoldwyn@suse.com
- dlm: fix missing endian conversion of rcom_status flags
  patches.fixes/dlm-fix-missing-endian-conversion-of-rcom_status-fla.patch:
  (bsc#940679).
- commit b427d3a
* Fri Aug  7 2015 jthumshirn@suse.de
- SCSI: fix regression in scsi_send_eh_cmnd() (bsc#930813).
- commit e33844f
* Fri Aug  7 2015 jlee@suse.com
- i2c: i801: Check if interrupts are disabled (fate#318514).
- i2c: i801: Fallback to polling if request_irq() fails
  (fate#318514).
- i2c: i801: Add Device IDs for Intel Sunrise Point PCH
  (fate#318514).
- i2c: i801: Use wait_event_timeout to wait for interrupts
  (fate#318514).
- i2c: i801: Add PCI ID for Intel Braswell (fate#318514).
- i2c: i801: Add device ID for Intel Wildcat Point PCH
  (fate#318514).
- i2c: i801: Fix the alignment of the device table (fate#318514).
- ahci: Remove Device ID for Intel Sunrise Point PCH
  (fate#318514).
- commit 903056e
* Wed Aug  5 2015 tiwai@suse.de
- ALSA: hda - Abort the probe without i915 binding for HSW/BDW
  (bsc#936556).
- commit 148a933
* Wed Aug  5 2015 tiwai@suse.de
- [SCSI] vmw_pvscsi: Fix pvscsi_abort() function (bnc#940398).
- commit d7cdc6a
* Wed Aug  5 2015 tiwai@suse.de
- kABI workaround for ieee80211_ops.flush argument change
  (bsc#940545).
- iwlwifi: dvm: drop non VO frames when flushing (bsc#940545).
- mac80211: add vif to flush call (bsc#940545).
- commit c011204
* Tue Aug  4 2015 jslaby@suse.cz
- Linux 3.12.46 (CVE-2015-4692 FATE#317347 FATE#317933 bnc#876699
  bnc#884840 bnc#902898 bnc#935542 bsc#927697 bsc#928131
  bsc#936556 bsc#937613).
- kABI: protect struct iscsi_conn.
- Refresh
  patches.drivers/0008-usbfs-Add-support-for-allocating-freeing-streams.patch.
- Refresh
  patches.drivers/0025-usbcore-rename-struct-dev_state-to-struct-usb_dev_st.patch.
- Refresh
  patches.drivers/0050-target-iscsi-Remove-macros-that-contain-typecasts.patch.
- Refresh
  patches.drivers/0060-ib_isert-Add-support-for-completion-interrupt-coales.patch.
- Refresh
  patches.drivers/0121-IB-isert-Avoid-frwr-notation-user-fastreg.patch.
- Refresh
  patches.drivers/0139-iser-target-Fix-command-leak-for-tx_desc-comp_llnode.patch.
- Refresh
  patches.drivers/be2iscsi-invalidate-wrb-in-abort-reset-path.
- Refresh
  patches.drivers/hda-0045-hdmi-apply-Valleyview-fix-ups-to-Cherryview.
- Refresh
  patches.suse/btrfs-0054-simplify-kmalloc-copy_from_user-to-memdup_user.patch.
- Refresh
  patches.suse/btrfs-0130-sanitize-btrfs_IOC_FILE_EXTENT_SAME.patch.
- Refresh patches.suse/kgr-0048-kgr-mark-even-more-kthreads.patch.
- Delete
  patches.arch/kvm-x86-fix-kvm_apic_has_events-to-check-for-NULL-po.
- Delete
  patches.arch/s390-sles12-kexec-0001-kexec-allocate-the-kexec-control-page-with-kexec_control_memory_gfp.patch.
- Delete patches.drivers/ALSA-usb-audio-Fix-deadlocks-at-resuming.
- Delete
  patches.drivers/ALSA-usb-audio-Resume-mixer-values-properly.
- Delete
  patches.drivers/ALSA-usb-audio-Save-mixer-status-only-once-at-suspen.
- Delete
  patches.drivers/hda-0036-Add-dock-pin-setups-for-Thinkpad-T440.
- Delete
  patches.drivers/hda-0039-Treat-zero-connection-as-non-error.
- Delete
  patches.drivers/hda-0041-Add-Device-IDs-for-Intel-Sunrise-Poin.
- Delete
  patches.drivers/hda-0042-Add-DeviceIDs-for-Sunrise-Point-LP.
- Delete
  patches.drivers/hda-0043-verify-pin-cvt-connection-on-preparing-a-st.
- Delete patches.drivers/hda-0046-Separate-stream_tag-for-input.
- Delete
  patches.drivers/hda-0047-apply-the-Seperate-stream_tag-for-Sky.
- Delete
  patches.drivers/hda-0048-apply-the-Seperate-stream_tag-for-Sun.
- Delete
  patches.drivers/hda-0049-add-codec-ID-for-Skylake-display-audio-code.
- Delete
  patches.drivers/hda-0050-hdmi-apply-Haswell-fix-ups-to-Skylake-displ.
- Delete
  patches.drivers/vTPM-set-virtual-device-before-passing-to-ibmvtpm_re.patch.
- Delete
  patches.fixes/reiserfs-Fix-use-after-free-in-journal-teardown.patch.
- Delete
  patches.suse/btrfs-8205-fix-memory-leak-in-the-extent-same-ioctl.patch.
- commit 170828b
* Tue Aug  4 2015 mmarek@suse.cz
- Update s390x kabi files after gcc update (bsc#924525)
- commit af5924a
* Mon Aug  3 2015 tiwai@suse.de
- mfd: lpc_ich: Assign subdevice ids automatically (bnc#898159).
- commit 44027be
* Mon Aug  3 2015 jroedel@suse.de
- Do not reserve crashkernel high memory if crashkernel low
  memory reserving failed (bsc#939145).
- commit 0d645e7
* Mon Aug  3 2015 neilb@suse.com
- md: use kzalloc() when bitmap is disabled (bsc#939994).
- commit ff3e893
* Fri Jul 31 2015 bp@suse.com
- Refresh
  patches.arch/08-x86-ldt-make-modify_ldt-synchronous.patch.
- commit b8bb358
* Thu Jul 30 2015 jdelvare@suse.de
- megaraid_sas: Handle firmware initialization after fast boot
  (bsc#922071).
- commit 39909fc
* Thu Jul 30 2015 neilb@suse.com
- NFSv4: don't set SETATTR for O_RDONLY|O_EXCL (bsc#939716).
- commit b09c4f0
* Wed Jul 29 2015 jslaby@suse.cz
- Refresh patches.fixes/0001-st-null-pointer-deref-panic.patch.
  Update upstream status.
- commit ff000a7
* Wed Jul 29 2015 bp@suse.com
- Refresh
  patches.arch/08-x86-ldt-make-modify_ldt-synchronous.patch.
- commit 7c36f62
* Tue Jul 28 2015 jslaby@suse.cz
- Linux 3.12.45 (CVE-2015-1805 CVE-2015-3212 CVE-2015-4167
  bnc#866911 bnc#880612 bnc#884893 bnc#907092 bnc#913466
  bnc#933117 bsc#914818 bsc#932793 bsc#933429 bsc#933907
  bsc#935881 bsc#935918 bsc#936502).
- Refresh
  patches.drivers/0005-Input-synaptics-support-min-max-board-id-in-min_max_.patch.
- Refresh
  patches.drivers/0013-Input-synaptics-remove-X1-Carbon-3rd-gen-from-the-to.patch.
- Refresh
  patches.drivers/0014-Input-synaptics-remove-X250-from-the-topbuttonpad-li.patch.
- Refresh
  patches.drivers/drm-mgag200-Don-t-use-crtc_-parameters-for-validation.patch.
- Refresh patches.drivers/hpsa-0013-Remove-unused-PCI-IDs.patch.
- Refresh
  patches.suse/btrfs-0003-drop-unused-parameter-from-btrfs_item_nr.patch.
- Refresh
  patches.suse/btrfs-0214-add-support-for-inode-properties.patch.
- Refresh
  patches.suse/cpuidle-Use-actual-state-latency-in-menu-governor.patch.
- Delete patches.drivers/drm-i915-Evict-CS-TLBs-between-batches.
- Delete
  patches.drivers/drm-i915-Fix-DDC-probe-for-passive-adapters.
- Delete
  patches.drivers/drm-i915-Handle-failure-to-kick-out-a-conflicting-fb.
- Delete
  patches.drivers/drm-i915-drop-WaSetupGtModeTdRowDispatch-snb.
- Delete
  patches.drivers/drm-i915-hsw-Fix-workaround-for-server-AUX-channel-c.
- Delete
  patches.drivers/drm-i915-save-restore-GMBUS-freq-across-suspend-resu.
- Delete patches.drivers/lpfc-Add-iotag-memory-barrier.patch.
- Delete patches.drivers/pcc_cpufreq_acpi_modalias.patch.
- Delete
  patches.fixes/PCI-pciehp-Add-hotplug_lock-to-serialize-hotplug-eve.patch.
- Delete patches.fixes/get-rid-of-s_files-and-files_lock.patch.
- Delete
  patches.fixes/iommu-amd-handle-large-pages-correctly-in-free_pagetable.
- Delete
  patches.fixes/ipr-Increase-default-adapter-init-stage-change-timeout.patch.
- Delete
  patches.fixes/pipe-fix-iov-overrun-for-failed-atomic-copy.patch.
- Delete patches.fixes/sctp-fix-ASCONF-list-handling.patch.
- Delete
  patches.fixes/udf-Check-length-of-extended-attributes-and-allocati.patch.
- Delete patches.fixes/udf-Remove-repeated-loads-blocksize.patch.
- Delete
  patches.fixes/uninline-destroy_super-consolidate-alloc_super.patch.
- Delete
  patches.fixes/x86-PCI-Use-host-bridge-_CRS-info-on-Foxconn-K8M890.
- Delete
  patches.fixes/x86-PCI-Use-host-bridge-_CRS-info-on-systems-with-32.
- Delete
  patches.fixes/xfrm-release-dst_orig-in-case-of-error-in-xfrm_looku.patch.
- Delete
  patches.suse/btrfs-8167-make-xattr-replace-operations-atomic.patch.
- Delete
  patches.suse/btrfs-8202-cleanup-orphans-while-looking-up-default-subvolume.patch.
- Delete
  patches.suse/cpuidle-menu-Return-1-if-there-are-no-suitable-states.patch.
- Delete
  patches.suse/msft-hv-0581-HID-hyperv-make-sure-input-buffer-is-big-enough.patch.
- commit 84dc441
* Tue Jul 28 2015 mgalbraith@suse.de
- sched: Fix KMALLOC_MAX_SIZE overflow during cpumask allocation (bnc#939266).
- commit f0e04b9
* Sun Jul 26 2015 jjolly@suse.de
- kernel/kvm: Fix MSA3/MSA4 detection (bsc#936916, LTC#127868).
- zcrypt: Fixed reset and interrupt handling of AP queues
  (bsc#936916, LTC#126491).
- kernel/kvm: Fix MSA3/MSA4 detection (bsc#936916, LTC#127868).
- zcrypt: Fixed reset and interrupt handling of AP queues
  (bsc#936916, LTC#126491).
- commit 7aaa5bf
* Fri Jul 24 2015 bpoirier@suse.com
- Remove stray space (" ") after Git-commit tags.
- commit b0e6e2f
* Fri Jul 24 2015 dvaleev@suse.com
- Unbreak kABI after disabling HIBERNATION on Power (bsc#938934).
- commit c91e564
* Fri Jul 24 2015 neilb@suse.com
- md: fix problems with freeing private data after ->run failure
  (bnc#912183).
- md: remove mddev_lock from rdev_attr_show() (bnc#912183).
- md: remove mddev_lock() from md_attr_show() (bnc#912183).
- md/raid5: use ->lock to protect accessing raid5 sysfs attributes
  (bnc#912183).
- md: remove need for mddev_lock() in md_seq_show() (bnc#912183).
- md/bitmap: protect clearing of ->bitmap by mddev->lock
  (bnc#912183).
- md: protect ->pers changes with mddev->lock (bnc#912183).
- md: level_store: group all important changes into one place
  (bnc#912183).
- md: split detach operation out from ->stop (bnc#912183).
- commit 15fa15a
* Thu Jul 23 2015 bp@suse.com
- x86/asm/entry/64: Fold the 'test_in_nmi' macro into its only
  user (bsc#938706, CVE-2015-5157).
- x86/asm/entry/64: Remove a redundant jump (bsc#938706,
  CVE-2015-5157).
- x86/asm/entry/64: Remove pointless jump to irq_return
  (bsc#938706, CVE-2015-5157).
- x86/nmi: Enable nested do_nmi() handling for 64-bit kernels
  (bsc#938706, CVE-2015-5157).
- x86/nmi/64: Remove asm code that saves cr2 (bsc#938706,
  CVE-2015-5157).
- x86/nmi/64: Switch stacks on userspace NMI entry (bsc#938706,
  CVE-2015-5157).
- Refresh patches.arch/x86_64-unwind-annotations.
- Delete
  patches.arch/x86-nmi-64-switch-stacks-on-userspace-nmi-entry.patch.
- commit 2a86802
* Tue Jul 21 2015 dvaleev@suse.com
- Update config files.
  Disable CONFIG_HIBERNATION on Power, due compile failures with latest
  binutils (bsc#938934)
- commit 19f8985
* Tue Jul 21 2015 jkosina@suse.com
- Input: synaptics - re-route tracksticks buttons on the Lenovo 2015 series - Input: synaptics: dump ext10 capabilities as well.
  This patch removes original (and dysfunctional) support for trackstick
  buttons on X1 Carbon, and replaces it with a working version from
  the same from upstream.
- commit 8c05c53
* Tue Jul 21 2015 jkosina@suse.com
- Input: synaptics - remove X250 from the topbuttonpad list.
- Input: synaptics - remove X1 Carbon 3rd gen from the topbuttonpad list (bsc#929092).
- Input: synaptics - do not retrieve the board id on old firmwares (bsc#929092).
- Input: synaptics - skip quirks when post-2013 dimensions (bsc#929092).
- Input: synaptics - support min/max board id in min_max_pnpid_table (bsc#929092).
- Input: synaptics - remove obsolete min/max quirk for X240 (bsc#929092).
- Input: synaptics - query min dimensions for fw v8.1.
- Input: synaptics - log queried and quirked dimension values (bsc#929092).
- Input: synaptics - split synaptics_resolution(), query first (bsc#929092).
- commit 43c87bf
* Tue Jul 21 2015 fdmanana@suse.com
- Btrfs: fix list transaction->pending_ordered corruption
  (bnc#938893).
- Btrfs: fix race between balance and unused block group deletion
  (bnc#938892).
- Btrfs: fix crash on close_ctree() if cleaner starts new
  transaction (bnc#938891).
- commit e2ad876
* Tue Jul 21 2015 fdmanana@suse.com
- Rename patch files to conform to existing naming convention
  All btrfs patch file names start with the patten "btrfs-NNNN-"...
- btrfs: Handle unaligned length in extent_same (bsc#937609).
- btrfs: pass unaligned length to btrfs_cmp_data() (bsc#937609).
- btrfs: fix deadlock with extent-same and readpage (bsc#937612).
- btrfs: fix clone / extent-same deadlocks (bsc#937612).
- btrfs: don't update mtime/ctime on deduped inodes (bsc#937616).
- Btrfs: fix memory leak in the extent_same ioctl (bsc#937613).
- Delete
  patches.suse/btrfs-Handle-unaligned-length-in-extent_same.patch.
- Delete
  patches.suse/btrfs-don-t-update-mtime-ctime-on-deduped-inodes.patch.
- Delete patches.suse/btrfs-fix-clone-extent-same-deadlocks.patch.
- Delete
  patches.suse/btrfs-fix-deadlock-with-extent-same-and-readpage.patch.
- Delete
  patches.suse/btrfs-fix-memory-leak-in-the-extent-same-ioctl.patch.
- Delete
  patches.suse/btrfs-pass-unaligned-length-to-btrfs_cmp_data.patch.
- commit 9e7bc81
* Mon Jul 20 2015 jeffm@suse.com
- cleanup: Update Patch headers for Xen
  Update headers for Patch-mainline, Git-commit, and Git-repo, removing
  references to maintainer branches were appropriate.  This iteration
  fixes Xen patches.  Many of the patches had invalid tags and others,
  like the autogenerated xen3* patches, inherited tags from their
  upstream counterparts incorrectly.
- commit f08fe10
* Sat Jul 18 2015 jeffm@suse.com
- cleanup: Update Patch headers
  Update headers for Patch-mainline, Git-commit, and Git-repo, removing
  references to maintainer branches were appropriate.  This iteration
  fixes "almost-there" tags.
  Newer commit rules mandate -p ab format and no timestamps, so any
  modified patches have been updated to meet those rules as well.
- commit b9975b2
* Fri Jul 17 2015 fdmanana@suse.com
- Btrfs: fix wrong check for btrfs_force_chunk_alloc()
  (bnc#938550).
- Btrfs: fix chunk allocation regression leading to transaction
  abort (bnc#938550).
- Btrfs: fix find_free_dev_extent() malfunction in case device
  tree has hole (bnc#938550).
- commit 256f005
* Fri Jul 17 2015 jroedel@suse.de
- kernel/modsign_uefi.c: Check for EFI_RUNTIME_SERVICES in
  load_uefi_certs (fate#314574, bsc#856382).
- commit 6594736
* Thu Jul 16 2015 ohering@suse.de
- Drivers: hv: vmbus: prefer 'die' notification chain to 'panic'.
- Drivers: hv: vmbus: add special crash handler.
- Drivers: hv: don't do hypercalls when hypercall_page is NULL.
- Drivers: hv: vmbus: add special kexec handler.
- commit bd06042
* Thu Jul 16 2015 ohering@suse.de
- kexec: define kexec_in_progress in !CONFIG_KEXEC case.
- Refresh patches.xen/xen-x86-panic-no-reboot.
- commit 57424ee
* Thu Jul 16 2015 ohering@suse.de
- Drivers: hv: vmbus: remove hv_synic_free_cpu() call from
  hv_synic_cleanup().
- commit fae3f8c
* Thu Jul 16 2015 dsterba@suse.com
- Backport subvolume mount option handling (bsc#934962)
- btrfs: allow mounting btrfs subvolumes with different ro/rw
  options.
- btrfs: fix use-after-free in mount_subvol().
- btrfs: cleanup orphans while looking up default subvolume
  (bsc#914818).
- Btrfs: lock superblock before remounting for rw subvol
  (bsc#934962).
- Btrfs: remove all subvol options before mounting top-level
  (bsc#934962).
- Btrfs: clean up error handling in mount_subvol() (bsc#934962).
- Btrfs: fail on mismatched subvol and subvolid mount options
  (bsc#934962).
- Btrfs: unify subvol= and subvolid= mounting (bsc#934962).
- Btrfs: show subvol= and subvolid= in /proc/mounts (bsc#934962).
- Delete
  patches.suse/btrfs-cleanup-orphans-while-looking-up-default-subvolume.patch.
- commit 57550cb
* Thu Jul 16 2015 jroedel@suse.de
- x86/smpboot: Check for cpu_active on cpu initialization
  (bsc#936773).
- commit e6cfdfc
* Wed Jul 15 2015 jjolly@suse.de
- kexec: allocate the kexec control page with
  KEXEC_CONTROL_MEMORY_GFP (bsc#928131).
- Refresh patches.xen/xen3-auto-common.diff.
- commit e85faeb
* Wed Jul 15 2015 jjolly@suse.de
- IB/mlx4: Fix wrong usage of IPv4 protocol for multicast
  attach/detach (bsc#918618).
- commit 0cf6012
* Wed Jul 15 2015 ohering@suse.de
- Update patch header for netdev_alloc_pcpu_stats change
- commit 5bfe12c
* Wed Jul 15 2015 dvaleev@suse.com
- vTPM: set virtual device before passing to ibmvtpm_reset_crq
  (bsc#937087).
- commit 50929d8
* Tue Jul 14 2015 ohering@suse.de
- Initialize hv_netvsc_packet->xmit_more to avoid transfer stalls
- commit 951c5da
* Tue Jul 14 2015 oneukum@suse.com
- usb: core: Fix USB 3.0 devices lost in NOTATTACHED state after
  a hub port reset (bnc#938024).
- commit 8dc98c4
* Tue Jul 14 2015 fdmanana@suse.com
- Btrfs: fix use after free when close_ctree frees the orphan_rsv
  (bnc#938022).
- commit 391ca7d
* Tue Jul 14 2015 fdmanana@suse.com
- Btrfs: add missing inode item update in fallocate()
  (bnc#938023).
- commit 4f61a73
* Tue Jul 14 2015 fdmanana@suse.com
- Btrfs: fix fsync data loss after append write (bnc#936446).
- commit d07af05
* Tue Jul 14 2015 ohering@suse.de
- Drivers: hv: vmbus: Use the vp_index map even for channels
  bound to CPU 0.
- Drivers: hv: balloon: check if ha_region_mutex was acquired
  in MEM_CANCEL_ONLINE case.
- Drivers: hv: vmbus:Update preferred vmbus protocol version to
  windows 10.
- hv_netvsc: Allocate the sendbuf in a NUMA aware way.
- hv_netvsc: Allocate the receive buffer from the correct
  NUMA node.
- Drivers: hv: vmbus: distribute subchannels among all vcpus.
- Drivers: hv: vmbus: move init_vp_index() call to
  vmbus_process_offer().
- Drivers: hv: vmbus: decrease num_sc on subchannel removal.
- Drivers: hv: vmbus: briefly comment num_sc and next_oc.
- Drivers: hv: vmbus: unify calls to percpu_channel_enq().
- Drivers: hv: vmbus: kill tasklets on module unload.
- Drivers: hv: vmbus: do cleanup on all vmbus_open() failure
  paths.
- commit 885c493
* Tue Jul 14 2015 ohering@suse.de
- Drivers: hv: vmbus: Implement the protocol for tearing down
  vmbus state.
- commit 014d009
* Tue Jul 14 2015 ohering@suse.de
- drivers: hv: vmbus: Get rid of some unused definitions.
- hv: vmbus_free_channels(): remove the redundant free_channel().
- Drivers: hv: vmbus: unregister panic notifier on module unload.
- Drivers: hv: vmbus: introduce vmbus_acpi_remove.
- Drivers: hv: util: introduce hv_utils_transport abstraction.
- Drivers: hv: fcopy: set .owner reference for file operations.
- Drivers: hv: fcopy: switch to using the hvutil_device_state
  state machine.
- Drivers: hv: vss: switch to using the hvutil_device_state
  state machine.
- Drivers: hv: kvp: switch to using the hvutil_device_state
  state machine.
- Drivers: hv: util: introduce state machine for util drivers.
- Drivers: hv: fcopy: rename fcopy_work -> fcopy_timeout_work.
- Drivers: hv: kvp: rename kvp_work -> kvp_timeout_work.
- Drivers: hv: vss: process deferred messages when we complete
  the transaction.
- Drivers: hv: fcopy: process deferred messages when we complete
  the transaction.
- Drivers: hv: kvp: move poll_channel() to hyperv_vmbus.h.
- Drivers: hv: kvp: reset kvp_context.
- Drivers: hv: util: move kvp/vss function declarations to
  hyperv_vmbus.h.
- hv_netvsc: change member name of struct netvsc_stats.
- hv_netvsc: use per_cpu stats to calculate TX/RX data.
- hv_netvsc: Use the xmit_more skb flag to optimize signaling
  the host.
- commit ddd5e7b
* Tue Jul 14 2015 ohering@suse.de
- Update a hv patch so that init_vp_index prototype follows upstream after an upstream mismerge in v3.16
- commit 7f2effd
* Tue Jul 14 2015 mmarek@suse.com
- Update s390x kabi files with netfilter change (bnc#936012)
- commit d7dd6f5
* Tue Jul 14 2015 ohering@suse.de
- Drivers: hv: util: Fix a bug in the KVP code.
  reapply upstream change ontop of v3.12-stable change
- commit 973e147
* Tue Jul 14 2015 ohering@suse.de
- netdev_alloc_pcpu_stats: use less common iterator variable.
- netdev: set __percpu attribute on netdev_alloc_pcpu_stats.
- net: introduce netdev_alloc_pcpu_stats() for drivers.
- commit b31262d
* Mon Jul 13 2015 jeffm@suse.com
- cleanup: Update Patch headers
  Update headers for Patch-mainline, Git-commit, and Git-repo, removing
  references to maintainer branches were appropriate.
  Newer commit rules mandate -p ab format and no timestamps, so any
  modified patches have been updated to meet those rules as well.
- commit 0911be8
* Mon Jul 13 2015 jack@suse.com
- jbd2: improve error messages for inconsistent journal heads
  (bsc#935174).
- commit ded0809
* Mon Jul 13 2015 jack@suse.com
- jbd2: revise KERN_EMERG error messages (bsc#935174).
- ext4: fix over-defensive complaint after journal abort
  (bsc#935174).
- commit e7cfabd
* Fri Jul 10 2015 jroedel@suse.de
- x86/mm: Improve AMD Bulldozer ASLR workaround (bsc#937032).
- commit 26b7abc
* Fri Jul 10 2015 bpoirier@suse.com
- vmxnet3: Bump up driver version number (bsc#936423).
- commit bbdb933
* Fri Jul 10 2015 bpoirier@suse.com
- Refresh
  patches.drivers/mpt3sas-0008-Added-Reply-Descriptor-Post-Queue-RDPQ-Array.patch.
  patch file has whitespace breakage
- commit fb02d28
* Fri Jul 10 2015 mfasheh@suse.de
- Btrfs: fix memory leak in the extent_same ioctl (bsc#937613).
- btrfs: don't update mtime/ctime on deduped inodes (bsc#937616).
- btrfs: fix clone / extent-same deadlocks (bsc#937612).
- btrfs: fix deadlock with extent-same and readpage (bsc#937612).
- btrfs: pass unaligned length to btrfs_cmp_data() (bsc#937609).
- btrfs: Handle unaligned length in extent_same (bsc#937609).
- commit b538808
* Wed Jul  8 2015 mkubecek@suse.cz
- xfrm: release dst_orig in case of error in xfrm_lookup()
  (bsc#932793).
- commit 9bbf193
* Wed Jul  8 2015 mkubecek@suse.cz
- sctp: fix ASCONF list handling (bsc#936502 CVE-2015-3212).
- commit 9143cb9
* Tue Jul  7 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8191-fix-hang-during-inode-eviction-due-to-concurre.patch.
- Refresh
  patches.suse/btrfs-8192-fix-block-group-space_info-null-pointer-derefe.patch.
- commit 6f4d8cc
* Tue Jul  7 2015 fdmanana@suse.com
- Btrfs: check pending chunks when shrinking fs to avoid
  corruption (bnc#936445).
- commit 75d108b
* Tue Jul  7 2015 ddiss@suse.de
- Update libceph kabi files
  s390x and ppc64le aren't configured to build libceph, so can be ignored.
- commit ed4718f
* Tue Jul  7 2015 ddiss@suse.de
- Revert "libceph: clear r_req_lru_item in
  __unregister_linger_request()" (fate#318918).
- libceph: announce support for straw2 buckets (fate#318918).
- libceph: enable PRIMARY_AFFINITY feature bit (fate#318918).
- crush: straw2 bucket type with an efficient 64-bit crush_ln()
  (fate#318918).
- crush: ensuring at most num-rep osds are selected (fate#318918).
- crush: drop unnecessary include from mapper.c (fate#318918).
- libceph: simplify our debugfs attr macro (fate#318918).
- libceph: expose client options through debugfs (fate#318918).
- libceph, ceph: split ceph_show_options() (fate#318918).
- rbd: mark block queue as non-rotational (fate#318918).
- libceph: don't overwrite specific con error msgs (fate#318918).
- libceph: osdmap.h: Add missing format newlines (fate#318918).
- rbd: be more informative on -ENOENT failures (fate#318918).
- Revert "libceph: use memalloc flags for net IO" (fate#318918).
- libceph: kfree() in put_osd() shouldn't depend on authorizer
  (fate#318918).
- libceph: tcp_nodelay support (fate#318918).
- rbd: do not treat standalone as flatten (fate#318918).
- rbd: fix error paths in rbd_dev_refresh() (fate#318918).
- rbd: nuke copy_token() (fate#318918).
- libceph: use mon_client.c/put_generic_request() more
  (fate#318918).
- libceph: nuke pool op infrastructure (fate#318918).
- libceph: fix sparse endianness warnings (fate#318918).
- libceph: fixup includes in pagelist.h (fate#318918).
- libceph: specify position of extent operation (fate#318918).
- libceph: add CREATE osd operation support (fate#318918).
- libceph: add SETXATTR/CMPXATTR osd operations support
  (fate#318918).
- rbd: don't treat CEPH_OSD_OP_DELETE as extent op (fate#318918).
- libceph: require cephx message signature by default
  (fate#318918).
- libceph: update ceph_msg_header structure (fate#318918).
- libceph: message signature support (fate#318918).
- libceph: store session key in cephx authorizer (fate#318918).
- rbd: delete unnecessary checks before two function calls
  (fate#318918).
- libceph: nuke ceph_kvfree() (fate#318918).
- libceph: clear r_req_lru_item in __unregister_linger_request()
  (fate#318918).
- libceph: unlink from o_linger_requests when clearing r_osd
  (fate#318918).
- libceph: eliminate unnecessary allocation in
  process_one_ticket() (fate#318918).
- libceph: use memalloc flags for net IO (fate#318918).
- rbd: use a single workqueue for all devices (fate#318918).
- rbd: rbd workqueues need a resque worker (fate#318918).
- libceph: separate multiple ops with commas in debugfs output
  (fate#318918).
- libceph: sync osd op definitions in rados.h (fate#318918).
- libceph: remove redundant declaration (fate#318918).
- libceph: reference counting pagelist (fate#318918).
- rbd: set the remaining discard properties to enable support
  (fate#318918).
- rbd: use helpers to handle discard for layered images correctly
  (fate#318918).
- rbd: extract a method for adding object operations
  (fate#318918).
- rbd: make discard trigger copy-on-write (fate#318918).
- rbd: tolerate -ENOENT for discard operations (fate#318918).
- rbd: fix snapshot context reference count for discards
  (fate#318918).
- rbd: read image size for discard check safely (fate#318918).
- rbd: initial discard bits from Guangliang Zhao (fate#318918).
- rbd: extend the operation type (fate#318918).
- rbd: skip the copyup when an entire object writing
  (fate#318918).
- rbd: add img_obj_request_simple() helper (fate#318918).
- rbd: access snapshot context and mapping size safely
  (fate#318918).
- rbd: do not return -ERANGE on auth failures (fate#318918).
- libceph: don't try checking queue_work() return value
  (fate#318918).
- libceph: Convert pr_warning to pr_warn (fate#318918).
- libceph: fix a use after free issue in osdmap_set_max_osd
  (fate#318918).
- libceph: select CRYPTO_CBC in addition to CRYPTO_AES
  (fate#318918).
- libceph: resend lingering requests with a new tid (fate#318918).
- libceph: abstract out ceph_osd_request enqueue logic
  (fate#318918).
- rbd: fix error return code in rbd_dev_device_setup()
  (fate#318918).
- rbd: avoid format-security warning inside alloc_workqueue()
  (fate#318918).
- rbd: remove extra newlines from rbd_warn() messages
  (fate#318918).
- rbd: allocate img_request with GFP_NOIO instead GFP_ATOMIC
  (fate#318918).
- rbd: rework rbd_request_fn() (fate#318918).
- rbd: take snap_id into account when reading in parent info
  (fate#318918).
- rbd: do not read in parent info before snap context
  (fate#318918).
- rbd: update mapping size only on refresh (fate#318918).
- rbd: harden rbd_dev_refresh() and callers a bit (fate#318918).
- rbd: split rbd_dev_spec_update() into two functions
  (fate#318918).
- rbd: remove unnecessary asserts in rbd_dev_image_probe()
  (fate#318918).
- rbd: introduce rbd_dev_header_info() (fate#318918).
- rbd: show the entire chain of parent images (fate#318918).
- rbd: use rbd_segment_name_free() instead of kfree()
  (fate#318918).
- rbd: do not leak image_id in rbd_dev_v2_parent_info()
  (fate#318918).
- libceph: drop osd ref when canceling con work (fate#318918).
- libceph: nuke ceph_osdc_unregister_linger_request()
  (fate#318918).
- rbd: use rbd_obj_watch_request_helper() helper (fate#318918).
- rbd: add rbd_obj_watch_request_helper() helper (fate#318918).
- rbd: rbd_obj_request_wait() should cancel the request if
  interrupted (fate#318918).
- libceph: introduce ceph_osdc_cancel_request() (fate#318918).
- libceph: fix linger request check in __unregister_request()
  (fate#318918).
- libceph: unregister only registered linger requests
  (fate#318918).
- libceph: harden ceph_osdc_request_release() a bit (fate#318918).
- libceph: move and add dout()s to ceph_osdc_request_{get,put}()
  (fate#318918).
- libceph: move and add dout()s to ceph_msg_{get,put}()
  (fate#318918).
- libceph: add maybe_move_osd_to_lru() and switch to it
  (fate#318918).
- libceph: rename ceph_osd_request::r_linger_osd to
  r_linger_osd_item (fate#318918).
- ceph: remove bogus extern (fate#318918).
- rbd: only set disk to read-only once (fate#318918).
- rbd: move calls that may sleep out of spin lock range
  (fate#318918).
- rbd: add ioctl for rbd (fate#318918).
- rbd: fix ida/idr memory leak (fate#318918).
- rbd: fix osd_request memory leak in
  __rbd_dev_header_watch_sync() (fate#318918).
- rbd: make sure we have latest osdmap on 'rbd map' (fate#318918).
- libceph: add ceph_monc_wait_osdmap() (fate#318918).
- libceph: mon_get_version request infrastructure (fate#318918).
- libceph: recognize poolop requests in debugfs (fate#318918).
- rbd: replace IS_ERR and PTR_ERR with PTR_ERR_OR_ZERO
  (fate#318918).
- ceph_sync_read: stop poking into iov_iter guts (fate#318918).
- crush: decode and initialize chooseleaf_vary_r (fate#318918).
- libceph: fix non-default values check in
  apply_primary_affinity() (fate#318918).
- libceph: dump pool {read,write}_tier to debugfs (fate#318918).
- libceph: output primary affinity values on osdmap updates
  (fate#318918).
- libceph: redo ceph_calc_pg_primary() in terms of
  ceph_calc_pg_acting() (fate#318918).
- libceph: add support for osd primary affinity (fate#318918).
- libceph: add support for primary_temp mappings (fate#318918).
- libceph: return primary from ceph_calc_pg_acting()
  (fate#318918).
- libceph: switch ceph_calc_pg_acting() to new helpers
  (fate#318918).
- libceph: introduce apply_temps() helper (fate#318918).
- libceph: introduce pg_to_raw_osds() and raw_to_up_osds()
  helpers (fate#318918).
- libceph: ceph_can_shift_osds(pool) and pool type defines
  (fate#318918).
- libceph: ceph_osd_{exists,is_up,is_down}(osd) definitions
  (fate#318918).
- libceph: enable OSDMAP_ENC feature bit (fate#318918).
- libceph: primary_affinity decode bits (fate#318918).
- libceph: primary_affinity infrastructure (fate#318918).
- libceph: primary_temp decode bits (fate#318918).
- libceph: primary_temp infrastructure (fate#318918).
- libceph: generalize ceph_pg_mapping (fate#318918).
- libceph: introduce get_osdmap_client_data_v() (fate#318918).
- libceph: introduce decode{,_new}_pg_temp() and switch to them
  (fate#318918).
- libceph: switch osdmap_set_max_osd() to krealloc()
  (fate#318918).
- libceph: introduce decode{,_new}_pools() and switch to them
  (fate#318918).
- libceph: rename __decode_pool{,_names}() to
  decode_pool{,_names}() (fate#318918).
- libceph: fix and clarify ceph_decode_need() sizes (fate#318918).
- libceph: nuke bogus encoding version check in
  osdmap_apply_incremental() (fate#318918).
- libceph: fixup error handling in osdmap_apply_incremental()
  (fate#318918).
- libceph: fix crush_decode() call site in osdmap_decode()
  (fate#318918).
- libceph: check length of osdmap osd arrays (fate#318918).
- libceph: safely decode max_osd value in osdmap_decode()
  (fate#318918).
- libceph: fixup error handling in osdmap_decode() (fate#318918).
- libceph: split osdmap allocation and decode steps (fate#318918).
- libceph: dump osdmap and enhance output on decode errors
  (fate#318918).
- libceph: dump pg_temp mappings to debugfs (fate#318918).
- libceph: do not prefix osd lines with \t in debugfs output
  (fate#318918).
- libceph: refer to osdmap directly in osdmap_show()
  (fate#318918).
- crush: support chooseleaf_vary_r tunable (tunables3) by default
  (fate#318918).
- crush: add SET_CHOOSELEAF_VARY_R step (fate#318918).
- crush: add chooseleaf_vary_r tunable (fate#318918).
- crush: allow crush rules to set (re)tries counts to 0
  (fate#318918).
- crush: fix off-by-one errors in total_tries refactor
  (fate#318918).
- libceph: fix oops in ceph_msg_data_{pages,pagelist}_advance()
  (fate#318918).
- rbd: prefix rbd writes with CEPH_OSD_OP_SETALLOCHINT osd op
  (fate#318918).
- rbd: num_ops parameter for rbd_osd_req_create() (fate#318918).
- libceph: bump CEPH_OSD_MAX_OP to 3 (fate#318918).
- libceph: add support for CEPH_OSD_OP_SETALLOCHINT osd op
  (fate#318918).
- libceph: encode CEPH_OSD_OP_FLAG_* op flags (fate#318918).
- rbd: remove out_partial label in rbd_img_request_fill()
  (fate#318918).
- libceph: a per-osdc crush scratch buffer (fate#318918).
- ceph: remove xattr when null value is given to setxattr()
  (fate#318918).
- net: remove unnecessary return's (fate#318918).
- libceph: support CEPH_FEATURE_OSD_CACHEPOOL feature
  (fate#318918).
- libceph: support CEPH_FEATURE_EXPORT_PEER (fate#318918).
- crush: support new indep mode and SET_* steps (crush v2)
  by default (fate#318918).
- commit 494329c
* Tue Jul  7 2015 jbohac@suse.cz
- Update patches.kernel.org/patch-3.12.43-44 (FATE#315482
  CVE-2015-4036 bnc#909684 bnc#927786 bnc#930599 bnc#931124
  bnc#931130 bsc#920805 bsc#930669 bsc#931014 bsc#931988
  bsc#936831 CVE-2015-5364 CVE-2015-5366).
- commit a962cc8
* Tue Jul  7 2015 ydfan@suse.com
- netfilter: xt_NFQUEUE: fix --queue-bypass regression (bsc#935083)
- commit e5fb229
* Fri Jul  3 2015 mmarek@suse.cz
- Remove stale comments from series.conf
- commit 3e47e8c
* Fri Jul  3 2015 jthumshirn@suse.de
- st: null pointer dereference panic caused by use after kref_put
  by st_open (bsc#936875).
- commit 8ba6653
* Thu Jul  2 2015 mfasheh@suse.de
- xfs: Skip dirty pages in ->releasepage (bnc#915183).
- commit ddb051a
* Thu Jul  2 2015 mszeredi@suse.cz
- ovl: default permissions (bsc#924071).
- commit 6c4cf57
* Thu Jul  2 2015 hare@suse.de
- NVMe: Add shutdown timeout as module parameter
  (bnc#936076,FATE#318544).
- commit 13d383b
* Wed Jul  1 2015 bpoirier@suse.com
- Update
  patches.drivers/vmxnet3-Changes-for-vmxnet3-adapter-version-2-fwd.patch
  (bsc#936423).
- Update
  patches.drivers/vmxnet3-Fix-memory-leaks-in-rx-path-fwd.patch
  (bsc#936423).
- Update
  patches.drivers/vmxnet3-Register-shutdown-handler-for-device-fwd.patch
  (bsc#936423).
  s/bug#/bsc#/
- commit 248c9ee
* Wed Jul  1 2015 bpoirier@suse.com
- vmxnet3: Changes for vmxnet3 adapter version 2 (fwd)
  (bug#936423).
- vmxnet3: Fix memory leaks in rx path (fwd) (bug#936423).
- vmxnet3: Register shutdown handler for device (fwd)
  (bug#936423).
- commit 83f5a9b
* Wed Jul  1 2015 jack@suse.com
- reiserfs: Fix use after free in journal teardown (bsc#927697).
- commit be5bda8
* Wed Jul  1 2015 ohering@suse.de
- Refresh hv patch to apply without fuzz on a SLE11 host
- commit aa4cb34
* Tue Jun 30 2015 tiwai@suse.de
- ALSA: hda_intel: add AZX_DCAPS_I915_POWERWELL for SKL and BSW
  (bsc#936556).
- ALSA: hda/hdmi - apply Haswell fix-ups to Skylake display codec
  (bsc#936556).
- ALSA: hda - add codec ID for Skylake display audio codec
  (bsc#936556).
- ALSA: hda_intel: apply the Seperate stream_tag for Sunrise Point
  (bsc#936556).
- ALSA: hda_intel: apply the Seperate stream_tag for Skylake
  (bsc#936556).
- ALSA: hda_controller: Separate stream_tag for input and output
  streams (bsc#936556).
- commit ddd7c1e
* Tue Jun 30 2015 mmarek@suse.cz
- Enable CONFIG_BRIDGE_NF_EBTABLES on s390x (bsc#936012)
- commit 15f78a1
* Tue Jun 30 2015 vbabka@suse.cz
- Refresh
  patches.fixes/mm-thp-respect-mpol_preferred-policy-with-non-local-node.patch.
- Refresh
  patches.fixes/mm-vmscan-do-not-throttle-based-on-pfmemalloc-reserves-if-node-has-no-reclaimable-pages.patch.
- commit 277b55f
* Fri Jun 26 2015 neilb@suse.com
- Fix connection reuse when sk_error_report is used (bnc#930972).
- commit 81f3df5
* Fri Jun 26 2015 neilb@suse.com
- SUNRPC: Report connection error values to rpc_tasks on the
  pending queue (bnc#930972).
- commit 5107caf
* Thu Jun 25 2015 tiwai@suse.de
- kvm: x86: fix kvm_apic_has_events to check for NULL pointer
  (bnc#935542,CVE-2015-4692).
- commit 37f067b
* Wed Jun 24 2015 mmarek@suse.cz
- Move kabi workarounds to patches.kabi
- commit ee803b1
* Wed Jun 24 2015 tiwai@suse.de
- drm/i915: Fix DDC probe for passive adapters (bsc#935918).
- drm/i915/hsw: Fix workaround for server AUX channel clock
  divisor (bsc#935918).
- drm/i915: Evict CS TLBs between batches (bsc#935918).
- drm/i915: save/restore GMBUS freq across suspend/resume on gen4
  (bsc#935918).
- drm/i915: Handle failure to kick out a conflicting fb driver
  (bsc#935918).
- drm/i915: drop WaSetupGtModeTdRowDispatch:snb (bsc#935918).
- commit 5edcfc5
* Wed Jun 24 2015 duwe@suse.de
- Update patches.drivers/hwrng-01-add-random-pool-input:
  half of the backport not only became unneccessary, but also
  caused bsc#931012. Undo it.
- commit 18d87da
* Wed Jun 24 2015 jroedel@suse.de
- iommu/amd: Handle large pages correctly in free_pagetable
  (bsc#935881).
- commit b90caa2
* Wed Jun 24 2015 ohering@suse.de
- Drivers: hv: vmbus: Permit sending of packets without payload.
- Drivers: hv: vmbus: Add device and vendor ID to vmbus devices.
- commit aeb1aa2
* Tue Jun 23 2015 mmarek@suse.cz
- Restore s390 config update
  It was not part of the reverted virtio series.
- commit ba1f468
* Tue Jun 23 2015 mmarek@suse.cz
- Revert s390/virtio series (bnc#931860, LTC#VS1256)
  The series is going to be reworked to not break the kabi on other
  architectures.
- commit 3381148
* Mon Jun 22 2015 vbabka@suse.cz
- mm, thp: respect MPOL_PREFERRED policy with non-local node
  (VM Performance, bnc#931620).
- mm, thp: really limit transparent hugepage allocation to local
  node (VM Performance, bnc#931620).
- mm/mempolicy.c: merge alloc_hugepage_vma to alloc_pages_vma
  (VM Performance, bnc#931620).
- mm/thp: allocate transparent hugepages on local node (VM
  Performance, bnc#931620).
- commit d2ca3d3
* Mon Jun 22 2015 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
  Add namespace to avoid clash with ext4.
- commit 0d0278e
* Mon Jun 22 2015 schwab@suse.de
- kernel-obs-build: add btrfs to initrd
  This is needed for kiwi builds.
- commit 1ebf037
* Fri Jun 19 2015 mkubecek@suse.cz
- net: fib6: fib6_commit_metrics: fix potential NULL pointer
  dereference (bsc#867362 FATE#318553).
- net: ipv6: fib: don't sleep inside atomic lock (bsc#867362
  FATE#318553).
- commit 6c47f10
* Thu Jun 18 2015 tiwai@suse.de
- x86/PCI: Use host bridge _CRS info on systems with >32 bit
  addressing (bnc#907092).
- x86/PCI: Use host bridge _CRS info on Foxconn K8M890-8237A
  (bnc#907092).
- commit e410b07
* Thu Jun 18 2015 ohering@suse.de
- hv: no rmmod for hv_vmbus and hv_utils.
- commit 1585cb2
* Thu Jun 18 2015 mkubecek@suse.cz
- ipv6: fix ECMP route replacement (bsc#930399).
- ipv6: do not delete previously existing ECMP routes if add fails
  (bsc#930399).
- commit 374ecee
* Wed Jun 17 2015 ohering@suse.de
- series.conf: remove empty lines
- commit dcfc44b
* Wed Jun 17 2015 ohering@suse.de
- hv_netvsc: remove unused variable in netvsc_send().
- hv_netvsc: Fix a bug in netvsc_start_xmit().
- hv_netvsc: introduce netif-msg into netvsc module.
- hv_netvsc: Implement partial copy into send buffer.
- hv_netvsc: try linearizing big SKBs before dropping them.
- hv_netvsc: use single existing drop path in netvsc_start_xmit.
- hv_netvsc: Fix the packet free when it is in skb headroom.
- hv_netvsc: Define a macro RNDIS_AND_PPI_SIZE.
- hv_netvsc: Clean up two unused variables.
- Drivers: hv: hv_balloon: correctly handle num_pages>INT_MAX
  case.
- Drivers: hv: hv_balloon: correctly handle val.freeram<num_pages
  case.
- hv_vmbus: Add gradually increased delay for retries in
  vmbus_post_msg().
- Drivers: hv: hv_balloon: survive ballooning request with
  num_pages=0.
- Drivers: hv: hv_balloon: eliminate jumps in piecewiese linear
  floor function.
- Drivers: hv: hv_balloon: do not online pages in offline blocks.
- hv: remove the per-channel workqueue.
- hv: don't schedule new works in
  vmbus_onoffer()/vmbus_onoffer_rescind().
- hv: run non-blocking message handlers in the dispatch tasklet.
- hv_netvsc: Eliminate memory allocation in the packet send path.
- hv_netvsc: Cleanup the test for freeing skb when we use
  sendbuf mechanism.
- hv_netvsc: remove vmbus_are_subchannels_present() in
  rndis_filter_device_add().
- hv_netvsc: Implement batching in send buffer.
- Drivers: hv: vmbus: Fix a siganlling host signalling issue.
- Drivers: hv: vmbus: Export the
  vmbus_sendpacket_pagebuffer_ctl().
- hv: hypervvssd: call endmntent before call setmntent again.
- Drivers: hv: vmbus: Fix a bug in rescind processing in
  vmbus_close_internal().
- hv: vmbus: missing curly braces in vmbus_process_offer().
- Drivers: hv: hv_balloon: don't lose memory when onlining order
  is not natural.
- Drivers: hv: hv_balloon: keep locks balanced on add_memory()
  failure.
- Drivers: hv: vmbus: Perform device register in the per-channel
  work element.
- hyperv: hyperv_fb: match wait_for_completion_timeout return
  type.
- mei: bus: () can be static.
- Drivers: hv: vmbus: Suport an API to send packet with additional
  control.
- Drivers: hv: vmbus: Suport an API to send pagebuffers with
  additional control.
- Drivers: hv: vmbus: Use a round-robin algorithm for picking
  the outgoing channel.
- Drivers: hv: hv_balloon: refuse to balloon below the floor.
- Drivers: hv: hv_balloon: report offline pages as being used.
- Drivers: hv: hv_balloon: eliminate the trylock path in
  acquire/release_region_mutex.
- Drivers: hv: vmbus: Get rid of some unnecessary messages.
- Drivers: hv: util: On device remove, close the channel after
  de-initializing the service.
- Drivers: hv: vmbus: Remove the channel from the channel list(s)
  on failure.
- Drivers: hv: vmbus: Handle both rescind and offer messages in
  the same context.
- Drivers: hv: vmbus: Introduce a function to remove a rescinded
  offer.
- Drivers: hv: vmbus: Properly handle child device remove.
- Drivers: hv: vmbus: Add support for the NetworkDirect GUID.
- hv: hv_balloon: match var type to return type of
  wait_for_completion.
- hv: channel: match var type to return type of
  wait_for_completion.
- hv: vmbus_open(): reset the channel state on ENOMEM.
- hv: vmbus_post_msg: retry the hypercall on some transient
  errors.
- hv: hv_util: move vmbus_open() to a later place.
- Drivers: hv: vmbus: Teardown clockevent devices on module
  unload.
- drivers: hv: vmbus: Teardown synthetic interrupt controllers
  on module unload.
- Drivers: hv: vmbus: teardown hv_vmbus_con workqueue and
  vmbus_connection pages on shutdown.
- Drivers: hv: vmbus: avoid double kfree for device_obj.
- Drivers: hv: vmbus: rename channel work queues.
- Drivers: hv: vmbus: prevent cpu offlining on newer hypervisors.
- hyperv: Implement netvsc_get_channels() ethool op.
- commit 1a0f8a0
* Wed Jun 17 2015 mmarek@suse.cz
- Update kabi files for s390x with changes from bnc#931860
  irq_stat and virtqueue_* are common symbols and should not be
  whitelisted in the severities file.
- commit c6498d4
* Wed Jun 17 2015 mmarek@suse.cz
- kabi/severities: Add s390 symbols allowed to change in bnc#931860
- commit e4c3e4a
* Wed Jun 17 2015 fdmanana@suse.com
- Btrfs: fix block group ->space_info null pointer dereference
  (bnc#935088).
- commit 81ca9b7
* Wed Jun 17 2015 fdmanana@suse.com
- Btrfs: fix hang during inode eviction due to concurrent
  readahead (bnc#935085).
- commit 19fc16d
* Wed Jun 17 2015 jbeulich@suse.com
- Update patches.xen/xen-blkfront-indirect (bsc#922235).
- Refresh other Xen patches.
- commit c291db3
* Wed Jun 17 2015 ohering@suse.de
- Adjust hv_netvsc patch to match mainline commit for followup
  changes to apply
- commit 76d265c
* Tue Jun 16 2015 jroedel@suse.de
- kvm: irqchip: Break up high order allocations of kvm_irq_routing_table (bsc#926953).
- commit eaf199d
* Tue Jun 16 2015 jjolly@suse.de
- Update config files.
- commit f7108e1
* Tue Jun 16 2015 jack@suse.cz
- udf: Check length of extended attributes and allocation
  descriptors (bsc#933907 CVE-2015-4167).
- udf: Remove repeated loads blocksize (bsc#933907).
- commit 6a8efef
* Tue Jun 16 2015 jack@suse.cz
- Update references in patches.kernel.org/patch-3.12.37-38 (CVE-2014-3647
  CVE-2014-3690 FATE#316038 bnc#800255 bnc#856659 bnc#873901
  bnc#876731 bnc#882900 bnc#899192 bnc#901090 bnc#901809
  bnc#902232 bnc#904659 bnc#907969 bnc#907970 bsc#911181
  bsc#913233 bsc#915188 bfo#71370 bnc#907325 bnc#915210
  bsc#916225 CVE-2015-1465 CVE-2014-9731 bsc#933904 CVE-2014-9728
  CVE-2014-9729 CVE-2014-9730).
- commit 567851c
* Tue Jun 16 2015 jjolly@suse.de
- s390/airq: silence lockdep warning (bnc#931860, LTC#VS1256).
- virtio_scsi: don't call virtqueue_add_sgs(... GFP_NOIO)
  holding spinlock (bnc#931860, LTC#VS1256).
- virtio_ccw: introduce device_lost in virtio_ccw_device
  (bnc#931860, LTC#VS1256).
- virtio: virtio_break_device() to mark all virtqueues broken
  (bnc#931860, LTC#VS1256).
- s390/sclp_vt220: Fix kernel panic due to early terminal input
  (bnc#931860, LTC#VS1256).
- virtio: fail adding buffer on broken queues (bnc#931860,
  LTC#VS1256).
- virtio-rng: don't crash if virtqueue is broken (bnc#931860,
  LTC#VS1256).
- virtio_net: don't crash if virtqueue is broken (bnc#931860,
  LTC#VS1256).
- virtio_ccw: fix hang in set offline processing (bnc#931860,
  LTC#VS1256).
- virtio-ccw: virtio-ccw adapter interrupt support (bnc#931860,
  LTC#VS1256).
- s390/irq: improve displayed interrupt order in /proc/interrupts
  (bnc#931860, LTC#VS1256).
- virtio_ccw: fix vcdev pointer handling issues (bnc#931860,
  LTC#VS1256).
- s390/airq: add support for irq ranges (bnc#931860, LTC#VS1256).
- KVM: s390: virtio-ccw: Handle command rejects (bnc#931860,
  LTC#VS1256).
- virtio_scsi: verify if queue is broken after virtqueue_get_buf()
  (bnc#931860, LTC#VS1256).
- virtio_ring: adapt to notify() returning bool (bnc#931860,
  LTC#VS1256).
- virtio_net: verify if queue is broken after virtqueue_get_buf()
  (bnc#931860, LTC#VS1256).
- virtio_blk: verify if queue is broken after virtqueue_get_buf()
  (bnc#931860, LTC#VS1256).
- virtio_ring: add new function virtqueue_is_broken() (bnc#931860,
  LTC#VS1256).
- virtio_ring: let virtqueue_{kick()/notify()} return a bool
  (bnc#931860, LTC#VS1256).
- virtio_ring: change host notification API (bnc#931860,
  LTC#VS1256).
- virtio_ring: plug kmemleak false positive (bnc#931860,
  LTC#VS1256).
- commit 5d09447
* Tue Jun 16 2015 jjolly@suse.de
- s390: z13 base performance (bnc#929879, LTC#KRN1514).
- s390/mm: limit STACK_RND_MASK for compat tasks (bnc#929879,
  LTC#KRN1514).
- s390/mm: align 64-bit PIE binaries to 4GB (bnc#929879,
  LTC#KRN1514).
- s390: avoid z13 cache aliasing (bnc#929879, LTC#KRN1514).
- s390: add z13 code generation support (bnc#929879, LTC#KRN1514).
- s390/kernel: use stnsm 255 instead of stosm 0 (bnc#929879,
  LTC#KRN1514).
- s390/time: use stck clock fast for do_account_vtime (bnc#929879,
  LTC#KRN1514).
- s390/spinlock: optimize spin_unlock code (bnc#929879,
  LTC#KRN1514).
- s390/spinlock: refactor arch_spin_lock_wait[_flags] (bnc#929879,
  LTC#KRN1514).
- s390/rwlock: add missing local_irq_restore calls (bnc#929879,
  LTC#KRN1514).
- s390/spinlock,rwlock: always to a load-and-test first
  (bnc#929879, LTC#KRN1514).
- s390/spinlock: optimize spinlock code sequence (bnc#929879,
  LTC#KRN1514).
- s390/spinlock: cleanup spinlock code (bnc#929879, LTC#KRN1514).
- s390: fix control register update (bnc#929879, LTC#KRN1514).
- s390: optimize control register update (bnc#929879,
  LTC#KRN1514).
- s390/smp: only send external call ipi if needed (bnc#929879,
  LTC#KRN1514).
- s390/compat,signal: change return values to -EFAULT (bnc#929879,
  LTC#KRN1514).
- s390: Remove zfcpdump NR_CPUS dependency (bnc#929879,
  LTC#KRN1514).
- commit 0b62016
* Tue Jun 16 2015 jjolly@suse.de
- ftrace: add oco handling patch (bnc#924526, LTC#123020).
- s390/ftrace: hotpatch support for function tracing (bnc#924526,
  LTC#123020).
- ftrace: let notrace function attribute disable hotpatching if
  necessary (bnc#924526, LTC#123020).
- ftrace: allow architectures to specify ftrace compile options
  (bnc#924526, LTC#123020).
- ftrace: revert oco handling patch (bnc#924526, LTC#123020).
- commit 0b9864c
* Tue Jun 16 2015 mszeredi@suse.cz
- ovl: move s_stack_depth .
- commit a91debf
* Tue Jun 16 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Change BuildRequires to match OBS's taste
- commit 15501f0
* Tue Jun 16 2015 mszeredi@suse.cz
- Refresh patches.suse/ovl01-vfs-add-i_op-dentry_open.patch.
- Refresh
  patches.suse/ovl02-vfs-export-do_splice_direct-to-modules.patch.
- Refresh
  patches.suse/ovl03-vfs-export-inode_permission-to-modules.patch.
- Refresh
  patches.suse/ovl04-vfs-introduce-clone_private_mount.patch.
- Refresh
  patches.suse/ovl09-fs-limit-filesystem-stacking-depth.patch.
- commit bab82c3
* Tue Jun 16 2015 ohering@suse.de
- Drivers: hv: vmbus: Correcting truncation error for constant
  HV_CRASH_CTL_CRASH_NOTIFY (bnc#934160).
- Drivers: hv: vmbus: Add support for VMBus panic notifier handler
  (bnc#934160).
- commit b947acb
* Tue Jun 16 2015 jack@suse.cz
- Update references in patches.kernel.org/patch-3.12.37-38 (CVE-2014-3647
  CVE-2014-3690 FATE#316038 bnc#800255 bnc#856659 bnc#873901
  bnc#876731 bnc#882900 bnc#899192 bnc#901090 bnc#901809
  bnc#902232 bnc#904659 bnc#907969 bnc#907970 bsc#911181
  bsc#913233 bsc#915188 bfo#71370 bnc#907325 bnc#915210 bsc#916225
  CVE-2015-1465 CVE-2014-9731).
- commit 3f07c61
* Tue Jun 16 2015 mgalbraith@suse.de
- sched: fix __sched_setscheduler() vs load balancing race (bnc#921430)
- commit ce60a92
* Mon Jun 15 2015 mkubecek@suse.cz
- Update patches.fixes/kernel-add-panic_on_warn.patch references
  (bsc#934742).
- commit 140e45b
* Fri Jun 12 2015 mcgrof@suse.com
- PCI: pciehp: Add hotplug_lock to serialize hotplug events (bnc#866911).
- commit 130b9e6
* Thu Jun 11 2015 jeffm@suse.com
- xfs: fix xfs_setattr for DMAPI (bsc#932900).
- commit 0b77781
* Thu Jun 11 2015 jeffm@suse.com
- xfs_dmapi: fix transaction ilocks (bsc#932899).
- commit 44675fe
* Thu Jun 11 2015 jeffm@suse.com
- xfs_dmapi: xfs_dm_rdwr() uses dir file ops not file's ops
  (bsc#932898).
- commit 1c6ab4b
* Thu Jun 11 2015 mszeredi@suse.cz
- pipe: fix iov overrun for failed atomic copy (bsc#933429
  CVE-2015-1805).
- commit 998e0d6
* Wed Jun 10 2015 jslaby@suse.cz
- Linux 3.12.44 (FATE#315482 CVE-2015-4036 bnc#909684 bnc#927786
  bnc#930599 bnc#931124 bnc#931130 bsc#920805 bsc#930669
  bsc#931014 bsc#931988).
- Revert "libata: Ignore spurious PHY event on LPM policy change".
- Refresh
  patches.arch/0015-ACPI-scan-Define-non-empty-device-removal-handler.patch.
- Refresh
  patches.drivers/qla2xxx-0088-Fix-warning-reported-by-smatch.patch.
- Refresh
  patches.fixes/crypto-rng-RNGs-must-return-0-in-success-case.
- Refresh
  patches.fixes/crypto-testmgr-fix-RNG-return-code-enforcement.
- Refresh patches.fixes/kapi-fix-move-of-d_rcu.patch.
- Refresh
  patches.suse/mm-numa-add-sysctl-for-numa-balancing.patch.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.34.
- Delete patches.fixes/cifs-fix-corrupt-SMB2-ioctl-requests.patch.
- Delete
  patches.fixes/fork-report-pid-reservation-failure-properly.patch.
- Delete
  patches.fixes/iommu-amd-correctly-encode-huge-pages-in-iommu-page-tables.
- Delete
  patches.fixes/iommu-amd-optimize-alloc_new_range-for-new-fetch_pte-interface.
- Delete
  patches.fixes/iommu-amd-optimize-amd_iommu_iova_to_phys-for-new-fetch_pte-interface.
- Delete
  patches.fixes/iommu-amd-optimize-iommu_unmap_page-for-new-fetch_pte-interface.
- Delete
  patches.fixes/iommu-amd-return-the-pte-page-size-in-fetch_pte.
- Delete
  patches.fixes/libata-Blacklist-queued-TRIM-on-all-Samsung-800-seri.
- Delete
  patches.fixes/powerpc-mm-fix-mmap-errno-when-map_fixed-is-set-and-mapping-exceeds-the-allowed-address-space.
- Delete patches.fixes/rtlwifi-rtl8192cu-Fix-kernel-deadlock.
- Delete
  patches.fixes/vhost-scsi-potential-memory-corruption.patch.
- Delete
  patches.suse/mm-numa-Initialse-numa-balancing-after-jump-label-initialisation.patch.
- Delete
  patches.suse/mm-numa-really-disable-NUMA-balancing-by-default-on-single-node-machines.patch.
- Delete
  patches.suse/suse-hv-storvsc-Set-the-SRB-flags-correctly-when-no-data-tra.patch.
- commit b4b3a0b
* Wed Jun 10 2015 jthumshirn@suse.de
- Update
  patches.drivers/mpt2sas-0001-Added-driver-module-parameter-max_msix_vecto.patch.
- Refresh
  patches.drivers/mpt2sas-0002-Added-new-driver-module-Parameter-disable_ee.patch.
- Refresh
  patches.drivers/mpt2sas-0003-MPI2-Rev-Y-2.00.17-and-Rev-Z-2.00.18-specifi.patch.
- Refresh
  patches.drivers/mpt2sas-0004-Copyright-in-driver-sources-is-updated-for-y.patch.
- Refresh
  patches.drivers/mpt2sas-0005-Clear-PFA-Status-on-SGPIO-when-PFA-Drive-is-.patch.
- Refresh
  patches.drivers/mpt2sas-0006-driver-version-to-17.100.00.00.patch.
- mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array  support
  (FATE#315931,bnc#854824).
- Refresh
  patches.drivers/mpt2sas-0009-Get-IOC_FACTS-information-using-handshake-pr.patch.
- Refresh
  patches.drivers/mpt2sas-0011-driver-version-to-18.100.00.00.patch.
- Refresh
  patches.drivers/mpt2sas-Rework-the-MSI-X-grouping-code.patch.
- commit 537dcf2
* Wed Jun 10 2015 mkubecek@suse.cz
- kernel: add panic_on_warn.
- commit 5ab4b95
* Tue Jun  9 2015 mszeredi@suse.cz
- Revert "pipe: fix iov overrun for failed atomic copy (bsc#933429"
  This reverts commit e78dab2aaadde863f20bcc97eb64e05ff5ba1cac.
- commit b5367ed
* Tue Jun  9 2015 jthumshirn@suse.de
- Refresh
  patches.drivers/mpt3sas-0002-MPI2.5-Rev-G-2.5.2-specifications.patch.
- Refresh
  patches.drivers/mpt3sas-0003-Clear-PFA-Status-on-SGPIO-when-PFA-Drive-is-.patch.
- mpt3sas: Bump mpt3sas driver version to 03.100.00.00
  (FATE#315932,bnc#854817).
- Refresh patches.drivers/mpt3sas-0005-MPI2.5-Rev-H-2.5.3-specifications.patch.
- Refresh patches.drivers/mpt3sas-0006-Copyright-in-driver-sources-is-updated-for-y.patch.
- Refresh patches.drivers/mpt3sas-0007-Added-OEM-branding-Strings.patch.
- Refresh patches.drivers/mpt3sas-0008-Added-Reply-Descriptor-Post-Queue-RDPQ-Array.patch.
- mpt3sas: Bump mpt3sas driver version to 04.100.00.00
  (FATE#315932,bnc#854817).
- commit e71d160
* Mon Jun  8 2015 mszeredi@suse.cz
- pipe: fix iov overrun for failed atomic copy (bsc#933429
  CVE-2015-1805).
- commit e78dab2
* Mon Jun  8 2015 jroedel@suse.de
- iommu/amd: Handle integer overflow in dma_ops_area_alloc
  (bsc#931538).
- commit 3577969
* Mon Jun  8 2015 jlee@suse.com
- MODSIGN: loading keys from db when SecureBoot disabled
  (bnc#929696).
- commit 2f38379
* Sun Jun  7 2015 bpoirier@suse.com
- net/mlx4_en: Call register_netdevice in the proper location
  (bnc#858727).
- net/mlx4_en: Don't attempt to TX offload the outer UDP checksum
  for VXLAN (bnc#858727).
- commit ce15a55
* Fri Jun  5 2015 fdmanana@suse.com
- Btrfs: fix race when reusing stale extent buffers that leads
  to BUG_ON (bsc#926369).
- commit c503362
* Fri Jun  5 2015 trenn@suse.de
- cpufreq: pcc: Enable autoload of pcc-cpufreq for ACPI processors
  (bnc#933117).
- Delete patches.drivers/pcc_cpufreq_modalias.patch.
- commit e95077e
* Fri Jun  5 2015 neilb@suse.de
- Remove sp1-only patches
- Delete
  patches.suse/0001-NFSv4.1-Don-t-trust-attributes-if-a-pNFS-LAYOUTCOMMI.patch.
- Delete
  patches.suse/0002-NFSv4.1-Fix-a-race-in-nfs4_write_inode.patch.
- Delete
  patches.suse/0003-NFSv4.1-Fix-wraparound-issues-in-pnfs_seqid_is_newer.patch.
- Delete
  patches.suse/0004-NFSv4-Don-t-update-the-open-stateid-unless-it-is-new.patch.
- Delete
  patches.suse/0005-NFSv4.1-Ensure-that-the-layout-recall-callback-match.patch.
- Delete
  patches.suse/0006-NFSv4.1-Minor-optimisation-in-get_layout_by_fh_locke.patch.
- Delete
  patches.suse/0007-NFSv4.1-Ensure-that-we-free-existing-layout-segments.patch.
- Delete patches.suse/0008-nfs-commit-layouts-in-fdatasync.patch.
- Delete
  patches.suse/0009-nfs-cap-request-size-to-fit-a-kmalloced-page-array.patch.
- Delete
  patches.suse/0010-pnfs-do-not-pass-uninitialized-lsegs-to-free_lseg.patch.
- Delete
  patches.suse/0011-pnfs-don-t-check-sequence-on-new-stateids-in-layoutg.patch.
- Delete
  patches.suse/0012-pnfs-retry-after-a-bad-stateid-error-from-layoutget.patch.
- Delete
  patches.suse/0013-pnfs-avoid-using-stale-stateids-after-layoutreturn.patch.
- Delete
  patches.suse/0014-pnfs-allow-splicing-pre-encoded-pages-into-the-layou.patch.
- Delete
  patches.suse/0015-pnfs-blocklayout-reject-pnfs-blocksize-larger-than-p.patch.
- Delete
  patches.suse/0016-pnfs-blocklayout-improve-GETDEVICEINFO-error-reporti.patch.
- Delete
  patches.suse/0017-pnfs-blocklayout-plug-block-queues.patch.
- Delete
  patches.suse/0018-pnfs-blocklayout-correctly-decrement-extent-length.patch.
- Delete
  patches.suse/0019-pnfs-force-a-layout-commit-when-encountering-busy-se.patch.
- Delete
  patches.suse/0020-pnfs-add-flag-to-force-read-modify-write-in-write_be.patch.
- Delete patches.suse/0021-pnfs-add-return_range-method.patch.
- Delete
  patches.suse/0022-pnfs-blocklayout-remove-read-modify-write-handling-i.patch.
- Delete
  patches.suse/0023-pnfs-blocklayout-don-t-set-pages-uptodate.patch.
- Delete
  patches.suse/0024-pnfs-blocklayout-rewrite-extent-tracking.patch.
- Delete
  patches.suse/0025-pnfs-blocklayout-implement-the-return_range-method.patch.
- Delete
  patches.suse/0026-pnfs-blocklayout-return-layouts-on-setattr.patch.
- Delete
  patches.suse/0027-pnfs-factor-GETDEVICEINFO-implementations.patch.
- Delete
  patches.suse/0028-pnfs-add-a-common-GETDEVICELIST-implementation.patch.
- Delete
  patches.suse/0029-pnfs-add-a-nfs4_get_deviceid-helper.patch.
- Delete
  patches.suse/0030-pnfs-blocklayout-use-the-device-id-cache.patch.
- Delete
  patches.suse/0031-pnfs-blocklayout-remove-some-debugging.patch.
- Delete
  patches.suse/0032-pnfs-remove-GETDEVICELIST-implementation.patch.
- Delete
  patches.suse/0033-pnfs-blocklayout-allocate-separate-pages-for-the-lay.patch.
- Delete
  patches.suse/0034-pnfs-blocklayout-move-extent-processing-to-blocklayo.patch.
- Delete
  patches.suse/0035-pnfs-blocklayout-refactor-extent-processing.patch.
- Delete
  patches.suse/0036-pnfs-blocklayout-move-all-rpc_pipefs-related-code-in.patch.
- Delete
  patches.suse/0037-pnfs-blocklayout-in-kernel-GETDEVICEINFO-XDR-parsing.patch.
- Delete
  patches.suse/0038-pnfs-enable-CB_NOTIFY_DEVICEID-support.patch.
- Delete
  patches.suse/0039-pNFS-blocklayout-Remove-a-couple-of-unused-variables.patch.
- Delete
  patches.suse/0040-pnfs-blocklayout-include-vmalloc.h-for-__vmalloc.patch.
- Delete
  patches.suse/0041-pnfs-blocklayout-Fix-a-64-bit-division-remainder-iss.patch.
- commit 77389dd
* Fri Jun  5 2015 mhocko@suse.cz
- hugetlb, kabi: do not account hugetlb pages as NR_FILE_PAGES
  (bnc#930092).
- commit 6aa7a00
* Fri Jun  5 2015 mmarek@suse.cz
- Delete disabled patches that have not been updated for years
- Delete
  patches.arch/kvm-only-export-selected-pv-ops-feature-structs.
- Delete
  patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic.
- Delete patches.arch/kvm-split-paravirt-ops-by-functionality.
- Delete patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature.
- Delete patches.arch/ppc64-xmon-dmesg-printing.patch.
- Delete patches.suse/ppc-no-LDFLAGS_MODULE.patch.
- commit a84dd48
* Thu Jun  4 2015 noel.power@suse.com
- client MUST ignore EncryptionKeyLength if CAP_EXTENDED_SECURITY
  is set (bnc#932348).
- commit b52ede7
* Thu Jun  4 2015 jeffm@suse.com
- supported.conf: add btrfs to kernel-$flavor-base (bsc#933637)
- commit 12e3144
* Thu Jun  4 2015 jkosina@suse.cz
- series.conf: fix bisectability
  x86-be-more-informative-when-signalling-an-SMEP-fault.patch depends on
  struct *pgd being brought into show_fault_oops() by
  x86-mm-pageattr-always-dump-the-right-page-table-in-an-oops.patch. Noticed
  by Jean Delvare.
- commit 8110ce1
* Thu Jun  4 2015 jeffm@suse.com
- kabi: only use sops->get_inode_dev with proper fsflag.
- btrfs: provide super_operations->inode_get_dev (bsc#927455).
- vfs: add super_operations->get_inode_dev (bsc#927455).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- Delete patches.suse/btrfs-use-correct-device-for-maps.patch.
- commit 18ebe27
* Wed Jun  3 2015 dvaleev@suse.com
- ipr: Increase default adapter init stage change timeout
  (bsc#930579).
- powerpc/pseries: Correct cpu affinity for dlpar added cpus
  (bsc #932967).
- commit 6dd43bb
* Wed Jun  3 2015 jslaby@suse.cz
- x86/kgr: move kgr infrastructure from asm to C (fate#313296).
- s390/kgr: reorganize kgr infrastructure in entry64.S
  (fate#313296).
- kgr: move kgr_task_in_progress() to sched.h (fate#313296).
- kgr: send a fake signal to all blocking tasks (fate#313296).
- kgr: remove immediate feature (fate#313296).
- Refresh patches.xen/xen3-patch-2.6.18.
- commit cd4e6a9
* Wed Jun  3 2015 mmarek@suse.cz
- Revert "MODSIGN: loading keys from db when SecureBoot disabled"
  This reverts commit b45412d4, because it breaks legacy boot.
- commit baebb7a
* Wed Jun  3 2015 dvaleev@suse.com
- powerpc: Fill in si_addr_lsb siginfo field (bsc#929475).
- powerpc: Add VM_FAULT_HWPOISON handling to powerpc page fault
  handler (bsc#929475).
- powerpc: Simplify do_sigbus (bsc#929475).
- commit 39f7de3
* Tue Jun  2 2015 jack@suse.cz
- dmapi: fix value from newer Linux strnlen_user() (bsc#932897).
- xfs_dmapi: fix value from newer Linux strnlen_user()
  (bsc#932897).
- commit 44ce692
* Tue Jun  2 2015 dvaleev@suse.com
- KVM: PPC: BOOK3S: HV: CMA: Reserve cma region only in hypervisor
  mode (bsc#908491).
- commit 5c27b37
* Tue Jun  2 2015 jslaby@suse.cz
- Refresh
  patches.suse/suse-hv-storvsc-Set-the-SRB-flags-correctly-when-no-data-tra.patch.
  Update upstream status.
- commit a390a4f
* Tue Jun  2 2015 jlee@suse.com
- MODSIGN: loading keys from db when SecureBoot disabled
  (bnc#929696).
- commit b45412d
* Fri May 29 2015 tiwai@suse.de
- rtlwifi: rtl8192cu: Fix kernel deadlock (bnc#927786).
- commit 374d444
* Fri May 29 2015 duwe@suse.de
- powerpc/perf/hv-24x7: use kmem_cache instead of aligned stack
  allocations (bsc#931403).
- commit 50ce9d9
* Thu May 28 2015 jslaby@suse.cz
- kgr: fix redirection on s390x arch (bsc#903279).
- commit 4eb1849
* Tue May 26 2015 hare@suse.de
- Fixup typo in patches.fixes/scsi_dh_alua-fixup-optimize-stpg.patch.
- commit ee69313
* Tue May 26 2015 hare@suse.de
- scsi_dh_alua: update all port states (bsc#895814).
- scsi_dh_alua: parse device id instead of target id (bsc#895814).
- scsi_dh_alua: fixup crash in alua_rtpg_work() (bsc#895814).
- scsi_dh_alua: recheck RTPG in regular intervals (bsc#895814).
- scsi: retry MODE SENSE on unit attention (bsc#895814).
- sd: always retry READ CAPACITY for ALUA state transition
  (bsc#895814).
- scsi_dh_alua: Recheck state on unit attention (bsc#895814).
- commit 9f6da87
* Fri May 22 2015 jdelvare@suse.de
- libata: Blacklist queued TRIM on all Samsung 800-series
  (bnc#930599).
- commit d227c94
* Fri May 22 2015 ddiss@suse.de
- fs/cifs: Fix corrupt SMB2 ioctl requests (bnc#931124).
- commit 6449ec0
* Fri May 22 2015 mhocko@suse.cz
- hugetlb: do not account hugetlb pages as NR_FILE_PAGES
  (bnc#930092).
- commit e557764
* Fri May 22 2015 bp@suse.de
- vhost/scsi: potential memory corruption (bsc#931988,
  CVE-2015-4036).
- commit 96d4a29
* Thu May 21 2015 hare@suse.de
- edd: support original Phoenix EDD 3.0 information
  (bnc#762285,bsc#929974).
- commit 212d5a9
* Wed May 20 2015 duwe@suse.de
- kabi/severities: ignore changes in the ipmi driver.
  There are no external, 3rd party modules known to exist.
- commit fc0ceac
* Wed May 20 2015 jslaby@suse.cz
- Refresh patches.kernel.org/patch-3.12.42-43.
  Update to .43 final.
- commit 2bb050b
* Wed May 20 2015 jslaby@suse.cz
- kgr: use kgr_in_progress for all threads (fate#313296
  bnc#929883).
- commit 466b788
* Tue May 19 2015 bp@suse.de
- GHES: Make NMI handler have a single reader (bsc#917630).
- GHES: Elliminate double-loop in the NMI handler (bsc#917630).
- GHES: Panic right after detection (bsc#917630).
- GHES: Carve out the panic functionality (bsc#917630).
- GHES: Carve out error queueing in a separate function
  (bsc#917630).
- commit 8725694
* Tue May 19 2015 duwe@suse.de
- ipmi: Turn off all activity on an idle ipmi interface
  (bsc#915540).
- commit 60af144
* Tue May 19 2015 mmarek@suse.cz
- series.conf: Move powerpc fix to the powerpc section
- commit 0cd9802
* Mon May 18 2015 jroedel@suse.de
- powerpc/mm: Fix mmap errno when MAP_FIXED is set and mapping
  exceeds the allowed address space (bsc#930669).
- commit cac691c
* Mon May 18 2015 mgorman@suse.de
- sched: Fix race between task_group and sched_task_group (Automatic NUMA Balancing (fate#315482)).
  (cherry-pick generic race fix, SLE12-SP1 commit 6b833a086c7b806fe46f6e4bfc4737ae7bd31d03)
- commit 3698f30
* Mon May 18 2015 mmarek@suse.cz
- patches.kernel.org/patch-3.12.39-40: Add bnc#927257 / CVE-2015-3331
- commit 2766bb6
* Mon May 18 2015 ohering@suse.de
- storvsc: Set the SRB flags correctly when no data transfer is
  needed (bnc#931130).
- commit 18b6ea9
* Mon May 18 2015 mgorman@suse.de
- mm, numa: really disable NUMA balancing by default on single node machines
  (Automatic NUMA Balancing (fate#315482)).
- commit 328d557
* Fri May 15 2015 mkubecek@suse.cz
- Update patches.kernel.org/patch-3.12.40-41 references (add CVE-2015-3332 bsc#928135).
- commit e48f7d6
* Fri May 15 2015 jbohac@suse.cz
- Update patches.kernel.org/patch-3.12.40-41 (CVE-2014-8159
  CVE-2014-8160 CVE-2015-2042 CVE-2015-2922 CVE-2015-2041
  bnc#903997 bnc#919719 bsc#913059 bsc#914742 bsc#919018
  bsc#924664 bsc#926156 bnc#909477 bnc#922583 bsc#919007).
- commit ef8673e
* Fri May 15 2015 jbohac@suse.cz
- Update patches.kernel.org/patch-3.12.40-41 (CVE-2014-8159
  CVE-2014-8160 CVE-2015-2042 CVE-2015-2922 bnc#903997 bnc#919719
  bsc#913059 bsc#914742 bsc#919018 bsc#924664 bsc#926156
  bnc#909477 bnc#922583).
- commit 603f309
* Fri May 15 2015 jbohac@suse.cz
- ipv4: Missing sk_nulls_node_init() in ping_unhash() (bsc#929525,
  CVE-2015-3636).
- commit 1a810c3
* Fri May 15 2015 jroedel@suse.de
- iommu/amd: Correctly encode huge pages in iommu page tables
  (bsc#931014).
- iommu/amd: Optimize amd_iommu_iova_to_phys for new fetch_pte
  interface (bsc#931014).
- iommu/amd: Optimize alloc_new_range for new fetch_pte interface
  (bsc#931014).
- iommu/amd: Optimize iommu_unmap_page for new fetch_pte interface
  (bsc#931014).
- iommu/amd: Return the pte page-size in fetch_pte (bsc#931014).
- commit 05bdc1a
* Fri May 15 2015 mgalbraith@suse.de
- sched: Fix potential near-infinite distribute_cfs_runtime() loop (bnc#930786)
- commit 08fb962
* Thu May 14 2015 jslaby@suse.cz
- Linux 3.12.43 (CVE-2015-3339 CVE-2015-3636 FATE#315482 bnc#904242
  bnc#927116 bnc#928122 bnc#928130 bnc#930224 bsc#929525).
- kABI: protect linux/mm.h include in seq_file.
- kABI: protect function wl1271_format_buffer.
- kABI: protect struct snd_emu10k1.
- kABI: protect struct se_cmd.
- Refresh
  patches.drivers/0049-usb-rename-usb_port-device-objects.patch.
- Refresh
  patches.kabi/mm-prevent-endless-growth-of-anon_vma-hierarchy-kabi.
- Refresh
  patches.suse/btrfs-0214-add-support-for-inode-properties.patch.
- Refresh
  patches.suse/btrfs-8032-fix-broken-free-space-cache-after-the-system-c.patch.
- Delete
  patches.arch/powerpc-perf-Cap-64bit-userspace-backtraces-to-PERF_.patch.
- Delete
  patches.fixes/fs-take-i_mutex-during-prepare_binprm-for-set-ug-id.patch.
- Delete
  patches.fixes/ipv4-missing-sk_nulls_node_init-in-ping_unhash.patch.
- Delete
  patches.fixes/mm-fix-anon_vma-degree-underflow-in-anon_vma-endless.patch.
- Delete
  patches.fixes/mm-fix-corner-case-in-anon_vma-endless-growing-prevention.patch.
- Delete
  patches.fixes/mm-prevent-endless-growth-of-anon_vma-hierarchy.
- Delete
  patches.fixes/proc-stat-convert-to-single_open_size.patch.
- Delete
  patches.suse/btrfs-8186-fix-log-tree-corruption-when-fs-mounted-with-o.patch.
- Delete
  patches.suse/btrfs-8187-fix-inode-eviction-infinite-loop-after-cloning.patch.
- Delete
  patches.suse/btrfs-8188-fix-inode-eviction-infinite-loop-after-extent_.patch.
- Delete
  patches.suse/mm-Fix-NULL-pointer-dereference-in-madvise-MADV_WILLNEED-support.patch.
- Delete
  patches.suse/msft-hv-0805-scsi-storvsc-Fix-a-bug-in-copy_from_bounce_buffer.patch.
- commit 3dd11af
* Thu May 14 2015 jslaby@suse.cz
- Refresh
  patches.fixes/fork-report-pid-reservation-failure-properly.patch.
  Update usptream status.
- commit e0bcce5
* Wed May 13 2015 dvaleev@suse.com
- Update config files.
- Refresh
  patches.arch/powerpc-Fix-warning-reported-by-verify_cpu_node_mapp.patch.
- Refresh
  patches.arch/powerpc-Only-set-numa-node-information-for-present-c.patch.
- Refresh
  patches.arch/powerpc-numa-check-error-return-from-proc_create.patch.
- Refresh
  patches.arch/powerpc-numa-ensure-per-cpu-NUMA-mappings-are-correc.patch.
- Refresh
  patches.arch/powerpc-numa-use-cached-value-of-update-cpu-in-updat.patch.
- Refresh
  patches.arch/powerpc-some-changes-in-numa_setup_cpu.patch.
- Refresh patches.fixes/sched-Robustify-topology-setup.patch.
- commit 899bf23
* Wed May 13 2015 dvaleev@suse.com
- powerpc: Fix warning reported by verify_cpu_node_mapping()
  (bsc#924809).
- powerpc: Only set numa node information for present cpus at
  boottime (bsc#924809).
- powerpc/numa: Add ability to disable and debug topology updates
  (bsc#924809).
- powerpc/numa: Enable CONFIG_HAVE_MEMORYLESS_NODES (bsc#924809).
- powerpc/numa: Enable USE_PERCPU_NUMA_NODE_ID (bsc#924809).
- powerpc/numa: check error return from proc_create (bsc#924809).
- powerpc/numa: ensure per-cpu NUMA mappings are correct on
  topology update (bsc#924809).
- powerpc/numa: use cached value of update->cpu in
  update_cpu_topology (bsc#924809).
- powerpc: reorder per-cpu NUMA information's initialization
  (bsc#924809).
- powerpc: some changes in numa_setup_cpu() (bsc#924809).
- sched: Robustify topology setup (bsc#924809).
- Update config files.
- commit 2972893
* Wed May 13 2015 jbeulich@suse.com
- Update Xen patches to 3.12.42.
- commit c8ca4e6
* Wed May 13 2015 vbabka@suse.cz
- mm: vmscan: do not throttle based on pfmemalloc reserves if
  node has no reclaimable pages (bnc#924803, VM Functionality).
- commit a2ca1d7
* Wed May 13 2015 ohering@suse.de
- Update mainline headers of some hv_storvsc patches
- commit b20c9d2
* Tue May 12 2015 mgalbraith@suse.de
- Add explicit #include <linux/hardirq.h> to fix config dependent
  (sigh) in_interrupt() build failure.
- Modified:
  patches.suse/sched-provide-rtkthreads-rtworkqueues-boot-options.patch
- commit f84ea1b
* Tue May 12 2015 mgalbraith@suse.de
- Fix rtworkqueues crash
  Calling __sched_setscheduler() in interrupt context is forbidden, and
  destroy_worker() did so in the timer interrupt with a nohz_full config.
  Preclude that possibility for both boot options.
- Modified:
  patches.suse/sched-provide-rtkthreads-rtworkqueues-boot-options.patch
- commit b4aa8fc
* Mon May 11 2015 jroedel@suse.de
- x86/apic/uv: Update the UV APIC HUB check (bsc#929145).
- x86/apic/uv: Update the UV APIC driver check (bsc#929145).
- x86/apic/uv: Update the APIC UV OEM check (bsc#929145).
- commit 4fbdcad
* Mon May 11 2015 jack@suse.cz
- Fixup compiler warning in
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit 3811c30
* Fri May  8 2015 bpoirier@suse.de
- bnx2x: Fix kdump when iommu=on (bug#921769).
- commit 8964497
* Fri May  8 2015 fdmanana@suse.com
- Btrfs: btrfs_release_extent_buffer_page didn't free pages of
  dummy extent (bnc#930226).
- Btrfs: fix inode eviction infinite loop after extent_same ioctl
  (bnc#930224).
- Btrfs: fix inode eviction infinite loop after cloning into it
  (bnc#930224).
- commit 3a369eb
* Fri May  8 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8186-fix-log-tree-corruption-when-fs-mounted-with-o.patch.
- commit fa917c6
* Thu May  7 2015 eich@suse.de
- Refresh
  patches.fixes/vfs-fix-race-between-fcntl-and-file-f_flags-checks.patch.
- commit ecc4168
* Thu May  7 2015 eich@suse.de
- drm/radeon: fix display tiling setup on SI (bnc#927285).
- drm/radeon: set correct number of banks for CIK chips in DCE
  (bnc#927285).
- drm/radeon/cik: Add macrotile mode array query (bnc#927285).
- commit 15f12fb
* Wed May  6 2015 tonyj@suse.de
- audit: do not reject all AUDIT_INODE filter types (bnc#927455).
- commit 70356e0
* Wed May  6 2015 bpoirier@suse.de
- ixgbe: fix detection of SFP+ capable interfaces (bug#922734).
- commit cab5e1a
* Wed May  6 2015 jslaby@suse.cz
- kgr: x86: make build possible on x86_64 only (fate#313296).
- kgr: take switching of the fops out of kgr_patch_code to new
  function (fate#313296).
- kgr: correct error handling of the first patching stage
  (fate#313296).
- kgr: handle the failure of finalization stage (fate#313296).
- kgr: handle the delayed patching of the modules (fate#313296).
- kgr: return error in kgr_init if notifier registration fails
  (fate#313296).
- kgr: add error code to the message in kgr_revert_replaced_funs
  (fate#313296).
- s390: kgr, change the kgraft state only if enabled
  (fate#313296).
- kgr: use for_each_process_thread (fate#313296 bnc#929883).
- Refresh patches.xen/xen-spinlock-poll-early.
- Refresh patches.xen/xen3-patch-3.10.
- commit a34ddc2
* Wed May  6 2015 jack@suse.cz
- vfs: Fix race between fcntl() and file->f_flags checks
  (bnc#900881 CVE-2014-8086).
- commit 90ee5b6
* Tue May  5 2015 jslaby@suse.cz
- kgr: add kgraft annotations to kthreads' wait_event_freezable()
  API calls (fate#313296).
- commit 5dcb2cf
* Tue May  5 2015 oneukum@suse.de
- Input: synaptics - handle spurious release of trackstick buttons
  (bnc#929092).
- Input: synaptics - fix middle button on Lenovo 2015 products
  (bnc#929092).
- Input: synaptics - re-route tracksticks buttons on the Lenovo
  2015 series (bnc#929092).
- Input: synaptics - remove TOPBUTTONPAD property for Lenovos 2015
  (bnc#929092).
- Input: synaptics - retrieve the extended capabilities in query
  $10 (bnc#929092).
- Input: psmouse - add psmouse_matches_pnp_id helper function
  (bnc#929092).
- commit fe547e3
* Thu Apr 30 2015 jslaby@suse.cz
- Linux 3.12.42.
- Refresh
  patches.arch/ppc64le-kvm-0039-kvm-Add-struct-kvm-arg-to-memslot-APIs.patch.
- Update config files.
- commit 26c872c
* Thu Apr 30 2015 jslaby@suse.cz
- Linux 3.12.41 (CVE-2014-8159 CVE-2014-8160 CVE-2015-2042
  bnc#903997 bnc#919719 bsc#913059 bsc#914742 bsc#919018
  bsc#924664 bsc#926156 bnc#909477).
- Refresh
  patches.arch/ppc64le-kvm-0039-kvm-Add-struct-kvm-arg-to-memslot-APIs.patch.
- Refresh
  patches.drivers/bonding-add-bond_has_slaves-and-use-it.patch.
- Refresh
  patches.drivers/bonding-extend-round-robin-mode-with-packets_per_sla.patch.
- Refresh
  patches.drivers/bonding-slight-optimization-for-bond_3ad_xmit_xor.patch.
- Refresh
  patches.drivers/bonding-slight-optimization-for-bond_alb_xmit.patch.
- Refresh
  patches.drivers/bonding-use-RCU-protection-for-3ad-xmit-path.patch.
- Refresh
  patches.drivers/bonding-use-RCU-protection-for-alb-xmit-path.patch.
- Refresh
  patches.suse/mm-thp-change-pmd_trans_huge_lock-to-return-taken-lock.patch.
- Delete
  patches.arch/pseries-LE-Fixes-for-post-mobility-dt-update.patch.
- Delete
  patches.drivers/cpufreq-fix-NULL-pointer-dereference-in-__cpufreq_governor.patch.
- Delete
  patches.drivers/ib-uverbs-prevent-integer-overflow-in-ib_umem_get-address-arithmetic.patch.
- Delete
  patches.fixes/cifs-fix-use-after-free-bug-in-find_writable_file.patch.
- Delete
  patches.fixes/libata-blacklist-queued-trim-on-samsung-ssd-850-pro.patch.
- Delete
  patches.fixes/net-rds-use-correct-size-for-max-unacked-packets-and.patch.
- Delete
  patches.fixes/netfilter-conntrack-disable-generic-tracking-for-known-protos.patch.
- Delete
  patches.fixes/tcp-prevent-fetching-dst-twice-in-early-demux-code.patch.
- Delete
  patches.kernel.org/core-nfqueue-openvswitch-fix-compilation-warning.patch.
- commit ed2cc77
* Wed Apr 29 2015 jdelvare@suse.de
- rpm/guards: Clarify user message
  When --config=series is used and a listed file is not found on the
  disk, guards prints the following message:
  Not found in series: file
  This message is confusing, as the file was found in series, it is
  missing on the disk. Change the message to make this more obvious.
- commit 3fbe9e5
* Tue Apr 28 2015 bpoirier@suse.de
- mlx4: Call dev_kfree_skby_any instead of dev_kfree_skb
  (bug#928708).
- commit 931d199
* Tue Apr 28 2015 bpoirier@suse.de
- net/mlx4: Cache line CQE/EQE stride fixes (bug#927084).
- net/mlx4_en: Add mlx4_en_get_cqe helper (bug#927084).
- net/mlx4_core: Cache line EQE size support (bug#927084).
- net/mlx4_core: Enable CQE/EQE stride support (bug#927084).
- commit 0af8dd4
* Tue Apr 28 2015 bpoirier@suse.de
- Group Mellanox patches together and sort them according to upstream order.
  This makes it easier to check which commits have already been backported and
  insert new ones.
- commit ee85378
* Tue Apr 28 2015 jjolly@suse.de
- dasd: Fix inability to set a DASD device offline (bnc#927308,
  LTC#123905).
- dasd: Fix device having no paths after suspend/resume
  (bnc#927308, LTC#123896).
- dasd: Fix unresumed device after suspend/resume (bnc#927308,
  LTC#123892).
- af_iucv: fix AF_IUCV sendmsg() errno (bnc#927308, LTC#123304).
- commit c99531b
* Mon Apr 27 2015 mszeredi@suse.cz
- fs: take i_mutex during prepare_binprm for setid executables
  (CVE-2015-3339 bnc#928130).
- commit 12e59f7
* Fri Apr 24 2015 jack@suse.cz
- quota: Fix use of units in quota getting / setting interfaces
  (bnc#913232).
- commit 8eea0a1
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: Documentation update
  * Fix synopsis format.
  * Document the new --path=@<file> option.
- commit 7fd4136
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: White space cleanups
- commit d8089eb
* Fri Apr 24 2015 dvaleev@suse.com
- powerpc/pseries: Simplify check for suspendability during
  suspend/migration (bsc#926314).
- powerpc/pseries: Introduce api_version to migration sysfs
  interface (bsc#926314).
- powerpc/pseries: Little endian fixes for post mobility device
  tree update (bsc#926314).
- powerpc/perf: Cap 64bit userspace backtraces to
  PERF_MAX_STACK_DEPTH (bsc#928141).
- commit 5f947b1
* Wed Apr 22 2015 mhocko@suse.cz
- /proc/stat: convert to single_open_size() (bnc#928122).
- commit 4bf9ae0
* Wed Apr 22 2015 mmarek@suse.cz
- scripts/refresh: Obsoleted by refresh_patch.sh
- commit 8614090
* Wed Apr 22 2015 jdelvare@suse.de
- libata: Blacklist queued TRIM on Samsung SSD 850 Pro
  (bsc#926156).
- commit a42cf46
* Wed Apr 22 2015 jdelvare@suse.de
- cpufreq: fix a NULL pointer dereference in __cpufreq_governor()
  (bsc#924664).
- commit 576c2a5
* Wed Apr 22 2015 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Add .build.hostarch.kvm to the filelist
- commit c65f3ca
* Wed Apr 22 2015 jlee@suse.com
- ACPI / sysfs: Treat the count field of counter_show() as
  unsigned (bnc#909312).
- commit ca3bcc8
* Tue Apr 21 2015 mmarek@suse.cz
- rpm/mkspec: Do not build kernel-obs-* on 32bit ppc
  The buildservice uses the ppc64 kernel-obs-build package for 32bit
  workers.
- commit d1e0beb
* Tue Apr 21 2015 dvaleev@suse.com
- create .build.hostarch.kvm for kernel-obs-build
  OBS needs to know hostarch, with ppc64/ppc64le this is not that easy.
  Lets create a marker file to help with it.
  See obs-build commit: e47399d738e51
- commit e5d9da9
* Fri Apr 17 2015 bp@suse.de
- IB/uverbs: Prevent integer overflow in ib_umem_get address
  arithmetic (bsc#914742, CVE-2014-8159).
- commit 3ba993b
* Wed Apr 15 2015 jbohac@suse.cz
- Revert "ipv4: try to cache dst_entries which would cause a redirect"
  This reverts commit 63513687d3149f8839a9a71b52f8854ef6f8f480.
  Already fixed by 3.12.38
- commit 36d0d11
* Wed Apr 15 2015 jbohac@suse.cz
- Update patches.kernel.org/patch-3.12.37-38 (CVE-2014-3647
  CVE-2014-3690 FATE#316038 bnc#800255 bnc#856659 bnc#873901
  bnc#876731 bnc#882900 bnc#899192 bnc#901090 bnc#901809
  bnc#902232 bnc#904659 bnc#907969 bnc#907970 bsc#911181
  bsc#913233 bsc#915188 bfo#71370 bnc#907325 bnc#915210 bsc#916225
  CVE-2015-1465).
  Added bsc#916225 and CVE-2015-1465 to the references.
- commit f3a277e
* Tue Apr 14 2015 jbohac@suse.cz
- ipv4: try to cache dst_entries which would cause a redirect
  (bsc#916225, CVE-2015-1465).
- commit 6351368
* Tue Apr 14 2015 fdmanana@suse.com
- Btrfs: fix log tree corruption when fs mounted with -o discard
  (bnc#927116).
- Btrfs: fix up bounds checking in lseek (bnc#927115).
- commit d377568
* Tue Apr 14 2015 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Do not fail if the kernel versions do not match
- commit 28e9e74
* Tue Apr 14 2015 bp@suse.de
- Delete patches.arch/perf-x86-amd-ibs-update-ibs-msrs-and-feature-definitions.patch.
  Move it to 12SP1 as it is a SP1 FATE.
- commit 592608f
* Mon Apr 13 2015 jslaby@suse.cz
- core, nfqueue, openvswitch: fix compilation warning.
- commit 96c80d0
* Mon Apr 13 2015 bp@suse.de
- perf/x86/amd/ibs: Update IBS MSRs and feature definitions
  (fate#318730).
- commit 80ea2a2
* Thu Apr  9 2015 jslaby@suse.cz
- Linux 3.12.40 (FATE#315482 LTC#111793 CVE-2015-2666 FATE#316038
  bnc#883741 bnc#892612 bnc#907969 bnc#914726 bnc#920262 bsc#921313
  bsc#921990 bsc#922944 bnc#854993 FATE#315929 bnc#877098 LTC#110078
  bsc#919463 CVE-2015-2150 XSA-120).
- Refresh
  patches.arch/x86-microcode-move-to-a-proper-location.patch.
- Refresh
  patches.drivers/0050-target-iscsi-Remove-macros-that-contain-typecasts.patch.
- Refresh
  patches.drivers/0072-target-core-rename-ex-im-plict-ex-im-plicit.patch.
- Refresh
  patches.drivers/bnx2x-0034-bnx2x-Add-AER-support-missing-bits.patch.
- Refresh
  patches.drivers/intel_idle-fine-tune-ivt-residency-targets.
- Refresh patches.drivers/intel_idle-support-Bay-Trail.patch.
- Refresh
  patches.drivers/mlx-net-mlx4_core-Replace-pr_warning-with-pr_warn.patch.
- Refresh
  patches.drivers/mlx4_core-Defer-VF-initialization-till-PF-is-fully-initialized.
- Refresh patches.suse/md-bitmap-unplug-fixes.
- Refresh
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
- Refresh
  patches.suse/mm-hugetlb-improve-page-fault-scalability.patch.
- Refresh patches.xen/xen3-patch-3.1.
- Delete
  patches.arch/power,-sched-stop-updating-inside-arch_update_cpu_topology-when-nothing-to-be-update.
- Delete
  patches.arch/powerpc-Fix-sys_call_table-declaration-to-enable-sys.patch.
- Delete
  patches.arch/s390-sles12-05-01-crypto-fix-des-aes-finding-in-ctr-mode.patch.
- Delete
  patches.arch/x86-microcode-intel-guard-against-stack-overflow-in-the-loader.patch.
- Delete
  patches.drivers/hda-0046-Fix-regression-of-HD-audio-controller-fallb.
- Delete
  patches.drivers/intel_idle-Add-CPU-model-54-Atom-N2000-series.patch.
- Delete
  patches.drivers/iommu-core-check-for-the-right-function-pointer-in-iommu_map.
- Delete
  patches.drivers/megaraid-Use-resource_size_t-for-PCI-resources-not-l.patch.
- Delete
  patches.fixes/0001-NFS-Add-attribute-update-barriers-to-nfs_setattr_upd.patch.
- Delete
  patches.fixes/ipc-shm.c-fix-overly-aggressive-shmdt-when-calls-spa.patch.
- Delete
  patches.fixes/module-Clean-up-ro-nx-after-early-module-load-failur.patch.
- Delete
  patches.fixes/module-set-nx-before-marking-module-MODULE_STATE_COM.patch.
- Delete
  patches.fixes/x86-irq-check-for-valid-irq-descriptor-in-check_irq_vectors_for_cpu_disable.
- Delete
  patches.suse/btrfs-8144-don-t-delay-inode-ref-updates-during-log-repla.patch.
- Delete
  patches.suse/mm-thp-give-transparent-hugepage-code-a-separate-copy_page.patch.
- Delete patches.xen/xen-pciback-decode.
- commit e64271d
* Thu Apr  9 2015 mkubecek@suse.cz
- net: rds: use correct size for max unacked packets and bytes
  (bsc#919018 CVE-2015-2042).
- commit ba471ce
* Wed Apr  8 2015 bp@suse.de
- x86/asm/entry/64: Remove a bogus 'ret_from_fork' optimization
  (bsc#926240, CVE-2015-2830).
- commit a500c59
* Tue Apr  7 2015 dbueso@suse.de
- ipc/shm.c: fix overly aggressive shmdt() when calls span
  multiple segments (ipc fixes).
- commit d2c35f9
* Fri Apr  3 2015 mmarek@suse.cz
- Automatically Provide/Obsolete all subpackages of old flavors (bnc#925567)
- commit e3547a5
* Fri Apr  3 2015 jslaby@suse.cz
- Refresh patches.arch/0001-efi-Autoload-efivars.patch.
- Refresh
  patches.arch/x86-microcode-intel-guard-against-stack-overflow-in-the-loader.patch.
- Refresh patches.fixes/0001-noveau-Fix-up-nouveau_acpi.patch.
- Refresh
  patches.fixes/crypto-drbg-panic-on-continuous-self-test-error.
- Refresh
  patches.fixes/crypto-rng-RNGs-must-return-0-in-success-case.
- Refresh
  patches.fixes/crypto-testmgr-fix-RNG-return-code-enforcement.
- Refresh
  patches.fixes/x86-irq-check-for-valid-irq-descriptor-in-check_irq_vectors_for_cpu_disable.
- Refresh
  patches.suse/0001-KEYS-Fix-termination-condition-in-assoc-array-garbag.patch.
- Refresh
  patches.suse/epoll-optimize-setting-task-running-after-blocking.patch.
  Cleanup references.
- commit ec7947f
* Thu Apr  2 2015 mmarek@suse.cz
- Update kabi files.
- commit 9cbed62
* Thu Apr  2 2015 neilb@suse.de
- restore kabi after change to nfs_setattr_update_inode
  (bnc#920262).
- commit 8929205
* Thu Apr  2 2015 neilb@suse.de
- NFS: Add attribute update barriers to nfs_setattr_update_inode()
  (bnc#920262).
- commit 77c46ae
* Tue Mar 31 2015 jjolly@suse.de
- s390/smp: limit number of cpus in possible cpu mask (bnc#917125,
  LTC#122429).
- s390/sclp_early: Return correct HSA block count also for zero
  (bnc#917125, LTC#122429).
- s390/sclp_early: Add function to detect sclp console
  capabilities (bnc#917125, LTC#122429).
- s390/sclp_early: Pass sccb pointer to every *_detect() function
  (bnc#917125, LTC#122429).
- s390/sclp_early: Replace early_read_info_sccb with sccb_early
  (bnc#917125, LTC#122429).
- s390/sclp_early: Get rid of sclp_early_read_info_sccb_valid
  (bnc#917125, LTC#122429).
- s390/sclp: replace uninitialized early_event_mask_sccb variable
  with sccb_early (bnc#917125, LTC#122429).
- s390/sclp: Consolidate early sclp init calls to
  sclp_early_detect() (bnc#917125, LTC#122429).
- s390/sclp: Move declarations for sclp_sdias into separate
  header file (bnc#917125, LTC#122429).
- s390/sclp: Move early code from sclp_cmd.c to sclp_early.c
  (bnc#917125, LTC#122429).
- s390/sclp: Determine HSA size dynamically for zfcpdump
  (bnc#917125, LTC#122429).
- s390/sclp: revert smp-detect-possible-cpus.patch (bnc#917125,
  LTC#122429).
- commit c5e3f7a
* Tue Mar 31 2015 jjolly@suse.de
- s390/bpf: Zero extend parameters before calling C function
  (bnc#917125,LTC#121759).
- s390/bpf: Fix sk_load_byte_msh() (bnc#917125,LTC#121759).
- s390/bpf: Fix offset parameter for skb_copy_bits()
  (bnc#917125,LTC#121759).
- s390/bpf: Fix skb_copy_bits() parameter passing
  (bnc#917125,LTC#121759).
- s390/bpf: Fix JMP_JGE_K (A >= K) and JMP_JGT_K (A > K)
  (bnc#917125,LTC#121759).
- s390/bpf: Fix JMP_JGE_X (A > X) and JMP_JGT_X (A >= X)
  (bnc#917125,LTC#121759).
- s390/bpf: Fix ALU_NEG (A = -A) (bnc#917125,LTC#121759).
- dasd: Missing partition after online processing (bnc#917125,
  LTC#120565).
- commit 139383f
* Mon Mar 30 2015 jjolly@suse.de
- Moved s390-sles12-13 and s390-sles12-14 patches into proper order
- Patch s390-sles12-13-01 simply reverts patch kgr-0027. Removing both.
  - Delete patches.arch/s390-sles12-13-01-ftrace.patch.
  - Delete
  patches.suse/kgr-0027-s390-add-support-for-DYNAMIC_FTRACE_WITH_REGS.patch.
- commit fbc2bc5
* Mon Mar 30 2015 mgorman@suse.de
- sched, time: Fix lock inversion in thread_group_cputime()
- Refresh
  patches.suse/time-signal-Protect-resource-use-statistics-with-seqlock-kabi.patch.
  (Time scalability).
- commit 4f20b3e
* Mon Mar 30 2015 mgorman@suse.de
- seqlock: Add irqsave variant of read_seqbegin_or_lock()
  (Time scalability).
- commit fd61490
* Sun Mar 29 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.30-31 (bnc#895983
  bnc#897912 bnc#901085).
- commit 213bb26
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Include the file name also in the "Not found" error
- commit 9b71e7b
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Add support for an external filelist in --check mode
  This will allow us to run --check without a kernel-source.git work tree.
- commit 61c3df5
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Simplify help text
- commit f0c085a
* Fri Mar 27 2015 dvaleev@suse.com
- powerpc: Fix sys_call_table declaration to enable syscall
  tracing.
- commit cfba9e4
* Thu Mar 26 2015 mmarek@suse.cz
- Revert "kgr: Allow patches to require an exact kernel version (bnc#920615)."
  This needs to be done differently, so that modprobe --force works as
  expected.
  This reverts commit b08d1301512a2bf61dfbcaf7f087dff259bd4d59.
- commit a901594
* Thu Mar 26 2015 mmarek@suse.cz
- Delete duplicate headers in some patches
- Refresh patches.arch/kvm-x86-fix-xsave-cpuid-exposing-bug.patch.
- Refresh
  patches.drivers/drm-ast-open-key-before-detect-chips.patch.
- mm: prevent endless growth of anon_vma hierarchy (bnc#904242).
- commit 9de293a
* Thu Mar 26 2015 jroedel@suse.de
- iommu/vt-d: Fix dmar_domain leak in iommu_attach_device
  (bsc#924460).
- commit 98ee275
* Thu Mar 26 2015 mhocko@suse.cz
- mm: fix anon_vma->degree underflow in anon_vma endless growing
  prevention (bnc#904242).
- mm: fix corner case in anon_vma endless growing prevention
  (bnc#904242).
- kabi, mm: prevent endless growth of anon_vma hierarchy
  (bnc#904242).
- mm: prevent endless growth of anon_vma hierarchy
  mm: prevent endless growth of anon_vma hierarchy (bnc#904242).
- commit 68b0be3
* Thu Mar 26 2015 mkubecek@suse.cz
- tcp: prevent fetching dst twice in early demux code (bnc#903997
  bnc#919719).
- commit fe29fb5
* Wed Mar 25 2015 jbeulich@suse.com
- xenbus: add proper handling of XS_ERROR from Xenbus for
  transactions.
- Update Xen patches to 3.12.39.
- commit 220a4ad
* Tue Mar 24 2015 ohering@suse.de
- scsi: storvsc: Don't assume that the scatterlist is not chained.
- scsi: storvsc: Fix a bug in copy_from_bounce_buffer().
- Refresh
  patches.suse/suse-hv-scsi-storvsc-Set-the-tablesize-based-on-the-informat.patch.
- Delete
  patches.suse/suse-hv-scsi-storvsc-Enable-clustering.patch.
- commit bc2f7d9
* Mon Mar 23 2015 mmarek@suse.cz
- kgr: Allow patches to require an exact kernel version (bnc#920615).
- commit b08d130
* Mon Mar 23 2015 mmarek@suse.cz
- kabi/severities: Stop maintaining the kgraft kabi
- Refresh patches.suse/kgr-0100-kabi-add-reserved-fields.patch.
- Delete patches.suse/kgr-0103-kabi-protect_kgr_structs.patch.
- commit 853ce48
* Mon Mar 23 2015 bp@suse.de
- Update
  patches.arch/x86-microcode-intel-guard-against-stack-overflow-in-the-loader.patch
  (bsc#922944, CVE-2015-2666).
- commit ca7750b
* Fri Mar 20 2015 jeffm@suse.com
- btrfs: cleanup orphans while looking up default subvolume
  (bsc#914818).
- commit c1a5301
* Thu Mar 19 2015 bp@suse.de
- x86, AVX-512: AVX-512 Feature Detection (bsc#921527).
- x86, AVX-512: Enable AVX-512 States Context Switch (bsc#921527).
- commit f53193f
* Thu Mar 19 2015 mhocko@suse.cz
- Refresh patches.fixes/cgroup-revert-cgroup_mutext-removal.patch.
  remove cgroup_mutex around deactivate_super because it might be
  dangerous.
- commit 4bc1d87
* Wed Mar 18 2015 bp@suse.de
- x86/microcode/intel: Guard against stack overflow in the loader
  (bsc#922944).
- commit cbca797
* Wed Mar 18 2015 ddiss@suse.de
- cifs: fix use-after-free bug in find_writable_file (bnc#909477).
- commit 2a7cc42
* Wed Mar 18 2015 mhocko@suse.cz
- cgroup: revert cgroup_mutex removal from idr_remove
  (bnc#918644).
- commit cc6bf92
* Tue Mar 17 2015 pmladek@suse.cz
- module: Clean up ro/nx after early module load failures
  (bsc#921990).
- module: set nx before marking module MODULE_STATE_COMING
  (bsc#921990).
- commit fdca804
* Mon Mar 16 2015 mhocko@suse.cz
- fork: report pid reservation failure properly (bnc#909684).
- commit fbbd1e7
* Fri Mar 13 2015 mmarek@suse.cz
- Move non-kabi workarounds out of patches.kabi
  Patches that pad structures or mark deprecated functions as such are
  needed in the next service pack as well. patches.kabi is removed in the
  next service pack.
- commit a68ea8a
* Fri Mar 13 2015 duwe@suse.de
- crypto: testmgr - fix RNG return code enforcement (bsc#920805).
- commit 1c88e3a
* Fri Mar 13 2015 fdmanana@suse.com
- Btrfs: add missing blk_finish_plug in btrfs_sync_log()
  (bnc#922284).
- Btrfs: fix BUG_ON in btrfs_orphan_add() when delete unused
  block group (bnc#922278).
- Btrfs: fix data loss in the fast fsync path (bnc#922275).
- Btrfs: fix fsync data loss after adding hard link to inode
  (bnc#922275).
- Btrfs: do not ignore errors from btrfs_lookup_xattr in
  do_setxattr (bnc#922272).
- commit cff3002
* Fri Mar 13 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8168-fix-directory-inconsistency-after-fsync-log-re.patch.
- Refresh
  patches.suse/btrfs-8169-fix-fsync-when-extend-references-are-added-to-.patch.
- Refresh
  patches.suse/btrfs-8170-fix-fsync-log-replay-for-inodes-with-a-mix-of-.patch.
- Refresh
  patches.suse/btrfs-8171-fix-setup_leaf_for_split-to-avoid-leaf-corrupt.patch.
- Refresh
  patches.suse/btrfs-8172-fix-scrub-race-leading-to-use-after-free.patch.
- Refresh
  patches.suse/btrfs-8172_2-scrub-fix-sleep-in-atomic-context.patch.
- Refresh
  patches.suse/btrfs-8173-fix-race-between-transaction-commit-and-empty-.patch.
- Refresh
  patches.suse/btrfs-8179-fix-fsync-race-leading-to-ordered-extent-memor.patch.
- commit 5a96277
* Thu Mar 12 2015 jslaby@suse.cz
- Linux 3.12.39 (bnc#904177 bnc#909309 bnc#915200 bsc#918620
  FATE#306586).
- mm: convert the rest to new page table lock api (the suse-only
  cases) (fate#315482).
- kABI: protect linux/namei.h include in procfs.
- kABI: protect struct hif_scatter_req.
- Refresh
  patches.drivers/0003-USB-EHCI-handle-isochronous-underruns-with-tasklets.patch.
- Refresh patches.fixes/mei-remove-flash_work_queue.
- Refresh patches.fixes/mei-revamp-mei-reset-state-machine.
- Refresh
  patches.fixes/mm-introduce-single-zone-pcplists-drain.patch.
- Refresh
  patches.fixes/mm-memory_hotplug-failure-drain-single-zone-pcplists.patch.
- Refresh
  patches.fixes/net-correct-error-path-in-rtnl_newlink.patch.
- Refresh
  patches.fixes/xfs-split-dquot-buffer-operations-out.patch.
- Refresh
  patches.suse/btrfs-0187-convert-printk-to-btrfs_-and-fix-btrfs-prefix.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- Refresh
  patches.suse/fs-change-direct_access-calling-convention.patch.
- Refresh
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
- Delete
  patches.drivers/powerpc-pseries-Added-Little-Endian-support-to-vtpm-module.patch.
- Delete
  patches.fixes/fsnotify-Fix-handling-of-renames-in-audit.patch.
- Delete
  patches.fixes/mm-compaction-fix-wrong-order-check-in-compact_finished.patch.
- Delete
  patches.fixes/udp-only-allow-UFO-for-packets-from-SOCK_DGRAM-socke.patch.
- Delete
  patches.suse/btrfs-8182-fix-data-loss-in-the-fast-fsync-path.patch.
- commit 1775417
* Wed Mar 11 2015 ohering@suse.de
- scsi: storvsc: Enable clustering.
- scsi: storvsc: Set the tablesize based on the information
  given by the host.
- scsi: storvsc: Retrieve information about the capability of
  the target.
- scsi: storvsc: Always send on the selected outgoing channel.
- scsi: storvsc: Size the queue depth based on the ringbuffer
  size.
- scsi: storvsc: Increase the ring buffer size.
- commit bb966c9
* Wed Mar 11 2015 ohering@suse.de
- hyperv: fix sparse warnings.
- commit 9c95c36
* Wed Mar 11 2015 ohering@suse.de
- hyperv: Fix the error processing in netvsc_send().
- commit 53fec0d
* Wed Mar 11 2015 ohering@suse.de
- hyperv: match wait_for_completion_timeout return type.
- commit 0838719
* Wed Mar 11 2015 ohering@suse.de
- hyperv: netvsc.c: match wait_for_completion_timeout return type.
- commit dafae6e
* Wed Mar 11 2015 ohering@suse.de
- HID: hyperv: match wait_for_completion_timeout return type.
- commit d325bd5
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: hv_process_timer_expiration() can be static.
- commit e32406b
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: serialize Offer and Rescind offer.
- commit b58b65c
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: rename sc_lock to the more generic lock.
- commit 5e61667
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: check vmbus_device_create() return value in
  vmbus_process_offer().
- commit 5f7ad7d
* Wed Mar 11 2015 ohering@suse.de
- hv: hv_fcopy: drop the obsolete message on transfer failure.
- commit 529e771
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: Support a vmbus API for efficiently sending
  page arrays.
- commit dd461c3
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: Fix a bug in vmbus_establish_gpadl().
- commit 81e28c9
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: Implement a clockevent device.
- commit 34a9802
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: hv_balloon: Don't post pressure status from
  interrupt context.
- Refresh patches.suse/kgr-0048-kgr-mark-even-more-kthreads.patch.
- commit 8574332
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: hv_balloon: Fix a locking bug in the balloon
  driver.
- commit eb66f73
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: hv_balloon: Make adjustments in computing the
  floor.
- commit b6748ea
* Wed Mar 11 2015 ohering@suse.de
- Tools: hv: do not add redundant '/' in hv_start_fcopy().
- commit bc770b7
* Wed Mar 11 2015 ohering@suse.de
- Tools: hv: address compiler warnings for hv_fcopy_daemon.c.
- commit 0ec195a
* Wed Mar 11 2015 ohering@suse.de
- Tools: hv: address compiler warnings for hv_kvp_daemon.c.
- commit 0be4c36
* Wed Mar 11 2015 ohering@suse.de
- Tools: hv: remove unused bytes_written from kvp_update_file().
- commit b7089ef
* Wed Mar 11 2015 ohering@suse.de
- tools: hv: kvp_daemon: make IPv6-only-injection work.
- commit 0f01bcd
* Wed Mar 11 2015 ohering@suse.de
- Drivers: hv: vmbus: Use get_cpu() to get the current CPU.
- commit a930b66
* Wed Mar 11 2015 ohering@suse.de
- storvsc: force SPC-3 compliance on win8 and win8 r2 hosts.
- commit c0b063d
* Wed Mar 11 2015 ohering@suse.de
- storvsc: fix a bug in storvsc limits.
- commit 69d34a5
* Wed Mar 11 2015 ohering@suse.de
- storvsc: force discovery of LUNs that may have been removed.
- commit 2abd8cc
* Wed Mar 11 2015 ohering@suse.de
- storvsc: in responce to a scan event, scan the host.
- commit 81af403
* Wed Mar 11 2015 ohering@suse.de
- sched: replace INIT_COMPLETION with reinit_completion.
- commit 026a442
* Tue Mar 10 2015 duwe@suse.de
- crypto: rng - RNGs must return 0 in success case (bsc#920805).
- commit 368f860
* Tue Mar 10 2015 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.1.
- commit 105650f
* Tue Mar 10 2015 jbeulich@suse.com
- usbback: copy only filled buffers to guest (bsc#917830
  CVE-2015-0777).
- commit 49f6ee1
* Tue Mar 10 2015 jbeulich@suse.com
- xen-pciback: limit guest control of command register (bsc#919463
  CVE-2015-2150 XSA-120).
- commit 88a9c8a
* Mon Mar  9 2015 tiwai@suse.de
- ALSA: hda - Fix regression of HD-audio controller fallback modes
  (bsc#921313).
- commit f6d57bd
* Fri Mar  6 2015 dvaleev@suse.com
- KVM: PPC: Book3S HV: ptes are big endian (bsc#920839).
- powerpc: add running_clock for powerpc to prevent spurious
  softlockup warnings (bsc#919939).
- kernel/sched/clock.c: add another clock for use with the soft
  lockup watchdog (bsc#919939).
- commit 528d8e9
* Thu Mar  5 2015 mkubecek@suse.cz
- udp: only allow UFO for packets from SOCK_DGRAM sockets
  (bnc#909309).
- commit 5609b2c
* Wed Mar  4 2015 neilb@suse.de
- Add support for pnfs block layout.
  Patches not included by default yet
- NFSv4.1: Don't trust attributes if a pNFS LAYOUTCOMMIT is
  outstanding (bnc#898675).
- NFSv4.1: Fix a race in nfs4_write_inode (bnc#898675).
- NFSv4.1: Fix wraparound issues in pnfs_seqid_is_newer()
  (bnc#898675).
- NFSv4: Don't update the open stateid unless it is newer than
  the old one (bnc#898675).
- NFSv4.1: Ensure that the layout recall callback matches layout
  stateids (bnc#898675).
- NFSv4.1: Minor optimisation in get_layout_by_fh_locked()
  (bnc#898675).
- NFSv4.1: Ensure that we free existing layout segments if we
  get a new layout (bnc#898675).
- nfs: commit layouts in fdatasync (bnc#898675).
- nfs: cap request size to fit a kmalloced page array
  (bnc#898675).
- pnfs: do not pass uninitialized lsegs to ->free_lseg
  (bnc#898675).
- pnfs: don't check sequence on new stateids in layoutget
  (bnc#898675).
- pnfs: retry after a bad stateid error from layoutget
  (bnc#898675).
- pnfs: avoid using stale stateids after layoutreturn
  (bnc#898675).
- pnfs: allow splicing pre-encoded pages into the layoutcommit
  args (bnc#898675).
- pnfs/blocklayout: reject pnfs blocksize larger than page size
  (bnc#898675).
- pnfs/blocklayout: improve GETDEVICEINFO error reporting
  (bnc#898675).
- pnfs/blocklayout: plug block queues (bnc#898675).
- pnfs/blocklayout: correctly decrement extent length
  (bnc#898675).
- pnfs: force a layout commit when encountering busy segments
  during recall (bnc#898675).
- pnfs: add flag to force read-modify-write in ->write_begin
  (bnc#898675).
- pnfs: add return_range method (bnc#898675).
- pnfs/blocklayout: remove read-modify-write handling in
  bl_write_pagelist (bnc#898675).
- pnfs/blocklayout: don't set pages uptodate (bnc#898675).
- pnfs/blocklayout: rewrite extent tracking (bnc#898675).
- pnfs/blocklayout: implement the return_range method
  (bnc#898675).
- pnfs/blocklayout: return layouts on setattr (bnc#898675).
- pnfs: factor GETDEVICEINFO implementations (bnc#898675).
- pnfs: add a common GETDEVICELIST implementation (bnc#898675).
- pnfs: add a nfs4_get_deviceid helper (bnc#898675).
- pnfs/blocklayout: use the device id cache (bnc#898675).
- pnfs/blocklayout: remove some debugging (bnc#898675).
- pnfs: remove GETDEVICELIST implementation (bnc#898675).
- pnfs/blocklayout: allocate separate pages for the layoutcommit
  payload (bnc#898675).
- pnfs/blocklayout: move extent processing to blocklayout.c
  (bnc#898675).
- pnfs/blocklayout: refactor extent processing (bnc#898675).
- pnfs/blocklayout: move all rpc_pipefs related code into a
  single file (bnc#898675).
- pnfs/blocklayout: in-kernel GETDEVICEINFO XDR parsing
  (bnc#898675).
- pnfs: enable CB_NOTIFY_DEVICEID support (bnc#898675).
- pNFS/blocklayout: Remove a couple of unused variables
  (bnc#898675).
- pnfs/blocklayout: include vmalloc.h for __vmalloc (bnc#898675).
- pnfs/blocklayout: Fix a 64-bit division/remainder issue in
  bl_map_stripe (bnc#898675).
- commit fef99dc
* Tue Mar  3 2015 dbueso@suse.de
- rtmutex: Document pi chain walk (mutex scalability).
- commit da22449
* Tue Mar  3 2015 dbueso@suse.de
- rtmutex: No need to keep task ref for lock owner check (mutex
  scalability).
- commit 65359bb
* Tue Mar  3 2015 dbueso@suse.de
- rtmutex: Simplify rtmutex_slowtrylock() (mutex scalability).
- commit 295a557
* Mon Mar  2 2015 dbueso@suse.de
- Refresh
  patches.suse/locking-rtmutex-Optimize-setting-task-running-after.patch.
- commit 217beb9
* Thu Feb 26 2015 dvaleev@suse.com
- Added Little Endian support to vtpm module (bsc#918620).
- powerpc/pseries: Fix endian problems with LE migration
  (bsc#918584).
- commit 6d86405
* Wed Feb 25 2015 jack@suse.cz
- fsnotify: Fix handling of renames in audit (bnc#915200).
- commit 7b3b70a
* Wed Feb 25 2015 vbabka@suse.cz
- mm: vmscan: count only dirty pages as congested (VM Performance,
  bnc#910517).
- commit 0d5431f
* Wed Feb 25 2015 mkubecek@suse.cz
- net: fix creation adjacent device symlinks (bnc#915660).
- net: prevent of emerging cross-namespace symlinks (bnc#915660).
- rtnetlink: fix a memory leak when ->newlink fails (bnc#915660).
- net: correct error path in rtnl_newlink() (bnc#915660).
- net: add sysfs helpers for netdev_adjacent logic (bnc#915660).
- net: rename sysfs symlinks on device name change (bnc#915660).
- commit 5b57bc1
* Thu Feb 19 2015 duwe@suse.de
- virtio: rng: add derating factor for use by hwrng core
  (bsc#918615).
- commit 469bd42
* Thu Feb 19 2015 jslaby@suse.cz
- Refresh
  patches.drivers/0054-tcm_loop-separate-out-tcm_loop_issue_tmr.patch.
  Do not forget to update the hunk header.
- commit 2deacbd
* Thu Feb 19 2015 jslaby@suse.cz
- Refresh
  patches.drivers/0054-tcm_loop-separate-out-tcm_loop_issue_tmr.patch.
  One comment was left in place, while removed in upstream.
- commit 7e55df7
* Thu Feb 19 2015 mmarek@suse.cz
- Build rbd and libceph for all x86_64 flavors (bsc#918255)
- commit 08670af
* Thu Feb 19 2015 jbeulich@suse.com
- scsifront: don't use bitfields for indicators modified under
  different locks.
- MSI: also reject resource with flags all clear.
- pvscsi: support suspend/resume (bsc#902286).
- x86, crash: Allocate enough low-mem when crashkernel=high
  (bsc#905783).
- x86: irq: Check for valid irq descriptor
  incheck_irq_vectors_for_cpu_disable (bnc#914726).
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- Refresh other Xen patches.
- commit 0889248
* Thu Feb 19 2015 mgorman@suse.de
- Delete
  patches.suse/Btrfs-fix-abnormal-long-waiting-in-fsync.patch.
  Reenable
  patches.suse/mm-msync.c-sync-only-the-requested-range-in-msync.patch
  patches.suse/msync-fix-incorrect-fstart-calculation.patch
- commit 3996b51
* Thu Feb 19 2015 mgorman@suse.de
- Refresh
  patches.drivers/hpsa-additional-controller-ids.patch.
  patches.drivers/hpsa-driver-controller-namestring-revert.patch.
  patches.drivers/hpsa-driver-controller-namestring-update.patch.
  patches.drivers/hpsa-driver-vers-update-to-3.4.4-126.patch.
- commit cd31367
* Thu Feb 19 2015 lduncan@suse.com
- libceph: take map_sem for read in handle_reply() (FATE#318350
  bsc#918255).
- libceph: factor out logic from ceph_osdc_start_request()
  (FATE#318350 bsc#918255).
- libceph: fix error handling in ceph_osdc_init() (FATE#318350
  bsc#918255).
- libceph: follow redirect replies from osds (FATE#318350
  bsc#918255).
- libceph: rename ceph_osd_request::r_{oloc,oid} to
  r_base_{oloc,oid} (FATE#318350 bsc#918255).
- libceph: follow {read,write}_tier fields on osd request
  submission (FATE#318350 bsc#918255).
- libceph: add ceph_pg_pool_by_id() (FATE#318350 bsc#918255).
- libceph: replace ceph_calc_ceph_pg() with ceph_oloc_oid_to_pg()
  (FATE#318350 bsc#918255).
- libceph: introduce and start using oid abstraction (FATE#318350
  bsc#918255).
- libceph: rename MAX_OBJ_NAME_SIZE to CEPH_MAX_OID_NAME_LEN
  (FATE#318350 bsc#918255).
- libceph: start using oloc abstraction (FATE#318350 bsc#918255).
- libceph: dout() is missing a newline (FATE#318350 bsc#918255).
- libceph: add ceph_kv{malloc,free}() and switch to them
  (FATE#318350 bsc#918255).
- libceph: use CEPH_MON_PORT when the specified port is 0
  (FATE#318350 bsc#918255).
- crush: fix crush_choose_firstn comment (FATE#318350 bsc#918255).
- crush: attempts -> tries (FATE#318350 bsc#918255).
- crush: add set_choose_local_[fallback_]tries steps (FATE#318350
  bsc#918255).
- crush: generalize descend_once (FATE#318350 bsc#918255).
- crush: CHOOSE_LEAF -> CHOOSELEAF throughout (FATE#318350
  bsc#918255).
- crush: add SET_CHOOSE_TRIES rule step (FATE#318350 bsc#918255).
- crush: apply chooseleaf_tries to firstn mode too (FATE#318350
  bsc#918255).
- crush: new SET_CHOOSE_LEAF_TRIES command (FATE#318350
  bsc#918255).
- crush: pass parent r value for indep call (FATE#318350
  bsc#918255).
- crush: clarify numrep vs endpos (FATE#318350 bsc#918255).
- crush: strip firstn conditionals out of crush_choose, rename
  (FATE#318350 bsc#918255).
- crush: add note about r in recursive choose (FATE#318350
  bsc#918255).
- crush: use breadth-first search for indep mode (FATE#318350
  bsc#918255).
- crush: return CRUSH_ITEM_UNDEF for failed placements with indep
  (FATE#318350 bsc#918255).
- crush: eliminate CRUSH_MAX_SET result size limitation
  (FATE#318350 bsc#918255).
- crush: fix some comments (FATE#318350 bsc#918255).
- crush: reduce scope of some local variables (FATE#318350
  bsc#918255).
- crush: factor out (trivial) crush_destroy_rule() (FATE#318350
  bsc#918255).
- crush: pass weight vector size to map function (FATE#318350
  bsc#918255).
- libceph: update ceph_features.h (FATE#318350 bsc#918255).
- libceph: all features fields must be u64 (FATE#318350
  bsc#918255).
- rbd: tear down watch request if rbd_dev_device_setup() fails
  (FATE#318350 bsc#918255).
- rbd: introduce rbd_dev_header_unwatch_sync() and switch to it
  (FATE#318350 bsc#918255).
- rbd: enable extended devt in single-major mode (FATE#318350
  bsc#918255).
- rbd: add support for single-major device number allocation
  scheme (FATE#318350 bsc#918255).
- rbd: wire up is_visible() sysfs callback for rbd bus
  (FATE#318350 bsc#918255).
- rbd: add 'minor' sysfs rbd device attribute (FATE#318350
  bsc#918255).
- rbd: switch to ida for rbd id assignments (FATE#318350
  bsc#918255).
- rbd: refactor rbd_init() a bit (FATE#318350 bsc#918255).
- rbd: tweak "loaded" message and module description (FATE#318350
  bsc#918255).
- rbd: rbd_device::dev_id is an int, format it as such
  (FATE#318350 bsc#918255).
- ceph: Add necessary clean up if invalid reply received in
  handle_reply() (FATE#318350 bsc#918255).
- net: 8021q/bluetooth/bridge/can/ceph: Remove extern from
  function prototypes (FATE#318350 bsc#918255).
- libceph: CEPH_OSD_FLAG_* enum update (FATE#318350 bsc#918255).
- commit 49967d4
* Thu Feb 19 2015 mfasheh@suse.de
- xfs: xfs_alloc_fix_minleft can underflow near ENOSPC
  (bnc#913080).
- commit d695612
* Wed Feb 18 2015 tonyj@suse.de
- AUDIT: Allow login in non-init namespaces (bnc#916107).
- commit 3bb07bf
* Wed Feb 18 2015 mgorman@suse.de
- sched, time: Atomically increment stime & utime (Time
  scalability).
- time, signal: Protect resource use statistics with seqlock -kabi
  (Time scalability).
- time, signal: Protect resource use statistics with seqlock
  (Time scalability).
- exit: Always reap resource stats in __exit_signal() (Time
  scalability).
- sched: Change thread_group_cputime() to use for_each_thread()
  (Time scalability).
- take read_seqbegin_or_lock() and friends to seqlock.h (Time
  scalability).
- commit 09deeb3
* Wed Feb 18 2015 ohering@suse.de
- hyperv: Add support for vNIC hot removal.
- commit f45a4d8
* Wed Feb 18 2015 lduncan@suse.com
- Adding build of rbd and libceph for x86_64 (bsc#918255)
- commit f25bed1
* Wed Feb 18 2015 ohering@suse.de
- kabi/severities: Ignore changes in drivers/hv
- commit d6c0fff
* Tue Feb 17 2015 neilb@suse.de
- nfs_prime_dcache needs fh to be set (bnc#908069 bnc#896484).
- commit b6bd487
* Tue Feb 17 2015 jroedel@suse.de
- Refresh
  patches.fixes/kvm-iommu-add-cond_resched-to-legacy-device-assignment-code.
  Add upstream commit id and revision.
- commit 0a01c9b
* Tue Feb 17 2015 jroedel@suse.de
- x86, crash: Allocate enough low-mem when crashkernel=high
  (bsc#905783).
- x86, swiotlb: Try coherent allocations with __GFP_NOWARN
  (bsc#905783).
- swiotlb: Warn on allocation failure in swiotlb_alloc_coherent
  (bsc#905783).
- commit ca8b2f8
* Tue Feb 17 2015 mmarek@suse.cz
- net:socket: set msg_namelen to 0 if msg_name is passed as NULL
  in msghdr struct from userland (bnc#900270).
- commit 88dcd52
* Tue Feb 17 2015 jslaby@suse.cz
- Linux 3.12.38 (CVE-2014-3647 CVE-2014-3690 FATE#316038
  bnc#800255 bnc#856659 bnc#873901 bnc#876731 bnc#882900
  bnc#899192 bnc#901090 bnc#901809 bnc#902232 bnc#904659
  bnc#907969 bnc#907970 bsc#911181 bsc#913233 bsc#915188 bfo#71370
  bnc#907325 bnc#915210).
- kABI: protect struct netns_ipv4.
- kABI: protect struct ak4113/4.
- Refresh patches.arch/kvm-x86-fix-xsave-cpuid-exposing-bug.patch.
- Refresh
  patches.arch/kvm-x86-mask-unsupported-xsave-entries-from-leaf-0dh-index-0.patch.
- Refresh
  patches.arch/kvm-x86-only-copy-xsave-state-for-the-supported-features.patch.
- Refresh
  patches.arch/kvm-x86-prevent-setting-unsupported-xsave-states.patch.
- Refresh
  patches.drivers/0053-tcm_loop-Implement-transport-offline.patch.
- Refresh
  patches.drivers/0054-tcm_loop-separate-out-tcm_loop_issue_tmr.patch.
- Refresh
  patches.drivers/0055-tcm_loop-TCQ-and-command-abort-support.patch.
- Refresh
  patches.drivers/0064-target-Add-per-device-xcopy_lun-for-copy-offload-I-O.patch.
- Refresh
  patches.drivers/0065-target-Pass-through-I-O-topology-for-block-backstore.patch.
- Refresh
  patches.drivers/0115-target-file-Add-DIF-protection-support-to-fd_execute.patch.
- Refresh patches.fixes/dm-table-switch-to-readonly.
- Refresh
  patches.fixes/ipv6-do-not-overwrite-inetpeer-metrics-prematurely.patch.
- Delete
  patches.arch/ACPI-idle-permit-sparse-C-state-sub-state-numbers.patch.
- Delete patches.arch/kvm-vmx-inject-gp-on-invalid-pat-cr.patch.
- Delete
  patches.arch/kvm-x86-distinguish-between-stack-operation-and-near-branches.patch.
- Delete
  patches.arch/kvm-x86-emulating-descriptor-load-misses-long-mode-case.patch.
- Delete
  patches.arch/kvm-x86-getting-rid-of-grp45-in-emulator.patch.
- Delete
  patches.arch/kvm-x86-handle-errors-when-rip-is-set-during-far-jumps.patch.
- Delete
  patches.arch/kvm-x86-sysexit-emulation-does-not-mask-rip-rsp.patch.
- Delete
  patches.arch/kvm-x86-warn-if-guest-virtual-address-space-is-not-48-bits.patch.
- Delete patches.arch/pseries-endiannes-issue-in-rtas-xmon.patch.
- Delete
  patches.arch/x86-kvm-vmx-preserve-cr4-across-vm-entry.patch.
- Delete
  patches.drivers/0052-tcm_loop-Check-for-valid-hba-in-tcm_loop_drop_nexus.patch.
- Delete
  patches.drivers/iscsi_ibft-search-for-broadcom-specific-ibft-sign.
- Delete
  patches.drivers/x86-early-quirk-use-gen6-stolen-detection-for-VLV.patch.
- Delete
  patches.fixes/0001-SUNRPC-call_connect_status-should-recheck-bind-and-c.patch.
- Delete
  patches.fixes/0002-SUNRPC-Ensure-xprt_connect_status-handles-all-potent.patch.
- Delete
  patches.fixes/0003-SUNRPC-Handle-connect-errors-ECONNABORTED-and-EHOSTU.patch.
- Delete
  patches.fixes/0004-SUNRPC-Ensure-that-call_connect-times-out-correctly.patch.
- Delete
  patches.fixes/0005-SUNRPC-Ensure-call_connect_status-deals-correctly-wi.patch.
- Delete
  patches.fixes/0006-SUNRPC-Ensure-that-we-handle-ENOBUFS-errors-correctl.patch.
- Delete
  patches.fixes/0007-SUNRPC-Handle-EPIPE-in-xprt_connect_status.patch.
- Delete
  patches.fixes/SELinux-fix-selinuxfs-policy-file-on-big-endian-systems.
- Delete
  patches.fixes/acpi-fix-bug-when-acpi-reset-register-is-implemented-in-system-memory.patch.
- Delete
  patches.fixes/dm-do-not-call-dm_sync_table-when-creating-new-devices.patch.
- Delete
  patches.fixes/net-sunrpc-suppress-allocation-warning-in-rpc_malloc.patch.
- Delete
  patches.fixes/ocfs2-remove-filesize-checks-for-sync-io-journal-commit.
- Delete
  patches.fixes/parport-parport_pc-do-not-remove-parent-devices-earl.
- Delete patches.fixes/tcm_loop-Wrong-I_T-nexus-association.patch.
- Delete
  patches.fixes/udf-Check-component-length-before-reading-it.patch.
- Delete
  patches.fixes/udf-Check-path-length-when-reading-symlink.patch.
- Delete patches.fixes/udf-Verify-i_size-when-loading-inode.patch.
- Delete
  patches.fixes/x86-uv-bau-avoid-null-pointer-reference-in-ptc_seq_show.
- Delete
  patches.suse/ipc-sem-change-memory-barrier-in-sem-lock.patch.
- commit d07dcc3
* Tue Feb 17 2015 eich@suse.de
- DRM/i915: On G45 enable cursor plane briefly after enabling
  the display plane (bnc#918161).
- commit 0700c45
* Tue Feb 17 2015 bpoirier@suse.de
- be2net: avoid flashing SH-B0 UFI image on SH-P2 chip
  (bug#908322).
- be2net: refactor code that checks flash file compatibility
  (bug#908322).
- PCI: Add ACS quirk for Emulex NICs (bug#917089).
- PCI: Add ACS quirk for Intel 10G NICs (bug#917089).
- PCI: Add ACS quirk for Solarflare SFC9120 & SFC9140
  (bug#917089).
- commit f079876
* Mon Feb 16 2015 jslaby@suse.cz
- Refresh patches.arch/kvm-vmx-inject-gp-on-invalid-pat-cr.patch.
- Refresh
  patches.arch/kvm-x86-warn-if-guest-virtual-address-space-is-not-48-bits.patch.
  Revert the patch changes. These were unintentional.
- commit 173e056
* Mon Feb 16 2015 jslaby@suse.cz
- Refresh
  patches.arch/ACPI-idle-permit-sparse-C-state-sub-state-numbers.patch.
- Refresh patches.arch/kvm-vmx-inject-gp-on-invalid-pat-cr.patch.
- Refresh
  patches.arch/kvm-x86-warn-if-guest-virtual-address-space-is-not-48-bits.patch.
- Refresh
  patches.drivers/intel_idle-Add-CPU-model-54-Atom-N2000-series.patch.
- Refresh
  patches.fixes/crypto-drbg-panic-on-continuous-self-test-error.
- Refresh
  patches.fixes/dm-do-not-call-dm_sync_table-when-creating-new-devices.patch.
- Refresh
  patches.fixes/md-be-more-relaxed-about-stopping-an-array-which-isn.patch.
- ocfs2: remove filesize checks for sync I/O journal commit
  (bnc#800255).
  Update references.
- commit 5ef1de3
* Mon Feb 16 2015 jslaby@suse.cz
- Refresh patches.arch/kvm-vmx-inject-gp-on-invalid-pat-cr.patch.
- Refresh
  patches.arch/kvm-x86-distinguish-between-stack-operation-and-near-branches.patch.
- Refresh
  patches.arch/kvm-x86-emulating-descriptor-load-misses-long-mode-case.patch.
- Refresh
  patches.arch/kvm-x86-getting-rid-of-grp45-in-emulator.patch.
- Refresh
  patches.arch/kvm-x86-handle-errors-when-rip-is-set-during-far-jumps.patch.
- Refresh
  patches.arch/kvm-x86-sysexit-emulation-does-not-mask-rip-rsp.patch.
- Refresh
  patches.arch/kvm-x86-use-new-is_noncanonical_address-in-linearize.patch.
- Refresh
  patches.arch/kvm-x86-warn-if-guest-virtual-address-space-is-not-48-bits.patch.
  Add Git-commit's.
- commit d477437
* Mon Feb 16 2015 vbabka@suse.cz
- mm/compaction: stop the isolation when we isolate enough
  freepage (VM Performance, bnc#904177).
- mm/compaction: fix wrong order check in compact_finished()
  (VM Performance, bnc#904177).
- commit a9de891
* Mon Feb 16 2015 vbabka@suse.cz
- mm: fix negative nr_isolated counts (VM Performance).
- commit e819397
* Sun Feb 15 2015 dbueso@suse.de
- epoll: optimize setting task running after blocking
  (epoll-performance).
- commit 2a084cd
* Thu Feb 12 2015 mkubecek@suse.cz
- net: allow macvlans to move to net namespace (bnc#915660).
- flow_dissector: add tipc support (bnc#916513).
- commit 65cdbbe
* Thu Feb 12 2015 jroedel@suse.de
- x86: irq: Check for valid irq descriptor in
  check_irq_vectors_for_cpu_disable (bnc#914726).
- commit a4f98be
* Wed Feb 11 2015 fdmanana@suse.com
- Update
  patches.suse/btrfs-8177-improve-free-space-cache-management-and-space-.patch
  (bnc#895805).
- commit b293e92
* Tue Feb 10 2015 fdmanana@suse.com
- Btrfs: fix fsync race leading to ordered extent memory leaks
  (bnc#917128).
- commit 2269bb1
* Tue Feb 10 2015 fdmanana@suse.com
- Btrfs: scrub, fix sleep in atomic context (bnc#915456).
- commit 6759146
* Tue Feb 10 2015 oneukum@suse.de
- usb-storage: support for more than 8 LUNs (bsc#906196).
- commit 8ec42e9
* Tue Feb 10 2015 dbueso@suse.de
- sched/completion: Add lock-free checking of the blocking case
  (scheduler scalability).
- commit a8449c2
* Tue Feb 10 2015 dbueso@suse.de
- mutex-debug: Always clear owner field upon mutex_unlock()
  (mutex bugfix).
- commit d8792d2
* Tue Feb 10 2015 dbueso@suse.de
- sched/Documentation: Remove unneeded word (mutex scalability).
- commit ecc9b3e
* Tue Feb 10 2015 dbueso@suse.de
- locking/osq: No need for load/acquire when acquire-polling
  (mutex scalability).
- commit 8090e99
* Tue Feb 10 2015 dbueso@suse.de
- locking/mutex: Explicitly mark task as running after wakeup
  (mutex scalability).
- commit 4ff1b1d
* Tue Feb 10 2015 dbueso@suse.de
- locking/rtmutex: Optimize setting task running after being
  blocked (mutex scalability).
- commit 9908ffa
* Mon Feb  9 2015 mszeredi@suse.cz
- splice: add generic_write_checks() (bnc#915322 CVE-2014-7822).
- commit cd25d8c
* Sat Feb  7 2015 bp@suse.de
- x86_64, switch_to(): Load TLS descriptors before switching DS
  and ES (bsc#911326, CVE-2014-9419).
- commit ea59438
* Sat Feb  7 2015 bp@suse.de
- x86/hpet: Make boot_hpet_disable extern (FATE#316038,
  bnc#916646).
- commit 971b581
* Fri Feb  6 2015 eich@suse.de
- x86/intel: Add quirk to disable HPET for the Baytrail platform
  (FATE#316038, bnc#916646).
- commit ba87174
* Fri Feb  6 2015 dsterba@suse.cz
- Delete patches.suse/btrfs-8176-make-btrfs_search_forward-return-with-nodes-un.patch.
- commit c376443
* Fri Feb  6 2015 dsterba@suse.cz
- Btrfs: fix missing error handler if submiting re-read bio fails.
- Btrfs: improve free space cache management and space allocation.
- Btrfs: make btrfs_search_forward return with nodes unlocked.
- Btrfs: avoid unnecessary switch of path locks to blocking mode.
- Btrfs: unlock nodes earlier when inserting items in a btree.
- commit d11145b
* Fri Feb  6 2015 dsterba@suse.cz
- Update git-commit tags
- Refresh
  patches.suse/btrfs-0403-btrfs-add-trace-for-qgroup-accounting.patch.
- Refresh
  patches.suse/btrfs-0406-btrfs-handle-return-from-ulist-add.patch.
- Refresh
  patches.suse/btrfs-0408-dont-crash-on-existing-qgroup-item.patch.
- Refresh
  patches.suse/btrfs-8051-label-should-not-contain-return-char.patch.
- Refresh
  patches.suse/btrfs-8053-device-add-must-be-sysloged.patch.
- Refresh
  patches.suse/btrfs-8054-device-delete-must-be-sysloged.patch.
- Refresh
  patches.suse/btrfs-8058-set-error-return-value-in-btrfs_get_blocks_dir.patch.
- Refresh
  patches.suse/btrfs-8071-fix-fsync-race-leading-to-invalid-data-after-l.patch.
- Refresh
  patches.suse/btrfs-8072-print-btrfs-specific-info-for-some-fatal-error.patch.
- Refresh
  patches.suse/btrfs-8073-fix-off-by-one-in-cow_file_range_inline.patch.
- Refresh
  patches.suse/btrfs-8074-fix-wrong-max-inline-data-size-limit.patch.
- Refresh
  patches.suse/btrfs-8075-sysfs-label-interface-should-check-for-read-on.patch.
- Refresh
  patches.suse/btrfs-8076-shrink-further-sizeof-struct-extent_buffer.patch.
- Refresh
  patches.suse/btrfs-8077-fix-data-corruption-after-fast-fsync-and-writeback-error.patch.
- Refresh
  patches.suse/btrfs-8078-fix-directory-recovery-from-fsync-log.patch.
- Refresh
  patches.suse/btrfs-8080-add-missing-compression-property-remove-in-btr.patch.
- Refresh
  patches.suse/btrfs-8087-fix-crash-of-btrfs_release_extent_buffer_page.patch.
- Refresh
  patches.suse/btrfs-8088-add-missing-end_page_writeback-on-submit_exten.patch.
- Refresh
  patches.suse/btrfs-8089-be-aware-of-btree-inode-write-errors-to-avoid-.patch.
- Refresh
  patches.suse/btrfs-8123-send-don-t-delay-dir-move-if-there-s-a-new-par.patch.
- Refresh
  patches.suse/btrfs-8134-fix-wrong-accounting-of-raid1-data-profile-in-.patch.
- commit d492858
* Fri Feb  6 2015 dvaleev@suse.com
- hotplug, powerpc, x86: Remove cpu_hotplug_driver_lock()
  (bsc#907069).
- commit 5922f3e
* Thu Feb  5 2015 jbeulich@suse.com
- re-order derived Xen patches to match their originals
- commit 4433909
* Thu Feb  5 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix build if there is no *.crt file
- commit c5b1275
* Wed Feb  4 2015 duwe@suse.de
- random: account for entropy loss due to overwrites
  (bsc#904883,bsc#904901).
- random: allow fractional bits to be tracked
  (bsc#904883,bsc#904901).
- random: statically compute poolbitshift, poolbytes, poolbits
  (bsc#904883,bsc#904901).
- commit e692a35
* Wed Feb  4 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.36-37 (CVE-2014-8559
  CVE-2014-9585 bnc#877456 bnc#897736 bnc#903640 bnc#905329
  bnc#908904 bsc#908825 bnc#912202 bsc#912705).
- commit 31ecb06
* Tue Feb  3 2015 jjolly@suse.de
- zcrypt: Number of supported ap domains is not retrievable
  (bnc#914291, LTC#120788).
- kernel: incorrect clock_gettime result (bnc#914291, LTC#121184).
- dasd: List corruption in error recovery (bnc#914291,
  LTC#120865).
- s390/dasd: remove unused code (bnc#914291, LTC#120608).
- s390/dasd: fix infinite loop during format (bnc#914291,
  LTC#120608).
- commit 628a604
* Tue Feb  3 2015 jbeulich@suse.com
- scsifront: avoid acquiring same lock twice if ring is full.
- kabi/severities: Ignore netfront exports.
- Refresh other Xen patches (bsc#909829).
- commit e2ad5c4
* Mon Feb  2 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.10-11 (LTC#103626
  LTC#103627 bnc#799216 bnc#860346 bnc#915335).
- commit e96a261
* Sun Feb  1 2015 jbohac@suse.cz
- netfilter: conntrack: disable generic tracking for known
  protocols (bsc#913059, CVE-2014-8160).
- commit f32dab8
* Fri Jan 30 2015 mmarek@suse.cz
- rpm/constraints.in: Lower the requirement to 4 CPUs on POWER
- commit 9e50821
* Fri Jan 30 2015 fdmanana@suse.com
- Btrfs: fix race between transaction commit and empty block
  group removal (bnc#915550).
- Btrfs: fix scrub race leading to use-after-free (bnc#915456).
- Btrfs: fix setup_leaf_for_split() to avoid leaf corruption
  (bnc#915454).
- commit 1c9651b
* Fri Jan 30 2015 jlee@suse.com
- KEYS: close race between key lookup and freeing (bnc#912202).
- commit 355a706
* Thu Jan 29 2015 dvaleev@suse.com
- powerpc/xmon: Fix another endiannes issue in RTAS call from xmon
  (bsc#915188).
- commit 310eccf
* Thu Jan 29 2015 duwe@suse.de
- __driver-gcm-aes-aesni needs to be listed explicitly inside
  the testmgr.c file (bsc#914457).
- Update patches.suse/allow-gcm_aes-for-FIPS-140-2
  (bsc#914126,bsc#914457).
- commit c297b05
* Thu Jan 29 2015 fdmanana@suse.com
- Btrfs: fix fsync log replay for inodes with a mix of regular
  refs and extrefs (bnc#915425).
- Btrfs: fix fsync when extend references are added to an inode
  (bnc#915425).
- Btrfs: fix directory inconsistency after fsync log replay
  (bnc#915425).
- commit 3a78dc3
* Wed Jan 28 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.33-34 (CVE-2014-3673
  CVE-2014-3687 CVE-2014-7841 bnc#875220 bnc#884407 bnc#902346
  bnc#902349 bnc#904899 bnc#905100).
- commit b2d9c0a
* Wed Jan 28 2015 jslaby@suse.cz
- Linux 3.12.37 (CVE-2014-8559 CVE-2014-9585 bnc#897736 bnc#903640
  bnc#905329 bnc#908904 bsc#908825 bnc#912202 bsc#912705).
- kABI: protect pagecache_get_page.
- kABI: reintroduce tick_nohz_idle_enter/exit.
- Refresh
  patches.arch/powernv-134-book3s-Queue-up-and-process-delayed-MCE-events.
- Refresh
  patches.arch/ppc-book3s-Return-from-interrupt-if-coming-from-evil-context.
- Refresh patches.arch/ppc-mce-4-move-machine-check-code.
- Refresh
  patches.arch/ppc64le-0008-Set-MSR_LE-bit-on-little-endian-builds.
- Refresh
  patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function.
- Refresh
  patches.arch/ppc64le-kvm-0032-kvm-powerpc-book3s-Add-a-new-config-variable-CONFIG_.patch.
- Refresh
  patches.drivers/0002-USB-EHCI-code-rearrangement-in-iso_stream_schedule.patch.
- Refresh
  patches.drivers/0003-USB-EHCI-handle-isochronous-underruns-with-tasklets.patch.
- Refresh
  patches.drivers/0060-ib_isert-Add-support-for-completion-interrupt-coales.patch.
- Refresh
  patches.drivers/0112-target-Add-protection-SGLs-to-target_submit_cmd_map_.patch.
- Refresh
  patches.drivers/0120-IB-isert-seperate-connection-protection-domains-and-.patch.
- Refresh
  patches.drivers/0121-IB-isert-Avoid-frwr-notation-user-fastreg.patch.
- Refresh
  patches.drivers/0152-IB-isert-Accept-RDMA_WRITE-completions.patch.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- Delete
  patches.arch/x86_64-vdso-fix-the-vdso-address-randomization-algorithm.patch.
- Delete patches.drivers/hp_accel-Add-support-for-HP-ZBook-15.
- Delete
  patches.fixes/0001-KEYS-close-race-between-key-lookup-and-freeing.patch.
- Delete patches.fixes/deal-with-deadlock-in-d_walk.patch.
- Delete
  patches.fixes/fsnotify-next_i-is-freed-during-fsnotify_unmount_ino.patch.
- Delete
  patches.fixes/iommu-vt-d-fix-an-off-by-one-bug-in-_domain_mapping.
- Delete
  patches.fixes/media-uvc-Fix-destruction-order-in-uvc_delete.
- Delete
  patches.fixes/move-d_rcu-from-overlapping-d_child-to-overlapping-d.patch.
- Delete
  patches.suse/msft-hv-0697-Drivers-hv-vmbus-Fix-a-race-condition-when-unregiste.patch.
- Delete
  patches.suse/msft-hv-0710-storvsc-ring-buffer-failures-may-result-in-I-O-freez.patch.
- Update config files.
- commit 9c57ddf
* Tue Jan 27 2015 jroedel@suse.de
- kvm: iommu: Add cond_resched to legacy device assignment code
  (bsc#898687).
- commit c226147
* Tue Jan 27 2015 jack@suse.cz
- Add CVE reference (CVE-2014-9584)
- commit eca6c58
* Mon Jan 26 2015 mmarek@suse.cz
- DocBook: Do not exceed argument list limit.
- DocBook: Make mandocs parallel-safe.
- commit 4356326
* Mon Jan 26 2015 mmarek@suse.cz
- locking/doc: Update references to kernel/mutex.c.
- commit 76cbc30
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not generate pdf documents
  This has only recently been fixed in master
- commit aae4843
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not ignore errors from make
- commit 86ebfa7
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop sparse from BuildRequires
- commit 9777c26
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Update the comment about NO_BRP_STALE_LINK_ERROR
  There is no stale symlink in the installed system anymore, but there is
  one during build.
- commit e575cce
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the modules directory in the devel
  package (bnc#910322)
- commit d89b963
* Fri Jan 23 2015 oneukum@suse.de
- uas: Use streams on upcoming 10Gbps / 3.1 USB (bnc#914464).
- commit 26f1025
* Thu Jan 22 2015 duwe@suse.de
- crypto: drbg - panic on continuous self test error (bsc#905482).
- commit 9f8357f
* Thu Jan 22 2015 duwe@suse.de
- We need to activate gcm(aes) in FIPS mode, RFCs 4106 and 4543
  (bsc#914126).
- commit e483927
* Thu Jan 22 2015 oneukum@suse.de
- uas: disable UAS on Apricorn SATA dongles (bnc#914300).
- commit b78fdaa
* Thu Jan 22 2015 oneukum@suse.de
- uas: Do not blacklist ASM1153 disk enclosures (bnc#914294).
- uas: Add missing le16_to_cpu calls to asm1051 / asm1053 usb-id
  check (bnc#914294).
- uas: Disable uas on ASM1051 devices (bnc#914294).
- commit e479ded
* Thu Jan 22 2015 oneukum@suse.de
- uas: Add US_FL_NO_ATA_1X for 2 more Seagate disk enclosures
  (bnc#914254).
- uas: Add US_FL_NO_ATA_1X quirk for 2 more Seagate models
  (bnc#914254).
- uas: Add NO_ATA_1X for VIA VL711 devices (bnc#914254).
- uas: Add US_FL_NO_ATA_1X quirk for 1 more Seagate model
  (bnc#914254).
- uas: Add US_FL_NO_ATA_1X for Seagate devices with usb-id
  0bc2:a013 (bnc#914254).
- uas: Add no-report-opcodes quirk (bnc#914254).
- uas: Add US_FL_NO_ATA_1X quirk for Seagate (0bc2:ab20) drives
  (bnc#914254).
- commit c89cab3
* Thu Jan 22 2015 oneukum@suse.de
- uas: Add a quirk for rejecting ATA_12 and ATA_16 commands
  (bnc#914254).
- commit df7b8ad
* Wed Jan 21 2015 mmarek@suse.cz
- Refresh patches.suse/supported-flag-external.
- commit 2c12935
* Wed Jan 21 2015 mmarek@suse.cz
- Fix Module.supported handling for external modules (bnc#905304).
- commit b57f055
* Wed Jan 21 2015 oneukum@suse.de
- xhci: Add broken-streams quirk for Fresco Logic FL1000G xhci
  controllers (bnc#914112).
- commit 3191e2e
* Tue Jan 20 2015 mszeredi@suse.cz
- kapi: fix move of d_rcu (bnc#903640 CVE-2014-8559).
- commit 0eb7bcc
* Tue Jan 20 2015 dchang@suse.com
- cxgb4: Fix FW flash logic using ethtool (bsc#912290).
- cxgb4: Allow T4/T5 firmware sizes up to 1MB (bsc#912290).
- cxgb4: Fix T5 adapter accessing T4 adapter registers
  (bsc#912290).
- cxgb4: Fix for handling 1Gb/s SFP+ Transceiver Modules
  (bsc#912290).
- cxgb4: Free completed tx skbs promptly (bsc#912290).
- cxgb4: Fix race condition in cleanup (bsc#912290).
- cxgb4: Add the MC1 registers to read in the interrupt handler
  (bsc#912290).
- cxgb4: Use FW interface to get BAR0 value (bsc#912290).
- cxgb4: Not need to hold the adap_rcu_lock lock when read
  adap_rcu_list (bsc#912290).
- commit 6b8698e
* Mon Jan 19 2015 bp@suse.de
- x86_64, vdso: Fix the vdso address randomization algorithm
  (bsc#912705, CVE-2014-9585).
- commit a5fee9a
* Mon Jan 19 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.35-36 (CVE-2014-8133
  CVE-2014-9420 fate#315482 FATE#316917 LTC#114562 bnc#862374
  bnc#891086 bnc#906545 bnc#908163 bnc#908198 bnc#911325
  bsc#909077).
  Add one more reference.
- commit 58488c9
* Mon Jan 19 2015 duwe@suse.de
- powerpc/pseries/hvcserver: Fix endian issue in
  hvcs_get_partner_info (bsc#912129).
- commit 19f9d87
* Mon Jan 19 2015 duwe@suse.de
- SELinux: fix selinuxfs policy file on big endian systems
  (bsc#913233).
- commit a4b96cc
* Fri Jan 16 2015 fdmanana@suse.com
- Btrfs: make xattr replace operations atomic (bnc#913466).
- commit 959b582
* Fri Jan 16 2015 dvaleev@suse.com
- powerpc/fadump: Fix endianess issues in firmware assisted dump
  handling (bsc#889192).
- commit c79d25f
* Fri Jan 16 2015 duwe@suse.de
- crypto: aesni - Add support for 192 & 256 bit keys to AESNI
  RFC4106 (bsc#913387).
- commit c9e00fc
* Thu Jan 15 2015 mszeredi@suse.cz
- deal with deadlock in d_walk() (bnc#903640 CVE-2014-8559).
- kabi: fix for move of d_rcu (bnc#903640 CVE-2014-8559).
- move d_rcu from overlapping d_child to overlapping d_alias
  (bnc#903640 CVE-2014-8559).
- commit 831790e
* Thu Jan 15 2015 bpoirier@suse.de
- benet: Use pci_enable_msix_range() instead of pci_enable_msix()
  (bug#912281).
- PCI/MSI: Add pci_enable_msi_range() and pci_enable_msix_range()
  (bug#912281).
- PCI/MSI: Add pci_enable_msi_range() and pci_enable_msix_range()
  (bug#912281).
- Refresh patches.xen/xen3-auto-common.diff.
- commit 364a724
* Wed Jan 14 2015 fdmanana@suse.com
- Btrfs: ensure ordered extent errors aren't missed on fsync
  (bnc#912946).
- Btrfs: collect only the necessary ordered extents on ranged
  fsync (bnc#912946).
- Btrfs: don't ignore log btree writeback errors (bnc#912946).
- Btrfs: make sure logged extents complete in the current
  transaction V3 (bnc#912946).
- Btrfs: make sure we wait on logged extents when fsycning two
  subvols (bnc#912946).
- Btrfs: fix abnormal long waiting in fsync (bnc#912946).
- Btrfs: use helpers for last_trans_log_full_commit instead of
  opencode (bnc#912946).
- commit 5a0157e
* Wed Jan 14 2015 jack@suse.cz
- fsnotify: next_i is freed during fsnotify_unmount_inodes
  (bnc#908904).
- commit 25b0672
* Tue Jan 13 2015 jbeulich@suse.com
- x86: fix step size adjustment during initial memory mapping
  (bsc#910249).
- patches.xen/xen-privcmd-hcall-preemption: Fix EFLAGS.IF check.
- Refresh other Xen patches.
- commit a89c3a9
* Tue Jan 13 2015 jslaby@suse.cz
- series.conf: remove orphan bnc comments
- commit 63df8c9
* Mon Jan 12 2015 jslaby@suse.cz
- Update
  patches.suse/kgr-0055-kgr-handle-IRQ-context-using-global-variable.patch
  (fate#313296 bnc#912278).
  add bnc entry
- commit 42e7a48
* Fri Jan  9 2015 fdmanana@suse.com
- Btrfs: fix fs corruption on transaction abort if device supports
  discard (bnc#908198).
- Btrfs: ensure deletion from pinned_chunks list is protected
  (bnc#908198).
- Btrfs: fix unprotected deletion from pending_chunks list
  (bnc#908198).
- Btrfs: fix fs mapping extent map leak (bnc#908198).
- Btrfs: fix memory leak after block remove + trimming
  (bnc#908198).
- Btrfs: make btrfs_abort_transaction consider existence of new
  block groups (bnc#908198).
- Btrfs: fix race between writing free space cache and trimming
  (bnc#908198).
- Btrfs: fix race between fs trimming and block group
  remove/allocation (bnc#908198).
- commit 5b7e5b1
* Fri Jan  9 2015 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8090-deal-with-convert_extent_bit-errors-to-avoid-f.patch.
- Refresh
  patches.suse/btrfs-8091-make-find_first_extent_bit-be-able-to-cache-an.patch.
- Refresh
  patches.suse/btrfs-8092-avoid-returning-ENOMEM-in-convert_extent_bit-t.patch.
- Refresh
  patches.suse/btrfs-8124-set-page-and-mapping-error-on-compressed-write.patch.
- Refresh
  patches.suse/btrfs-8125-fix-hang-on-compressed-write-error.patch.
- Refresh
  patches.suse/btrfs-8126-don-t-leak-pages-and-memory-on-compressed-writ.patch.
- Refresh
  patches.suse/btrfs-8127-process-all-async-extents-on-compressed-write-.patch.
- Refresh
  patches.suse/btrfs-8128-make-inode.c-submit_compressed_extents-return-.patch.
- Refresh
  patches.suse/btrfs-8129-don-t-ignore-compressed-bio-write-errors.patch.
- Refresh
  patches.suse/btrfs-8130-report-error-after-failure-inlining-extent-in-.patch.
- Refresh
  patches.suse/btrfs-8131-make-inode.c-compress_file_range-return-void.patch.
- Refresh
  patches.suse/btrfs-8132-correctly-flush-compressed-data-before-after-d.patch.
- Refresh
  patches.suse/btrfs-8133-add-helper-btrfs_fdatawrite_range.patch.
- commit 41c5fb1
* Fri Jan  9 2015 fdmanana@suse.com
- Btrfs: always clear a block group node when removing it from
  the tree (bnc#912514).
- Btrfs: fix freeing used extents after removing empty block group
  (bnc#912514).
- Btrfs: fix crash caused by block group removal (bnc#912514).
- Btrfs: fix invalid block group rbtree access after bg is removed
  (bnc#912514).
- Btrfs: fix freeing used extent after removing empty block group
  (bnc#912514).
- Btrfs: remove empty block groups automatically (bnc#912514).
- Btrfs: Fix misuse of chunk mutex (bnc#912514).
- Btrfs: fix unprotected system chunk array insertion
  (bnc#912514).
- commit 4b4dad0
* Fri Jan  9 2015 jslaby@suse.cz
- kgr: handle IRQ context using global variable (fate#313296).
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
- Refresh patches.kabi/kgr-0103-kabi-protect_kgr_structs.patch.
- commit 52c20e6
* Fri Jan  9 2015 ohering@suse.de
- hyperv: Fix some variable name typos in send-buffer init/revoke.
- storvsc: ring buffer failures may result in I/O freeze.
- hv: hv_balloon: avoid memory leak on alloc_error of 2MB
  memory block.
- tools: hv: ignore ENOBUFS and ENOMEM in the KVP daemon.
- Tools: hv: vssdaemon: skip all filesystems mounted readonly.
- Tools: hv: vssdaemon: report freeze errors.
- Drivers: hv: kvp,vss: Fast propagation of userspace
  communication failure.
- Drivers: hv: vss: Introduce timeout for communication with
  userspace.
- net: Hyper-V: Deletion of an unnecessary check before the
  function call "vfree".
- hyperv: Add processing of MTU reduced by the host.
- Drivers: hv: vmbus: Fix a race condition when unregistering
  a device.
- Drivers: hv: util: make struct hv_do_fcopy match Hyper-V
  host messages.
- tools: hv: introduce -n/--no-daemon option.
- Tools: hv: vssdaemon: ignore the EBUSY on multiple freezing
  the same partition.
- hyperv: Fix the total_data_buflen in send path.
- Drivers: hv: util: Properly pack the data for file copy
  functionality.
- commit 217420c
* Thu Jan  8 2015 jslaby@suse.cz
- Linux 3.12.36 (CVE-2014-8133 CVE-2014-9420 fate#315482 FATE#316917
  LTC#114562 bnc#862374 bnc#891086 bnc#908163 bnc#908198 bnc#911325
  bsc#909077).
- kABI: protect struct user_namespace.
- kABI: protect user_namespace.h include in kernel/groups.c.
- Refresh
  patches.drivers/mlx-0014-net-mlx4_core-Implement-resource-quota-enforcement.patch.
- Refresh
  patches.suse/0001-KEYS-fix-uninitialized-persistent_keyring_register_s.patch.
- Refresh
  patches.suse/0012-KEYS-Add-per-user_namespace-registers-for-persistent.patch.
- Refresh
  patches.suse/mm-thp-move-ptl-taking-inside-page_check_address_pmd.patch.
- Delete patches.arch/s390-sles12-10-02-3215-tty-hang.patch.
- Delete
  patches.fixes/KEYS-Fix-stale-key-registration-at-error-path.
- Delete
  patches.fixes/audit-change-decimal-constant-to-macro-for-invalid-uid.patch.
- Delete
  patches.fixes/isofs-Fix-infinite-looping-over-CE-entries.patch.
- Delete
  patches.fixes/isofs-Fix-unchecked-printing-of-ER-records.patch.
- Delete
  patches.fixes/udf-Verify-symlink-size-before-loading-it.patch.
- Delete
  patches.fixes/x86-tls-validate-tls-entries-to-protect-espfix.patch.
- Delete
  patches.suse/btrfs-8160-fix-fs-corruption-on-transaction-abort-if-devi.patch.
- Delete
  patches.suse/mm-let-mm_find_pmd-fix-buggy-race-with-THP-fault.patch
- Delete
  patches.suse/thp-close-race-between-split-and-zap-huge-pages.patch.
- commit c368df3
* Thu Jan  8 2015 jslaby@suse.cz
- kgr: set revert slow state for all reverted symbols when
  loading patched module (fate#313296).
- kgr: fix typo in error message (fate#313296).
- commit 7a6fd4f
* Thu Jan  8 2015 jslaby@suse.cz
- kgr: fix unwinder and user addresses (fate#313296, bnc#908803).
- commit 97532c9
* Tue Jan  6 2015 dsterba@suse.cz
- Btrfs: don't delay inode ref updates during log replay.
- Refresh patches.suse/btrfs-0404-account-shared-subtrees.patch.
- Refresh
  patches.suse/btrfs-0405-__btrfs_mod_ref-should-always-use-no_quo.patch.
- Refresh
  patches.suse/btrfs-8050-fill_holes-Fix-slot-number-passed-to-hole_merg.patch.
- Refresh
  patches.suse/btrfs-8052-adjust-statfs-calculations-according-to-raid-p.patch.
- Refresh
  patches.suse/btrfs-8061-fix-wrong-write-range-for-filemap_fdatawrite_r.patch.
- commit d97a246
* Tue Jan  6 2015 dsterba@suse.cz
- btrfs: free ulist in qgroup_shared_accounting() error path.
- Btrfs: remove unused wait queue in struct extent_buffer.
- Btrfs: ensure btrfs_prev_leaf doesn't miss 1 item.
- btrfs: replace EINVAL with ERANGE for resize when ULLONG_MAX.
- Btrfs: fix transaction leak during fsync call.
- Btrfs: ioctl, don't re-lock extent range when not necessary.
- Btrfs: don't access non-existent key when csum tree is empty.
- commit 6b99ed7
* Tue Jan  6 2015 mmarek@suse.cz
- rpm/gitlog-fixups: Fix invalid address in two commits
- commit e15e84b
* Tue Jan  6 2015 jack@suse.cz
- udf: Check component length before reading it.
- udf: Check path length when reading symlink.
- udf: Verify symlink size before loading it.
- udf: Verify i_size when loading inode.
- isofs: Fix unchecked printing of ER records.
- isofs: Fix infinite looping over CE entries (bnc#911325
  CVE-2014-9420).
- commit 713d309
* Mon Jan  5 2015 dvaleev@suse.com
- powerpc: fix dlpar memory
- commit f5e56da
* Mon Jan  5 2015 jroedel@suse.de
- x86: UV BAU: Increase maximum CPUs per socket/hub (bsc#911181).
- x86: UV BAU: Avoid NULL pointer reference in ptc_seq_show
  (bsc#911181).
- commit 37e1824
* Mon Jan  5 2015 jslaby@suse.cz
- Refresh patches.kabi/kgr-0103-kabi-protect_kgr_structs.patch.
  New kabi breakage fixed.
- commit da371a6
* Mon Jan  5 2015 jslaby@suse.cz
- kgr: allow to search various types of struct kgr_patch_fun
  (fate#313296).
- kgr: be consistent when applying patches on loaded modules
  (fate#313296).
- kgr: unregister only the used ftrace ops when removing a
  patched module (fate#313296).
- kgr: fix replace_all (fate#313296 fate#318214).
- Refresh
  patches.suse/kgr-0102-kgr-mark-kernel-unsupported-upon-patch-revert.patch.
- commit 3cd4a61
* Fri Dec 19 2014 mhocko@suse.cz
- Disabled patches.suse/mm-msync.c-sync-only-the-requested-range-in-msync.patch (bnc#910697)
  because it needs to be revisited due partial msync behavior.
  Conflicts:
  series.conf
- Disabled patches.suse/mm-msync.c-sync-only-the-requested-range-in-msync.patch (bnc#910697)
  because it needs to be revisited due partial msync behavior.
- commit a2814e9
* Fri Dec 19 2014 mhocko@suse.cz
- Disbale patches.suse/msync-fix-incorrect-fstart-calculation.patch (bnc#910697)
  because it needs to be revisited due partial msync behavior.
- commit 5ffdbe0
* Fri Dec 19 2014 mhocko@suse.cz
- Disable patches.suse/Btrfs-fix-abnormal-long-waiting-in-fsync.patch
  (bnc#910697)
  because it needs to be revisited due partial msync behavior.
- commit 353305a
* Fri Dec 19 2014 mgorman@suse.de
- Btrfs: fix abnormal long waiting in fsync (VM/FS
  Micro-optimisations).
- msync: fix incorrect fstart calculation (VM/FS
  Micro-optimisations).
- commit c59b5f9
* Thu Dec 18 2014 duwe@suse.de
- Refresh
  patches.arch/pseries-Fix-endian-issues-in-onlining-cpu-threads.patch.
  Add last line, empty context, which makes sequence-patch.sh --fast work again.
- commit c85b208
* Thu Dec 18 2014 hare@suse.de
- tcm_loop: Wrong I_T nexus association (bnc#907325).
- commit 2c7268b
* Thu Dec 18 2014 duwe@suse.de
- powerpc/pseries: Make CPU hotplug path endian safe (bsc#907069).
- pseries: Fix endian issues in cpu hot-removal (bsc#907069).
- pseries: Fix endian issues in onlining cpu threads (bsc#907069).
- commit 17abcda
* Wed Dec 17 2014 jack@suse.cz
- ext4: introduce aging to extent status tree (bnc#893428).
- ext4: cleanup flag definitions for extent status tree
  (bnc#893428).
- ext4: limit number of scanned extents in status tree shrinker
  (bnc#893428).
- ext4: move handling of list of shrinkable inodes into extent
  status code (bnc#893428).
- ext4: change LRU to round-robin in extent status tree shrinker
  (bnc#893428).
- ext4: cache extent hole in extent status tree for
  ext4_da_map_blocks() (bnc#893428).
- ext4: fix block reservation for bigalloc filesystems
  (bnc#893428).
- ext4: track extent status tree shrinker delay statictics
  (bnc#893428).
- commit 44c3f61
* Wed Dec 17 2014 jack@suse.cz
- ext4: improve extents status tree trace point (bnc#893428).
- commit 8d95e8d
* Wed Dec 17 2014 mmarek@suse.cz
- Repair the tree after an erroneous merge
  The merge commit 0dbf74ef was meant to throw away the changes made by
  the 8231b71 branch, but I accidentally swapped the sides of the merge.
- commit 9f4e547
* Tue Dec 16 2014 jeffm@suse.com
- patches.suse/supported-flag: fix mis-reported supported status (bnc#809493).
- commit cda163d
* Tue Dec 16 2014 jeffm@suse.com
- Reorder series so that kGraft is applied after backports and Secure Boot.  No code changes.
- Refresh patches.suse/printk-mark_kgr_task_safe.patch.
- Refresh patches.suse/printk-remove-spinning.patch.
- commit 5a1f4c0
* Tue Dec 16 2014 mmarek@suse.cz
- x86_64, traps: Fix the espfix64 #DF fixup and rewrite it in C
  (bsc#909077,CVE-2014-8133).
- x86_64, traps: Stop using IST for #SS
  (bsc#909077,CVE-2014-8133).
- x86_64, traps: Rework bad_iret (bsc#909077,CVE-2014-8133).
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh patches.xen/xen3-patch-2.6.31.
- commit 82d99cf
* Tue Dec 16 2014 vbabka@suse.cz
- mm: page_alloc: determine migratetype only once (VM Performance,
  bnc#904177).
- commit dcbe3c0
* Tue Dec 16 2014 tiwai@suse.de
- parport: parport_pc, do not remove parent devices early
  (bnc#856659).
- commit 96c1792
* Tue Dec 16 2014 vbabka@suse.cz
- mm, compaction: more focused lru and pcplists draining (VM
  Performance, bnc#904177).
- mm, memory_hotplug/failure: drain single zone pcplists (VM
  Performance, bnc#904177).
- mm, cma: drain single zone pcplists (VM Performance,
  bnc#904177).
- mm, page_isolation: drain single zone pcplists (VM Performance,
  bnc#904177).
- mm: introduce single zone pcplists drain (VM Performance,
  bnc#904177).
- mm, compaction: always update cached scanner positions (VM
  Performance, bnc#904177).
- mm, compaction: defer only on COMPACT_COMPLETE (VM Performance,
  bnc#904177).
- mm, compaction: simplify deferred compaction (VM Performance,
  bnc#904177).
- mm, compaction: pass classzone_idx and alloc_flags to watermark
  checking (VM Performance, bnc#904177).
- mm/compaction: skip the range until proper target pageblock
  is met (VM Performance, bnc#904177).
- mm/compaction.c: avoid premature range skip in
  isolate_migratepages_range (VM Functionality, bnc#904177).
- mm, compaction: pass gfp mask to compact_control (VM Cleanup,
  bnc#904177).
- mm: rename allocflags_to_migratetype for clarity (VM Cleanup,
  bnc#904177).
- mm, compaction: skip buddy pages by their order in the migrate
  scanner (VM Performance, bnc#904177).
- mm, compaction: remember position within pageblock in free
  pages scanner (VM Performance, bnc#904177).
- mm, compaction: prevent infinite loop in compact_zone (VM
  Functionality, bnc#904177).
- mm, compaction: skip rechecks when lock was already held
  (VM Performance, bnc#904177).
- mm, compaction: periodically drop lock and restore IRQs in
  scanners (VM Performance, bnc#904177).
- mm, compaction: khugepaged should not give up due to
  need_resched() (VM Performance, bnc#904177).
- mm, compaction: reduce zone checking frequency in the migration
  scanner (VM Performance, bnc#904177).
- mm, compaction: move pageblock checks up from
  isolate_migratepages_range() (VM Performance, bnc#904177).
- mm, compaction: do not recheck suitable_migration_target under
  lock (VM Performance, bnc#904177).
- mm, compaction: do not count compact_stall if all zones skipped
  compaction (VM Performance, bnc#904177).
- mm, compaction: defer each zone individually instead of
  preferred zone (VM Performance, bnc#904177).
- mm: improve documentation of page_order (VM Cleanup,
  bnc#904177).
- mm, thp: restructure thp avoidance of light synchronous
  migration (VM Performance, bnc#904177).
- mm, thp: avoid excessive compaction latency during fault
  (VM Performance, bnc#904177).
- commit 7ba0e9c
* Tue Dec 16 2014 mkubecek@suse.cz
- macvlan: allow setting LRO independently of lower device
  (bnc#829110 bnc#891277 bnc#904053).
- net: generic dev_disable_lro() stacked device handling
  (bnc#829110 bnc#891277 bnc#904053).
- net: Find the nesting level of a given device by type
  (bnc#829110 bnc#891277 bnc#904053).
- commit 3d38aad
* Tue Dec 16 2014 jbeulich@suse.com
- Update Xen patches to 3.12.35.
- Refresh patches.xen/xen3-patch-3.9 (bsc#909829).
- commit 44222f1
* Mon Dec 15 2014 bp@suse.de
- x86/tls: Validate TLS entries to protect espfix
  (bsc#909077,CVE-2014-8133).
- commit 8231b71
* Mon Dec 15 2014 dbueso@suse.de
- mm: unmapped page migration avoid unmap+remap overhead (MM
  performance).
- commit 407efab
* Mon Dec 15 2014 dbueso@suse.de
- ipc/sem.c: change memory barrier in sem_lock() to smp_rmb()
  (IPC scalability).
- commit 8bd7433
* Mon Dec 15 2014 mgorman@suse.de
- sched/fair: cleanup: Remove useless assignment in
  select_task_rq_fair() (cpuidle performance).
- cpuidle: menu: Lookup CPU runqueues less (cpuidle performance).
- cpuidle: menu: Call nr_iowait_cpu less times (cpuidle
  performance).
- cpuidle: menu: Use ktime_to_us instead of reinventing the wheel
  (cpuidle performance).
- cpuidle: menu: Use shifts when calculating averages where
  possible (cpuidle performance).
- cpuidle: menu governor - remove unused macro STDDEV_THRESH
  (cpuidle performance).
- cpuidle / menu: move repeated correction factor check to init
  (cpuidle performance).
- cpuidle / menu: Return (-1) if there are no suitable states
  (cpuidle performance).
- cpuidle: Move perf multiplier calculation out of the selection
  loop (cpuidle performance).
- cpuidle: Do not substract exit latency from assumed sleep length
  (cpuidle performance).
- cpuidle: Ensure menu coefficients stay within domain (cpuidle
  performance).
- cpuidle: Use actual state latency in menu governor (cpuidle
  performance).
- cpuidle: rename expected_us to next_timer_us in menu governor
  (cpuidle performance).
- commit 7df4536
* Mon Dec 15 2014 hare@suse.de
- supported.conf: mark tcm_qla2xxx as supported
  Has not been ported from SLES11 SP3 automatically.
- commit 4d5cbf1
* Fri Dec 12 2014 brogers@suse.com
- x86,kvm,vmx: Preserve CR4 across VM entry (CVE-2014-3690
  bnc#902232).
- commit 0975593
* Fri Dec 12 2014 mmarek@suse.cz
- Update s390x kabi files again (bnc#903279, LTC#118177)
- commit 500d540
* Fri Dec 12 2014 jjolly@suse.de
- kernel: kprobes instruction corruption (bnc#908057, LTC#119330).
- s390/ftrace: revert mcount_adjust change (bnc#903279,
  LTC#118177).
- s390/ftrace: add code replacement sanity checks (bnc#903279,
  LTC#118177).
- s390/ftrace,kprobes: allow to patch first instruction
  (bnc#903279, LTC#118177).
- kprobes: introduce weak arch_check_ftrace_location() helper
  function (bnc#903279, LTC#118177).
- s390/ftrace: simplify enabling/disabling of ftrace_graph_caller
  (bnc#903279, LTC#118177).
- s390/ftrace: remove 31 bit ftrace support (bnc#903279,
  LTC#118177).
- s390/ftrace: optimize mcount code (bnc#903279, LTC#118177).
- s390/ftrace: enforce DYNAMIC_FTRACE if FUNCTION_TRACER is
  selected (bnc#903279, LTC#118177).
- s390/ftrace: add HAVE_DYNAMIC_FTRACE_WITH_REGS support
  (bnc#903279, LTC#118177).
- s390/ftrace: remove check of obsolete variable
  function_trace_stop (bnc#903279, LTC#118177).
- s390/ftrace: optimize function graph caller code (bnc#903279,
  LTC#118177).
- s390: pass march flag to assembly files as well (bnc#903279,
  LTC#118177).
- kernel: reduce function tracer overhead (bnc#903279,
  LTC#118177).
- crypto: kernel oops at insmod of the z90crypt device driver
  (bnc#908057, LTC#119591).
- commit 5ce3f4b
* Thu Dec 11 2014 mmarek@suse.cz
- Revert "rpm/kernel-binary.spec.in: Obsolete kGraft patches for older kernels (fate#313296)"
  The kgraft patches use different names for different kernel versions.
  This reverts commit 99e98dea2da9794315ee2768b9e9499a358ce96a.
- commit 6be8c06
* Thu Dec 11 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove hack for 13.1-based KOTD
- commit 1a9e5e7
* Thu Dec 11 2014 jroedel@suse.de
- x86/uv: Update the UV3 TLB shootdown logic (bsc#909092).
- commit 27d15fb
* Thu Dec 11 2014 jroedel@suse.de
- x86/UV: Fix conditional in gru_exit() (bsc#909095).
- commit 9227b91
* Wed Dec 10 2014 jbeulich@suse.com
- fix kABI after "x86: use custom dma_get_required_mask()".
- commit 00e0073
* Wed Dec 10 2014 jbeulich@suse.com
- Update Xen patches to 3.12.34.
- x86: use custom dma_get_required_mask().
- x86-64/MCE: flip CPU and bank numbers in log message.
- x86, cpu: Detect more TLB configuration (TLB Performance).
- x86/mm: Add tracepoints for TLB flushes (TLB Performance).
- x86/mm: Rip out complicated, out-of-date, buggy TLB flushing
  (TLB Performance).
- x86: use optimized ioresource lookup in ioremap function
  (Boot time optimisations (bnc#895387)).
- commit b23522c
* Wed Dec 10 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.34-35 (bnc#887108
  bnc#907818 CVE-2014-9090).
  Add CVE ref.
- commit 697aaba
* Wed Dec 10 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.34-35 (bnc#887108
  bnc#907818).
  Add a ref to bnc#907818.
- commit 5a36a19
* Wed Dec 10 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.33-34 (CVE-2014-3673
  CVE-2014-3687 CVE-2014-7841 bnc#875220 bnc#884407 bnc#902346
  bnc#902349 bnc#905100).
- Delete patches.fixes/dmraid-read-size.patch.
  It was superseded by an upstream commit
  40d43c4b4cac4c2647bf07110d7b07d35f399a84. It was merged via 3.12.34.
- commit c341a17
* Tue Dec  9 2014 hare@suse.de
- bfa: check for terminated commands (bnc#906027).
- commit 0853c30
* Tue Dec  9 2014 mhocko@suse.cz
- net, sunrpc: suppress allocation warning in rpc_malloc()
  (bnc#904659).
- commit f5a4d08
* Mon Dec  8 2014 jroedel@suse.de
- iommu/vt-d: Fix an off-by-one bug in __domain_mapping()
  (bsc#908825).
- commit baa3cbd
* Mon Dec  8 2014 hare@suse.de
- scsi: call device handler for failed TUR command (bnc#895814).
- commit 5aafe30
* Mon Dec  8 2014 hare@suse.de
- lpfc: Fix race on command completion (bnc#906027).
- commit eaf78b1
* Sat Dec  6 2014 jslaby@suse.cz
- Linux 3.12.35 (bnc#887108).
- kABI: protect struct pci_dev.
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh
  patches.drivers/0163-Target-iser-Use-Fastreg-only-if-device-supports-sign.patch.
- Refresh patches.xen/xen3-patch-2.6.18.
- Refresh patches.xen/xen3-patch-2.6.31.
- Delete
  patches.drivers/0001-Input-serio-add-firmware_id-sysfs-attribute.patch.
- Delete
  patches.drivers/0002-Input-i8042-add-firmware_id-support.patch.
- Delete
  patches.drivers/0003-Input-Add-INPUT_PROP_TOPBUTTONPAD-device-property.patch.
- Delete
  patches.drivers/0004-Input-synaptics-report-INPUT_PROP_TOPBUTTONPAD-prope.patch.
- commit bdaeeb4
* Sat Dec  6 2014 jslaby@suse.cz
- Refresh
  patches.drivers/drm-i915-Move-DP-port-disable-to-post_disable-for-pch-platforms.patch.
- Refresh patches.drivers/ibmvfc-fix-little-endian-issues.
- Refresh patches.fixes/block-unbalanced-bypass-disable.patch.
  Proper SHAs.
- commit 0aba38e
* Fri Dec  5 2014 jslaby@suse.cz
- Linux 3.12.34 (CVE-2014-3673 CVE-2014-3687 CVE-2014-7841
  bnc#875220 bnc#902346 bnc#902349 bnc#905100).
- kABI: protect struct iwl_trans.
- kABI: reintroduce generic_write_sync.
- Refresh patches.drivers/0018-iwlwifi-mvm-new-BT-Coex-API.
- Refresh
  patches.drivers/0034-iwlwifi-mvm-Add-device-wide-power-command.
- Refresh patches.fixes/dmraid-read-size.patch.
- Refresh
  patches.fixes/net-Explicitly-initialize-u64_stats_sync-structures-.patch.
- Delete
  patches.fixes/net-sctp-fix-null-pointer-dereference-in-af-from_add.patch.
- Delete
  patches.fixes/net-sctp-fix-panic-on-duplicate-ASCONF-chunks.patch.
- Delete
  patches.fixes/net-sctp-fix-skb_over_panic-when-receiving-malformed.patch.
- Delete patches.fixes/pvpanic-Set-high-notifier-priority.
- commit 28b39e4
* Fri Dec  5 2014 tiwai@suse.de
- KEYS: Fix stale key registration at error path (bnc#908163).
- commit ca00d54
* Fri Dec  5 2014 bpoirier@suse.de
- net: sctp: fix panic on duplicate ASCONF chunks (bnc#902349
  CVE-2014-3687).
- commit 893ebc6
* Thu Dec  4 2014 hare@suse.de
- nvme: Add missing hunk from backport (bnc#873252).
- commit 47ab21c
* Wed Dec  3 2014 mmarek@suse.cz
- Build against the :Update project in the IBS
- commit d5ca4ae
* Wed Dec  3 2014 mmarek@suse.cz
- Revert s390x ftrace changes (bnc#908184)
- commit 3b7212e
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Fix BYT frequency reporting (bnc#907973,
  FATE#316038).
- commit 2110a87
* Tue Dec  2 2014 eich@suse.de
- intel_idle: Add CPU model 54 (Atom N2000 series)
  (bnc#907969, FATE#316038).
- commit 02f15bf
* Tue Dec  2 2014 eich@suse.de
- intel_idle: support Bay Trail (bnc#907969, FATE#316038).
- commit 0ecc614
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Fix setting VID (bnc#907973, FATE#316038).
- commit b8ab814
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Set turbo VID for BayTrail (bnc#907973,
  FATE#316038).
- commit 44f4928
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Use LFM bus ratio as min ratio/P state
  (bnc#907973, FATE#316038).
- commit 7422522
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Add support for Baytrail turbo P states
  (bnc#907973, FATE#316038).
- commit 0a3e324
* Tue Dec  2 2014 eich@suse.de
- intel_pstate: Add setting voltage value for baytrail P states
  (bnc#907973, FATE#316038).
- commit 41b0b87
* Tue Dec  2 2014 eich@suse.de
- intel_idle: allow sparse sub-state numbering, for Bay Trail
  (bnc#907969, FATE#316038).
- commit 45c9d68
* Tue Dec  2 2014 eich@suse.de
- ACPI idle: permit sparse C-state sub-state numbers (bnc#907969, FATE#316038).
- commit 6ab651f
* Tue Dec  2 2014 eich@suse.de
- drm: add MIPI DSI encoder and connector types (bnc#907971, FATE#316038).
- commit c50d456
* Tue Dec  2 2014 eich@suse.de
- x86/early quirk: use gen6 stolen detection for VLV (bnc#907970, FATE#316038).
- commit d0e6d9b
* Tue Dec  2 2014 agraf@suse.de
- kvm: Don't expose MONITOR cpuid as available (bnc#887597)
- commit 410d10f
* Tue Dec  2 2014 tiwai@suse.de
- ALSA: hda/hdmi - apply Valleyview fix-ups to Cherryview display
  codec (FATE#317933).
- ALSA: hda - verify pin:converter connection on unsol event
  for HSW and VLV (FATE#317933).
- ALSA: hda - verify pin:cvt connection on preparing a stream
  for Intel HDMI codec (FATE#317933).
- ALSA: hda_intel: Add DeviceIDs for Sunrise Point-LP
  (FATE#317347).
- ALSA: hda_intel: Add Device IDs for Intel Sunrise Point PCH
  (FATE#317347).
- commit 47bfbb7
* Mon Dec  1 2014 jslaby@suse.cz
- kgr: prevent recursive loops of stubs in ftrace (fate#313296).
- kgr: mark even more kthreads (fate#313296 bnc#905087
  bnc#906140).
- Refresh patches.drivers/mtip32xx-Add-SRSI-support.patch.
- Refresh
  patches.drivers/nvme-0007-Schedule-reset-for-failed-controllers.patch.
- Refresh
  patches.suse/kgr-0041-kgr-clean-up-reference-handling-when-a-patch-replace.patch.
- Refresh
  patches.suse/kgr-0042-kgr-correctly-remove-replaced-patch-when-using-fast-.patch.
- Refresh
  patches.suse/kgr-0043-kgr-do-not-allow-double-revert.patch.
- Refresh
  patches.suse/kgr-0044-kgr-force-patching-process-to-succeed.patch.
- Refresh
  patches.suse/kgr-0045-kgr-always-use-locked-bit-ops-for-thread_info-flags.patch.
- Refresh
  patches.suse/kgr-0046-kgr-lower-the-workqueue-scheduling-timeout.patch.
- Delete patches.suse/kgr-0047-kgr-mark-even-more-kthreads.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh
  patches.xen/xen3-kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- commit e95fb32
* Sun Nov 30 2014 eich@suse.de
- drm/i915: Do a dummy DPCD read before the actual read
  (bnc#907714).
- commit 616ea5f
* Fri Nov 28 2014 eich@suse.de
- patches.drivers/drm-i915-take-mode-config-lock-around-crtc-disable-a.patch:
  (bnc#907593).
- commit a49ea29
* Thu Nov 27 2014 eich@suse.de
- patches.drivers/drm-i915-don-t-disable-the-DP-port-if-the-link-is-lo.patch:
  (bnc#907536).
- commit 928b8d0
* Thu Nov 27 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB of disk space also on 32bit POWER
- commit 33a282b
* Wed Nov 26 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB disk space on POWER
  A debuginfo build currently requires about 8.5 GB on POWER. Also,
  require at least 8 CPUs, so that builds do not get accidentally
  scheduled on slow machines.
- commit 596d9cf
* Tue Nov 25 2014 mmarek@suse.cz
- tags.sh: Fixup regex definition for etags.
- scripts/tags.sh: fix DEFINE_HASHTABLE in emacs case.
- scripts/tags.sh: Don't specify kind-spec for emacs' ctags/etags.
- scripts/tags.sh: include compat_sys_* symbols in the generated
  tags.
- commit a0ab6c0
* Mon Nov 24 2014 rgoldwyn@suse.de
- Remove filesize checks for sync I/O journal commit (bnc#800255).
- commit 26c7845
* Fri Nov 21 2014 jslaby@suse.cz
- Refresh
  patches.kabi/kabi-uninline-of_property_count_string-functions.patch.
  OK, fix non_OF platforms.
- commit 595299b
* Fri Nov 21 2014 jslaby@suse.cz
- kABI: uninline of_property_count_string* functions.
  Omitted ppc64le kabi fix for 3.12.33.
- commit 7c55cf1
* Thu Nov 20 2014 ptesarik@suse.cz
- x86/efi: Do not export efi runtime map in case old map
  (bsc#904969).
- commit fdfaf86
* Thu Nov 20 2014 mgorman@suse.de
- Delete
  patches.suse/mm-shrinker-trace-points-fix-negatives.patch.
- commit 2f2b904
* Thu Nov 20 2014 neilb@suse.de
- NFSv4: test SECINFO RPC_AUTH_GSS pseudoflavors for support
  (bnc#905758).
- commit 996da5b
* Wed Nov 19 2014 mgorman@suse.de
- Delete
  patches.suse/mm-shrinker-add-nid-to-tracepoint-output.patch.
- commit dce4342
* Wed Nov 19 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.12-13 (CVE-2014-8709
  bnc#859342 bnc#860346 bnc#865919 bnc#904700 LTC#103575
  fate#315482 FATE#315595).
- Update patches.kernel.org/patch-3.12.23-24 (CVE-2014-3940
  CVE-2014-4608 CVE-2014-4652 CVE-2014-4653 CVE-2014-4654
  CVE-2014-4655 CVE-2014-4656 FATE#315054 FATE#315942 bnc#845378
  bnc#856380 bnc#865310 bnc#866937 bnc#867753 bnc#872634
  bnc#875242 bnc#875440 bnc#878059 bnc#879957 bnc#881091
  bnc#881101 bnc#881939 bnc#882991 bnc#883081 bnc#883795
  bnc#883948 LTC#110452).
- Update patches.kernel.org/patch-3.12.28-29 (CVE-2014-3185
  bnc#879255 bnc#880892 bnc#887046 bnc#887418 bnc#891619
  bnc#892612 bnc#892650 bnc#896391 bnc#897101).
  Add some references (CVEs+bncs).
- commit 34c4991
* Tue Nov 18 2014 jslaby@suse.cz
- Linux 3.12.33 (CVE-2014-3610 CVE-2014-3611 CVE-2014-3647
  CVE-2014-7826 bnc#815494 bnc#864288 bnc#864657 bnc#882648
  bnc#899192 bnc#904115 bnc#904876 bsc#904013).
- kABI: protect rmap include in mm/truncate.c.
- kABI: protect ipv6.h include in drivers/net.
- Refresh
  patches.arch/kvm-nvmx-clean-up-handling-of-vmx-related-msrs.patch.
- Refresh
  patches.drivers/0002-usb-core-Track-if-an-endpoint-has-streams.patch.
- Refresh
  patches.drivers/cpufreq-Implement-light-weight--target_index-routine.
- Refresh
  patches.fixes/xfs-xfs_readsb-needs-to-check-for-magic-numbers.patch.
- Refresh patches.kabi/kabi-resettle-select_ident.patch.
- Delete
  patches.arch/kvm-vmx-handle-invvpid-vm-exit-gracefully.patch.
- Delete
  patches.arch/kvm-x86-check-non-canonical-addresses-upon-wrmsr.patch.
- Delete
  patches.arch/kvm-x86-emulator-fixes-for-eip-canonical-checks-on-near-branches.patch.
- Delete
  patches.arch/kvm-x86-fix-wrong-masking-on-relative-jump-call.patch.
- Delete patches.arch/kvm-x86-improve-thread-safety-in-pit.patch.
- Delete
  patches.arch/kvm-x86-prevent-guest-from-writing-non-canonical-msr-addresses.patch.
- Delete
  patches.drivers/0001-media-ttusb-dec-buffer-overflow-in-ioctl.patch.
- Delete
  patches.drivers/drm-i915-HD-audio-Don-t-continue-probing-when-nomode.
- Delete
  patches.drivers/drm-i915-provide-interface-for-audio-driver-to-query.
- Delete
  patches.drivers/hda-0038-restore-BCLK-M-N-value-as-per-CDCLK-for-HSW.
- Delete
  patches.fixes/drm-cirrus-bind-also-to-qemu-xen-traditional.patch.
- Delete
  patches.fixes/tracing-syscalls-ignore-numbers-outside-nr_syscalls-range.patch.
- Delete patches.suse/btrfs-8081-fix-kfree-on-list_head.patch.
- Delete
  patches.suse/mm-free-compound-page-with-correct-order.patch.
- commit af940d1
* Tue Nov 18 2014 duwe@suse.de
- We need to activate cmac(3des_ede) in FIPS mode (bnc#905772).
- commit 49111cd
* Tue Nov 18 2014 hare@suse.de
- scsi_dh_alua: disable ALUA handling for non-disk devices
  (bnc#876633).
- commit 198c841
* Sat Nov 15 2014 bpoirier@suse.de
- net: sctp: fix skb_over_panic when receiving malformed ASCONF
  chunks (bnc#902346 CVE-2014-3673).
- commit 64f6c28
* Fri Nov 14 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide name-version-release for kgraft
  packages (bnc#901925)
- commit c9157ee
* Fri Nov 14 2014 oneukum@suse.de
- [media] ttusb-dec: buffer overflow in ioctl (bnc#904876).
- commit fc0bcaf
* Fri Nov 14 2014 dsterba@suse.cz
- btrfs: fix wrong accounting of raid1 data profile in statfs.
- commit bd34de3
* Thu Nov 13 2014 tiwai@suse.de
- hp_accel: Add support for HP ZBook 15 (bnc#905329).
- commit 7a1d2bb
* Thu Nov 13 2014 duwe@suse.de
- We need to activate cmac(aes) in FIPS mode (bnc#905296).
- commit 5be3496
* Thu Nov 13 2014 jbohac@suse.cz
- net: sctp: fix NULL pointer dereference in af->from_addr_param
  on (bnc#905100, CVE-2014-7841).
- commit 8184216
* Thu Nov 13 2014 dchang@suse.com
- cxgb4/cxgb4vf: Add Devicde ID for two more adapter (bsc#903999).
- cxgb4/cxgb4vf: Add device ID for new adapter and remove for
  dbg adapter (bsc#903999).
- cxgb4: Adds device ID for few more Chelsio T4 Adapters
  (bsc#903999).
- cxgb4: Check if rx checksum offload is enabled, while reading
  hardware calculated checksum (bsc#903999).
- commit 81be34a
* Wed Nov 12 2014 jbeulich@suse.com
- xen-pciback: drop SR-IOV VFs when PF driver unloads
  (bsc#901839).
- commit ca2b891
* Wed Nov 12 2014 fdmanana@suse.com
- Btrfs: fix race that makes btrfs_lookup_extent_info miss skinny
  extent items (bnc#904077).
- Btrfs: fix invalid leaf slot access in btrfs_lookup_extent()
  (bnc#904077).
- commit eef938c
* Wed Nov 12 2014 jslaby@suse.cz
- kgr: lower the workqueue scheduling timeout (fate#313296
  bnc#905087).
- kgr: mark even more kthreads (fate#313296 bnc#904871).
- Update
  patches.suse/kgr-0043-kgr-do-not-allow-double-revert.patch
  (fate#313296 bnc#901169).
- Update
  patches.suse/kgr-0045-kgr-always-use-locked-bit-ops-for-thread_info-flags.patch
  (fate#313296 bnc#904681).
- Update
  patches.xen/xen3-kgr-0045-kgr-always-use-locked-bit-ops-for-thread_info-flags.patch
  (fate#313296 bnc#904681).
- commit c7e1f63
* Wed Nov 12 2014 jslaby@suse.cz
- kgr: always use locked bit ops for thread_info->flags
  (fate#313296).
- commit f75514e
* Mon Nov 10 2014 mgorman@suse.de
- Delete
  patches.suse/mm-page-writeback-inline-account_page_dirtied-into-single-caller.patch.
- commit f83ca3e
* Mon Nov 10 2014 mgorman@suse.de
- mm: free compound page with correct order (VM Functionality).
- commit 79b12ee
* Mon Nov 10 2014 bp@suse.de
- Update patches.fixes/tracing-syscalls-ignore-numbers-outside-nr_syscalls-range.patch
  (bsc#904013, CVE-2014-7826).
- commit 86531c0
* Mon Nov 10 2014 bp@suse.de
- tracing/syscalls: Ignore numbers outside NR_syscalls' range
  (bsc#853040, CVE-2013-6405).
- commit feee2d2
* Fri Nov  7 2014 mgorman@suse.de
- mm: actually clear pmd_numa before invalidating (VM Functionality).
- mm, writeback: prevent race when calculating dirty limits
  (VM Functionality).
- mm: shrinker: add nid to tracepoint output (VM Functionality/RAS).
- mm: shrinker trace points: fix negatives (VM Functionality/RAS).
- commit 801c51d
* Fri Nov  7 2014 mgorman@suse.de
- mm: page-writeback: inline account_page_dirtied() into single
  caller (VM/FS Micro-optimisations).
- mm: page_alloc: default node-ordering on 64-bit NUMA,
  zone-ordering on 32-bit (VM/FS Micro-optimisations).
- mm: page_alloc: Make paranoid check in move_freepages a
  VM_BUG_ON (VM/FS Micro-optimisations).
- mm: page_alloc: avoid wakeup kswapd on the unintended node
  (VM/FS Micro-optimisations).
- mempolicy: change alloc_pages_vma() to use mpol_cond_put()
  (VM/FS Micro-optimisations).
- mm, vmalloc: constify allocation mask
  (VM/FS Micro-optimisations).
- mm/vmalloc.c: add a schedule point to vmalloc()
  (VM/FS Micro-optimisations).
- mm/readahead.c: remove unused file_ra_state from
  count_history_pages (VM/FS Micro-optimisations).
- mm/msync.c: sync only the requested range in msync() (VM/FS
  Micro-optimisations).
- mm: use the light version __mod_zone_page_state in
  mlocked_vma_newpage() (VM/FS Micro-optimisations).
- mm/mmap.c: remove the first mapping check (VM/FS
  Micro-optimisations).
- commit b70b096
* Fri Nov  7 2014 mgorman@suse.de
- x86: use optimized ioresource lookup in ioremap function
  (Boot time optimisations (bnc#895387)).
- x86: optimize resource lookups for ioremap (Boot time
  optimisations (bnc#895387)).
- commit dd2f28c
* Fri Nov  7 2014 mmarek@suse.cz
- Delete remaining sp3_review patches
- commit 737ee20
* Fri Nov  7 2014 oneukum@suse.de
- usb: Do not re-read descriptors for wired devices in
  usb_authorize_device() (bnc#904354).
- commit d1067c6
* Fri Nov  7 2014 mkubecek@suse.cz
- netxen: Fix link event handling (bnc#873228).
- commit 21ebc8a
* Fri Nov  7 2014 mgorman@suse.de
- x86, cpu: Detect more TLB configuration -xen (TLB Performance).
- Refresh
  patches.suse/x86-cpu-Detect-more-TLB-configuration.patch.
- commit d973e97
* Fri Nov  7 2014 mgorman@suse.de
- Refresh
  patches.suse/x86-cpu-Detect-more-TLB-configuration.patch.
- commit 6cba619
* Thu Nov  6 2014 mgorman@suse.de
- x86/mm: Fix RCU splat from new TLB tracepoints (TLB
  Performance).
- x86/mm: Set TLB flush tunable to sane value (33) (TLB
  Performance).
- x86/mm: New tunable for single vs full TLB flush (TLB
  Performance).
- x86/mm: Add tracepoints for TLB flushes (TLB Performance).
- x86/mm: Unify remote INVLPG code (TLB Performance).
- x86/mm: Fix missed global TLB flush stat (TLB Performance).
- x86/mm: Rip out complicated, out-of-date, buggy TLB flushing
  (TLB Performance).
- x86, cpu: Detect more TLB configuration (TLB Performance).
- mm, x86: Revisit tlb_flushall_shift tuning for page flushes
  except on IvyBridge (TLB Performance).
- x86/mm: Clean up the TLB flushing code (TLB Performance).
- commit 1f9369d
* Thu Nov  6 2014 mmarek@suse.cz
- rpm/config.sh: Build against the SLE12 target in the OBS
- commit 67dde23
* Thu Nov  6 2014 vbabka@suse.cz
- mm: vmscan: clean up struct scan_control (VM Cleanup,
  bnc#904177).
- mm: vmscan: move swappiness out of scan_control (VM Cleanup,
  bnc#904177).
- mm: vmscan: remove all_unreclaimable() (VM Cleanup, bnc#904177).
- mm: vmscan: rework compaction-ready signaling in direct reclaim
  (VM Cleanup, bnc#904177).
- mm: vmscan: remove remains of kswapd-managed
  zone->all_unreclaimable (VM Cleanup, bnc#904177).
- mm/vmscan.c: use DIV_ROUND_UP for calculation of zone's
  balance_gap and correct comments (VM Cleanup, bnc#904177).
- vmscan: memcg: always use swappiness of the reclaimed memcg
  (VM Cleanup, bnc#904177).
- mm: memcontrol: remove hierarchy restrictions for swappiness
  and oom_control (VM Cleanup, bnc#904177).
- mm/vmscan: do not check compaction_ready on promoted zones
  (VM Cleanup, bnc#904177).
- mm/vmscan: restore sc->gfp_mask after promoting it to
  __GFP_HIGHMEM (VM Cleanup, bnc#904177).
- mm: vmscan: remove shrink_control arg from
  do_try_to_free_pages() (VM Cleanup, bnc#904177).
- mm: vmscan: move call to shrink_slab() to shrink_zones()
  (VM Cleanup, bnc#904177).
- commit 75abcf0
* Wed Nov  5 2014 mfasheh@suse.de
- Btrfs: fix kfree on list_head in btrfs_lookup_csums_range
  error cleanup (bnc#904115).
- commit 3caa43a
* Wed Nov  5 2014 lduncan@suse.com
- bnx2x: Utilize FW 7.10.51 (bnc#887382).
- bnx2x: Remove unnecessary internal mem config (bnc#887382).
- commit cb1ddd9
* Wed Nov  5 2014 jbohac@suse.cz
- Fix build: move rtnetlink-fix-oops-in-rtnl_link_get_slave_info_data_.patch after the patch that
  introduces bnc#901774 (patches.drivers/rtnetlink-provide-api-for-getting-and-setting-slave-.patch)
- commit 4051c9f
* Wed Nov  5 2014 jbohac@suse.cz
- rtnetlink: fix oops in rtnl_link_get_slave_info_data_size
  (bnc#901774).
- commit 4d343b3
* Wed Nov  5 2014 hare@suse.de
- dm: do not call dm_sync_table() when creating new devices
  (bnc#901809).
- commit 61be11b
* Wed Nov  5 2014 tiwai@suse.de
- [media] uvc: Fix destruction order in uvc_delete() (bnc#897736).
- commit 465c366
* Wed Nov  5 2014 jslaby@suse.cz
- uas: replace WARN_ON_ONCE() with lockdep_assert_held()
  (FATE#315595).
- commit fd3be79
* Wed Nov  5 2014 jslaby@suse.cz
- kgr: force patching process to succeed (fate#313296).
- Delete
  patches.suse/kgr-0099-kgr-force-patching-process-to-succeed.patch.
  Acked version now :).
- commit f277c6c
* Tue Nov  4 2014 mmarek@suse.cz
- Update s390x kabi files after ftrace changes (bnc#903279, LTC#118177)
- commit 271a4f3
* Tue Nov  4 2014 mmarek@suse.cz
- kabi: Restore include in arch/s390/kernel/setup.c.
- commit 6ea529f
* Tue Nov  4 2014 mgalbraith@suse.de
- Update patch header.
  futex: Fix a race condition between REQUEUE_PI and task death
  (bcn#851603 (futex scalability series)).
- commit 17e4851
* Mon Nov  3 2014 jslaby@suse.cz
- kgr: clean up reference handling when a patch replaces all
  others (fate#313296).
- kgr: correctly remove replaced patch when using fast path
  (fate#313296).
- kgr: do not allow double revert (fate#313296).
- kgr: force patching process to succeed (fate#313296).
- Delete
  patches.suse/kgr-0041-kgr-force-patching-process-to-succeed.patch.
- commit 41cd212
* Mon Nov  3 2014 jslaby@suse.cz
- Linux 3.12.32 (bnc#874025 bnc#881085 bnc#891259 bnc#892254
  FATE#315518).
- kABI: protect include in kernel/events/core.c.
- Refresh
  patches.drivers/0001-usb-phy-move-some-error-messages-to-debug.patch.
- Refresh
  patches.drivers/0012-uas-replace-BUG_ON-WARN_ON-with-WARN_ON_ONCE.patch.
- Refresh
  patches.drivers/0041-uas-task_mgmt-Kill-the-sense-urb-if-we-fail-to-submi.patch.
- Refresh patches.drivers/0055-uas-Improve-error-reporting.patch.
- Refresh
  patches.suse/memcg-rework-memcg_update_kmem_limit-synchronization.patch.
- Refresh
  patches.suse/msft-hv-0625-Drivers-hv-Eliminate-the-channel-spinlock-in-the-cal.patch.
- Refresh patches.suse/sparc-handle-pgtable_page_ctor-fail.patch.
- Delete
  patches.arch/0001-powerpc-Add-smp_mb-to-arch_spin_is_locked.patch.
- Delete
  patches.arch/0002-powerpc-Add-smp_mb-s-to-arch_spin_unlock_wait.patch.
- Delete
  patches.drivers/0014-usb-hub-set-hub-change_bits-when-over-current-happen.patch.
- Delete
  patches.fixes/dcache-add-missing-lockdep-annotation.patch.
- Delete
  patches.fixes/dcache-don-t-need-rcu-in-shrink_dentry_list.patch.
- Delete
  patches.fixes/dealing-with-the-rest-of-shrink_dentry_list-livelock.patch.
- Delete
  patches.fixes/dentry_kill-doesn-t-need-the-second-argument-now.patch.
- Delete
  patches.fixes/dentry_kill-don-t-try-to-remove-from-shrink-list.patch.
- Delete
  patches.fixes/don-t-remove-from-shrink-list-in-select_collect.patch.
- Delete
  patches.fixes/expand-dentry_kill-dentry-0-in-shrink_dentry_list.patch.
- Delete
  patches.fixes/expand-the-call-of-dentry_lru_del-in-dentry_kill.patch.
- Delete
  patches.fixes/fold-__d_shrink-into-its-only-remaining-caller.patch.
- Delete patches.fixes/fold-d_kill-and-d_free.patch.
- Delete patches.fixes/fold-try_prune_one_dentry.patch.
- Delete
  patches.fixes/fold-try_to_ascend-into-the-sole-remaining-caller.patch.
- Delete
  patches.fixes/lift-the-already-marked-killed-case-into-shrink_dent.patch.
- Delete
  patches.fixes/lock_parent-don-t-step-on-stale-d_parent.patch.
- Delete
  patches.fixes/more-graceful-recovery-in-umount_collect.patch.
- Delete
  patches.fixes/net-fix-checksum-features-handling-in-netif_skb_feat.patch.
- Delete patches.fixes/new-helper-dentry_free.patch.
- Delete
  patches.fixes/shrink_dentry_list-take-parent-s-d_lock-earlier.patch.
- Delete patches.fixes/split-dentry_kill.patch.
- Delete
  patches.fixes/switch-shrink_dcache_for_umount-to-use-of-d_walk.patch.
- Delete
  patches.kernel.org/regulatory-fix-misapplied-alpha2-fix.patch.
- Delete
  patches.suse/btrfs-8062-wake-up-transaction-thread-from-SYNC_FS-ioctl.patch.
- Delete
  patches.suse/msft-hv-0659-Drivers-hv-vmbus-Cleanup-vmbus_post_msg.patch.
- Delete
  patches.suse/msft-hv-0660-Drivers-hv-vmbus-Cleanup-vmbus_teardown_gpadl.patch.
- Delete
  patches.suse/msft-hv-0661-Drivers-hv-vmbus-Cleanup-vmbus_establish_gpadl.patch.
- Delete
  patches.suse/msft-hv-0662-Drivers-hv-vmbus-Fix-a-bug-in-vmbus_open.patch.
- Delete
  patches.suse/msft-hv-0663-Drivers-hv-vmbus-Cleanup-vmbus_close_internal.patch.
- commit e63ebcc
* Sat Nov  1 2014 jjolly@suse.de
- s390/ftrace,kprobes: allow to patch first instruction
  (bnc#903279, LTC#118177).
- kprobes: introduce weak arch_check_ftrace_location() helper
  function (bnc#903279, LTC#118177).
- s390/ftrace: simplify enabling/disabling of ftrace_graph_caller
  (bnc#903279, LTC#118177).
- s390/ftrace: remove 31 bit ftrace support (bnc#903279,
  LTC#118177).
- s390/ftrace: optimize mcount code (bnc#903279, LTC#118177).
- s390/ftrace: enforce DYNAMIC_FTRACE if FUNCTION_TRACER is
  selected (bnc#903279, LTC#118177).
- s390/ftrace: add HAVE_DYNAMIC_FTRACE_WITH_REGS support
  (bnc#903279, LTC#118177).
- s390/ftrace: remove check of obsolete variable
  function_trace_stop (bnc#903279, LTC#118177).
- s390/ftrace: optimize function graph caller code (bnc#903279,
  LTC#118177).
- s390: pass march flag to assembly files as well (bnc#903279,
  LTC#118177).
- kernel: reduce function tracer overhead (bnc#903279,
  LTC#118177).
- commit ed17774
* Thu Oct 30 2014 jroedel@suse.de
- iommu/vt-d: Check return value of acpi_bus_get_device() (bnc#903307).
- commit eba4e3e
* Thu Oct 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix including the secure boot cert in /etc/uefi/certs
- commit 72255c9
* Thu Oct 30 2014 fdmanana@suse.com
- Btrfs: add helper btrfs_fdatawrite_range (bnc#902010).
- Btrfs: correctly flush compressed data before/after direct IO
  (bnc#902010).
- Btrfs: make inode.c:compress_file_range() return void
  (bnc#902010).
- Btrfs: report error after failure inlining extent in compressed
  write path (bnc#902010).
- Btrfs: don't ignore compressed bio write errors (bnc#902010).
- Btrfs: make inode.c:submit_compressed_extents() return void
  (bnc#902010).
- Btrfs: process all async extents on compressed write failure
  (bnc#902010).
- Btrfs: don't leak pages and memory on compressed write error
  (bnc#902010).
- Btrfs: fix hang on compressed write error (bnc#902010).
- Btrfs: set page and mapping error on compressed write failure
  (bnc#902010).
- commit 8cff1b1
* Thu Oct 30 2014 vbabka@suse.cz
- Refresh
  patches.fixes/mm-thp-dont-hold-mmap_sem-in-khugepaged-when-allocating-thp.patch.
- commit 1b23130
* Wed Oct 29 2014 dbueso@suse.de
- sched: Reduce contention in update_cfs_rq_blocked_load()
  (Scheduler/core performance).
- commit aafac1f
* Wed Oct 29 2014 jslaby@suse.cz
- kgr: force patching process to succeed (fate#313296).
- commit b8cd4ce
* Wed Oct 29 2014 duwe@suse.de
- powerpc/vphn: NUMA node code expects big-endian (bsc#900126).
- commit 0e31f31
* Wed Oct 29 2014 mkubecek@suse.cz
- net: fix checksum features handling in netif_skb_features()
  (bnc#891259).
- commit 9d11cad
* Wed Oct 29 2014 fdmanana@suse.com
- Btrfs: avoid returning -ENOMEM in convert_extent_bit() too early
  (bnc#902016).
- Btrfs: make find_first_extent_bit be able to cache any state
  (bnc#902016).
- Btrfs: deal with convert_extent_bit errors to avoid fs
  corruption (bnc#902016).
- commit e9f6331
* Wed Oct 29 2014 neilb@suse.de
- Delete
  patches.suse/md-raid1-request_counting_bug_new_barrier_code.
- Delete
  patches.suse/md-raid1-rewrite_the_implementation_of_iobarrier.
  The new iobarrier implementation turned out to be rather buggy.
  There are 7 upstream patches to fix various issues.
  It isn't really very valuable, so remove it rather than include
  all the bug-fixes and risk there being more bugs.
- commit 9df573c
* Wed Oct 29 2014 neilb@suse.de
- SUNRPC: Handle EPIPE in xprt_connect_status (bnc#901090).
- SUNRPC: Ensure that we handle ENOBUFS errors correctly
  (bnc#901090).
- SUNRPC: Ensure call_connect_status() deals correctly with
  SOFTCONN tasks (bnc#901090).
- SUNRPC: Ensure that call_connect times out correctly
  (bnc#901090).
- SUNRPC: Handle connect errors ECONNABORTED and EHOSTUNREACH
  (bnc#901090).
- SUNRPC: Ensure xprt_connect_status handles all potential
  connection errors (bnc#901090).
- SUNRPC: call_connect_status should recheck bind and connect
  status on error (bnc#901090).
- commit c0effd9
* Tue Oct 28 2014 bpoirier@suse.de
- be2net: Fix invocation of be_close() after be_clear()
  (bnc#895468).
- commit 353d322
* Tue Oct 28 2014 ohering@suse.de
- hyperv: Fix a bug in netvsc_send().
- hyperv: Fix a bug in netvsc_start_xmit().
- Drivers: hv: vmbus: Enable interrupt driven flow control.
- Drivers: hv: vmbus: Properly protect calls to
  smp_processor_id().
- Drivers: hv: vmbus: Cleanup hv_post_message().
- Drivers: hv: vmbus: Cleanup vmbus_close_internal().
- Drivers: hv: vmbus: Fix a bug in vmbus_open().
- Drivers: hv: vmbus: Cleanup vmbus_establish_gpadl().
- Drivers: hv: vmbus: Cleanup vmbus_teardown_gpadl().
- Drivers: hv: vmbus: Cleanup vmbus_post_msg().
- storvsc: get rid of overly verbose warning messages.
- hyperv: NULL dereference on error.
- hyperv: Increase the buffer length for netvsc_channel_cb().
- commit 579dd45
* Tue Oct 28 2014 bp@suse.de
- PCI: pciehp: Clear Data Link Layer State Changed during init
  (bnc#898297).
- PCI: pciehp: Use symbolic constants, not hard-coded bitmask
  (bnc#898297).
- commit 11e2fac
* Tue Oct 28 2014 tiwai@suse.de
- ALSA: hda - Treat zero connection as non-error (bnc#902898).
- commit 070d7ae
* Tue Oct 28 2014 oneukum@suse.de
- bcache: add mutex lock for bch_is_open (bnc#902893).
- commit d9ad793
* Tue Oct 28 2014 mgalbraith@suse.de
- futex: Fix a race condition between REQUEUE_PI and task death
  (bcn #851603 (futex scalability series)).
- commit 49821bb
* Thu Oct 23 2014 bp@suse.de
- PCI: pciehp: Use link change notifications for hot-plug and
  removal (bnc#898297).
- PCI: pciehp: Make check_link_active() non-static (bnc#898297).
- PCI: pciehp: Enable link state change notifications
  (bnc#898297).
- commit 9511c64
* Wed Oct 22 2014 tiwai@suse.de
- Use fop for creating PDF files in kernel-docs package
  As some files still cannot be built with the default backend.
- commit 0de03e2
* Wed Oct 22 2014 tiwai@suse.de
- Fix build of PDF files in kernel-docs package
  Double the spaces for tex, and fix buildrequires for docbook.
- commit 9e1f511
* Wed Oct 22 2014 jslaby@suse.cz
- Linux 3.12.31 (bnc#895983 bnc#897912).
- Refresh
  patches.drivers/0060-ib_isert-Add-support-for-completion-interrupt-coales.patch.
- Refresh
  patches.drivers/0139-iser-target-Fix-command-leak-for-tx_desc-comp_llnode.patch.
- Refresh
  patches.suse/0015_hibernate_Disable_in_a_signed_modules_environment.patch.
- Refresh
  patches.suse/msft-hv-0605-Drivers-net-hyperv-Enable-scatter-gather-I-O.patch.
- Refresh
  patches.suse/msft-hv-0606-Drivers-net-hyperv-Cleanup-the-send-path.patch.
- Refresh
  patches.suse/msft-hv-0609-Drivers-net-hyperv-Enable-send-side-checksum-offload.patch.
- Refresh
  patches.suse/msft-hv-0610-Drivers-net-hyperv-Enable-large-send-offload.patch.
- Refresh
  patches.suse/msft-hv-0615-Drivers-net-hyperv-Address-UDP-checksum-issues.patch.
- Refresh
  patches.suse/msft-hv-0630-hyperv-Add-hash-value-into-RNDIS-Per-packet-info.patch.
- Refresh patches.suse/nfs-no-share-transport-nfsv4.
- Delete
  patches.drivers/drm-ast-AST2000-cannot-be-detected-correctly.patch.
- Delete patches.fixes/mm-mempolicy-fix-vma-in-new_vma_page.patch.
- Delete
  patches.fixes/mm-new_vma_page-cannot-see-null-vma-for-hugetlb-pages.patch.
- Delete
  patches.suse/mm-thp-move-invariant-bug-check-out-of-loop-in-__split_huge_page_map.patch.
- Delete
  patches.suse/msft-hv-0667-hyperv-Fix-a-bug-in-netvsc_start_xmit.patch.
- regulatory: fix misapplied alpha2 fix (stable-3.12).
- kABI: protect struct vb2_queue.
- kABI: protect includes in linux/hid-sensor-hub.h.
- Revert "tcp: fix tcp_release_cb() to dispatch via address family for
  mtu_reduced()".
- Revert "regulatory: add NUL to alpha2".
- kABI: reintroduce vlan_untag.
- commit d373ef8
* Tue Oct 21 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8071-fix-fsync-race-leading-to-invalid-data-after-l.patch.
- Refresh
  patches.suse/btrfs-8076-shrink-further-sizeof-struct-extent_buffer.patch.
- Refresh
  patches.suse/btrfs-8077-fix-data-corruption-after-fast-fsync-and-writeback-error.patch.
- Refresh
  patches.suse/btrfs-8078-fix-directory-recovery-from-fsync-log.patch.
- Refresh
  patches.suse/btrfs-8080-add-missing-compression-property-remove-in-btr.patch.
- Refresh
  patches.suse/btrfs-8087-fix-crash-of-btrfs_release_extent_buffer_page.patch.
- Refresh
  patches.suse/btrfs-8088-add-missing-end_page_writeback-on-submit_exten.patch.
- Refresh
  patches.suse/btrfs-8089-be-aware-of-btree-inode-write-errors-to-avoid-.patch.
- Refresh
  patches.suse/btrfs-8123-send-don-t-delay-dir-move-if-there-s-a-new-par.patch.
- commit 7546287
* Mon Oct 20 2014 dbueso@suse.de
- futex: Ensure get_futex_key_refs() always implies a barrier
  (bcn #851603 (futex scalability series)).
- commit 7280fc9
* Fri Oct 17 2014 brogers@suse.com
- KVM: x86: Sysexit emulation does not mask RIP/RSP (CVE-2014-3647
  bnc#899192).
- KVM: vmx: Inject #GP on invalid PAT CR (CVE-2014-3647
  bnc#899192).
- KVM: x86: emulating descriptor load misses long-mode case
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Distinguish between stack operation and near branches
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Getting rid of grp45 in emulator (CVE-2014-3647
  bnc#899192).
- KVM: x86: Use new is_noncanonical_address in _linearize
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Handle errors when RIP is set during far jumps
  (CVE-2014-3647 bnc#899192).
- KVM: x86: Emulator fixes for eip canonical checks on near
  branches (CVE-2014-3647 bnc#899192).
- KVM: x86: Fix wrong masking on relative jump/call (CVE-2014-3647
  bnc#899192).
- KVM: x86: Warn if guest virtual address space is not 48-bits
  (CVE-2014-3647 bnc#899192).
- kvm: vmx: handle invvpid vm exit gracefully (CVE-2014-3647
  bnc#899192).
- KVM/x86: Improve thread safety in pit (CVE-2014-3611
  bnc#899192).
- KVM: x86: Check non-canonical addresses upon WRMSR
  (CVE-2014-3647 bnc#899192).
- KVM/x86: Prevent guest from writing non-canonical MSR addresses
  (CVE-2014-3610 bnc#899192).
- commit b473519
* Thu Oct 16 2014 jbeulich@suse.com
- usbback: don't access request fields in shared ring more
  than once.
- Update Xen patches to 3.12.30.
- commit 08e6483
* Wed Oct 15 2014 dbueso@suse.de
- Revert "locking/mutexes: Use MUTEX_SPIN_ON_OWNER when appropriate"
  This reverts commit 495e858f07fcfe802fda1610fa29a9c842470a2e.
- commit 77cc6c3
* Wed Oct 15 2014 dbueso@suse.de
- locking/rwsem: Avoid double checking before try acquiring
  write lock (Locking scalability.).
- commit b7f96bb
* Wed Oct 15 2014 dbueso@suse.de
- locking/mutexes: Use MUTEX_SPIN_ON_OWNER when appropriate
  (Mutex scalability).
- commit 495e858
* Mon Oct 13 2014 jjolly@suse.de
- zcrypt: toleration of new crypto adapter hardware (bnc#894057,
  LTC#117041).
- zcrypt: support for extended number of ap domains (bnc#894057,
  LTC#117041).
- commit 455fdea
* Fri Oct 10 2014 jslaby@suse.cz
- kgr: usb-storage, mark kthread safe (fate#313296 bnc#899908).
- Refresh
  patches.suse/kgr-0038-kgr-make-it-possible-to-avoid-lazy-switching.patch.
- Refresh patches.suse/kgr-0039-kgr-fix-ugly-race.patch.
  Fix few bugs, and also races (immutable vs mark_processes vs other
  threads).
- commit 203f15b
* Thu Oct  9 2014 jslaby@suse.cz
- kABI: protect linux/fs.h include in mm/internal.h.
- commit 867bcea
* Wed Oct  8 2014 jslaby@suse.cz
- Linux 3.12.30 (FATE#315482 bnc#862957 bnc#863526 bnc#870498).
- Refresh
  patches.kabi/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- Delete
  patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch.
- Delete
  patches.fixes/memcg-vmscan-Fix-forced-scan-of-anonymous-pages.patch.
- Delete
  patches.fixes/mm-fix-direct-reclaim-writeback-regression.patch.
- Delete
  patches.suse/callers-of-iov_copy_from_user_atomic-don-t-need-pagecache_disable.patch.
- Delete
  patches.suse/fs-buffer-Do-not-use-unnecessary-atomic-operations-when-discarding-buffers.patch.
- Delete
  patches.suse/fs-superblock-Avoid-locking-counting-inodes-and-dentries-before-reclaiming-them.patch.
- Delete
  patches.suse/fs-superblock-Unregister-sb-shrinker-before-kill_sb.patch.
- Delete
  patches.suse/hugetlb-ensure-hugepage-access-is-denied-if-hugepages-are-not-supported.patch.
- Delete patches.suse/jump_label-Expose-the-reference-count.patch.
- Delete patches.suse/lib-plist-add-helper-functions.patch.
- Delete patches.suse/lib-plist-add-plist_requeue.patch.
- Delete
  patches.suse/lib-radix-tree-add-radix_tree_delete_item.patch.
- Delete
  patches.suse/mm-Avoid-unnecessary-atomic-operations-during-end_page_writeback.patch.
- Delete
  patches.suse/mm-Do-not-use-atomic-operations-when-releasing-pages.patch.
- Delete
  patches.suse/mm-Do-not-use-unnecessary-atomic-operations-when-adding-pages-to-the-LRU.patch.
- Delete
  patches.suse/mm-Non-atomically-mark-page-accessed-during-page-cache-allocation-where-possible.patch.
- Delete
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-post.patch.
- Delete
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-prep.patch.
- Delete
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
- Delete
  patches.suse/mm-__rmqueue_fallback-should-respect-pageblock-type.patch.
- Delete
  patches.suse/mm-compaction-add-per-zone-migration-pfn-cache-for-async-compaction.patch.
- Delete
  patches.suse/mm-compaction-avoid-isolating-pinned-pages.patch.
- Delete
  patches.suse/mm-compaction-avoid-rescanning-pageblocks-in-isolate_freepages.patch.
- Delete
  patches.suse/mm-compaction-change-the-timing-to-check-to-drop-the-spinlock.patch.
- Delete
  patches.suse/mm-compaction-check-pageblock-suitability-once-per-pageblock.patch.
- Delete
  patches.suse/mm-compaction-clean-up-code-on-success-of-ballon-isolation.patch.
- Delete
  patches.suse/mm-compaction-clean-up-unused-code-lines.patch.
- Delete
  patches.suse/mm-compaction-cleanup-isolate_freepages.patch.
- Delete
  patches.suse/mm-compaction-determine-isolation-mode-only-once.patch.
- Delete
  patches.suse/mm-compaction-disallow-high-order-page-for-migration-target.patch.
- Delete
  patches.suse/mm-compaction-do-not-call-suitable_migration_target-on-every-page.patch.
- Delete
  patches.suse/mm-compaction-do-not-count-migratepages-when-unnecessary.patch.
- Delete
  patches.suse/mm-compaction-do-not-mark-unmovable-pageblocks-as-skipped-in-async-compaction.patch.
- Delete
  patches.suse/mm-compaction-embed-migration-mode-in-compact_control.patch.
- Delete
  patches.suse/mm-compaction-encapsulate-defer-reset-logic.patch.
- Delete
  patches.suse/mm-compaction-ignore-pageblock-skip-when-manually-invoking-compaction.patch.
- Delete
  patches.suse/mm-compaction-properly-signal-and-act-upon-lock-and-need_sched-contention.patch.
- Delete
  patches.suse/mm-compaction-reset-scanner-positions-immediately-when-they-meet.patch.
- Delete
  patches.suse/mm-compaction-return-failed-migration-target-pages-back-to-freelist.patch.
- Delete
  patches.suse/mm-compaction-terminate-async-compaction-when-rescheduling.patch.
- Delete
  patches.suse/mm-compaction-trace-compaction-begin-and-end.patch.
- Delete
  patches.suse/mm-don-t-pointlessly-use-BUG_ON-for-sanity-check.patch.
- Delete
  patches.suse/mm-exclude-memory-less-nodes-from-zone_reclaim.patch.
- Delete
  patches.suse/mm-filemap-move-radix-tree-hole-searching-here.patch.
- Delete
  patches.suse/mm-filemap.c-avoid-always-dirtying-mapping-flags-on-O_DIRECT.patch.
- Delete
  patches.suse/mm-fix-bad-rss-counter-if-remap_file_pages-raced-migration.patch.
- Delete
  patches.suse/mm-fs-prepare-for-non-page-entries-in-page-cache-radix-trees.patch.
- Delete
  patches.suse/mm-get-rid-of-unnecessary-overhead-of-trace_mm_page_alloc_extfrag.patch.
- Delete
  patches.suse/mm-get-rid-of-unnecessary-pageblock-scanning-in-setup_zone_migrate_reserve.patch.
- Delete
  patches.suse/mm-madvise-fix-MADV_WILLNEED-on-shmem-swapouts.patch.
- Delete patches.suse/mm-make-copy_pte_range-static-again.patch.
- Delete
  patches.suse/mm-memory.c-use-entry-ACCESS_ONCE-pte-in-handle_pte_fault.patch.
- Delete
  patches.suse/mm-migration-add-destination-page-freeing-callback.patch.
- Delete
  patches.suse/mm-move-zone-pages_scanned-into-vmstat.patch.
- Delete
  patches.suse/mm-page_alloc-Calculate-classzone_idx-once-from-the-zonelist-ref.patch.
- Delete
  patches.suse/mm-page_alloc-Convert-hot-cold-parameter-and-immediate-callers-to-bool.patch.
- Delete
  patches.suse/mm-page_alloc-Do-not-treat-a-zone-that-cannot-be-used-for-dirty-pages-as-full.patch.
- Delete
  patches.suse/mm-page_alloc-Do-not-update-zlc-unless-the-zlc-is-active.patch.
- Delete
  patches.suse/mm-page_alloc-Only-check-the-alloc-flags-and-gfp_mask-for-dirty-once.patch.
- Delete
  patches.suse/mm-page_alloc-Only-check-the-zone-id-check-if-pages-are-buddies.patch.
- Delete
  patches.suse/mm-page_alloc-Take-the-ALLOC_NO_WATERMARK-check-out-of-the-fast-path.patch.
- Delete
  patches.suse/mm-page_alloc-Use-jump-labels-to-avoid-checking-number_of_cpusets.patch.
- Delete
  patches.suse/mm-page_alloc-Use-unsigned-int-for-order-in-more-places.patch.
- Delete
  patches.suse/mm-page_alloc-lookup-pageblock-migratetype-with-IRQs-enabled-during-free.patch.
- Delete
  patches.suse/mm-page_alloc-only-apply-the-fair-zone-allocation-policy-if-eligible.patch.
- Delete
  patches.suse/mm-page_alloc-prevent-MIGRATE_RESERVE-pages-from-being-misplaced.patch.
- Delete
  patches.suse/mm-page_alloc-reduce-cost-of-the-fair-zone-allocation-policy.patch.
- Delete
  patches.suse/mm-page_alloc-reduce-number-times-page_to_pfn-is-called.patch.
- Delete
  patches.suse/mm-pagemap-Avoid-unnecessary-overhead-when-tracepoints-are-deactivated.patch.
- Delete patches.suse/mm-per-thread-vma-caching.patch.
- Delete
  patches.suse/mm-prevent-setting-of-a-value-less-than-0-to-min_free_kbytes.patch.
- Delete
  patches.suse/mm-readahead.c-fix-readahead-failure-for-memoryless-NUMA-nodes-and-limit-readahead-pages.patch.
- Delete patches.suse/mm-remove-read_cache_page_async.patch.
- Delete
  patches.suse/mm-shmem-Avoid-atomic-operation-during-shmem_getpage_gfp.patch.
- Delete
  patches.suse/mm-shmem-save-one-radix-tree-lookup-when-truncating-swapped-pages.patch.
- Delete
  patches.suse/mm-swap-add-a-simple-detector-for-inappropriate-swapin-readahead.patch.
- Delete
  patches.suse/mm-swap.c-clean-up-lru_cache_add-functions.patch.
- Delete
  patches.suse/mm-thp-cleanup-mv-alloc_hugepage-to-better-place.patch.
- Delete
  patches.suse/mm-thp-khugepaged-add-policy-for-finding-target-node.patch.
- Delete
  patches.suse/mm-thp-only-collapse-hugepages-to-nodes-with-affinity-for-zone_reclaim_mode.patch.
- Delete
  patches.suse/mm-vmscan-Use-proportional-scanning-during-direct-reclaim-and-full-scan-at-DEF_PRIORITY.patch.
- Delete
  patches.suse/mm-vmscan-call-NUMA-unaware-shrinkers-irrespective-of-nodemask.patch.
- Delete
  patches.suse/mm-vmscan-only-update-per-cpu-thresholds-for-online-cpus.patch.
- Delete
  patches.suse/mm-vmscan-respect-NUMA-policy-mask-when-shrinking-slab-on-direct-reclaim.patch.
- Delete
  patches.suse/mm-vmscan-shrink-all-slab-objects-if-tight-on-memory.patch.
- Delete
  patches.suse/mm-vmscan-shrink_slab-rename-max_pass-freeable.patch.
- Delete
  patches.suse/readahead-fix-sequential-read-cache-miss-detection.patch.
- Delete
  patches.suse/shmem-fix-init_page_accessed-use-to-stop-PageLRU-bug.patch.
- Delete patches.suse/slab-correct-pfmemalloc-check.patch.
- Delete
  patches.suse/swap-change-swap_info-singly-linked-list-to-list_head.patch.
- Delete
  patches.suse/swap-change-swap_list_head-to-plist-add-swap_avail_head.patch.
- Delete
  patches.suse/vmalloc-use-rcu-list-iterator-to-reduce-vmap_area_lock-contention.patch.
- Delete
  patches.suse/vmscan-reclaim_clean_pages_from_list-must-use-mod_zone_page_state.patch.
- Delete
  patches.suse/x86-clearing-access-bit-don-t-flush-tlb.patch.
- Delete
  patches.suse/x86-mm-Account-for-TLB-flushes-only-when-debugging.patch.
- Delete
  patches.suse/x86-mm-Clean-up-inconsistencies-when-flushing-TLB-ranges.patch.
- Delete
  patches.suse/x86-mm-Eliminate-redundant-page-table-walk-during-TLB-range-flushing.patch.
- commit f07a9c2
* Wed Oct  8 2014 jslaby@suse.cz
- kABI: protect struct machdep_calls.
- Revert "s390/locking: Reenable optimistic spinning".
- Update config files.
  kABI fixes for s390 and ppc64le.
- commit efce918
* Tue Oct  7 2014 fdmanana@suse.com
- Btrfs: be aware of btree inode write errors to avoid fs
  corruption (bnc#899551).
- Btrfs: add missing end_page_writeback on submit_extent_page
  failure (bnc#899551).
- Btrfs: fix crash of btrfs_release_extent_buffer_page
  (bnc#899551).
- commit b8c2cab
* Mon Oct  6 2014 jack@suse.cz
- Update
  patches.fixes/xfs-mark-all-internal-workqueues-as-freezable.patch
  (bnc#899785).
- commit 3bacd40
* Mon Oct  6 2014 jack@suse.cz
- xfs: mark all internal workqueues as freezable.
- commit 899093c
* Sun Oct  5 2014 eich@suse.de
- drm/i915: Move DP port disable to post_disable for pch platforms
  (bnc#899787).
- commit 4369624
* Fri Oct  3 2014 mhocko@suse.cz
- pagecachelimit: reduce lru_lock congestion for heavy parallel
  reclaim fix (bnc#895680).
- commit 53c0f08
* Fri Oct  3 2014 fdmanana@suse.com
- Btrfs: send, don't delay dir move if there's a new parent inode
  (bnc#897770).
- commit f57464c
* Thu Oct  2 2014 jslaby@suse.cz
- Linux 3.12.29 (bnc#879255 bnc#880892 bnc#887046 bnc#887418
  bnc#891619 bnc#892612 bnc#892650 bnc#897101).
- kABI: protect struct tpm_vendor_specific.
- Revert "svcrdma: Select NFSv4.1 backchannel transport based
  on forward channel".
- Update config files.
- Refresh patches.arch/powerpc-iommu-ddw-Fix-endianness.
- Refresh patches.fixes/futex-Clean-up-various-details.patch.
- Refresh
  patches.fixes/scsi-Use-BLIST_TESTLUN-for-Fujitsu-Eternus-DXL.patch.
- Refresh
  patches.suse/0002-md-raid1-add-failfast-handling-for-reads.patch.
- Refresh
  patches.suse/powerpc-mm-Add-new-set-flag-argument-to-pte-pmd-update-function.patch.
- Refresh
  patches.suse/powerpc-mm-Free-up-_PAGE_COHERENCE-for-numa-fault-use-later.patch.
- Delete
  patches.drivers/iommu-amd-fix-cleanup_domain-for-mass-device-removal.
- Delete
  patches.fixes/CIFS-Possible-null-ptr-deref-in-SMB2_tcon.patch.
- Delete
  patches.fixes/futex-Unlock-hb-lock-in-futex_wait_requeue_pi-error.patch.
- Delete
  patches.fixes/md-raid6-avoid-data-corruption-during-recovery-of-do.patch.
- Delete
  patches.fixes/scsi-Add-a-blacklist-flag-which-enables-VPD-page-inq.patch.
- Delete
  patches.fixes/x86-add-check-for-number-of-available-vectors-before-cpu-down.
- Delete
  patches.fixes/x86-cpu-hotplug-fix-stack-frame-warning-in-check_irq_vectors_for_cpu_disable.
- Delete
  patches.fixes/xfs-ensure-verifiers-are-attached-to-recovered-buffers.patch.
- Delete
  patches.fixes/xfs-quotacheck-leaves-dquot-buffers-without-verifiers.patch.
- Delete
  patches.suse/btrfs-8055-read-lock-extent-buffer-while-walking-backrefs.patch.
- Delete
  patches.suse/btrfs-8068-fix-csum-tree-corruption-duplicate-and-outdate.patch.
- Delete
  patches.suse/btrfs-8069-fix-memory-corruption-by-ulist-add.patch.
- Delete
  patches.suse/msft-hv-0643-Drivers-scsi-storvsc-Change-the-limits-to-reflect-th.patch.
- Delete
  patches.suse/msft-hv-0644-Drivers-scsi-storvsc-Set-cmd_per_lun-to-reflect-valu.patch.
- Delete
  patches.suse/msft-hv-0645-Drivers-scsi-storvsc-Filter-commands-based-on-the-st.patch.
- Delete
  patches.suse/msft-hv-0646-Drivers-scsi-storvsc-Fix-a-bug-in-handling-VMBUS-pro.patch.
- Delete
  patches.suse/msft-hv-0647-Drivers-scsi-storvsc-Implement-a-eh_timed_out-handle.patch.
- Delete
  patches.suse/msft-hv-0648-drivers-scsi-storvsc-Set-srb_flags-in-all-cases.patch.
- Delete
  patches.suse/msft-hv-0649-drivers-scsi-storvsc-Correctly-handle-TEST_UNIT_READ.patch.
- commit 1c83de4
* Thu Oct  2 2014 jroedel@suse.de
- iommu/vt-d: Work around broken RMRR firmware entries
  (bnc#892860).
- iommu/vt-d: Store bus information in RMRR PCI device path
  (bnc#892860).
- iommu/vt-d: Only remove domain when device is removed
  (bnc#883139).
- driver core: Add BUS_NOTIFY_REMOVED_DEVICE event (bnc#883139).
- commit 8ec2464
* Thu Oct  2 2014 jroedel@suse.de
- PM / hibernate: Iterate over set bits instead of PFNs in
  swsusp_free() (bnc#860441).
- Revert "PM / Hibernate: Iterate over set bits instead of PFNs
  in swsusp_free()" (bnc#860441).
- commit 8c6cadb
* Thu Oct  2 2014 jdelvare@suse.de
- Update config files: Re-enable CONFIG_FUNCTION_PROFILER (bnc#899489)
  Option FUNCTION_PROFILER was enabled in debug and trace kernels so far,
  but it was accidentally disabled before tracing features were merged
  into the default kernel and the trace flavor was discarded. So all
  kernels are missing the feature now. Re-enable it.
- commit 223b4cc
* Wed Oct  1 2014 jack@suse.cz
- Refresh
  patches.fixes/xfs-xlog_cil_force_lsn-doesnt-always-wait-correctly.patch.
- commit 0844c72
* Wed Oct  1 2014 jack@suse.cz
- xfs: xlog_cil_force_lsn doesn't always wait correctly.
- commit 8411c28
* Wed Oct  1 2014 fdmanana@suse.com
- Btrfs: ensure readers see new data after a clone operation
  (bnc#898234).
- Btrfs: avoid visiting all extent items when cloning a range
  (bnc#898234).
- Btrfs: fix clone to deal with holes when NO_HOLES feature is
  enabled (bnc#898234).
- Btrfs: make fsync work after cloning into a file (bnc#898234).
- Btrfs: fix use-after-free when cloning a trailing file hole
  (bnc#898234).
- Btrfs: clone, don't create invalid hole extent map (bnc#898234).
- commit 8c0cfc3
* Mon Sep 29 2014 hare@suse.de
- scsi: clear 'host_scribble' upon successful abort (bnc#894863).
- commit 5efe192
* Fri Sep 26 2014 mcgrof@suse.com
- module: warn if module init + probe takes long (bnc#889297
  bnc#877622 bnc#889295 bnc#893454).
- Rename
  patches.drivers/0005-module-warn-if-module-init-probe-takes-long.patch.
- commit 4be131e
* Fri Sep 26 2014 mcgrof@suse.com
- Update
  patches.drivers/0005-module-warn-if-module-init-probe-takes-long.patch
  (bnc#889297 bnc#877622 bnc#889295 bnc#893454).
- Delete
  patches.drivers/0001-init-kthread-add-module_long_probe_init-and-module_l.patch.
- Delete
  patches.drivers/0002-cxgb4-use-module_long_probe_init.patch.
- Delete
  patches.drivers/0003-mptsas-use-module_long_probe_init.patch.
- Delete
  patches.drivers/0004-pata_marvell-use-module_long_probe_init.patch.
- commit 9ddea15
* Thu Sep 25 2014 duwe@suse.de
- powerpc/iommu/ddw: Fix endianness (bsc#896028).
- commit 9879bd4
* Thu Sep 25 2014 mcgrof@suse.com
- module: warn if module init + probe takes long (bnc#889297).
- commit 8dd55d7
* Tue Sep 23 2014 spargaonkar@suse.com
- Block: fix unbalanced bypass-disable in blk_register_queue
  (bnc#880794).
- commit c7a790c
* Tue Sep 23 2014 fdmanana@suse.com
- Btrfs: limit the path size in send to PATH_MAX (bnc#897770).
- Btrfs: send, fix more issues related to directory renames
  (bnc#897770).
- Btrfs: send, remove dead code from __get_cur_name_and_parent
  (bnc#897770).
- Btrfs: send, account for orphan directories when building path
  strings (bnc#897770).
- Btrfs: send, avoid unnecessary inode item lookup in the btree
  (bnc#897770).
- Btrfs: send, fix incorrect ref access when using extrefs
  (bnc#897770).
- Btrfs: send, build path string only once in send_hole
  (bnc#897770).
- Btrfs: part 2, fix incremental send's decision to delay a dir
  move/rename (bnc#897770).
- Btrfs: fix incremental send's decision to delay a dir
  move/rename (bnc#897770).
- Btrfs: remove unnecessary inode generation lookup in send
  (bnc#897770).
- Btrfs: avoid unnecessary utimes update in incremental send
  (bnc#897770).
- Btrfs: fix send issuing outdated paths for utimes, chown and
  chmod (bnc#897770).
- Btrfs: fix send attempting to rmdir non-empty directories
  (bnc#897770).
- Btrfs: send, don't send rmdir for same target multiple times
  (bnc#897770).
- Btrfs: incremental send, fix invalid path after dir rename
  (bnc#897770).
- Btrfs: fix assert screwup for the pending move stuff
  (bnc#897770).
- Btrfs: make some tree searches in send.c more efficient
  (bnc#897770).
- Btrfs: use right extent item position in send when finding
  extent clones (bnc#897770).
- Btrfs: more send support for parent/child dir relationship
  inversion (bnc#897770).
- Btrfs: fix send dealing with file renames and directory moves
  (bnc#897770).
- Btrfs: add missing error check in incremental send (bnc#897770).
- Btrfs: make send's file extent item search more efficient
  (bnc#897770).
- Btrfs: fix infinite path build loops in incremental send
  (bnc#897770).
- commit 026c160
* Tue Sep 23 2014 hare@suse.de
- iscsi_ibft: Always display netmask (bnc#897960).
- commit aa28ca6
* Tue Sep 23 2014 jbohac@suse.cz
- ipv6: fix a refcnt leak with peer addr (bnc#896495).
- commit 3b90fcc
* Tue Sep 23 2014 vbabka@suse.cz
- mm: new_vma_page() cannot see NULL vma for hugetlb pages
  (bnc#897912).
- mm/mempolicy: fix !vma in new_vma_page() (bnc#897912).
- commit a976933
* Tue Sep 23 2014 neilb@suse.de
- NFS: limit the time we might block in nfs_release_page()
  (fate#315220).
- commit 885f96f
* Mon Sep 22 2014 jack@suse.cz
- ext4: add allow_unsupported module parameter (fate#317919).
- commit e814ae9
* Mon Sep 22 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 17342e6
* Mon Sep 22 2014 vbabka@suse.cz
- mm, THP: don't hold mmap_sem in khugepaged when allocating THP
  (bnc#880767, VM Performance).
- commit 2787c0c
* Mon Sep 22 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8079-set-inode-s-logged_trans-last_log_commit-after.patch.
- commit ba26399
* Mon Sep 22 2014 hare@suse.de
- qla2xxx: avoid reset for out-of-range handle (bnc#891212).
- qla2xxx: Do not crash system for sp ref count zero (bnc#891212).
- qla2xxx: Do not reset adapter if SRB handle is in range
  (bnc#891212).
- commit a3f9bf6
* Mon Sep 22 2014 hare@suse.de
- mpt3sas: Rework the MSI-X grouping code (bnc#880657).
- mpt2sas: Rework the MSI-X grouping code (bnc#880657).
- commit a097573
* Mon Sep 22 2014 jdelvare@suse.de
- supported.conf: Fix sorting
  Also strip a stray leading space.
- commit 54ba019
* Mon Sep 22 2014 neilb@suse.de
- md: be more relaxed about stopping an array which isn't started
  (bnc#896248).
- commit 8e705e3
* Fri Sep 19 2014 jlee@suse.com
- Refresh
  patches.arch/0001-acpi-Add-container-online-uevent-to-acpi_bus_attach.patch.
  Change #if to #ifdef to avoid CONFIG_ACPI_CONTAINER warning:
  warning: "CONFIG_ACPI_CONTAINER" is not defined [-Wundef]
  [#]if CONFIG_ACPI_CONTAINER
- commit 1af9c99
* Fri Sep 19 2014 hare@suse.de
- Enable logging for mpt2sas/mpt3sas (bnc#880657)
- commit 93ea4b1
* Fri Sep 19 2014 dbueso@suse.de
- locking/mutexes: Optimize mutex trylock slowpath (Mutex
  scalability).
- commit e68cf68
* Fri Sep 19 2014 dbueso@suse.de
- mm,vmacache: optimize overflow system-wide flushing (VM
  Performance).
- commit fe7ddbc
* Fri Sep 19 2014 jlee@suse.com
- KEYS: Fix termination condition in assoc array garbage
  collection (bnc#896262).
- commit 0e0bbb9
* Thu Sep 18 2014 ddiss@suse.de
- cifs: avoid null deref in SMB2_tcon (bnc#897101)
- patches.fixes/CIFS-Possible-null-ptr-deref-in-SMB2_tcon.patch
- commit cfc6590
* Thu Sep 18 2014 dbueso@suse.de
- futex: Unlock hb->lock in futex_wait_requeue_pi() error path
  (fix bcn#880892).
- commit 9f1f03e
* Wed Sep 17 2014 tonyj@suse.de
- Additional warning when sampling rate if decayed below startup
  minimum.
- commit cb92064
* Mon Sep 15 2014 mhocko@suse.cz
- pagecache_limit: batch large nr_to_scan targets (bnc#895221).
- commit 0ce84de
* Mon Sep 15 2014 hare@suse.de
- scsi: add defines for new FC port speeds (bnc#895352).
- commit 1564c06
* Mon Sep 15 2014 fdmanana@suse.com
- Btrfs: add missing compression property remove in
  btrfs_ioctl_setflags (bnc#895825).
- commit 575d4ed
* Mon Sep 15 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8064-fix-corruption-after-write-fsync-failure-fsync.patch.
- Refresh
  patches.suse/btrfs-8065-fix-crash-while-doing-a-ranged-fsync.patch.
- commit e0cd329
* Mon Sep 15 2014 fdmanana@suse.com
- Btrfs: set inode's logged_trans/last_log_commit after ranged
  fsync (bnc#894656).
- Refresh
  patches.suse/btrfs-8070-fix-fsync-data-loss-after-a-ranged-fsync.patch.
- commit de6d529
* Fri Sep 12 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8064-fix-corruption-after-write-fsync-failure-fsync.patch.
- Refresh
  patches.suse/btrfs-8065-fix-crash-while-doing-a-ranged-fsync.patch.
- commit ad6da6d
* Fri Sep 12 2014 jroedel@suse.de
- x86, cpu hotplug: Fix stack frame warning in
  check_irq_vectors_for_cpu_disable() (bnc#887418).
- x86: Add check for number of available vectors before CPU down
  (bnc#887418).
- commit aa1ec5d
* Fri Sep 12 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0038-kgr-make-it-possible-to-avoid-lazy-switching.patch.
- Refresh patches.suse/kgr-0039-kgr-fix-ugly-race.patch.
  immediate flag cleanup
- commit 16ccafb
* Fri Sep 12 2014 jlee@suse.com
- Refresh patches.arch/0001-efi-Autoload-efivars.patch.
  Update Git-commit and Patch-mainline tags.
- commit 4df0ecb
* Thu Sep 11 2014 jdelvare@suse.de
- supported.conf: Mark w83627ehf and nct6775 as supported (bnc#891281)
  As requested by customers. Both drivers are good code-wise, hardware
  is popular and we have datasheets for all supported chips AFAIK.
- commit 9c30b06
* Wed Sep 10 2014 jack@suse.cz
- Update Git-commit
  patches.suse/blk-mq-support-partial-I-O-completions.patch.
- commit 3f43974
* Wed Sep 10 2014 jslaby@suse.cz
- kabi: kgr, protect kgr structs (fate#313296).
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh
  patches.suse/kgr-0014-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Refresh
  patches.suse/kgr-0015-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Delete patches.kabi/kgr-0103-kabi-protext_kgr_structs.patch.
  Several fixes and rename the kabi patch to have a sane name.
- commit aa41044
* Wed Sep 10 2014 eich@suse.de
- drm/ast: open key before detect chips (bnc#895983).
- drm/ast: AST2000 cannot be detected correctly (bnc#895983).
- commit 1500a88
* Wed Sep 10 2014 fdmanana@suse.com
- Btrfs: fix directory recovery from fsync log (bnc#895797).
- commit 51afc67
* Wed Sep 10 2014 fdmanana@suse.com
- Btrfs: fix data corruption after fast fsync and writeback error
  (bnc#895794).
- commit 0eb7109
* Wed Sep 10 2014 neilb@suse.de
- Refresh
  patches.suse/0016-NFS-nfs4_do_open-should-add-negative-results-to-the-.patch.
  bugfix
- commit 257ea26
* Wed Sep 10 2014 mgalbraith@suse.de
- Fix reversed patch application order.
- sched: Fix the rq->next_balance logic in rebalance_domains() and idle_balance().
- Refresh patches.suse/sched-fair-Stop-searching-for-tasks-in-newidle-balance-if-there-are-runnable-tasks.patch.
- Delete patches.fixes/sched-Fix-the-rq-next_balance-logic-in-rebalance_domains-and-idle_balance.patch.
- commit f6db240
* Mon Sep  8 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8070-fix-fsync-data-loss-after-a-ranged-fsync.patch.
- commit 53d03e2
* Mon Sep  8 2014 eich@suse.de
- drm/ast: Actually load DP501 firmware when required (bnc#895608
  bnc#871134).
- commit 0d51d2f
* Mon Sep  8 2014 jlee@suse.com
- acpi : Add container online uevent to acpi_bus_attach
  (bnc#881784).
- commit 646e225
* Mon Sep  8 2014 agraf@suse.de
- kernel-obs-build: Force load kernel modules
  - fixes QEMU kiwi builds
- commit 9a27fc1
* Sun Sep  7 2014 agraf@suse.de
- rpm/kernel-obs-build.spec.in: Enable 32bit ARM builds
- commit 3ccdab2
* Sun Sep  7 2014 jlee@suse.com
- Refresh
  patches.arch/0001-ACPI-scan-not-cache-_SUN-value-in-struct-acpi_device.patch.
  Add sun element back to acpi_device_pnp struct for keep kABI.
- commit 15ab1ab
* Sat Sep  6 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8070-fix-fsync-data-loss-after-a-ranged-fsync.patch.
- commit aff039d
* Sat Sep  6 2014 bpoirier@suse.de
- be2net: do external loopback test only when it is requested
  (bnc#855062 FATE#315961).
- commit 829c42f
* Sat Sep  6 2014 jlee@suse.com
- ACPI / scan: not cache _SUN value in struct acpi_device_pnp
  (bnc#881783).
- commit 8937e97
* Fri Sep  5 2014 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-8070-fix-fsync-data-loss-after-a-ranged-fsync.patch.
- commit 96baedb
* Fri Sep  5 2014 ptesarik@suse.cz
- Refresh patches.xen/xen3-fixup-common.
- commit 76cd219
* Fri Sep  5 2014 ptesarik@suse.cz
- Put each per-cpu kdump ELF notes into a single page
  (bnc#879460).
- commit 505cb7b
* Fri Sep  5 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
- Refresh
  patches.suse/kgr-0030-kgr-avoid-potential-races-in-kgr_finalize.patch.
- Refresh
  patches.suse/kgr-0031-kgr-try-to-apply-skipped-patches-when-a-module-is-lo.patch.
- Refresh
  patches.suse/kgr-0032-kgr-handle-patched-modules-that-are-being-removed.patch.
- Refresh
  patches.suse/kgr-0033-kgr-handle-module-load-and-removal-for-non-finished-.patch.
- Refresh patches.suse/kgr-0037-kgr-allow-replace_all.patch.
- Refresh
  patches.suse/kgr-0038-kgr-make-it-possible-to-avoid-lazy-switching.patch.
- Refresh patches.suse/kgr-0039-kgr-fix-ugly-race.patch.
- Refresh
  patches.suse/kgr-0102-kgr-mark-kernel-unsupported-upon-patch-revert.patch.
  replace_all working, other fixes
- commit be2b475
* Fri Sep  5 2014 dsterba@suse.cz
- Btrfs: print btrfs specific info for some fatal error cases.
- Btrfs: fix off-by-one in cow_file_range_inline().
- Btrfs: fix wrong max inline data size limit.
- btrfs: sysfs label interface should check for read only FS.
- Btrfs: shrink further sizeof(struct extent_buffer).
- Refresh
  patches.suse/btrfs-8064-fix-corruption-after-write-fsync-failure-fsync.patch.
- Refresh
  patches.suse/btrfs-8065-fix-crash-while-doing-a-ranged-fsync.patch.
- Refresh
  patches.suse/btrfs-8070-fix-fsync-data-loss-after-a-ranged-fsync.patch.
- Refresh
  patches.suse/btrfs-8071-fix-fsync-race-leading-to-invalid-data-after-l.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- commit c47997d
* Fri Sep  5 2014 jjolly@suse.de
- Update config files.
  - CONFIG_WATCHDOG_NOWAYOUT causing immediate reboot on s390x (bnc#895103)
- commit b3ce337
* Thu Sep  4 2014 agraf@suse.de
- rpm/kernel-binary.spec.in: Always build zImage for ARM
- commit 14e56cc
* Thu Sep  4 2014 tiwai@suse.de
- Fix i915 HSW WARNING at S4 resume (bnc#894993).
- commit ac85059
* Thu Sep  4 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
- Refresh
  patches.suse/kgr-0031-kgr-try-to-apply-skipped-patches-when-a-module-is-lo.patch.
- Refresh
  patches.suse/kgr-0032-kgr-handle-patched-modules-that-are-being-removed.patch.
- Refresh
  patches.suse/kgr-0033-kgr-handle-module-load-and-removal-for-non-finished-.patch.
- Refresh
  patches.suse/kgr-0034-kgr-remove-patch-from-global-list-when-being-removed.patch.
- Refresh
  patches.suse/kgr-0035-kgr-fix-patch-stacking-also-when-loading-module.patch.
- Refresh patches.suse/kgr-0037-kgr-allow-replace_all.patch.
- Refresh
  patches.suse/kgr-0038-kgr-make-it-possible-to-avoid-lazy-switching.patch.
- Refresh patches.suse/kgr-0039-kgr-fix-ugly-race.patch.
  Just a small cleanup.
- commit 6183b16
* Thu Sep  4 2014 tonyj@suse.de
- powerpc/perf: Add Power8 cache & TLB events (bnc#893527).
- commit c3d1f22
* Thu Sep  4 2014 neilb@suse.de
- Support dm-raid on large-sector devices (bnc#884407).
- commit 3a57ad0
* Wed Sep  3 2014 jjolly@suse.de
- s390/ipl: Add missing SCSI loadparm attributes to /sys/firmware
  (bnc#894067, LTC#115286).
- commit 1f6f473
* Wed Sep  3 2014 jjolly@suse.de
- IB/iser: Add TIMEWAIT_EXIT event handling (bnc#890296).
- commit c9be653
* Wed Sep  3 2014 jbeulich@suse.com
- Update Xen patches to 3.12.27.
- don't automatically reboot Dom0 on panic (match native)
  (bnc#893968).
- Refresh
  patches.xen/xen3-kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch
  (bnc#890556).
- Refresh other Xen patches.
- commit 9e52902
* Wed Sep  3 2014 hare@suse.de
- scsi: Use BLIST_TESTLUN for Fujitsu Eternus DXL (bnc#893377).
- commit c506eb5
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Create a kernel-macros package with the KMP macros
  This package does not have multiversion(kernel) and is not built in the
  - rt tree (bnc#867595).
- commit 9b6a6fe
* Wed Sep  3 2014 jslaby@suse.cz
- Linux 3.12.28 (CVE-2014-5471 CVE-2014-5472 bnc#872177
  bnc#892490).
- kABI: protect struct bio_integrity_payload.
- Refresh
  patches.drivers/0061-usb-introduce-port-status-lock.patch.
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen-x86-bzImage.
- Refresh patches.xen/xen3-patch-2.6.37.
- Delete
  patches.drivers/0001-USB-OHCI-fix-bugs-in-debug-routines.patch.
- Delete
  patches.drivers/0001-devio-fix-issue-with-log-flooding.patch.
- Delete patches.drivers/0001-usb-core-bInterval-quirk.patch.
- Delete
  patches.drivers/0002-USB-core-hcd-pci-free-IRQ-before-disabling-PCI-devic.patch.
- Delete
  patches.drivers/0003-USB-Fix-persist-resume-of-some-SS-USB-devices.patch.
- Delete
  patches.fixes/isofs-Fix-unbounded-recursion-when-processing-reloca.patch.
- Delete
  patches.suse/0001-PM-hibernate-avoid-unsafe-pages-in-e820-reserved-reg.patch.
- Update config files. This add RELOCATABLE to XEN, which is wrong
  IMO. EFI_STUB should be disabled on XEN instead.
- commit f917bb9
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install doc files in a versioned directory (bnc#867595)
- commit deb25bc
* Tue Sep  2 2014 fdmanana@suse.com
- Btrfs: fix fsync race leading to invalid data after log replay
  (bnc#894666).
- commit 5869036
* Tue Sep  2 2014 fdmanana@suse.com
- Btrfs: fix fsync data loss after a ranged fsync (bnc#894656).
- commit 34d208d
* Tue Sep  2 2014 dsterba@suse.cz
- btrfs; disable defrag of tree roots.
- Btrfs: fix crash when starting transaction (bnc#892066).
- Btrfs: fix csum tree corruption, duplicate and outdated
  checksums (bnc#891619).
- Btrfs: Fix memory corruption by ulist_add_merge() on 32bit arch
  (bnc#887046).
- Delete
  patches.fixes/Btrfs-Fix-memory-corruption-by-ulist_add_merge-on-32.
- Delete
  patches.suse/btrfs-6000-Btrfs-fix-crash-when-starting-transaction.patch.
- Delete
  patches.suse/btrfs-9000-fix-csum-tree-corruption-duplicate-and-outdate.patch.
- commit 1601d25
* Tue Sep  2 2014 fdmanana@suse.com
- Btrfs: fix crash while doing a ranged fsync (bnc#894485).
- commit c3e473c
* Mon Sep  1 2014 mmarek@suse.cz
- kabi/severities: Whitelist more s390x symbols (bnc#894391)
- commit 3757dea
* Mon Sep  1 2014 eich@suse.de
- drm/panic: Add option to set panic mode (bnc#892114).
- drm/panic: Set priority of the drm panic code to the lowest
  value possible (bnc#892114).
- drm/panic: Only restore console if kernel isn't set to reboot
  on panic (bnc#892114).
- commit 32ac651
* Fri Aug 29 2014 lduncan@suse.com
- be2iscsi: Fix processing CQE before connection resources are
  freed (bnc#869278).
- be2iscsi: Fix updating the boot enteries in sysfs (bnc#869278).
- be2iscsi: Fix the copyright year (bnc#869278).
- be2iscsi: Fix the sparse warning introduced in previous
  submission (bnc#869278).
- commit c55036d
* Fri Aug 29 2014 mmarek@suse.cz
- Enable rcutorture as an unsupported module (bnc#893376)
- commit a928cf1
* Fri Aug 29 2014 fdmanana@suse.com
- Btrfs: fix corruption after write/fsync failure + fsync +
  log recovery (bnc#894185).
- commit 92c3504
* Fri Aug 29 2014 bpoirier@suse.de
- bnx2x: Revert UNDI flushing mechanism (bnc#853494 FATE#315918).
- bnx2x: Fix link for KR with swapped polarity lane (bnc#853494
  FATE#315918).
- commit 5c6c56f
* Fri Aug 29 2014 bpoirier@suse.de
- Refresh
  patches.drivers/bnx2x-Adapter-not-recovering-from-EEH-error-injection.
- Refresh
  patches.drivers/bnx2x-Fix-kernel-crash-and-data-miscompare-after-EEH-recovery.
- commit 12f8247
* Thu Aug 28 2014 jslaby@suse.cz
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Refresh
  patches.suse/kgr-0020-kgr-rephrase-the-kGraft-failed-message.patch.
- Refresh
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Refresh
  patches.suse/kgr-0022-kgr-add-state-machine-to-a-patch.patch.
- Refresh
  patches.suse/kgr-0024-kgr-move-the-logic-to-kgr_patch_code-s-switch.patch.
- Refresh
  patches.suse/kgr-0025-kgr-add-patch-information-into-sysfs.patch.
- Refresh
  patches.suse/kgr-0026-kgr-support-revert-of-patches.patch.
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
- Refresh
  patches.suse/kgr-0030-kgr-avoid-potential-races-in-kgr_finalize.patch.
- Refresh
  patches.suse/kgr-0034-kgr-remove-patch-from-global-list-when-being-removed.patch.
- Refresh patches.suse/kgr-0037-kgr-allow-replace_all.patch.
  Fix replace_all a bit. Still to be finished.
- commit 065a038
* Thu Aug 28 2014 mmarek@suse.cz
- kabi/severities: Whitelist s390x drivers and KVM
- commit a76dc0d
* Thu Aug 28 2014 jslaby@suse.cz
- Refresh patches.kabi/kabi-resettle-select_ident.patch.
  Fix kabi breakage.
- commit 72991b2
* Thu Aug 28 2014 tiwai@suse.de
- Update config files for CONFIG_FW_LOADER_USER_HELPER_FALLBACK
- Make CONFIG_FW_LOADER_USER_HELPER selectable (bnc#889297).
- firmware loader: inform direct failure when udev loader is
  disabled (bnc#889297).
- firmware loader: allow disabling of udev as firmware loader
  (bnc#889297).
- firmware: Suppress fallback warnings when
  CONFIG_FW_LOADER_USER_HELPER=n (bnc#889297).
- firmware: Use bit flags instead of boolean combos (bnc#889297).
- commit 40456d5
* Thu Aug 28 2014 tiwai@suse.de
- firmware: Introduce request_firmware_direct() (bnc#889297).
- firmware: Be a bit more verbose about direct firmware loading
  failure (bnc#889297).
- commit 502f70c
* Thu Aug 28 2014 oneukum@suse.de
- bcache: Stripe size isn't necessarily a power of two
  (bnc#893949).
- commit 0275cdc
* Wed Aug 27 2014 jack@suse.cz
- patches.fixes/isofs-Fix-unbounded-recursion-when-processing-reloca.patch:
  Update references
- commit 940d8f7
* Wed Aug 27 2014 oneukum@suse.de
- bcache: Fix a lockdep splat (bnc#893777).
- bcache: Fix a journalling performance bug (bnc#893777).
- commit 98fea91
* Wed Aug 27 2014 mcgrof@suse.com
- pata_marvell: use module_long_probe_init() (bnc#893454).
- commit ff7a2f3
* Wed Aug 27 2014 mcgrof@suse.com
- mptsas: use module_long_probe_init() (bnc#889295).
- commit be94913
* Wed Aug 27 2014 mcgrof@suse.com
- cxgb4: use module_long_probe_init() (bnc#877622).
- commit c520565
* Wed Aug 27 2014 mcgrof@suse.com
- init / kthread: add module_long_probe_init() and
  module_long_probe_exit() (bnc#889297).
- commit bf1af04
* Tue Aug 26 2014 jslaby@suse.cz
- Linux 3.12.27 (CVE-2014-3534 CVE-2014-4943 CVE-2014-5077
  CVE-2014-5206 CVE-2014-5207 FATE#315648 FATE#315649 FATE#315660
  FATE#315661 FATE#315667 FATE#315668 FATE#315916 FATE#315918
  FATE#315937 FATE#315938 FATE#315961 FATE#317088 bnc#404881
  bnc#850493 bnc#852650 bnc#853494 bnc#853679 bnc#855062
  bnc#855232 bnc#857394 bnc#857395 bnc#857399 bnc#857400
  bnc#857401 bnc#857402 bnc#863634 bnc#867789 bnc#871676
  bnc#874464 bnc#875687 bnc#879464 bnc#881730 bnc#884925
  bnc#885460 bnc#886633 bnc#887082 bnc#888849 bnc#889173
  bnc#891689).
- kABI: protect struct inet_peer.
- Refresh
  patches.arch/0020-x86-Export-x86-boot_params-to-sysfs.patch.
- Refresh patches.arch/s390-sles12-07-01-uaccess.patch.
- Refresh patches.arch/s390-sles12-07-02-uaccess.patch.
- Refresh
  patches.arch/x86-ptdump-add-the-functionality-to-dump-an-arbitrary-pagetable.patch.
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh
  patches.drivers/ixgbe-0005-ixgbe-remove-marketing-names-from-busy-poll-code.patch.
- Refresh
  patches.fixes/macvlan-Add-support-for-always_on-offload-features.patch.
- Refresh patches.fixes/net-generalize-skb_segment.patch.
- Refresh
  patches.fixes/printk-nmi-0009-printk-merge-and-flush-NMI-buffer-predictably-via-IR.patch.
- Refresh
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
- Refresh
  patches.suse/mm-hugetlb.c-call-MMU-notifiers-when-copying-a-hugetlb-page-range.patch.
- Refresh patches.suse/paravirt-Split-paravirt-MMU-ops.patch.
- Refresh
  patches.suse/printk-Remove-separate-printk_sched-buffers-and-use-.patch.
- Refresh
  patches.xen/xen3-0020-x86-Export-x86-boot_params-to-sysfs.patch.
- Delete patches.arch/s390-sles12-ptrace-poke-exploit.patch.
- Delete
  patches.drivers/0001-HID-logitech-dj-Fix-USB-3.0-issue.patch.
- Delete
  patches.drivers/0001-RDMA-cxgb3-Fix-information-leak-in-send_abort.patch.
- Delete
  patches.drivers/0001-drivers-rtc-rtc-efi.c-avoid-subtracting-day-twice-wh.patch.
- Delete patches.drivers/0001-offb-Little-endian-fixes.patch.
- Delete patches.drivers/0002-EFI-RTC-check-time.patch.
- Delete
  patches.drivers/ALSA-hda-load-EQ-params-into-IDT-codec-on-HP-bNB13-s.
- Delete
  patches.drivers/bna-0001-DMA-API-net-brocade-bna-bnad.c-fix-32-bit-DMA-mask-h.patch.
- Delete
  patches.drivers/bnx2fc-fix-memory-leak-in-bnx2fc_allocate_hash_table.patch.
- Delete
  patches.drivers/bnx2x-0003-bnx2x-Test-nvram-when-interface-is-down.patch.
- Delete
  patches.drivers/e1000-0003-e1000-fix-wrong-queue-idx-calculation.patch.
- Delete
  patches.drivers/e1000-0004-e1000-prevent-oops-when-adapter-is-being-closed-and-.patch.
- Delete
  patches.drivers/e1000-0006-e1000-fix-possible-reset_task-running-after-adapter-.patch.
- Delete
  patches.drivers/e1000e-0001-DMA-API-net-intel-e1000e-fix-32-bit-DMA-mask-handlin.patch.
- Delete
  patches.drivers/e1000e-0006-e1000e-Fix-a-compile-flag-mis-match-for-suspend-resu.patch.
- Delete
  patches.drivers/e1000e-0008-e1000e-Fix-compilation-warning-when-CONFIG_PM_SLEEP.patch.
- Delete
  patches.drivers/igb-0001-DMA-API-net-intel-igb-fix-32-bit-DMA-mask-handling.patch.
- Delete
  patches.drivers/igb-0003-igb-Add-ethtool-offline-tests-for-i354.patch.
- Delete
  patches.drivers/igb-0006-igb-Fix-master-slave-mode-for-all-m88-i354-PHY-s.patch.
- Delete
  patches.drivers/igb-0007-igb-fix-driver-reload-with-VF-assigned-to-guest.patch.
- Delete
  patches.drivers/igb-0008-igb-Don-t-let-ethtool-try-to-write-to-iNVM-in-i210-i.patch.
- Delete
  patches.drivers/igb-0010-igb-Fixed-Wake-On-LAN-support.patch.
- Delete
  patches.drivers/igbvf-0001-DMA-API-net-intel-igbvf-fix-32-bit-DMA-mask-handling.patch.
- Delete
  patches.drivers/igbvf-0004-igbvf-integer-wrapping-bug-setting-the-mtu.patch.
- Delete
  patches.drivers/igbvf-0005-igbvf-add-missing-iounmap-on-error-in-igbvf_probe.patch.
- Delete
  patches.drivers/ixgbe-0001-DMA-API-net-intel-ixgbe-fix-32-bit-DMA-mask-handling.patch.
- Delete
  patches.drivers/ixgbe-0009-ixgbe-fix-rx-usecs-range-checks-for-BQL.patch.
- Delete
  patches.drivers/ixgbe-0010-ixgbe-fix-qv_lock_napi-call-in-ixgbe_napi_disable_al.patch.
- Delete
  patches.drivers/ixgbe-0014-ixgbe-fix-inconsistent-clearing-of-the-multicast-tab.patch.
- Delete
  patches.drivers/ixgbevf-0001-DMA-API-net-intel-ixgbevf-fix-32-bit-DMA-mask-handli.patch.
- Delete
  patches.drivers/ixgbevf-0004-ixgbevf-cleanup-redundant-mailbox-read-failure-check.patch.
- Delete
  patches.drivers/netxen_nic-0003-netxen-Correct-off-by-one-errors-in-bounds-checks.patch.
- Delete
  patches.drivers/tg3-0002-tg3-Add-support-for-new-577xx-device-ids.patch.
- Delete
  patches.fixes/DMA-API-provide-a-helper-to-set-both-DMA-and-coheren.patch.
- Delete
  patches.fixes/drivers-rtc-interface.c-fix-infinite-loop-in-initial.patch.
- Delete
  patches.fixes/ext4-Fix-block-zeroing-when-punching-holes-in-indire.patch.
- Delete
  patches.fixes/fbcon-Clean-up-fbcon-data-in-fb_info-on-FB_EVENT_FB_.
- Delete patches.fixes/input-add-acer-aspire-5710-to-nomux.patch.
- Delete patches.fixes/memcg-oom_notify-use-after-free-fix.patch.
- Delete
  patches.fixes/mm-thp-do-not-allow-thp-faults-to-avoid-cpuset-restriction.patch.
- Delete
  patches.fixes/mnt-correct-permission-checks-in-do_remount.patch.
- Delete
  patches.fixes/mnt-move-the-test-for-mnt_lock_readonly-from-change_.patch.
- Delete
  patches.fixes/mnt-only-change-user-settable-mount-flags-in-remount.patch.
- Delete
  patches.fixes/net-l2tp-don-t-fall-back-on-udp-get-set-sockopt.patch.
- Delete
  patches.fixes/net-sctp-inherit-auth_capable-on-INIT-collisions.patch.
- Delete patches.fixes/pci-hotplug-rphahp-fix-endianess-issues.
- Delete
  patches.suse/0001-tipc-don-t-use-memcpy-to-copy-from-user-space.patch.
- Update config files.
- commit 3147cab
* Tue Aug 26 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-uas-Limit-qdepth-to-32-when-connected-over-usb-2.patch.
- commit 41042bc
* Tue Aug 26 2014 eich@suse.de
- drm/mgag200: Add command line option to specify preferred depth
  (bnc#893040).
- commit 3b57f5d
* Mon Aug 25 2014 dvaleev@suse.com
- powerpc/perf: Fix MMCR2 handling for EBB.
- commit 54e2f08
* Fri Aug 22 2014 eich@suse.de
- drm/i915: don't disable ERR_INT on the IRQ handler (bnc#892722).
- commit 7212dc4
* Fri Aug 22 2014 eich@suse.de
- Refresh
  patches.drivers/drm-ast-Add-reduced-non-reduced-mode-parsing-for-wide-screen-mode.patch.
- commit faf0394
* Fri Aug 22 2014 eich@suse.de
- drm/ast: Add reduced non reduced mode parsing for wide screen
  mode (bnc#892723).
- drm/ast: Add missing entry to dclk_table[].
- commit 3acc69d
* Fri Aug 22 2014 jslaby@suse.cz
- x86, tools: Fix more compiler errors.
- commit 05da6fe
* Fri Aug 22 2014 jslaby@suse.cz
- kabi: kgr, protext kgr structs (fate#313296).
- kgr: fix patch stacking also when loading module (fate#313296).
- kgr: confusion with fatal state (fate#313296).
- kgr: allow replace_all (fate#313296).
- kgr: make it possible to avoid lazy switching (fate#313296).
- kgr: fix ugly race (fate#313296).
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
- Refresh
  patches.suse/kgr-0032-kgr-handle-patched-modules-that-are-being-removed.patch.
- Refresh
  patches.suse/kgr-0033-kgr-handle-module-load-and-removal-for-non-finished-.patch.
- Refresh
  patches.suse/kgr-0034-kgr-remove-patch-from-global-list-when-being-removed.patch.
- Delete
  patches.suse/kgr-0035-kgr-confusion-with-fatal-state.patch.
- Delete patches.suse/kgr-0036-kgr-allow-replace_all.patch.
  Fix few races & bugs, add 'immediate' flag.
- commit 98e35b3
* Fri Aug 22 2014 eich@suse.de
- drm: Print EDID errors less obviously (bnc#892889).
- commit 8072658
* Fri Aug 22 2014 eich@suse.de
- drm/mgag200: Reject modes when h-parameters are no multiple of 8
  (bnc #806990).
- Refresh
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch.
- Refresh
  patches.drivers/drm-mgag200-Consolidate-depth-bpp-handling.patch.
- Refresh
  patches.drivers/drm-mgag200-Don-t-use-crtc_-parameters-for-validation.patch.
- Delete
  patches.drivers/drm-mgag200-Reject-modes-when-hdisplay-is-no-multiple-of-8.patch.
- commit b26d8bd
* Thu Aug 21 2014 jack@suse.cz
- isofs: Fix unbounded recursion when processing relocated
  directories (bnc#892490).
- commit be9fe84
* Thu Aug 21 2014 tiwai@suse.de
- Btrfs: Fix memory corruption by ulist_add_merge() on 32bit arch
  (bnc#887046).
- commit 4954d3f
* Thu Aug 21 2014 mmarek@suse.cz
- Make the kabi checks fatal now
- commit 8d7103a
* Thu Aug 21 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix the version variables in the generated
  Makefile (bnc#892973)
- commit 8331f47
* Wed Aug 20 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Do not duplicate the job of brp-99-compress-vmlinux
- commit e561498
* Wed Aug 20 2014 jroedel@suse.de
- PM / hibernate: Use put_page in free_image_page() (bnc#892004, bnc#890373).
- commit 8381331
* Wed Aug 20 2014 neilb@suse.de
- autofs4: make "autofs4_can_expire" idempotent (bnc#866130).
- commit 19fd3c7
* Wed Aug 20 2014 neilb@suse.de
- md/raid6: avoid data corruption during recovery of
  double-degraded RAID6 (bnc#892650).
- commit 46fffad
* Tue Aug 19 2014 jroedel@suse.de
- PM / hibernate: Use put_page to free ring-buffer pages (bnc#892004, bnc#890373).
- commit f909c29
* Tue Aug 19 2014 jroedel@suse.de
- iommu/core: Check for the right function pointer in iommu_map()
  (bnc#892612).
- iommu/amd: Fix cleanup_domain for mass device removal
  (bnc#892612).
- commit be011cf
* Tue Aug 19 2014 jroedel@suse.de
- Refresh patches.drivers/iommu-vt-d-defer-domain-removal-if-device-is-assigned-to-a-driver.
- commit 6c6121e
* Tue Aug 19 2014 jslaby@suse.cz
- Refresh
  patches.fixes/sched-Fix-task_sched_runtime-monotonicity.patch.
- Refresh
  patches.drivers/cxgb4i-use-cxgb4_select_ntuple-to-correctly-calculate-ntuple-fields.
- Refresh
  patches.fixes/ext4-Fix-block-zeroing-when-punching-holes-in-indire.patch.
- Refresh
  patches.fixes/net-sctp-inherit-auth_capable-on-INIT-collisions.patch.
- Refresh patches.fixes/pci-hotplug-rphahp-fix-endianess-issues.
- Refresh
  patches.suse/0001-PM-hibernate-avoid-unsafe-pages-in-e820-reserved-reg.patch.
  Update SHAs and such.
- commit 2bb39b0
* Tue Aug 19 2014 tiwai@suse.de
- usbcore: Fix wrong device in an error message in
  hub_port_connect() (bnc#892457).
- commit 1c5b02e
* Tue Aug 19 2014 jslaby@suse.cz
- kgr: mark kernel unsupported upon patch revert (fate#313296).
- commit 8f90c43
* Tue Aug 19 2014 mszeredi@suse.cz
- mnt: Correct permission checks in do_remount (bnc#891689,
  CVE-2014-5206, CVE-2014-5207).
- mnt: Move the test for MNT_LOCK_READONLY from change_mount_flags
  into do_remount (bnc#891689, CVE-2014-5206, CVE-2014-5207).
- mnt: Only change user settable mount flags in remount
  (bnc#891689, CVE-2014-5206, CVE-2014-5207).
- commit 7391728
* Mon Aug 18 2014 mfasheh@suse.de
- btrfs: don't crash on existing qgroup items (bnc#892408).
- commit 71b2293
* Mon Aug 18 2014 mgorman@suse.de
- Refresh
  patches.suse/hugetlb-ensure-hugepage-access-is-denied-if-hugepages-are-not-supported.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-post.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-prep.patch.
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
  patches.suse/mm-page_alloc-do-not-cache-reclaim-distances.patch.
  patches.suse/mm-page_alloc-reduce-cost-of-the-fair-zone-allocation-policy.patch.
  patches.suse/pagecache-limit-reduce-zone-lrulock-bouncing.patch.
- commit d2b232f
* Mon Aug 18 2014 jjolly@suse.de
- ptrace: fix PSW mask check (CVE-2014-3534,bnc#885460).
- commit 1ea94c5
* Mon Aug 18 2014 mmarek@suse.cz
- Update
  patches.arch/0001-powerpc-Add-smp_mb-to-arch_spin_is_locked.patch
  (bnc#892254).
- Update
  patches.arch/0002-powerpc-Add-smp_mb-s-to-arch_spin_unlock_wait.patch
  (bnc#892254).
- commit d318f3a
* Mon Aug 18 2014 mmarek@suse.cz
- powerpc: Add smp_mb()s to arch_spin_unlock_wait().
- powerpc: Add smp_mb() to arch_spin_is_locked().
- commit 2e7306c
* Mon Aug 18 2014 jslaby@suse.cz
- Update
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch
  (fate#313296 bnc#889207 bnc#891710).
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
- Refresh
  patches.suse/kgr-0030-kgr-avoid-potential-races-in-kgr_finalize.patch.
- Refresh
  patches.suse/kgr-0031-kgr-try-to-apply-skipped-patches-when-a-module-is-lo.patch.
- Refresh
  patches.suse/kgr-0032-kgr-handle-patched-modules-that-are-being-removed.patch.
- Refresh
  patches.suse/kgr-0033-kgr-handle-module-load-and-removal-for-non-finished-.patch.
- Refresh
  patches.suse/kgr-0034-kgr-remove-patch-from-global-list-when-being-removed.patch.
- Refresh patches.suse/kgr-0036-kgr-allow-replace_all.patch.
- Update patches.suse/kgr-0101-handle-btrfs-kthreads.patch
  (fate#313296 bnc#889207).
- Refresh
  patches.suse/kgr-pre-0002-module-add-within_module-function.patch.
- Refresh
  patches.suse/kgr-pre-0003-module-return-bool-from-within_module.patch.
  Fix some bugs, update commit SHAs, bug references.
- commit 165f94a
* Mon Aug 18 2014 schwab@suse.de
- rpm/kernel-binary.spec.in: Fix missing quotes around %%build_flavor
  %%build_flavor can be an arbitrary string, so it needs to be quoted for
  string comparison.
- commit 0134440
* Mon Aug 18 2014 mmarek@suse.cz
- Update kabi files.
- commit 010a35c
* Mon Aug 18 2014 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in: Use dracut for SLE12
- commit ec64eaf
* Fri Aug 15 2014 jlee@suse.com
- PM / hibernate: avoid unsafe pages in e820 reserved regions
  (bnc#872177).
- commit 6ab852f
* Fri Aug 15 2014 jroedel@suse.de
- mm: use 'const char *' insted of 'char *' for reason in
  dump_page() (bnc#892071).
- mm: print more details for bad_page() (bnc#892071).
- commit 8447660
* Fri Aug 15 2014 fdmanana@suse.com
- Btrfs: fix crash when starting transaction (bnc#892066).
- commit e63a2a0
* Thu Aug 14 2014 jroedel@suse.de
- PM / Hibernate: Touch Soft Lockup Watchdog in rtree_next_node
  (bnc#860441).
- PM / Hibernate: Remove the old memory-bitmap implementation
  (bnc#860441).
- PM / Hibernate: Iterate over set bits instead of PFNs in
  swsusp_free() (bnc#860441).
- PM / Hibernate: Implement position keeping in radix tree
  (bnc#860441).
- PM / Hibernate: Add memory_rtree_find_bit function (bnc#860441).
- PM / Hibernate: Create a Radix-Tree to store memory bitmap (bnc#860441).
- commit 0f37633
* Thu Aug 14 2014 jjolly@suse.de
- qeth: don't query for info if hardware not ready (bnc#892005,
  LTC#113780).
- commit 281d74b
* Thu Aug 14 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Include the x509 certs also in kernel-vanilla
- commit 6f8a341
* Thu Aug 14 2014 duwe@suse.de
- crypto: drbg - fix failure of generating multiple of 2**16 bytes
  (bnc#856310).
- commit 7bdcdf4
* Thu Aug 14 2014 jjolly@suse.de
- dasd: validate request size before building CCW/TCW (bnc#891086,
  LTC#114068).
- kernel: 3215 tty hang (bnc#891086, LTC#114562).
- Delete
  patches.suse/0001-s390-3215-fix-hanging-console-issue.patch.
- commit 0c15ea4
* Thu Aug 14 2014 ohering@suse.de
- hyperv_fb: use mainline version of screen refresh after panic
- commit 51dc159
* Thu Aug 14 2014 ohering@suse.de
- hv_netvsc: use rcnetwork to restart on
  RNDIS_STATUS_NETWORK_CHANGE event.
- commit cf19eee
* Thu Aug 14 2014 ohering@suse.de
- Input: hyperv-keyboard - register as a wakeup source.
- commit a03b171
* Thu Aug 14 2014 ohering@suse.de
- hyperv: Adjust the size of sendbuf region to support ws2008r2.
- Drivers: net-next: hyperv: Increase the size of the sendbuf
  region.
- commit 5f3a359
* Thu Aug 14 2014 ohering@suse.de
- HID: hyperv: register as a wakeup source.
- commit 4b2d8c5
* Thu Aug 14 2014 ohering@suse.de
- Add mainline tags for hv_storvsc upatches
- commit 740f074
* Thu Aug 14 2014 ohering@suse.de
- hyperv: Fix error return code in netvsc_init_buf().
- commit 3ab5f67
* Thu Aug 14 2014 ohering@suse.de
- hyperv: Add netpoll support.
- commit b6820e4
* Thu Aug 14 2014 ohering@suse.de
- hyperv: remove meaningless pr_err() in vmbus_recvpacket_raw().
- commit 99c733e
* Thu Aug 14 2014 ohering@suse.de
- Tools: hv: fix file overwriting of hv_fcopy_daemon.
- commit 300dca9
* Thu Aug 14 2014 ohering@suse.de
- drivers/net/hyperv/netvsc.c: remove unnecessary null test
  before kfree.
- commit 805a888
* Thu Aug 14 2014 ohering@suse.de
- hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event.
- commit 1e06286
* Wed Aug 13 2014 mgorman@suse.de
- Delete
  patches.suse/mm-replace-init_page_accessed-by-__SetPageReferenced.patch.
- commit b5ec32e
* Wed Aug 13 2014 mcgrof@suse.com
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
  Filipe noticed a regression cased by the VFS btrfs
  patch and also provided a fix. The crash is only
  currently known to be triggered if the stress
  tests are used. This amends the original patch
  with Filipe's fix.
- commit 04eeacf
* Wed Aug 13 2014 jbohac@suse.cz
- net/l2tp: don't fall back on UDP [get|set]sockopt (bnc#887082,
  CVE-2014-4943).
- commit e95e9b5
* Wed Aug 13 2014 mfasheh@suse.de
- Refresh patches.suse/btrfs-0404-account-shared-subtrees.patch.
- fixes an error where we passed a bad root pointer to
  btrfs_delayed_qgroup_accounting() in btrfs_drop_snapshot()
- commit 678d606
* Wed Aug 13 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-thp-replace-smp_mb-after-atomic_add-by-smp_mb__after_atomic.patch.
- commit c132f2e
* Wed Aug 13 2014 mgorman@suse.de
- mm, thp: replace smp_mb after atomic_add by smp_mb__after_atomic
  (VM Performance).
- mm, thp: move invariant bug check out of loop in
  __split_huge_page_map (VM Performance).
- mm: replace init_page_accessed by __SetPageReferenced (VM
  Performance).
- mm: make copy_pte_range static again (VM Performance).
- mm/memory.c: use entry = ACCESS_ONCE(*pte) in handle_pte_fault()
  (VM Performance).
- vmalloc: use rcu list iterator to reduce vmap_area_lock
  contention (VM Performance).
- commit 13985e6
* Wed Aug 13 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
  patches.suse/mm-move-zone-pages_scanned-into-vmstat.patch.
  patches.suse/mm-page_alloc-only-apply-the-fair-zone-allocation-policy-if-eligible.patch
  patches.suse/mm-page_alloc-reduce-cost-of-the-fair-zone-allocation-policy.patch.
  patches.suse/mm-pagemap-Avoid-unnecessary-overhead-when-tracepoints-are-deactivated.patch.
  patches.suse/mm-thp-only-collapse-hugepages-to-nodes-with-affinity-for-zone_reclaim_mode.patch.
  patches.suse/mm-vmscan-only-update-per-cpu-thresholds-for-online-cpus.patch.
- commit b848210
* Wed Aug 13 2014 fdmanana@suse.com
- Btrfs: fix csum tree corruption, duplicate and outdated checksums (bnc#891619).
- commit 55bd146
* Wed Aug 13 2014 jlee@suse.com
- Refresh patches.drivers/0002-EFI-RTC-check-time.patch.
  Refresh Git-commit and Patch-mainline tag because upstream merged
  it.
- commit c3ea435
* Tue Aug 12 2014 jbohac@suse.cz
- supported.conf: support net/sched/act_police.ko (bnc#890426)
- commit 89864b4
* Tue Aug 12 2014 fdmanana@suse.com
- Btrfs: fix qgroups sanity test crash or hang.
- commit da16f12
* Tue Aug 12 2014 hare@suse.de
- qla2xxx: Do not decrement the reference count in abort handler
  if only one reference is held (bnc#891212).
- commit d3026fa
* Mon Aug 11 2014 tiwai@suse.de
- cxgb4: Update FW version string to match FW binary version
  (bnc#871734).
- commit 2b15acb
* Mon Aug 11 2014 jack@suse.cz
- Fixup compilation breakage in
  patches.fixes/fanotify-fix-double-free-of-pending-permission
- commit 248e590
* Mon Aug 11 2014 mgorman@suse.de
- exec: kill the unnecessary mm->def_flags setting in
  load_elf_binary() (THP Scalabilty (bnc#891116)).
- mm, thp: add VM_INIT_DEF_MASK and PRCTL_THP_DISABLE (THP
  Scalabilty (bnc#891116)).
- mm: revert "thp: make MADV_HUGEPAGE check for mm->def_flags"
  (THP Scalabilty (bnc#891116)).
- commit b4a2442
* Mon Aug 11 2014 jbeulich@suse.com
- vscsi: support larger transfer sizes (bnc#774818).
- kgr: mark task_safe in some kthreads (fate#313296, bnc#890556).
- memory-hotplug: x86_64: suitable memory should go to
  ZONE_MOVABLE (fate#316483).
- x86: Allow kernel_map_pages_in_pgd() to work when NX is disabled
  (bnc#884369).
- x86: Configure NX support earlier in setup_arch (bnc#884369).
- Refresh patches.xen/xen-netback-defer-netdev-destruction
  (bnc#889966).
- Refresh other Xen patches.
- commit 051b463
* Mon Aug 11 2014 jack@suse.cz
- fanotify: fix double free of pending permission events.
- fsnotify: rename event handling functions.
- commit 52ab028
* Fri Aug  8 2014 mszeredi@suse.cz
- apparmor: fix open after profile replacement (bnc#885599).
- commit 5eb71a0
* Fri Aug  8 2014 jack@suse.cz
- dmapi: Fix access beyond end of array in fsreg_read_pfs().
- commit d80c1ec
* Fri Aug  8 2014 mhocko@suse.cz
- moved the patch before XEN series
- commit 1876584
* Fri Aug  8 2014 eich@suse.de
- Delete patches.drivers/drm-cirrus-Use-16bpp-as-default (bnc#890599).
- commit 1bfbad3
* Thu Aug  7 2014 duwe@suse.de
- powerpc: use _GLOBAL_TOC for memmove (bnc#890567).
- s390/zcrypt: improve device probing for zcrypt adapter cards.
- hwrng: Pass entropy to add_hwgenerator_randomness() in bits,
  not bytes (fate#316346).
- s390/3270: correct size detection with the read-partition
  command (bnc#881529, LTC#112394).
- s390/zcrypt: enable s390 hwrng to seed kernel entropy
  (fate#316346).
- commit 9ffa01c
* Thu Aug  7 2014 mhocko@suse.cz
- Refresh - fix compile warning
  patches.fixes/memcg-vmscan-Fix-forced-scan-of-anonymous-pages.patch.
- commit 582d2a8
* Thu Aug  7 2014 oneukum@suse.de
- xhci: Rename Asrock P67 pci product-id to EJ168 (bnc#890389).
- xhci: Blacklist using streams on the Etron EJ168 controller
  (bnc#890389).
- commit f42fbd7
* Thu Aug  7 2014 mhocko@suse.cz
- memcg, vmscan: Fix forced scan of anonymous pages (memory
  reclaim).
- commit 3da9b3f
* Wed Aug  6 2014 mszeredi@suse.cz
- apparmor: Fix: replacement not being applied due to cred not
  being updated (bnc#885599).
- commit a000f64
* Tue Aug  5 2014 bp@suse.de
- x86: Configure NX support earlier in setup_arch (bnc#884369).
- x86: Allow kernel_map_pages_in_pgd() to work when NX is disabled
  (bnc#884369).
- commit f17397f
* Tue Aug  5 2014 jroedel@suse.de
- iommu/vt-d: Defer domain removal if device is assigned to a driver (bnc#883139 bnc#889911).
- commit fe10725
* Tue Aug  5 2014 oneukum@suse.de
- uas: Limit qdepth to 32 when connected over usb-2 (FATE#315595).
- commit fa0a16f
* Tue Aug  5 2014 jlee@suse.com
- Backport more patches for ACPI/PNP
- PNPACPI: check return value of pnp_add_device() (fate#316836).
- ACPI / PNP: do ACPI binding directly (fate#316836).
  Also update the patches priority.
- commit 62d7573
* Mon Aug  4 2014 jjolly@suse.de
- Update config files.
- Added CONFIG_GENWQE=m to s390x/default (bnc#888493)
- commit 407d418
* Mon Aug  4 2014 oneukum@suse.de
- usb-core bInterval quirk (bnc#890232).
- commit aec9923
* Mon Aug  4 2014 mmarek@suse.cz
- Update kabi files
  struct ata_host, kgraft and s390x's struct mutex changed.
- commit e6ef83b
* Mon Aug  4 2014 mkubecek@suse.cz
- bonding: fix ad_select module param check (fate#316924
  bnc#875631 bnc#876145).
- commit 6623d88
* Mon Aug  4 2014 oneukum@suse.de
- devio: fix issue with log flooding (bnc#890088).
- commit 07d228c
* Mon Aug  4 2014 neilb@suse.de
- Refresh
  patches.suse/0010-NFS-prepare-for-RCU-walk-support-but-pushing-tests-l.patch.
- Refresh
  patches.suse/0013-NFS-teach-nfs_neg_need_reval-to-understand-LOOKUP_RC.patch.
  Minor issues with new NFS-RCU-walk code.
- commit 85f5535
* Fri Aug  1 2014 jslaby@suse.cz
- Linux 3.12.26 (CVE-2014-4171 CVE-2014-5045 FATE#317088
  bnc#870380 bnc#873790 bnc#880794 bnc#883518 bnc#889060).
- Refresh
  patches.arch/ppc64le-0017-Use-generic-checksum-code-in-little-endian.
- Refresh patches.arch/x86-tools-consolidate-ifdef-code.patch.
- Refresh
  patches.drivers/be2net-0014-be2net-add-support-for-ndo_busy_poll.patch.
- Refresh
  patches.drivers/hda-0038-restore-BCLK-M-N-value-as-per-CDCLK-for-HSW.
- Refresh
  patches.drivers/igb-0002-intel-Remove-extern-from-function-prototypes.patch.
- Refresh
  patches.drivers/net-fix-rtnl-notification-in-atomic-context.patch.
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen3-patch-3.10.
- Delete
  patches.fixes/PM-sleep-Fix-request_firmware-error-at-resume.
- Delete patches.fixes/blkcg-root_blkg-gone-policy-draining.patch.
- Delete patches.fixes/fs-umount-on-symlink-leaks-mnt-count.patch.
- Delete
  patches.fixes/net-sctp-check-proc_dointvec-result-in-proc_sctp_do_.patch.
- Delete
  patches.fixes/shmem-fix-faulting-into-a-hole-not-taking-i_mutex.patch.
- Delete
  patches.fixes/shmem-fix-faulting-into-a-hole-while-it-s-punched.patch.
- Delete
  patches.fixes/shmem-fix-splicing-from-a-hole-while-its-punched.patch.
- Delete
  patches.suse/0078-tipc-clear-next-pointer-of-message-fragments-before.patch.
- Delete
  patches.suse/Don-t-trigger-congestion-wait-on-dirty-but-not-writeout-pages.patch.
- Delete
  patches.suse/msft-hv-0635-Drivers-hv-util-Fix-a-bug-in-the-KVP-code.patch.
- Delete
  patches.suse/slab_common-fix-the-check-for-duplicate-slab-names.patch.
- Update config files.
- commit 89a473b
* Fri Aug  1 2014 dsterba@suse.cz
- Delete patches.suse/btrfs-0407-btrfs-remove-stale-comment-from-btrfs_flush_all_pend.patch.
- commit aafcfdb
* Fri Aug  1 2014 mhocko@suse.cz
- Refresh patches.fixes/memcg-oom_notify-use-after-free-fix.patch.
- commit 03898ce
* Thu Jul 31 2014 mfasheh@suse.de
- btrfs: remove stale comment from btrfs_flush_all_pending_stuffs.
- commit 5b5c245
* Thu Jul 31 2014 jack@suse.cz
- xfs: catch buffers written without verifiers attached.
- xfs: dquot recovery needs verifiers.
- xfs: quotacheck leaves dquot buffers without verifiers.
- Update
  patches.fixes/xfs-ensure-verifiers-are-attached-to-recovered-buffers.patch.
- commit fcf93ca
* Thu Jul 31 2014 jslaby@suse.cz
- kgr: avoid potential races in kgr_finalize() (fate#313296).
- kgr: try to apply skipped patches when a module is loaded
  (fate#313296).
- kgr: handle patched modules that are being removed
  (fate#313296).
- kgr: handle module load and removal for non-finished patches
  (fate#313296).
- kgr: remove patch from global list when being removed
  (fate#313296).
- kgr: confusion with fatal state (fate#313296).
- kgr: allow replace_all (fate#313296).
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh
  patches.suse/kgr-0025-kgr-add-patch-information-into-sysfs.patch.
- Refresh
  patches.suse/kgr-0026-kgr-support-revert-of-patches.patch.
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
  Petr's patches + my fixes (kthreads mainly).
- commit c2cc339
* Thu Jul 31 2014 jack@suse.cz
- printk: enable interrupts before calling
  console_trylock_for_printk() (bnc#744692, bnc#789311).
  Replace patch with a new version that is going upstream.
- Refresh
  patches.fixes/printk-nmi-0006-printk-NMI-safe-printk.patch.
- Refresh
  patches.fixes/printk-nmi-0008-printk-try-hard-to-print-Oops-message-in-NMI-context.patch.
- Refresh
  patches.fixes/printk-nmi-0009-printk-merge-and-flush-NMI-buffer-predictably-via-IR.patch.
- Refresh
  patches.suse/printk-Remove-separate-printk_sched-buffers-and-use-.patch.
- commit 2abadca
* Thu Jul 31 2014 mmarek@suse.cz
- Update kabi files
  - >remap_pages() / generic_remap_pages() has been renamed.
- commit ceb3abb
* Thu Jul 31 2014 jkosina@suse.cz
- Refresh patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: update
  upstream reference.
- commit fa6b1a7
* Thu Jul 31 2014 jslaby@suse.cz
- kgr: handle btrfs kthreads (fate#313296).
- commit a3b33cb
* Thu Jul 31 2014 hare@suse.de
- tcm_fc: Fix free-after-use regression in ft_free_cmd.
- commit 75159de
* Thu Jul 31 2014 hare@suse.de
- hpsa: fix non-x86 builds.
- commit 383a594
* Thu Jul 31 2014 ohering@suse.de
- supported.conf: remove external from drivers/net/veth (bnc#889732)
- commit 3a3d261
* Thu Jul 31 2014 mgorman@suse.de
- locking/rwsem: Allow conservative optimistic spinning when
  readers have lock (Locking scalability).
- mm, thp: only collapse hugepages to nodes with affinity for
  zone_reclaim_mode (Automatic NUMA Balancing (fate#315482)).
- commit c438dad
* Thu Jul 31 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-migrate.c-fix-setting-of-cpupid-on-page-migration-twice-against-normal-page.patch.
- commit 11d9c69
* Thu Jul 31 2014 vbabka@suse.cz
- mm: fix direct reclaim writeback regression (VM Functionality).
- commit 74b581c
* Thu Jul 31 2014 hare@suse.de
- Refresh
  patches.fixes/sd-fix-a-bug-in-deriving-FLUSH_TIMEOUT.patch.
- Delete patches.drivers/hpsa-fix-NULL-pointer.patch.
- commit 1aa26f5
* Thu Jul 31 2014 mmarek@suse.cz
- supported.conf: Remove external keyword from vmw* drivers (bnc#873335)
- commit fb86840
* Thu Jul 31 2014 hare@suse.de
- hpsa: fix NULL dereference in
  hpsa_put_ctlr_into_performant_mode().
- Refresh
  patches.drivers/hpsa-0015-hpsa-fixup-MSI-X-registration.patch.
- commit 4e02cbc
* Thu Jul 31 2014 hare@suse.de
- sd: fix a bug in deriving the FLUSH_TIMEOUT from the basic
  I/O timeout.
- commit 8196274
* Thu Jul 31 2014 neilb@suse.de
- locks: missing unlock on error in generic_add_lease()
  (internal review).
- commit c07636a
* Wed Jul 30 2014 lduncan@suse.com
- be2iscsi: remove potential junk pointer free (FATE#315960
  bnc#855063).
- commit de85b14
* Wed Jul 30 2014 jbohac@suse.cz
- tipc: clear 'next'-pointer of message fragments before
  reassembly (fate#317088).
- commit aea3616
* Wed Jul 30 2014 bpoirier@suse.de
- RDMA/cxgb4: Initialize the device status page (bnc#863619
  FATE#315951).
- commit 364d6bf
* Mon Jul 28 2014 bpoirier@suse.de
- net: sctp: inherit auth_capable on INIT collisions (bnc#889173
  CVE-2014-5077).
- commit 1909088
* Mon Jul 28 2014 jdelvare@suse.de
- supported.conf: Don't support drivers with missing firmware files
  Mark the following drivers are unsupported:
  tuner-xc2028, ivtv, isight_firmware, snd-riptide, snd-usb-6fire
  These drivers require firmware files which we don't or can't ship
  (bnc#884321.)
- commit 4659e94
* Mon Jul 28 2014 hare@suse.de
- fcoe: Fix missing mutex_unlock in fcoe_sysfs_fcf_add error path
  (bnc#889181).
- fcoe: Add missing newlines in debug messages (bnc#889181).
- fcoe: Declare fcoe_ctlr_mode_set() static (bnc#889181).
- fcp: Do not interpret check condition as underrun (bnc#889181).
- libfc: Do not invoke the response handler after fc_exch_done()
  (bnc#889181).
- libfc: Reduce exchange lock contention in fc_exch_recv_abts()
  (bnc#889181).
- libfc: Avoid that sending after an abort triggers a kernel
  warning (bnc#889181).
- libfc: Protect ep->esb_stat changes via ex_lock (bnc#889181).
- libfc: Fix a race in fc_exch_timer_set_locked() (bnc#889181).
- libfc: Clarify fc_exch_find() (bnc#889181).
- libfc: Micro-optimize fc_setup_exch_mgr() (bnc#889181).
- libfc: Debug code fixes (bnc#889181).
- libfc: Source code comment spelling fixes (bnc#889181).
- fcoe: cleanup return codes from fcoe_rcv (bnc#889181).
- fcoe: make sure fcoe frames are unshared prior to manipulating
  them (bnc#889181).
- fcoe: ensure that skb placed on the fip_recv_list are unshared
  (bnc#889181).
- commit 1251dab
* Mon Jul 28 2014 tiwai@suse.de
- PM / sleep: Fix request_firmware() error at resume (bnc#873790).
- commit b50f2b8
* Mon Jul 28 2014 mhocko@suse.cz
- fs: umount on symlink leaks mnt count (bnc#889060,
  CVE-2014-5045).
- commit f84fde4
* Mon Jul 28 2014 mhocko@suse.cz
- kabi: remove export for generic_file_remap_pages (fate#317811).
- commit 2270131
* Mon Jul 28 2014 lpechacek@suse.cz
- doc/README.SUSE: update Solid Driver team contacts
- commit a90946c
* Sat Jul 26 2014 jjolly@suse.de
- Refresh
  patches.drivers/0002-IB-core-Introduce-signature-verbs-API.patch.
- Refresh
  patches.drivers/0007-IB-mlx4-Add-support-for-steerable-IB-UD-QPs.patch.
- Refresh
  patches.drivers/mlx-0052-IB-core-extended-command-an-improved-infrastructure-.patch.
- Refresh
  patches.drivers/mlx-0053-IB-core-Re-enable-create_flow-destroy_flow-uverbs.patch.
- Delete: No plan to implement upstream. (bnc#855817)
  patches.arch/s390-sles12-00-03-pci-ofed-uverbs_add_kwrite-mmio-v2.patch.
- commit ea5d221
* Sat Jul 26 2014 jjolly@suse.de
- s390/pci: introduce lazy IOTLB flushing for DMA unmap
  (bnc#888623, LTC#113725).
- kernel: fix kernel oops with load of fpc register (bnc#888623,
  LTC#113596).
- dasd: fix error recovery for alias devices during format
  (bnc#888623, LTC#113047).
- dasd: fix list_del corruption during format (bnc#888623,
  LTC#113046).
- dasd: fix unresponsive device during format (bnc#888623,
  LTC#113045).
- dasd: use aliases for formatted devices during format
  (bnc#888623, LTC#113043).
- commit 4dfc31e
* Sat Jul 26 2014 jjolly@suse.de
- s390/3215: fix hanging console issue (bnc#860401,LTC#113233).
- commit f365c25
* Fri Jul 25 2014 jslaby@suse.cz
- module: add within_module() function (fate#313296).
- module: return bool from within_module*() (fate#313296).
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh
  patches.suse/kgr-0014-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Refresh
  patches.suse/kgr-0016-kgr-add-support-for-missing-functions.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Refresh
  patches.suse/kgr-0020-kgr-rephrase-the-kGraft-failed-message.patch.
- Refresh
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Refresh
  patches.suse/kgr-0022-kgr-add-state-machine-to-a-patch.patch.
- Refresh
  patches.suse/kgr-0023-kgr-make-ftrace-ops-initialization-simpler.patch.
- Refresh
  patches.suse/kgr-0024-kgr-move-the-logic-to-kgr_patch_code-s-switch.patch.
- Refresh
  patches.suse/kgr-0025-kgr-add-patch-information-into-sysfs.patch.
- Refresh
  patches.suse/kgr-0026-kgr-support-revert-of-patches.patch.
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
  Latest and greatest.
- commit 162af17
* Fri Jul 25 2014 jeffm@suse.de
- Update kabi files.
  Previous update was missing symtypes update due to not including -devel
  packages in the RPM list.
- commit 5267e17
* Fri Jul 25 2014 trenn@suse.de
- ACPI / scan: ACPI device object sysfs attribute for _STA
  evaluation (bnc#888934, FATE#316483, FATE#316836, FATE#316481).
- commit 1e348cd
* Fri Jul 25 2014 oneukum@suse.de
- usbcore: don't log on consecutive debounce failures of the
  same port (bnc#888100).
- commit 2194748
* Fri Jul 25 2014 oneukum@suse.de
- usb: core: allow zero packet flag for interrupt urbs
  (FATE#316422).
- USB: Fix persist resume of some SS USB devices (bnc#888962).
- USB: core: hcd-pci: free IRQ before disabling PCI device when
  shutting down (bnc#888928).
- USB: OHCI: fix bugs in debug routines (FATE#316422).
- commit 44d535c
* Fri Jul 25 2014 hare@suse.de
- qla2xxx: Update the driver version to 8.07.00.08.12.0-k
  (bnc#879633).
- commit 16caa05
* Fri Jul 25 2014 oneukum@suse.de
- USB: OHCI: add SG support (FATE#315595).
- commit ad03a8e
* Fri Jul 25 2014 duwe@suse.de
- supported.conf:
  add crypto/drbg.ko for future FIPS compliance (bnc#856310)
- commit 2432a00
* Fri Jul 25 2014 dsterba@suse.cz
- Disable patches.suse/btrfs-8063-delete-qgroup-items-in-drop_snapshot.patch
- commit d91844e
* Fri Jul 25 2014 oneukum@suse.de
- cdc-ether: clean packet filter upon probe (bnc#888926).
- commit f1149fd
* Fri Jul 25 2014 hare@suse.de
- lpfc: Update lpfc version to 10.2.8040.1 (bnc#884893).
- commit 5198883
* Fri Jul 25 2014 hare@suse.de
- lpfc: Fix ExpressLane priority setup (bnc#884893).
- lpfc: Fix for initializing RRQ bitmap (bnc#884893).
- lpfc: Fix for cleaning up stale ring flag and sp_queue_event
  entries (bnc#884893).
- lpfc: Update Copyright on changed files from 8.3.45 patches
  (bnc#884893).
- lpfc: Update Copyright on changed files (bnc#884893).
- lpfc: Fixed locking for scsi task management commands
  (bnc#884893).
- lpfc: Convert runtime references to old xlane cfg param to
  fof cfg (bnc#884893).
- lpfc: Fix FW dump using sysfs (bnc#884893).
- lpfc: Fix SLI4 s abort loop to process all FCP rings and under
  (bnc#884893).
- lpfc: Fixed kernel panic in lpfc_abort_handler (bnc#884893).
- lpfc: Fix locking for postbufq when freeing (bnc#884893).
- lpfc: Fix locking for lpfc_hba_down_post (bnc#884893).
- lpfc: Fix dynamic transitions of FirstBurst from on to off
  (bnc#884893).
- commit 83a2d02
* Fri Jul 25 2014 mhocko@suse.cz
- mm, thp: do not allow thp faults to avoid cpuset restrictions
  (bnc#888849).
- commit 5f3010c
* Fri Jul 25 2014 lpechacek@suse.cz
- supported.conf: Mark VMware modules as supported:external (bnc#873335)
  Revert 63d494f5b4 (supported.conf: Mark VMware modules as
  supported:yes).  The rationale is that VMware modules were
  marked with `external' in accordance with the kernel module
  support scheme, which is documented at
  http://www.novell.com/support/kb/doc.php?id=3582750.  In
  SLE11 the modules were marked with `yes' only by mistake.
- commit 61625ec
* Fri Jul 25 2014 mhocko@suse.cz
- memcg: oom_notify use-after-free fix (3.12 follow up fix).
- commit 9b7bc9b
* Fri Jul 25 2014 jbeulich@suse.com
- scsiback: correct grant page unmapping.
- scsiback: fix retry handling in __report_luns().
- scsiback: free resources after error.
- Update Xen patches to 3.12.25.
- commit 72efc62
* Fri Jul 25 2014 oneukum@suse.de
- cdc_subset: deal with a device that needs reset for timeout
  (bnc#885268).
- commit 12bbdc4
* Fri Jul 25 2014 lduncan@suse.com
- target: Allow non-supporting backends to set pi_prot_type to 0
  (bnc#885565).
- commit 82f7d79
* Thu Jul 24 2014 dsterba@suse.cz
- Btrfs: set error return value in btrfs_get_blocks_direct.
- btrfs: syslog when quota is enabled.
- btrfs: syslog when quota is disabled.
- Btrfs: fix wrong write range for filemap_fdatawrite_range().
- btrfs: wake up transaction thread from SYNC_FS ioctl.
- btrfs: delete qgroup items in drop_snapshot.
- Refresh
  patches.suse/btrfs-0406-btrfs-handle-return-from-ulist-add.patch.
- commit 2015a94
* Thu Jul 24 2014 jeffm@suse.de
- Update kabi files.
  Changes in:
  struct kvm_vcpu_arch
  struct blkcq_gq
  struct tracer
  struct edac_raw_error_desc
  struct scsi_device
- commit 4c408be
* Thu Jul 24 2014 ohering@suse.de
- add mainline tags to hyperv patches
- commit 1901af9
* Thu Jul 24 2014 ohering@suse.de
- hyper-v: make uuid_le const.
- commit f4c35e6
* Thu Jul 24 2014 duwe@suse.de
- cpufreq: create cpufreq_generic_init() routine (bnc#885934).
- cpufreq: remove CONFIG_CPU_FREQ_TABLE (bnc#885934).
- Update config files:
  With the latest cpufreq change, CONFIG_CPU_FREQ_TABLE is no longer optional.
- commit e943e93
* Thu Jul 24 2014 mgorman@suse.de
- memory-hotplug: sh: suitable memory should go to ZONE_MOVABLE
  (fate#316483).
- memory-hotplug: ppc: suitable memory should go to ZONE_MOVABLE
  (fate#316483).
- commit 2ebce5f
* Thu Jul 24 2014 mgorman@suse.de
- memory-hotplug: ia64: suitable memory should go to ZONE_MOVABLE
  (fate#316483).
- memory-hotplug: x86_32: suitable memory should go to
  ZONE_MOVABLE (fate#316483).
- commit f1e823a
* Thu Jul 24 2014 mgorman@suse.de
- memory-hotplug: x86_64: suitable memory should go to
  ZONE_MOVABLE (fate#316483).
- memory-hotplug: add zone_for_memory() for selecting zone for
  new memory (fate#316483).
- commit 1cdbedc
* Thu Jul 24 2014 vbabka@suse.cz
- Refresh
  patches.fixes/shmem-fix-faulting-into-a-hole-not-taking-i_mutex.patch.
- Refresh
  patches.fixes/shmem-fix-splicing-from-a-hole-while-its-punched.patch.
- commit 45b6264
* Thu Jul 24 2014 neilb@suse.de
- NFS: nfs4_lookup_revalidate need to report STALE inodes
  (bnc#866130).
- NFS: nfs4_do_open should add negative results to the dcache
  (bnc#866130).
- NFS: allow lockless access to access_cache (bnc#866130).
- NFS: teach nfs_lookup_verify_inode to handle LOOKUP_RCU
  (bnc#866130).
- NFS: teach nfs_neg_need_reval to understand LOOKUP_RCU
  (bnc#866130).
- NFS: support RCU_WALK in nfs_permission() (bnc#866130).
- sunrpc/auth: allow lockless (rcu) lookup of credential cache
  (bnc#866130).
- NFS: prepare for RCU-walk support but pushing tests later in
  code (bnc#866130).
- NFS: nfs4_lookup_revalidate: only evaluate parent if it will
  be used (bnc#866130).
- autofs4: avoid taking fs_lock during rcu-walk (bnc#866130).
- autofs4: factor should_expire() out of autofs4_expire_indirect
  (bnc#866130).
- autofs4: allow RCU-walk to walk through autofs4 (bnc#866130).
- autofs4: comment typo: remove a a doubled word (bnc#866130).
- autofs4: remove some unused inline functions (bnc#866130).
- autofs4: don't take spinlock when not needed in
  autofs4_lookup_expiring (bnc#866130).
- autofs4: remove a redundant assignment (bnc#866130).
- autofs4: remove unused autofs4_ispending() (bnc#866130).
- commit a8aa345
* Wed Jul 23 2014 duwe@suse.de
- ibmvfc: fix little endian issues (bnc#886377).
- commit 9635f07
* Wed Jul 23 2014 vbabka@suse.cz
- Refresh
  patches.fixes/shmem-fix-faulting-into-a-hole-not-taking-i_mutex.patch.
- commit 6cfe550
* Wed Jul 23 2014 ohering@suse.de
- Drivers: scsi: storvsc: Filter commands based on the storage
  protocol version.
- commit 20f0e86
* Tue Jul 22 2014 ohering@suse.de
- Drivers: scsi: storvsc: Add blist flags.
- commit 9b14ac9
* Tue Jul 22 2014 ohering@suse.de
- SCSI: Add a blacklist flag which enables VPD page inquiries.
- commit 840e7da
* Tue Jul 22 2014 duwe@suse.de
- powerpc/powernv: Fix endian issues in memory error handling code
  (bnc#887009).
- powerpc/powernv: Fix endianness problems in EEH (bnc#887009).
- powerpc/ppc64: Gracefully handle early interrupts (bnc#887009).
- Refresh
  patches.arch/powernv-173-Add-OPAL-call-to-resync-timebase-on-wakeup.
  (bnc#887009).
- Refresh
  patches.arch/powerpc-powernv-Add-context-management-for-Fast-Sleep.
- Refresh
  patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function.
- commit 4ea0f24
* Tue Jul 22 2014 tiwai@suse.de
- supported.conf: Mark VMware modules as supported:yes (bnc#873335)
  SUSE accepts L3 support and VMware takes over it.
- commit 63d494f
* Tue Jul 22 2014 trenn@suse.de
- CPUFREQ: Try to load pcc driver on HP ProLiants automatically
  (bnc#874496).
- commit 3817d75
* Mon Jul 21 2014 dsterba@suse.cz
- btrfs: test for valid bdev before kobj removal in
  btrfs_rm_device.
- btrfs: fix nossd and ssd_spread mount option regression.
- commit 87eab5c
* Mon Jul 21 2014 jdelvare@suse.de
- Update kabi files: drop references to remoteproc drivers
  We no longer build these drivers so they can't belong to the kABI.
- commit e9757db
* Mon Jul 21 2014 hare@suse.de
- qla2xxx: Add support for ISP2071 (bnc#879633).
- qla2xxx: Correct the port no assignment for ISP82XX
  (bnc#879633).
- qla2xxx: Fix Task Management command asynchronous handling
  (bnc#879633).
- qla2xxx: Add IOCB Abort command asynchronous handling
  (bnc#879633).
- qla2xxx: Re-sync module parameter descriptions with the code
  (bnc#879633).
- qla2xxx: Fixup looking for a space in the outstanding_cmds
  (bnc#879633).
- qla2xxx: Wait for reset completion without lock for ISPFX00
  (bnc#879633).
- qla2xxx: Do not schedule reset when one is already active when
  (bnc#879633).
- qla2xxx: Correct operations for ISP27xx template types 270
  and 271 (bnc#879633).
- qla2xxx: Allow ISP83XX and ISP27XX both to write req_q_out
  register (bnc#879633).
- qla2xxx: Correct ISP83xx/ISP27xx mislogic in setting out_mb in
  (bnc#879633).
- qla2xxx: Add pci device id 0x2271 (bnc#879633).
- qla2xxx: Support of new firmware dump opcodes QLA8044_RDDFE(38),
  (bnc#879633).
- qla2xxx: Add ISP8044 serdes bsg interface (bnc#879633).
- qla2xxx: Correction to ISP27xx template entry types 256 and 258
  (bnc#879633).
- qla2xxx: Track the process when the ROM_LOCK failure happens
  (bnc#879633).
- qla2xxx: Remove unnecessary delays from fw dump code path
  (bnc#879633).
- qla2xxx: Introduce fw_dump_flag to track fw dump progress
  (bnc#879633).
- qla2xxx: Enable fw_dump_size for ISP8044 (bnc#879633).
- qla2xxx: Update entry type 270 to match spec update
  (bnc#879633).
- qla2xxx: Change copyright year to 2014 in all the source files
  (bnc#879633).
- qla2xxx: Decrease pci access for response queue processing for
  (bnc#879633).
- qla2xxx: Use proper log message for flash lock failed error
  (bnc#879633).
- qla2xxx: Include <delay.h> file for msleep declartion in
  qla_nx2.c (bnc#879633).
- qla2xxx: Remove unnecessary printk_ratelimited from qla_nx2.c
  (bnc#879633).
- qla2xxx: ISP8044 poll ipmdio bus timeout improvement
  (bnc#879633).
- qla2xxx: IOCB data should be copied to I/O mem using memcpy_toio
  (bnc#879633).
- qla2xxx: Avoid escalating the SCSI error handler if the command
  is (bnc#879633).
- qla2xxx: Adjust adapter reset routine to the changes in firmware
  (bnc#879633).
- qla2xxx: Clear loop_id for ports that are marked lost during
  fabric (bnc#879633).
- qla2xxx: Check the QLA8044_CRB_DRV_ACTIVE_INDEX register when
  we are (bnc#879633).
- qla2xxx: Reduce the time we wait for a command to complete
  during (bnc#879633).
- qla2xxx: ISP27xx firmware dump template spec updates (including
  (bnc#879633).
- qla2xxx: ISP27xx queue index shadow registers (bnc#879633).
- qla2xxx: Delay driver unload if there is any pending activity
  going (bnc#879633).
- qla2xxx: Don't check for firmware hung during the reset context
  for (bnc#879633).
- qla2xxx: Fix beacon blink logic for ISP26xx/83xx (bnc#879633).
- qla2xxx: Add MBC option for fast SFP data access (bnc#879633).
- qla2xxx: Remove mapped vp index iterator macro dead code
  (bnc#879633).
- qla2xxx: Do logins from a chip reset in DPC thread instead of
  the (bnc#879633).
- qla2xxx: Remove wait for online from host reset handler
  (bnc#879633).
- qla2xxx: Fix warning reported by smatch (bnc#879633).
- qla2xxx: Fix build errors related to invalid print fields on
  (bnc#879633).
- scsi_transport_fc: Add 32Gbps speed definition (bnc#879633).
- Delete
  patches.drivers/qla2xxx-Fixup-space-outstanding_cmds-array.patch.
- commit 4cd7b57
* Mon Jul 21 2014 jdelvare@suse.de
- Update config files: Disable STE Modem driver
  Disable CONFIG_STE_MODEM_RPROC (and in turn CONFIG_REMOTEPROC.) This
  driver is for 4G modem in cell phones, which are not the target
  hardware for SLE12.
- commit b881ff9
* Fri Jul 18 2014 spargaonkar@suse.com
- hpsa: Revert some marketing names which are not yet ready for
  prime time (bnc#887837).
- commit 25a1ec7
* Fri Jul 18 2014 mmarek@suse.cz
- scripts/tags.sh: ignore symlink'ed source files.
- scripts/tags.sh: add regular expression replacement pattern
  for memcg.
- scripts/tags.sh: ignore code of user space tools.
- scripts/tags.sh: add pattern for DEFINE_HASHTABLE.
- scripts/tags.sh: Ignore *.mod.c.
- scripts/tags.sh: remove obsolete __devinit[const|data].
- scripts/tags.sh: Increase identifier list.
- commit e944593
* Fri Jul 18 2014 jslaby@suse.cz
- Linux 3.12.25 (CVE-2014-4699 bnc#875415 bnc#876981 bnc#878115
  bnc#880599 bnc#881304 bnc#881730 bnc#881903 bnc#882054
  bnc#883750 bnc#884925 bnc#885725).
- Refresh
  patches.arch/powerpc-Make-irq_stat.timers_irqs-counting-more-specific.
- Refresh
  patches.drivers/cpufreq_pstate_intel_refactor_driver.patch.
- Refresh patches.fixes/scsi-improved-eh-timeout-handler.patch.
- Refresh
  patches.suse/locking-Move-the-rtmutex-code-to-kernel-locking.patch.
- Refresh
  patches.suse/mm-migration-add-destination-page-freeing-callback.patch.
- Refresh patches.xen/xen3-patch-3.6.
- Delete
  patches.arch/ppc-Check-paca-psize-is-up-to-date-for-huge-mappings.
- Delete
  patches.arch/ptrace-x86-force-IRET-path-after-a-ptrace_stop.patch.
- Delete
  patches.drivers/sym53c8xx_2-Set-DID_REQUEUE-return-code-when-abortin.patch.
- Delete
  patches.fixes/cifs-fix-broken-pathnames-with-mapchars.patch.
- Delete
  patches.fixes/ext4-Fix-buffer-double-free-in-ext4_alloc_branch.patch.
- Delete
  patches.fixes/ext4-Fix-hole-punching-for-files-with-indirect-block.patch.
- Delete
  patches.fixes/ibmvscsi-Abort-init-sequence-during-error-recovery.
- Delete
  patches.fixes/ibmvscsi-Add-memory-barriers-for-send-receive.
- Delete patches.fixes/ppc-reenable-sendfile64.
- Delete
  patches.fixes/reiserfs-call-truncate_setsize-under-tailpack-mutex.
- Delete
  patches.fixes/scsi_error-fix-invalid-setting-of-host-byte.patch.
- Delete
  patches.fixes/virtio_scsi-fix-race-issue-between-tmf-and-command-c.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-vmbus-Fix-a-bug-in-the-channel-callback-d.patch.
- commit 264677a
* Fri Jul 18 2014 dsterba@suse.cz
- Reorder patches.
- btrfs: use the new VFS super_block_dev (bnc#865869).
- fs/super.c: add new super block sub devices super_block_dev
  (bnc#865869).
- Refresh
  patches.suse/btrfs-8011-use-bitfield-instead-of-integer-data-type-for-.patch.
- Delete
  patches.suse/btrfs-0413-fs-super.c-add-new-super-block-devices-super_block_d.patch.
- Delete
  patches.suse/btrfs-0414-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 87d2b32
* Fri Jul 18 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign firmware files (bnc#867199)
- commit 38f105d
* Fri Jul 18 2014 hare@suse.de
- iscsi_ibft: Add prefix-len attribute (bnc#887542).
- commit 83424b0
* Fri Jul 18 2014 mmarek@suse.cz
- Update kabi files
  struct superblock changed.
- commit f4e80a3
* Thu Jul 17 2014 mcgrof@suse.com
- btrfs: use the new VFS super_block_dev (bnc#865869).
- fs/super.c: add new super block sub devices super_block_dev
  (bnc#865869).
- commit 4d39464
* Thu Jul 17 2014 duwe@suse.de
- Refresh patches.arch/ppc-module-fix-.TOC.-symbol-CRC.
  Add Commit-ID.
- commit 8b77ab3
* Thu Jul 17 2014 duwe@suse.de
- Delete
  patches.arch/powerpc-powernv-hwmon-driver-for-power-values,-fan-rpm-and-temperature.
  reverted later by 4952ef9a
- Update config files accordingly (removed option SENSORS_IBMPOWERNV)
- commit 93d383a
* Thu Jul 17 2014 vbabka@suse.cz
- shmem: fix faulting into a hole, not taking i_mutex (bnc#883518,
  CVE-2014-4171).
- shmem: fix faulting into a hole while it's punched (bnc#883518,
  CVE-2014-4171).
- shmem: fix splicing from a hole while it's punched (bnc#883518,
  CVE-2014-4171).
- Delete
  patches.fixes/shmem-fix-faulting-into-a-hole-while-its-punched-take-2.patch.
- commit 57b54a8
* Thu Jul 17 2014 jack@suse.cz
- xfs: null unused quota inodes when quota is on.
- xfs: ensure verifiers are attached to recovered buffers
  (bnc#883603).
- xfs: always do log forces via the workqueue.
- commit 1b99cbc
* Thu Jul 17 2014 mgalbraith@suse.de
- Forward port/apply SUSE cpufreq ondemand governor performance tweak
  Refresh patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch.
- commit 513691b
* Wed Jul 16 2014 mfasheh@suse.de
- btrfs: correctly handle return from ulist_add (bnc#887322).
- commit 70c24a8
* Wed Jul 16 2014 hare@suse.de
- iscsi_ibft: Print correct IPv6 netmask (bnc#887542).
- Refresh
  patches.fixes/scsi-disable-eh_deadline-if-no-host_reset_handler.patch.
- commit c50a835
* Wed Jul 16 2014 mmarek@suse.cz
- Disable CONFIG_VMXNET3 and CONFIG_ISDN on ppc64le
- commit 04cc564
* Wed Jul 16 2014 mmarek@suse.cz
- Update kabi files
  task_struct changed.
- commit 61a5170
* Wed Jul 16 2014 oneukum@suse.de
- supported.conf: fixed format for unsupporting of cdc_subset
- commit 780638e
* Wed Jul 16 2014 ohering@suse.de
- netbk: Don't destroy the netdev until the vif is shut down
  (bnc#881008).
- commit 82dc505
* Wed Jul 16 2014 ohering@suse.de
- Drivers: hv: hv_fcopy: fix a race condition for SMP guest.
- commit 09bec3d
* Wed Jul 16 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install hmaccalc when building the KOTD
- commit 88d6289
* Wed Jul 16 2014 mmarek@suse.cz
- Import kabi files from RC1
  The check is not fatal, yet.
- commit e5382b0
* Wed Jul 16 2014 jlee@suse.com
- KEYS: Set the asymmetric-key type default search method
  (bnc#886592).
- commit 97b824a
* Tue Jul 15 2014 mgorman@suse.de
- Refresh
  patches.fixes/blkcg-root_blkg-gone-policy-draining.patch.
- commit cba5bc7
* Tue Jul 15 2014 eich@suse.de
- Refresh
  patches.drivers/drm-ast-Make-local-function-ast_bo_unref-static.patch.
- Refresh patches.drivers/drm-ast-add-AST-2400-support.patch.
- Refresh
  patches.drivers/drm-ast-add-widescreen-rb-modes-from-X.org-driver.patch.
- Refresh
  patches.drivers/drm-ast-initial-DP501-support-v0.2.patch.
- commit f4c5db6
* Tue Jul 15 2014 eich@suse.de
- drm/ast: initial DP501 support (v0.2) (bnc#871134).
- Refresh patches.drivers/drm-ast-add-AST-2400-support.patch.
- drm/ast: add widescreen + rb modes from X.org driver (v2)
  (bnc#871134).
- Refresh
  patches.drivers/drm-ast-rename-the-mindwm-moutdwm-and-deinline-them.patch.
- Refresh
  patches.drivers/drm-ast-resync-the-dram-post-code-with-upstream.patch.
- Delete
  patches.drivers/drm-ast-Use-correct-structure-member-for-mode-validation.patch.
- commit 950a7d0
* Mon Jul 14 2014 tiwai@suse.de
- Input: synaptics - report INPUT_PROP_TOPBUTTONPAD property
  (bnc#887108).
- Input: Add INPUT_PROP_TOPBUTTONPAD device property (bnc#887108).
- Input: i8042 - add firmware_id support (bnc#887108).
- Input: serio - add firmware_id sysfs attribute (bnc#887108).
- commit 8b0d99f
* Mon Jul 14 2014 ohering@suse.de
- Drivers: scsi: storvsc: Implement a timedout handler.
- commit 777e62d
* Mon Jul 14 2014 jlee@suse.com
- efi: Autoload efivars (bnc#881559).
- Refresh patches.xen/xen-x86-EFI.
- commit 9b5056f
* Mon Jul 14 2014 spargaonkar@suse.com
- blkcg: don't call into policy draining if root_blkg is already
  gone (bnc#880794, bnc#870380).
- commit f60add6
* Fri Jul 11 2014 oneukum@suse.de
- usb-storage/SCSI: Add broken_fua blacklist flag (bnc#886885).
- commit 74478de
* Fri Jul 11 2014 duwe@suse.de
- crypto: drbg - SP800-90A Deterministic Random Bit Generator
  (bnc#856310).
- crypto: drbg - header file for DRBG (bnc#856310).
- crypto: drbg - DRBG kernel configuration options (bnc#856310).
- crypto: drbg - compile the DRBG code (bnc#856310).
- crypto: drbg - DRBG testmgr test vectors (bnc#856310).
- crypto: drbg - Add DRBG test code to testmgr (bnc#856310).
- crypto: drbg - simplify ordering of linked list in drbg_ctr_df
  (bnc#856310).
- crypto: fips - only panic on bad/missing crypto mod signatures
  (bnc#856310).
- crypto: drbg - fix memory corruption for AES192 (bnc#856310).
- crypto: drbg - use of kernel linked list (bnc#856310).
- crypto: drbg - Use Kconfig to ensure at least one RNG option
  is set (bnc#856310).
- crypto: drbg - cleanup of preprocessor macros (bnc#856310).
- crypto: drbg - Fix format string for debugging statements
  (bnc#856310).
- crypto: drbg - Call CTR DRBG DF function only once (bnc#856310).
- crypto: drbg - Select correct DRBG core for stdrng (bnc#856310).
- crypto: drbg - Mix a time stamp into DRBG state (bnc#856310).
- crypto: drbg - HMAC-SHA1 DRBG has crypto strength of 128 bits
  (bnc#856310).
- crypto: drbg - drbg_exit() can be static (bnc#856310).
- Update config files.
- commit 7fd2a5d
* Fri Jul 11 2014 oneukum@suse.de
- supported.conf: remove cdc_subset due to low quality of driver
- commit 1543c58
* Fri Jul 11 2014 pmladek@suse.cz
- powerpc: Add ppc_global_function_entry() (bnc#878240).
- powerpc/ftrace: Fix nop of modules on 64bit LE (ABIv2)
  (bnc#878240).
- powerpc/kprobes: Fix jprobes on ABI v2 (LE) (bnc#878240).
- powerpc/ftrace: Fix inverted check of create_branch()
  (bnc#863764 fate#315275, LTC#103998).
- powerpc/ftrace: Fix typo in mask of opcode (bnc#863764
  fate#315275, LTC#103998).
- Refresh
  patches.arch/ppc64le-ELFv2-0046-ftrace-Fix-ABIv2-issues-with-__ftrace_make_call.
- commit 3ab154f
* Fri Jul 11 2014 jdelvare@suse.de
- Update ppc64le config files: Disable ChromeOS drivers
  No Chromebook is based on PowerPC so these drivers are useless on
  ppc64le.
- commit d7f8009
* Fri Jul 11 2014 jslaby@suse.cz
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh
  patches.suse/kgr-0015-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh
  patches.suse/kgr-0016-kgr-add-support-for-missing-functions.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Refresh
  patches.suse/kgr-0019-kgr-expose-global-in_progress-state-through-sysfs.patch.
- Refresh
  patches.suse/kgr-0020-kgr-rephrase-the-kGraft-failed-message.patch.
- Refresh
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Refresh
  patches.suse/kgr-0022-kgr-add-state-machine-to-a-patch.patch.
- Refresh
  patches.suse/kgr-0023-kgr-make-ftrace-ops-initialization-simpler.patch.
- Refresh
  patches.suse/kgr-0024-kgr-move-the-logic-to-kgr_patch_code-s-switch.patch.
- Refresh
  patches.suse/kgr-0025-kgr-add-patch-information-into-sysfs.patch.
- Refresh
  patches.suse/kgr-0026-kgr-support-revert-of-patches.patch.
- Refresh
  patches.suse/kgr-0029-kgr-allow-stacking-of-patches.patch.
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
  Update to the latest (filter removal, owner link, no chaining).
- commit d858035
* Thu Jul 10 2014 ro@suse.de
- config.conf: Add -syms for zfcpdump
- commit bf59cbf
* Thu Jul 10 2014 bpoirier@suse.de
- supported.conf: add ax88179_178a usb ethernet adapter
  ASIX AX88179/178A USB 3.0/2.0 to Gigabit Ethernet
  Similar use case to the already supported asix.ko.
  Tony Jones has a 88179 adapter and noticed the problem with the
  ax88179_178a.ko not being supported.
- commit 3e91207
* Thu Jul 10 2014 ohering@suse.de
- Drivers: scsi: storvsc: Set cmd_per_lun to reflect value
  supported by the Host.
- commit f9a587b
* Thu Jul 10 2014 ohering@suse.de
- drivers: scsi: storvsc: Correctly handle TEST_UNIT_READY failure
  (bnc#879255).
- commit 21c45c0
* Thu Jul 10 2014 ohering@suse.de
- drivers: scsi: storvsc: Set srb_flags in all cases.
- commit 6ee861b
* Thu Jul 10 2014 ohering@suse.de
- Drivers: scsi: storvsc: Fix a bug in the handling of SRB
  status flags.
- commit 1606e09
* Thu Jul 10 2014 ohering@suse.de
- Drivers: scsi: storvsc: Fix a bug in handling VMBUS protocol
  version.
- commit 2e70b21
* Thu Jul 10 2014 ohering@suse.de
- Refresh to current upstream submission
  patches.suse/suse-hv-Drivers-scsi-storvsc-Change-the-limits-to-reflect-th.patch.
- commit 11b5620
* Thu Jul 10 2014 ohering@suse.de
- video: hyperv: hyperv_fb: refresh the VM screen by force on
  VM panic.
- commit 526ecbc
* Thu Jul 10 2014 ohering@suse.de
- Drivers: hv: util: Fix a bug in the KVP code.
- Drivers: hv: vmbus: Fix a bug in the channel callback dispatch
  code.
- commit 14e11e1
* Thu Jul 10 2014 duwe@suse.de
- powerpc: Fix races with irq_work (bnc#883741).
- powerpc: Make irq_stat.timers_irqs counting more specific
  (bnc#883741).
- powerpc: irq work racing with timer interrupt can result in
  timer interrupt hang (bnc#883741).
- Refresh
  patches.arch/powerpc-Split-timer_interrupt-into-timer-handling-and-interrupt-handling-routines.
- commit 1ed3ab1
* Thu Jul 10 2014 duwe@suse.de
- powerpc: Split timer_interrupt() into timer handling and
  interrupt handling routines (bnc#883741,bnc#885934).
- cpuidle: Handle clockevents_notify(BROADCAST_ENTER) failure
  (bnc#885934).
- cpufreq: powernv: make local function static (bnc#885934).
- cpufreq, powernv: Fix build failure on UP (bnc#885934).
- commit ddc8ff2
* Thu Jul 10 2014 oneukum@suse.de
- HID: logitech-dj: Fix USB 3.0 issue (bnc#886633).
- commit 5404194
* Thu Jul 10 2014 duwe@suse.de
- Reenable POWERNV_CPUFREQ
- commit 62bf57d
* Thu Jul 10 2014 duwe@suse.de
- powerpc: Correct DSCR during TM context switch (bnc#886371).
- cpufreq: acpi: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: arm_big_little: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: at32ap: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: cpufreq-cpu0: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: cris: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: davinci: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: dbx500: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: e_powersaver: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: elanfreq: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: ia64-acpi: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: imx6q: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: kirkwood: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: longhaul: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: loongson2: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: maple: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: omap: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: p4-clockmod: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: pasemi: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: pmac: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: powernow: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: ppc-corenet: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: ppc_cbe: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: s3cx4xx: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: s5pv210: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: sa11x0: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: sc520: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: sh: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: sparc: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: spear: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: speedstep: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: tegra: Use generic cpufreq routines
  (bnc#885934,bnc#878240).
- cpufreq: Implement light weight ->target_index() routine
  (bnc#878240,bnc#885934).
- Refresh
  patches.arch/ppc64le-kvm-0058-KVM-PPC-Use-load_fp-vr_state-rather-than-load_up_fpu.patch.
- commit 6007e65
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/package-descriptions: Drop descriptions for dropped flavors
- commit aa68ae6
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/post(un).sh: Drop checks for dropped archs/flavors
- commit bd6afed
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: No scriptlets in kernel-zfcpdump
  The kernel should not be added to the bootloader nor are there any KMPs.
- commit bcca34b
* Wed Jul  9 2014 jjolly@suse.de
- RDMA/cxgb3: Remove a couple unneeded conditions (bnc#863634).
- RDMA/cxgb3: Fix information leak in send_abort() (bnc#863634).
- commit 82aa525
* Wed Jul  9 2014 mmarek@suse.cz
- firmware: Create directories for external firmware.
- kbuild: Fix packaging targets with relative $(srctree).
- kbuild: Do not print the build directory with make -s.
- kbuild: Print the name of the build directory.
- kbuild: Fix silent builds with make-4.
- commit 5d4f893
* Wed Jul  9 2014 spargaonkar@suse.com
- hpsa: Update the controller names (bnc#886292).
- commit 9584c00
* Wed Jul  9 2014 mmarek@suse.cz
- Refresh
  patches.kabi/0001-kabi-Lift-ifdefs-for-some-disabled-network-protocols.patch:
  Fix for CONFIG_INET=n
- Delete
  patches.kabi/0004-kabi-Expose-dependent-funcs-for-some-disabled-networ.patch.
- commit 72ded89
* Wed Jul  9 2014 pmladek@suse.cz
- Fix build with CONFIG_DEBUG_RODATA disabled (bnc#886272)
- Update
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
- commit da8135a
* Wed Jul  9 2014 hare@suse.de
- Review SP3 patches
- Re-enable patches.suse/fcoe-reduce-max_sectors.
- Delete
  patches.drivers/0001-cxgb4-fix-SQ-allocation-when-On-Chip-SQ-is-disabled.patch.
- Delete
  patches.fixes/scsi-dh-rdac-allow-for-empty-scsi_dh_data-pointer.
- Delete
  patches.fixes/scsi-dh-rdac-get-sdev-reference-in-queue_mode_select.
- commit cc840f9
* Wed Jul  9 2014 jjolly@suse.de
- Update config files.
  - Removed from config/s390x/default (bnc#884701)
    /drivers/net/phy/amd.ko
    /drivers/net/phy/at803x.ko
    /drivers/net/phy/bcm87xx.ko
    /drivers/net/phy/broadcom.ko
    /drivers/net/phy/cicada.ko
    /drivers/net/phy/davicom.ko
    /drivers/net/phy/et1011c.ko
    /drivers/net/phy/icplus.ko
    /drivers/net/phy/libphy.ko
    /drivers/net/phy/lxt.ko
    /drivers/net/phy/marvell.ko
    /drivers/net/phy/mdio-bitbang.ko
    /drivers/net/phy/micrel.ko
    /drivers/net/phy/national.ko
    /drivers/net/phy/qsemi.ko
    /drivers/net/phy/realtek.ko
    /drivers/net/phy/smsc.ko
    /drivers/net/phy/ste10Xp.ko
    /drivers/net/phy/vitesse.ko
    /drivers/misc/eeprom/eeprom_93cx6.ko
    /drivers/misc/enclosure.ko
- commit 5fedce1
* Wed Jul  9 2014 jjolly@suse.de
- kabi: Expose dependent function necessary for previous path
  (bnc#886321).
- config.conf:
  - Added zfcpdump to s390x arch
- Update config files.
  - config/s390x/zfcpdump:
  - Added CONFIG_DEBUG_INFO=Y (bnc#884999)
  - Added CONFIG_SCLP_CONSOLE=y for LPAR output (bnc#884769)
- rpm/package-descriptions:
  - Added description for zfcpdump
- commit 9e78956
* Tue Jul  8 2014 jslaby@suse.cz
- kgr: allow stacking of patches (fate#313296).
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh
  patches.suse/kgr-0004-kgr-add-testing-kgraft-patch.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh
  patches.suse/kgr-0008-kgr-sched.h-introduce-kgr_task_safe-helper.patch.
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh
  patches.suse/kgr-0015-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh
  patches.suse/kgr-0016-kgr-add-support-for-missing-functions.patch.
- Refresh
  patches.suse/kgr-0017-kgr-exercise-non-present-function.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Refresh
  patches.suse/kgr-0019-kgr-expose-global-in_progress-state-through-sysfs.patch.
- Refresh
  patches.suse/kgr-0020-kgr-rephrase-the-kGraft-failed-message.patch.
- Refresh
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Refresh
  patches.suse/kgr-0022-kgr-add-state-machine-to-a-patch.patch.
- Refresh
  patches.suse/kgr-0023-kgr-make-ftrace-ops-initialization-simpler.patch.
- Refresh
  patches.suse/kgr-0024-kgr-move-the-logic-to-kgr_patch_code-s-switch.patch.
- Refresh
  patches.suse/kgr-0025-kgr-add-patch-information-into-sysfs.patch.
- Refresh
  patches.suse/kgr-0026-kgr-support-revert-of-patches.patch.
- Refresh
  patches.suse/kgr-0027-s390-add-support-for-DYNAMIC_FTRACE_WITH_REGS.patch.
- Refresh patches.suse/kgr-0028-s390-kgr-add-support.patch.
  One more update (cleanup + patch stacking support)
- commit 90b3f77
* Tue Jul  8 2014 duwe@suse.de
- Update config files.
  CONFIG_POWERNV_CPUIDLE=y (bnc#885934)
- commit eaf2d59
* Tue Jul  8 2014 duwe@suse.de
- powerpc/pseries/cpuidle: smt-snooze-delay cleanup (bnc#885934).
- Refresh
  patches.arch/cpuidle-powernv-Add-Fast-Sleep-CPU-idle-state.
- Refresh
  patches.arch/cpuidle-powernv-Parse-device-tree-to-setup-idle-states.
- Update
  patches.arch/powerpc-powernv-Add-context-management-for-Fast-Sleep
  (bnc#878240,bnc#885934).
- Update
  patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function
  (bnc#863764 fate#315275, LTC#103998, bnc#885934).
- commit 79cf7f5
* Tue Jul  8 2014 mgorman@suse.de
- Update patches.suse/powerpc-thp-Fix-crash-on-mremap.patch
  (bnc#885899).
- commit f876e4e
* Tue Jul  8 2014 hare@suse.de
- Add zfcpdump config file
- commit c94fb47
* Tue Jul  8 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-move-zone-pages_scanned-into-vmstat.patch.
  patches.suse/mm-page_alloc-reduce-cost-of-the-fair-zone-allocation-policy.patch.
  patches.suse/mm-pagemap-Avoid-unnecessary-overhead-when-tracepoints-are-deactivated.patch.
- commit 3893cac
* Tue Jul  8 2014 mgorman@suse.de
- Rearrange some VM patches to clarify how they are related to each other
- commit c2a8cce
* Tue Jul  8 2014 mgorman@suse.de
- mm/filemap.c: avoid always dirtying mapping->flags on O_DIRECT
- mm: fix bad rss-counter if remap_file_pages raced migration
- mm, hugetlb: fix race in region tracking
- mm, hugetlb: improve, cleanup resv_map parameters
- mm, hugetlb: remove resv_map_put (VM Functionality).
- mm, hugetlb: unify region structure handling (VM Functionality).
- mm, hugetlb: use vma_resv_map() map types (VM Functionality).
- mm/hugetlb.c: call MMU notifiers when copying a hugetlb page range
- mm: page_alloc: do not cache reclaim distances
- mm: page_alloc: lookup pageblock migratetype with IRQs enabled during free
- mm, page_alloc: warn for non-blockable __GFP_NOFAIL allocation failure
- mm: prevent setting of a value less than 0 to min_free_kbytes
- mm: vmscan: call NUMA-unaware shrinkers irrespective of nodemask
- mm: vmscan: respect NUMA policy mask when shrinking slab on direct reclaim
- mm: vmscan: shrink all slab objects if tight on memory
- mm: vmscan: shrink_slab: rename max_pass -> freeable
- readahead: fix sequential read cache miss detection
- slab: correct pfmemalloc check
- vmscan: reclaim_clean_pages_from_list() must use mod_zone_page_state()
- Refresh
  patches.suse/mm-page_alloc-reduce-cost-of-the-fair-zone-allocation-policy.patch.
  (VM Functionality).
- commit aefb766
* Tue Jul  8 2014 agraf@suse.de
- supported.conf: Add KVM on ppc64le (FATE#317763)
- commit bfe9304
* Tue Jul  8 2014 agraf@suse.de
- Backport and enable KVM support on ppc64le (FATE#317763)
- KVM: PPC: Book3S HV: Save/restore SIAR and SDAR along with
  other PMU registers (FATE#317763).
- KVM: PPC: Book3S HV: Reserve POWER8 space in get/set_one_reg
  (FATE#317763).
- KVM: PPC: Book3S HV: Implement timebase offset for guests
  (FATE#317763).
- KVM: PPC: Book3S: Add GET/SET_ONE_REG interface for VRSAVE
  (FATE#317763).
- KVM: PPC: Book3S HV: Implement H_CONFER (FATE#317763).
- KVM: PPC: Book3S HV: Restructure kvmppc_hv_entry to be a
  subroutine (FATE#317763).
- KVM: PPC: Book3S HV: Pull out interrupt-reading code into a
  subroutine (FATE#317763).
- KVM: PPC: Book3S HV: Avoid unbalanced increments of VPA yield
  count (FATE#317763).
- KVM: PPC: BookE: Add GET/SET_ONE_REG interface for VRSAVE
  (FATE#317763).
- KVM: PPC: Book3S HV: Store LPCR value for each virtual core
  (FATE#317763).
- KVM: PPC: Book3S HV: Add support for guest Program Priority
  Register (FATE#317763).
- KVM: PPC: Book3S HV: Support POWER6 compatibility mode on POWER7
  (FATE#317763).
- KVM: PPC: Book3S HV: Don't crash host on unknown guest interrupt
  (FATE#317763).
- KVM: PPC: Book3S PR: Fix compilation without CONFIG_ALTIVEC
  (FATE#317763).
- KVM: PPC: Book3S PR: Keep volatile reg values in vcpu rather
  than shadow_vcpu (FATE#317763).
- KVM: PPC: Book3S PR: Allow guest to use 64k pages (FATE#317763).
- KVM: PPC: Book3S PR: Use 64k host pages where possible
  (FATE#317763).
- KVM: PPC: Book3S PR: Allocate kvm_vcpu structs from
  kvm_vcpu_cache (FATE#317763).
- KVM: PPC: Book3S PR: Handle PP0 page-protection bit in guest
  HPTEs (FATE#317763).
- KVM: PPC: Book3S PR: Correct errors in H_ENTER implementation
  (FATE#317763).
- KVM: PPC: Book3S PR: Make HPT accesses and updates SMP-safe
  (FATE#317763).
- KVM: PPC: Book3S: Move skip-interrupt handlers to common code
  (FATE#317763).
- KVM: PPC: Book3S PR: Better handling of host-side read-only
  pages (FATE#317763).
- KVM: PPC: Book3S PR: Use mmu_notifier_retry() in
  kvmppc_mmu_map_page() (FATE#317763).
- KVM: PPC: Book3S PR: Mark pages accessed, and dirty if being
  written (FATE#317763).
- KVM: PPC: Book3S PR: Reduce number of shadow PTEs invalidated
  by MMU notifiers (FATE#317763).
- kvm: powerpc: book3s hv: Fix vcore leak (FATE#317763).
- KVM: PPC: Book3S HV: Better handling of exceptions that happen
  in real mode (FATE#317763).
- kvm: powerpc: book3s: remove kvmppc_handler_highmem label
  (FATE#317763).
- kvm: powerpc: book3s: move book3s_64_vio_hv.c into the main
  kernel binary (FATE#317763).
- kvm: powerpc: book3s: pr: Rename KVM_BOOK3S_PR to
  KVM_BOOK3S_PR_POSSIBLE (FATE#317763).
- kvm: powerpc: book3s: Add a new config variable
  CONFIG_KVM_BOOK3S_HV_POSSIBLE (FATE#317763).
- kvm: powerpc: Add kvmppc_ops callback (FATE#317763).
- kvm: powerpc: book3s: Cleanup interrupt handling code
  (FATE#317763).
- kvm: powerpc: book3s: Add is_hv_enabled to kvmppc_ops
  (FATE#317763).
- kvm: powerpc: book3s: pr: move PR related tracepoints to a
  separate header (FATE#317763).
- kvm: powerpc: booke: Move booke related tracepoints to separate
  header (FATE#317763).
- kvm: powerpc: book3s: Support building HV and PR KVM as module
  (FATE#317763).
- kvm: Add struct kvm arg to memslot APIs (FATE#317763).
- kvm: powerpc: book3s: Allow the HV and PR selection per virtual
  machine (FATE#317763).
- kvm: powerpc: book3s: drop is_hv_enabled (FATE#317763).
- KVM: PPC: Book3S HV: Fix physical address calculations
  (FATE#317763).
- KVM: PPC: Book3S HV: Refine barriers in guest entry/exit
  (FATE#317763).
- KVM: PPC: Book3S HV: Make tbacct_lock irq-safe (FATE#317763).
- KVM: PPC: Book3S HV: Take SRCU read lock around kvm_read_guest()
  call (FATE#317763).
- KVM: PPC: Book3S: PR: Don't clobber our exit handler id
  (FATE#317763).
- KVM: PPC: Book3S: PR: Export kvmppc_copy_to|from_svcpu
  (FATE#317763).
- KVM: PPC: Book3S: PR: Make svcpu -> vcpu store preempt savvy
  (FATE#317763).
- KVM: PPC: Book3S: PR: Enable interrupts earlier (FATE#317763).
- powerpc: book3s: kvm: Don't abuse host r2 in exit path
  (FATE#317763).
- KVM: PPC: Book3S HV: Don't drop low-order page address bits
  (FATE#317763).
- KVM: Use cond_resched() directly and remove useless
  kvm_resched() (FATE#317763).
- powerpc: kvm: optimize "sc 1" as fast return (FATE#317763).
- KVM: PPC: Add devname:kvm aliases for modules (FATE#317763).
- KVM: PPC: fix couple of memory leaks in MPIC/XICS devices
  (FATE#317763).
- kvm/powerpc: rename kvm_hypercall() to epapr_hypercall()
  (FATE#317763).
- kvm/powerpc: move kvm_hypercall0() and friends to
  epapr_hypercall0() (FATE#317763).
- KVM: PPC: Use load_fp/vr_state rather than load_up_fpu/altivec
  (FATE#317763).
- KVM: PPC: Store FP/VSX/VMX state in thread_fp/vr_state
  structures (FATE#317763).
- KVM: PPC: Load/save FP/VMX/VSX state directly to/from vcpu
  struct (FATE#317763).
- KVM: PPC: Book3S HV: Use load/store_fp_state functions in HV
  guest entry/exit (FATE#317763).
- kvm: booke: clear host tlb reference flag on guest tlb
  invalidation (FATE#317763).
- kvm: book3s: rename lookup_linux_pte() to
  lookup_linux_pte_and_update() (FATE#317763).
- KVM: PPC: NULL return of kvmppc_mmu_hpte_cache_next should be
  handled (FATE#317763).
- KVM: PPC: Unify kvmppc_get_last_inst and sc (FATE#317763).
- KVM: PPC: Book3S: MMIO emulation support for little endian
  guests (FATE#317763).
- kvm/ppc: IRQ disabling cleanup (FATE#317763).
- KVM: PPC: Book3S HV: Don't set DABR on POWER8 (FATE#317763).
- KVM: PPC: Book3S HV: Align physical and virtual CPU thread
  numbers (FATE#317763).
- KVM: PPC: Book3S HV: Context-switch new POWER8 SPRs
  (FATE#317763).
- KVM: PPC: Book3S HV: Flush the correct number of TLB sets on
  POWER8 (FATE#317763).
- KVM: PPC: Book3S HV: Add handler for HV facility unavailable
  (FATE#317763).
- KVM: PPC: Book3S HV: Implement architecture compatibility
  modes for POWER8 (FATE#317763).
- KVM: PPC: Book3S HV: Consolidate code that checks reason for
  wake from nap (FATE#317763).
- KVM: PPC: Book3S HV: Handle guest using doorbells for IPIs
  (FATE#317763).
- KVM: PPC: Book3S HV: Handle new LPCR bits on POWER8
  (FATE#317763).
- KVM: PPC: Book3S HV: Prepare for host using hypervisor doorbells
  (FATE#317763).
- KVM: PPC: Book3S HV: Add support for DABRX register on POWER7
  (FATE#317763).
- KVM: PPC: Book3S HV: Basic little-endian guest support
  (FATE#317763).
- KVM: PPC: Book3S HV: Add new state for transactional memory
  (FATE#317763).
- KVM: PPC: Book3S PR: Cope with doorbell interrupts
  (FATE#317763).
- KVM: PPC: Book3S HV: Remove bogus duplicate code (FATE#317763).
- KVM: PPC: Book3S HV: Fix register usage when loading/saving
  VRSAVE (FATE#317763).
- KVM: PPC: Book3S HV: Fix KVM hang with CONFIG_KVM_XICS=n
  (FATE#317763).
- KVM: PPC: Book3S HV: Add software abort codes for transactional
  memory (FATE#317763).
- KVM: PPC: Book3S HV: Add transactional memory support
  (FATE#317763).
- KVM: PPC: Book3S HV: Add get/set_one_reg for new TM state
  (FATE#317763).
- KVM: PPC: Book3S: Trim top 4 bits of physical address in RTAS
  code (FATE#317763).
- KVM: PPC: Book3S HV: Return ENODEV error rather than EIO
  (FATE#317763).
- KVM: PPC: Book3S HV: Don't use kvm_memslots() in real mode
  (FATE#317763).
- KVM: PPC: Book3S HV: Fix decrementer timeouts with non-zero
  TB offset (FATE#317763).
- KVM: PPC: Book3S HV: Save/restore host PMU registers that are
  new in POWER8 (FATE#317763).
- ppc/kvm: Set the runlatch bit of a CPU just before starting
  guest (FATE#317763).
- ppc/kvm: Clear the runlatch bit of a vcpu before napping
  (FATE#317763).
- KVM: PPC: Book3S: HV: make _PAGE_NUMA take effect (FATE#317763).
- KVM: PPC: Book3S HV: Add missing code for transaction reclaim
  on guest exit (FATE#317763).
- KVM: PPC: Book3S: ifdef on CONFIG_KVM_BOOK3S_32_HANDLER for
  32bit (FATE#317763).
- KVM guest: Make pv trampoline code executable (FATE#317763).
- KVM: PPC: BOOK3S: PR: Enable Little Endian PR guest
  (FATE#317763).
- KVM: PPC: BOOK3S: PR: Fix WARN_ON with debug options on
  (FATE#317763).
- KVM: PPC: Book3S: PR: Fix C/R bit setting (FATE#317763).
- KVM: PPC: Book3S_32: PR: Access HTAB in big endian
  (FATE#317763).
- KVM: PPC: Book3S_64 PR: Access HTAB in big endian (FATE#317763).
- KVM: PPC: Book3S_64 PR: Access shadow slb in big endian
  (FATE#317763).
- KVM: PPC: Book3S PR: Default to big endian guest (FATE#317763).
- KVM: PPC: Book3S PR: PAPR: Access HTAB in big endian
  (FATE#317763).
- KVM: PPC: Book3S PR: PAPR: Access RTAS in big endian
  (FATE#317763).
- KVM: PPC: PR: Fill pvinfo hcall instructions in big endian
  (FATE#317763).
- KVM: PPC: Make shared struct aka magic page guest endian
  (FATE#317763).
- KVM: PPC: Book3S PR: Do dcbz32 patching with big endian
  instructions (FATE#317763).
- KVM: PPC: Book3S: Move little endian conflict to HV KVM
  (FATE#317763).
- KVM: PPC: Book3S PR: Ignore PMU SPRs (FATE#317763).
- KVM: PPC: Book3S PR: Emulate TIR register (FATE#317763).
- KVM: PPC: Book3S PR: Handle Facility interrupt and FSCR
  (FATE#317763).
- KVM: PPC: Book3S PR: Expose TAR facility to guest (FATE#317763).
- KVM: PPC: Book3S PR: Expose EBB registers (FATE#317763).
- KVM: PPC: Book3S PR: Expose TM registers (FATE#317763).
- KVM: PPC: BOOK3S: HV: Prefer CMA region for hash page table
  allocation (FATE#317763).
- KVM: PPC: BOOK3S: HV: Add mixed page-size support for guest
  (FATE#317763).
- KVM: PPC: Disable NX for old magic page using guests
  (FATE#317763).
- PPC: KVM: Make NX bit available with magic page (FATE#317763).
- KVM: PPC: BOOK3S: Always use the saved DAR value (FATE#317763).
- KVM: PPC: BOOK3S: Remove open coded make_dsisr in alignment
  handler (FATE#317763).
- KVM: PPC: Graciously fail broken LE hypercalls (FATE#317763).
- KVM: PPC: Add CAP to indicate hcall fixes (FATE#317763).
- KVM: PPC: Book3S: Add ONE_REG register names that were missed
  (FATE#317763).
- KVM: PPC: Book3S: Move KVM_REG_PPC_WORT to an unused register
  number (FATE#317763).
- KVM: PPC: Book3S HV: Fix check for running inside guest in
  global_invalidates() (FATE#317763).
- KVM: PPC: Book3S HV: Put huge-page HPTEs in rmap chain for
  base address (FATE#317763).
- KVM: PPC: Book3S HV: Fix dirty map for hugepages (FATE#317763).
- KVM: PPC: Book3S HV: Make sure we don't miss dirty pages
  (FATE#317763).
- KVM: PPC: Book3S HV: Work around POWER8 performance monitor bugs
  (FATE#317763).
- KVM: PPC: Book3S HV: Fix machine check delivery to guest
  (FATE#317763).
- KVM: PPC: Book3S PR: Use SLB entry 0 (FATE#317763).
- KVM: PPC: Book3S PR: Rework SLB switching code (FATE#317763).
- powerpc/kvm/book3s_hv: Rework the secondary inhibit code
  (FATE#317763).
- powerpc/book3s: Fix guest MC delivery mechanism to avoid soft
  lockups in guest (FATE#317763).
- KVM: PPC: BOOK3S: HV: Use base page size when comparing against
  slb value (FATE#317763).
- KVM: PPC: BOOK3S: PR: Fix PURR and SPURR emulation
  (FATE#317763).
- KVM: PPC: BOOK3S: PR: Emulate virtual timebase register
  (FATE#317763).
- KVM: PPC: BOOK3S: PR: Emulate instruction counter (FATE#317763).
- KVM: PPC: Book3s PR: Disable AIL mode with OPAL (FATE#317763).
- KVM: PPC: Book3s HV: Fix tlbie compile error (FATE#317763).
- KVM: PPC: Book3S PR: Handle hyp doorbell exits (FATE#317763).
- KVM: PPC: Book3S HV: Fix ABIv2 indirect branch issue
  (FATE#317763).
- KVM: PPC: Assembly functions exported to modules need
  _GLOBAL_TOC() (FATE#317763).
- KVM: PPC: Book3S PR: Fix ABIv2 on LE (FATE#317763).
- KVM: PPC: Book3S PR: Fix sparse endian checks (FATE#317763).
- KVM: PPC: Book3S: Controls for in-kernel sPAPR hypercall
  handling (FATE#317763).
- KVM: PPC: Book3S: Allow only implemented hcalls to be enabled
  or disabled (FATE#317763).
- KVM: PPC: Book3S HV: Add H_SET_MODE hcall handling
  (FATE#317763).
- KVM: PPC: Book3S HV: Make HTAB code LE host aware (FATE#317763).
- PPC: Add asm helpers for BE 32bit load/store (FATE#317763).
- KVM: PPC: Book3S HV: Access guest VPA in BE (FATE#317763).
- KVM: PPC: Book3S HV: Access host lppaca and shadow slb in BE
  (FATE#317763).
- KVM: PPC: Book3S HV: Access XICS in BE (FATE#317763).
- KVM: PPC: Book3S HV: Fix ABIv2 on LE (FATE#317763).
- KVM: PPC: Book3S HV: Enable for little endian hosts
  (FATE#317763).
- KVM: PPC: Book3S: Move vcore definition to end of kvm_arch
  struct (FATE#317763).
- KVM: PPC: RTAS: Do byte swaps explicitly (FATE#317763).
- Update config files.
- commit ea5897b
* Mon Jul  7 2014 mfasheh@suse.de
- Btrfs: __btrfs_mod_ref should always use no_quota (bnc#865621,
  bnc#884001).
- Refresh patches.suse/btrfs-0404-account-shared-subtrees.patch.
- commit f7c85d8
* Mon Jul  7 2014 bpoirier@suse.de
- Enable Function Graph tracer in config files.
- commit 97fb4ba
* Mon Jul  7 2014 bpoirier@suse.de
- Refresh config files.
  Simply ran run_oldconfig.sh without any actual change.
- commit 87e1bea
* Mon Jul  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Delete the build-id links created by vdso_install
- commit ca040af
* Mon Jul  7 2014 duwe@suse.de
- powerpc: Add a cpu feature CPU_FTR_PMAO_BUG (bnc#885935).
- commit 26942ef
* Mon Jul  7 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0027-s390-add-support-for-DYNAMIC_FTRACE_WITH_REGS.patch.
- Refresh patches.suse/kgr-0028-s390-kgr-add-support.patch.
  Still not complete, fix missing kgraft.h.
- commit 348dd80
* Mon Jul  7 2014 mgorman@suse.de
- mm: let mm_find_pmd fix buggy race with THP fault
  (VM Functionality).
- commit c9b6a68
* Mon Jul  7 2014 duwe@suse.de
- powerpc/powernv: Add calls to support little endian host
  (bnc#885936).
- powerpc/perf: Add lost exception workaround (bnc#885935).
- commit b29076b
* Mon Jul  7 2014 jslaby@suse.cz
- Update config files.
  s390: Enable kGraft as we have th ecode now.
- commit 3a4b89a
* Mon Jul  7 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0027-s390-add-support-for-DYNAMIC_FTRACE_WITH_REGS.patch.
- Refresh patches.suse/kgr-0028-s390-kgr-add-support.patch.
  Let them apply.
- commit 9d22aea
* Mon Jul  7 2014 jslaby@suse.cz
- s390: kgr, add support (fate#313296).
- s390: add support for DYNAMIC_FTRACE_WITH_REGS (fate#313296).
- commit 2fb9c39
* Mon Jul  7 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
  Mark more kthreads.
- commit 1c77800
* Fri Jul  4 2014 jdelvare@suse.de
- supported.conf: Sort again
- commit 777f82f
* Fri Jul  4 2014 jdelvare@suse.de
- supported.conf: metro-usb driver is unsupported
  No SLEPOS being based on SLE12, we don't need to support a bar code
  reader driver.
- commit 29a8482
* Fri Jul  4 2014 mgorman@suse.de
- powerpc/thp: Fix crash on mremap (VM Functionality).
- commit 000c280
* Fri Jul  4 2014 jdelvare@suse.de
- supported.conf: Add new x86 platform drivers
  All unsupported until we get hardware and requests.
- commit 87789ec
* Fri Jul  4 2014 mgorman@suse.de
- mm/swap.c: clean up *lru_cache_add* functions
- Refresh
  patches.suse/mm-Do-not-use-unnecessary-atomic-operations-when-adding-pages-to-the-LRU.patch
  patches.suse/mm-Non-atomically-mark-page-accessed-during-page-cache-allocation-where-possible.patch.
- commit cf556f5
* Fri Jul  4 2014 mgorman@suse.de
- Refresh
  patches.suse/shmem-fix-init_page_accessed-use-to-stop-PageLRU-bug.patch.
- commit 43eb398
* Fri Jul  4 2014 mgorman@suse.de
- shmem: fix init_page_accessed use to stop !PageLRU bug
  (VM/FS Performance).
- commit 7c5543c
* Fri Jul  4 2014 duwe@suse.de
- kernel: size detection of 3270 terminals fails (bnc#881529,
  LTC#112394).
- commit 823b62e
* Fri Jul  4 2014 hare@suse.de
- lpfc: Add iotag memory barrier (bnc#884893).
- commit de0af03
* Fri Jul  4 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_DRM_I2C_NXP_TDA998X
  Unused helper driver.
- commit 7628653
* Fri Jul  4 2014 mmarek@suse.cz
- Drop the richacl series
- Refresh patches.suse/ovl01-vfs-add-i_op-dentry_open.patch.
- Delete
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- Delete
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch.
- Delete
  patches.suse/0003-vfs-Add-IS_RICHACL-test-for-richacl-support.patch.
- Delete
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch.
- Delete
  patches.suse/0005-richacl-Permission-mapping-functions.patch.
- Delete
  patches.suse/0006-richacl-Compute-maximum-file-masks-from-an-acl.patch.
- Delete
  patches.suse/0007-richacl-Update-the-file-masks-in-chmod.patch.
- Delete
  patches.suse/0008-richacl-Permission-check-algorithm.patch.
- Delete
  patches.suse/0009-richacl-Helper-functions-for-implementing-richacl-in.patch.
- Delete patches.suse/0010-richacl-Create-time-inheritance.patch.
- Delete
  patches.suse/0011-richacl-Check-if-an-acl-is-equivalent-to-a-file-mode.patch.
- Delete patches.suse/0012-richacl-Automatic-Inheritance.patch.
- Delete
  patches.suse/0013-richacl-Restrict-access-check-algorithm.patch.
- Delete patches.suse/0014-richacl-xattr-mapping-functions.patch.
- Delete
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch.
- commit ae7d45a
* Fri Jul  4 2014 jdelvare@suse.de
- supported.conf: Update for SLE12 RC1
  Based on feedback from the kernel list.
- commit 9779aa4
* Fri Jul  4 2014 duwe@suse.de
- powerpc/book3s: Fix some ABIv2 issues in machine check code
  (bnc#883741, LTC 111793).
- powerpc/book3s: Fix machine check handling for unhandled errors
  (bnc#883741, LTC 111793).
- power, sched: stop updating inside arch_update_cpu_topology()
  when nothing to be update (bnc#883741, LTC 111793).
- crypto/nx: disable NX on little endian builds (bnc#883741,
  LTC 111793).
- commit 19ee205
* Fri Jul  4 2014 dsterba@suse.cz
- Btrfs: read lock extent buffer while walking backrefs.
- btrfs: device delete must be sysloged.
- btrfs: device add must be sysloged.
- btrfs: adjust statfs calculations according to raid profiles.
- btrfs: label should not contain return char.
- Btrfs: fill_holes: Fix slot number passed to hole_mergeable()
  call.
- commit e9fc751
* Fri Jul  4 2014 duwe@suse.de
- af_iucv: recvmsg problem for SOCK_STREAM sockets (bnc#881529,
  LTC#111065).
- af_iucv: correct cleanup if listen backlog is full (bnc#881529,
  LTC#111065).
- s390/sclp_vt220: Enable ASCII console per default (bnc#881529,
  LTC#111065).
- s390/smp: limit number of cpus in possible cpu mask (bnc#881529,
  LTC#111065).
- s390/crypto: fix aes_s390 crypto module unload problem
  (bnc#881529, LTC#111065).
- commit 25e2943
* Fri Jul  4 2014 dsterba@suse.cz
- Disable patches reverted upstream.
  patches.suse/btrfs-0364-allow-mounting-btrfs-subvolumes-with-different.patch
  patches.suse/btrfs-0365-fix-use-after-free-in-mount_subvol.patch
- commit 4f22942
* Fri Jul  4 2014 dsterba@suse.cz
- Btrfs updates
- btrfs: fix error handling in create_pending_snapshot.
- Btrfs: make free space cache write out functions more readable.
- Btrfs: fix broken free space cache after the system crashed.
- btrfs: Skip scrubbing removed chunks to avoid -ENOENT.
- Btrfs: fix NULL pointer crash when running balance and scrub
  concurrently.
- btrfs: rename add_device_membership to btrfs_kobj_add_device.
- btrfs: dev delete should remove sysfs entry.
- btrfs: dev add should add its sysfs entry.
- btrfs: dev replace should replace the sysfs entry.
- Btrfs: atomically set inode->i_flags in btrfs_update_iflags.
- Btrfs: fix race between balance recovery and root deletion.
- btrfs: fix null pointer dereference in clone_fs_devices when
  name is null.
- btrfs: fix null pointer dereference in btrfs_show_devname when
  name is null.
- Btrfs: fix race of using total_bytes_pinned.
- Btrfs: fix btrfs_print_leaf for skinny metadata.
- Btrfs: break up __btrfs_write_out_cache to cut down stack usage.
- Btrfs: cut down stack usage in btree_write_cache_pages.
- Btrfs: split up __extent_writepage to lower stack usage.
- Btrfs: fix hang on error (such as ENOSPC) when writing extent
  pages.
- Refresh patches.suse/btrfs-0400-rework-qgroup-accounting.patch.
- Refresh
  patches.suse/btrfs-0401-free-tmp-ulist-for-qgroup-rescan.patch.
- Refresh
  patches.suse/btrfs-0402-add-sanity-tests-for-new-qgroup-accounting-cod.patch.
- Refresh
  patches.suse/btrfs-8012-btrfs_rm_device-should-zero-mirror-SB-as-well.patch.
- Refresh
  patches.suse/btrfs-8019-allocate-raid-type-kobjects-dynamically.patch.
- Refresh
  patches.suse/btrfs-8025-fix-leaf-corruption-after-__btrfs_drop_extents.patch.
- Refresh
  patches.suse/btrfs-8029-don-t-check-nodes-for-extent-items.patch.
- Delete
  patches.suse/btrfs-8021-dev-delete-should-remove-sysfs-entry.patch.
- Delete
  patches.suse/btrfs-8022-dev-add-should-add-its-sysfs-entry.patch.
- Delete
  patches.suse/btrfs-8023-dev-replace-should-replace-the-sysfs-entry.patch.
- commit 7dc9bf3
* Fri Jul  4 2014 duwe@suse.de
- tick: Fixup more fallout from hrtimer broadcast mode
  (bnc#878240).
- time: Fixup fallout from recent clockevent/tick changes
  (bnc#878240).
- powerpc: Implement tick broadcast IPI as a fixed IPI message
  (bnc#878240).
- powerpc: Free up the slot of PPC_MSG_CALL_FUNC_SINGLE IPI
  message (bnc#878240).
- commit d7d8476
* Fri Jul  4 2014 dchang@suse.com
- net/mlx4_core: Replace pr_warning() with pr_warn() (bnc#874940).
- net/mlx4_core: Deprecate use_prio module parameter (bnc#874940).
- commit 4f6f6dd
* Fri Jul  4 2014 oneukum@suse.de
- usb: fix ->update_hub_device() vs hdev->maxchild (FATE#315518).
- commit f5ddc03
* Fri Jul  4 2014 oneukum@suse.de
- usb: phy: move some error messages to debug (FATE#315518).
- commit 2469acd
* Fri Jul  4 2014 mgorman@suse.de
- mm: page_alloc: Reduce cost of the fair zone allocation policy
  (VM Performance).
- mm: page_alloc: Only apply the fair zone allocation policy if
  it's eligible (VM Performance).
- commit a9e3b71
* Fri Jul  4 2014 mgorman@suse.de
- mm: vmscan: Only update per-cpu thresholds for online CPU
  (VM Performance).
- commit 3cf256b
* Fri Jul  4 2014 mgorman@suse.de
- mm: page_alloc: reduce number of times page_to_pfn is called
  (VM/FS Performance).
- commit c907716
* Fri Jul  4 2014 mgorman@suse.de
- mm: Move zone->pages_scanned into a vmstat counter
  (VM Performance).
- commit 21744ea
* Fri Jul  4 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-post.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-prep.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
- Delete
  patches.suse/mm-page_alloc-Reduce-cost-of-dirty-zone-balancing.patch.
  patches.suse/mm-page_alloc-Reduce-cost-of-the-fair-zone-allocation-policy.patch.
  patches.suse/mm-vmscan-Do-not-reclaim-from-lower-zones-if-they-are-balanced.patch.
- commit 3798bfb
* Fri Jul  4 2014 mhocko@suse.cz
- ptrace,x86: force IRET path after a ptrace_stop() (bnc#885725,
  CVE-2014-4699).
- commit 2362748
* Fri Jul  4 2014 jslaby@suse.cz
- Refresh patches.kernel.org/patch-3.12.23-24.
- Delete
  patches.fixes/xfs-don-t-break-from-growfs-ag-update-loop-on-error.patch.
- Delete
  patches.fixes/xfs-don-t-emit-corruption-noise-on-fs-probes.patch.
- Delete
  patches.fixes/xfs-don-t-perform-discard-if-the-given-range-length.patch.
- Delete
  patches.fixes/xfs-fix-possible-NULL-dereference-in-xlog_verify_ic.patch.
- Delete
  patches.fixes/xfs-fix-the-extent-count-when-allocating-an-new-ind.patch.
- Delete
  patches.fixes/xfs-fix-the-wrong-new_size-rnew_size-at-xfs_iext_re.patch.
- Delete
  patches.fixes/xfs-prevent-deadlock-trying-to-cover-an-active-log.patch.
- Delete
  patches.fixes/xfs-prevent-stack-overflows-from-page-cache-allocat.patch.
- Delete
  patches.fixes/xfs-xfs_remove-deadlocks-due-to-inverted-AGF-vs-AGI.patch.
  Update 3.12.24-rc1 to 3.12.24 final (xfs was under discussion).
- commit d7cfdb6
* Fri Jul  4 2014 tiwai@suse.de
- ALSA: hda - restore BCLK M/N value as per CDCLK for HSW/BDW
  display HDA controller (bnc#815494).
- drm/i915: provide interface for audio driver to query cdclk
  (bnc#815494).
- commit 147115d
* Thu Jul  3 2014 duwe@suse.de
- Update config files.
  CPU{FREQ,IDLE} on PowerNV is incomplete. Disable.
- commit f3b2e7a
* Thu Jul  3 2014 duwe@suse.de
- cpufreq: Add new helper cpufreq_table_validate_and_show()
  (bnc#878240).
- cpufreq: define generic .attr, .exit() and .verify() routines
  (bnc#878240).
- cpufreq: powernv: Use cpufreq_frequency_table.driver_data to
  store pstate ids (bnc#878240).
- cpufreq: powernv: cpufreq driver for powernv platform
  (bnc#878240).
- cpuidle/powernv: Add "Fast-Sleep" CPU idle state (bnc#878240).
- cpuidle/powernv: Parse device tree to setup idle states
  (bnc#878240).
- powerpc/powernv: Add config option for hwpoisoning (bnc#878240).
- powerpc/powernv: Add context management for Fast Sleep
  (bnc#878240).
- powerpc/powernv: Fix opal_xscom_{read,write} prototype
  (bnc#878240).
- powerpc/powernv: Remove some OPAL function declaration
  duplication (bnc#878240).
- powerpc/powernv: hwmon driver for power values, fan rpm and
  temperature (bnc#878240).
- powerpc/scom: Change scom_read() and scom_write() to return
  errors (bnc#878240).
- tick: Introduce hrtimer based broadcast (bnc#878240).
- time: Change the return type of clockevents_notify() to integer
  (bnc#878240).
- ibmvscsi: Abort init sequence during error recovery
  (bnc#882054).
- ibmvscsi: Add memory barriers for send / receive (bnc#882054).
- Update config files.
- commit 80a7e59
* Thu Jul  3 2014 mhocko@suse.cz
- pagecachelimit: reduce lru_lock contention for heavy parallel
  reclaim (bnc#878509, bnc#864464).
- Refresh
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
- commit 576b720
* Thu Jul  3 2014 vbabka@suse.cz
- shmem: fix faulting into a hole while it's punched, take 2
  (bnc#883518, CVE-2014-4171).
- commit bec9e90
* Thu Jul  3 2014 oneukum@suse.de
- Add a void* suse_kabi_padding placeholder to some gspca
  structures (fate#312013).
- Add a void* suse_kabi_padding placeholder to some USB structures
  (fate#312013).
- commit bb22373
* Thu Jul  3 2014 vbabka@suse.cz
- Re-enable the fixed 'asm goto' atomics backport, bnc#884738
- commit 0211b7b
* Thu Jul  3 2014 jroedel@suse.de
- Refresh
  patches.drivers/iommu-amd-fix-small-race-between-invalidate_range_end-start.
- Refresh
  patches.drivers/iommu-vt-d-fix-bug-in-handling-multiple-rmrrs-for-the-same-pci-device.
- commit 1dd7094
* Thu Jul  3 2014 acho@suse.com
- tg3: Change nvram command timeout value to 50ms (bnc#855657
  bnc#768714).
- commit 9cbfd16
* Thu Jul  3 2014 vbabka@suse.cz
- x86: Apply the asm_volatile_goto() compiler quirk (Locking
  scalability, bnc#884738).
- commit 5748e92
* Wed Jul  2 2014 pmladek@suse.cz
- printk: automatic ring buffer size (bnc#835888)
- printk: make dynamic kernel ring buffer alignment explicit
- printk: move power of 2 practice of ring buffer size to a helper
- printk: make dynamic units clear for the kernel ring buffer
- printk: allow increasing the ring buffer depending on the
  number of CPUs
  Update config files. Use the default size, extra 4kB per CPU (bnc#835888).
- Refresh
  patches.fixes/printk-nmi-0002-printk-allow-to-handle-more-log-buffers.patch.
- Refresh
  patches.fixes/printk-nmi-0004-printk-add-NMI-ring-and-cont-buffers.patch.
- Refresh
  patches.fixes/printk-nmi-0005-printk-allow-to-modify-NMI-log-buffer-size-using-boo.patch.
- Refresh
  patches.fixes/printk-nmi-correct-detection-of-the-continuous-buffer-si.patch.
- commit 1ad9412
* Wed Jul  2 2014 tiwai@suse.de
- ALSA: usb-audio: Fix deadlocks at resuming (bnc#884840).
- ALSA: usb-audio: Save mixer status only once at suspend
  (bnc#884840).
- ALSA: usb-audio: Resume mixer values properly (bnc#884840).
- commit 15cfdd7
* Wed Jul  2 2014 mmarek@suse.cz
- kabi: Lift ifdefs for some disabled network protocols
  (fate#312013).
- patches.kabi/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch:
  (fate#312013).
- kabi: Add placeholders to a couple of important structures
  (fate#312013).
- Refresh
  patches.suse/Revert-mm-sched-numa-Delay-PTE-scanning-until-a-task-is-scheduled-on-a-new-node.patch.
- Refresh
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
- commit 87f661c
* Wed Jul  2 2014 jslaby@suse.cz
- Linux 3.12.24 (CVE-2014-3940 CVE-2014-4652 CVE-2014-4653
  CVE-2014-4654 CVE-2014-4655 CVE-2014-4656 FATE#315054
  FATE#315942 bnc#845378 bnc#856380 bnc#865310 bnc#866937
  bnc#867753 bnc#872634 bnc#875242 bnc#875440 bnc#878059
  bnc#879957 bnc#881091 bnc#881101 bnc#881939 bnc#882991
  bnc#883081 bnc#883795 LTC#110452).
- Refresh
  patches.arch/0002-ACPI-Introduce-acpi_set_device_status.patch.
- Refresh
  patches.drivers/0059-iscsi-target-Implement-demo_mode_discovery-logic.patch.
- Refresh
  patches.drivers/0060-ib_isert-Add-support-for-completion-interrupt-coales.patch.
- Refresh
  patches.drivers/0102-target-Convert-inquiry-temporary-buffer-to-heap-memo.patch.
- Refresh
  patches.drivers/0121-IB-isert-Avoid-frwr-notation-user-fastreg.patch.
- Refresh
  patches.drivers/0132-target-Simplify-command-completion-by-removing-CMD_T.patch.
- Refresh
  patches.fixes/mei-do-not-run-reset-flow-from-the-interrupt-thread.
- Refresh patches.fixes/mei-revamp-mei-reset-state-machine.
- Refresh
  patches.suse/btrfs-0030-free-up-block-groups-after-everything.patch.
- Refresh
  patches.suse/btrfs-0035-stop-all-workers-after-we-free-block-groups.patch.
- Refresh
  patches.suse/btrfs-0187-convert-printk-to-btrfs_-and-fix-btrfs-prefix.patch.
- Refresh
  patches.suse/btrfs-0230-fix-extent-state-leak-on-transaction-abortion.patch.
- Refresh
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
- Refresh
  patches.suse/x86-mm-enable-split-page-table-lock-for-PMD-level.patch.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete
  patches.arch/0001-powerpc-mm-fix-.__node_distance-undefined.patch.
- Delete
  patches.arch/KVM-PPC-Book3S-HV-Fix-KVM-hang-without-CONFIG_KVM_XICS.
- Delete patches.arch/add-acpi_no_memhotplug-parameter.
- Delete
  patches.arch/s390-sles12-06-03-af_iucv-data-corruption.patch.
- Delete
  patches.drivers/ACPI-video-clean-up-DMI-table-for-initial-black-scre.
- Delete
  patches.drivers/alsa-0001-control-Protect-user-controls-against-concurren.
- Delete
  patches.drivers/alsa-0002-control-Fix-replacing-user-controls.
- Delete
  patches.drivers/alsa-0003-control-Don-t-access-controls-outside-of-protec.
- Delete patches.drivers/alsa-0004-control-Handle-numid-overflow.
- Delete
  patches.drivers/alsa-0005-control-Make-sure-that-id-index-does-not-overfl.
- Delete
  patches.drivers/hda-0031-hdmi-Use-TFx-channel-positions-instead-of-F.
- Delete patches.drivers/ipr-add-grand-canyon-PCIIDs.
- Delete
  patches.fixes/cifs-Check-SMB3-dialects-against-downgrade-attacks.patch.
- Delete
  patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch.
- Delete
  patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch.
- Delete patches.fixes/dlm-abort-listening-connection.patch.
- Delete
  patches.fixes/ftrace-x86-call-text_ip_addr-instead-of-the-duplicat.patch.
- Delete
  patches.fixes/media-ivtv-Fix-Oops-when-no-firmware-is-loaded.
- Delete
  patches.fixes/mm-add-pte_present-check-on-existing-hugetlb_entry-c.patch.
- Delete
  patches.fixes/mm-memory-failure-c-don-t-let-collect_procs-skip-over-processes-for-mf_action_required.patch.
- Delete
  patches.fixes/mm-memory-failure-c-failure-send-right-signal-code-to-correct-thread.patch.
- Delete
  patches.fixes/mm-memory-failure-c-support-use-of-a-dedicated-thread-to-handle-sigbusbus_mceerr_ao.patch.
- Delete
  patches.fixes/net-Do-not-enable-tx-nocache-copy-by-default.patch.
- Delete
  patches.fixes/net-compat-Fix-minor-information-leak-in-siocdevpriv.patch.
- Delete
  patches.fixes/nfsd4-fix-FREE_STATEID-lockowner-leak.patch.
- Delete
  patches.fixes/ocfs2-Avoid-blocking-in-ocfs2_mark_lockres_freeing-i.patch.
- Delete
  patches.fixes/ocfs2-Implement-delayed-dropping-of-last-dquot-refer.patch.
- Delete
  patches.fixes/ocfs2-Move-dquot_initialize-in-ocfs2_delete_inode-so.patch.
- Delete
  patches.fixes/ocfs2-Revert-iput-deferring-code-in-ocfs2_drop_dentr.patch.
- Delete
  patches.fixes/quota-Provide-function-to-grab-quota-structure-refer.patch.
- Delete
  patches.fixes/sched-Make-scale_rt_power-deal-with-backward-clocks.patch.
- Delete
  patches.fixes/vlan-more-careful-checksum-features-handling.patch.
- Delete
  patches.fixes/xfrm-fix-race-between-netns-cleanup-and-state-expire.patch.
- Delete
  patches.suse/btrfs-0009-fix-tracking-of-orphan-inode-count.patch.
- Delete
  patches.suse/btrfs-0010-fix-sync-fs-to-actually-wait-for-all-data-to-b.patch.
- Delete
  patches.suse/btrfs-0011-don-t-leak-block-group-on-error.patch.
- Delete
  patches.suse/btrfs-0014-do-not-release-metadata-for-space-cache-inodes.patch.
- Delete
  patches.suse/btrfs-0015-cleanup-transaction-on-abort.patch.
- Delete
  patches.suse/btrfs-0016-don-t-delete-ordered-roots-from-list-during-cl.patch.
- Delete
  patches.suse/btrfs-0018-fix-two-use-after-free-bugs-with-transaction-c.patch.
- Delete
  patches.suse/btrfs-0020-fix-BUG_ON-casued-by-the-reserved-space-migrat.patch.
- Delete
  patches.suse/btrfs-8006-Add-ctime-mtime-update-for-btrfs-device-add-re.patch.
- Delete
  patches.suse/btrfs-8007-output-warning-instead-of-error-when-loading-f.patch.
- Delete
  patches.suse/btrfs-8014-make-sure-there-are-not-any-read-requests-befo.patch.
- Delete
  patches.suse/btrfs-8017-fix-double-free-in-find_lock_delalloc_range.patch.
- Delete
  patches.suse/btrfs-8030-use-right-type-to-get-real-comparison.patch.
- Delete
  patches.suse/btrfs-8031-fix-scrub_print_warning-to-handle-skinny-metad.patch.
- Delete
  patches.suse/btrfs-8033-fix-use-of-uninit-ret-in-end_extent_writepage.patch.
- Delete
  patches.suse/mm-page_alloc-use-word-based-accesses-for-get-set-pageblock-bitmaps.patch.
- Delete
  patches.suse/mm-vmscan-do-not-throttle-on-normalless-zones.patch.
- Delete
  patches.suse/msft-hv-0628-Drivers-hv-balloon-Ensure-pressure-reports-are-poste.patch.
- Update config files.
- commit 1d6a4f1
* Wed Jul  2 2014 vbabka@suse.cz
- Delete
  patches.fixes/shmem-fix-faulting-into-a-hole-while-its-punched.patch.
  (bnc#883518: patch can cause deadlocks, will be reverted and replaced upstream)
- commit ad95ab6
* Wed Jul  2 2014 jslaby@suse.cz
- kgr: expose global 'in_progress' state through sysfs
  (fate#313296).
- kgr: add state machine to a patch (fate#313296).
- kgr: make ftrace ops initialization simpler (fate#313296).
- kgr: move the logic to kgr_patch_code's switch (fate#313296).
- kgr: add patch information into sysfs (fate#313296).
- kgr: support revert of patches (fate#313296).
- Refresh
  patches.suse/kgr-0001-ftrace-Add-function-to-find-fentry-of-function.patch.
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh
  patches.suse/kgr-0004-kgr-add-testing-kgraft-patch.patch.
- Refresh
  patches.suse/kgr-0005-kgr-update-Kconfig-documentation.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh patches.suse/kgr-0012-kgr-add-MAINTAINERS-entry.patch.
- Refresh
  patches.suse/kgr-0013-kgr-x86-refuse-to-build-without-fentry-support.patch.
- Refresh
  patches.suse/kgr-0014-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Refresh
  patches.suse/kgr-0015-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh
  patches.suse/kgr-0016-kgr-add-support-for-missing-functions.patch.
- Refresh
  patches.suse/kgr-0017-kgr-exercise-non-present-function.patch.
- Refresh
  patches.suse/kgr-0018-kgr-fix-race-of-stub-and-patching.patch.
- Refresh
  patches.suse/kgr-0020-kgr-rephrase-the-kGraft-failed-message.patch.
- Refresh
  patches.suse/kgr-0021-kgr-x86-optimize-handling-of-CPU-bound-tasks.patch.
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
- Delete
  patches.suse/kgr-0019-kgr-expose-global-in_progress-state-through-procfs.patch.
  Updated to the latest snapshot (revert and sysfs support added).
- commit ea2f84e
* Wed Jul  2 2014 vbabka@suse.cz
- Disable two patches causing bnc#884738:
- patches.suse/x86-Use-asm-goto-to-implement-better-modify_and_test-functions.patch
- patches.suse/x86-bitops-Correct-the-assembly-constraints-to-testing-bitops.patch
- commit 548d475
* Wed Jul  2 2014 hare@suse.de
- Update Mainline tags and remove mptfusion patches after review
- Refresh
  patches.drivers/lpfc-8.3.44-Fix-Crash-in-lpfc_els_timeout_handler.patch.
- Refresh
  patches.drivers/lpfc-8.3.44-Fix-kernel-panics-from-corrupted-ndlp-li.patch.
- Refresh
  patches.drivers/lpfc-8.3.44-Fixed-IO-hang-when-in-msi-mode.patch.
- Refresh
  patches.drivers/lpfc-8.3.44-Fixed-incorrect-allocation-of-iDiags-dir.patch.
- Refresh
  patches.drivers/lpfc-8.3.44-Fixed-stopped-FCF-discovery-on-failed-FC.patch.
- Refresh
  patches.drivers/lpfc-8.3.44-Fixed-unassigned-variable-in-ELS-timeout.patch.
- Refresh patches.drivers/lpfc-8.3.44-Update-lpfc-version.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Added-dport-mailbox-pass-through-support.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Fix-sysfs-buffer-overrun-in-read-of-lpfc.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Fixed-crash-during-driver-unload.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Fixed-driver-error-messages-after-firmwa.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Fixed-missing-initialization-for-task-ma.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Incorporate-changes-to-use-reason-in-cha.patch.
- Refresh
  patches.drivers/lpfc-8.3.45-Incorporated-support-of-a-low-latency-io.patch.
- Refresh patches.drivers/lpfc-remove-self-assignments.patch.
- Refresh
  patches.drivers/lpfc-use-NULL-instead-of-0-for-pointer.patch.
- Refresh
  patches.drivers/megaraid_sas-Add-Dell-PowerEdge-VRTX-SR-IOV-VF-suppo.patch.
- Refresh
  patches.drivers/megaraid_sas-Big-endian-code-related-fixes.patch.
- Refresh
  patches.drivers/megaraid_sas-Don-t-wait-forever-for-non-IOCTL-DCMDs.patch.
- Refresh
  patches.drivers/megaraid_sas-Fix-megasas_ioc_init_fusion.patch.
- Refresh
  patches.drivers/megaraid_sas-Load-correct-raid-context-timeout.patch.
- Refresh
  patches.drivers/megaraid_sas-Performance-boost-fixes.patch.
- Refresh
  patches.drivers/megaraid_sas-Return-leaked-MPT-frames-to-MPT-frame-p.patch.
- Refresh patches.drivers/megaraid_sas-Set-32-bit-DMA-mask.patch.
- Refresh
  patches.fixes/scsi-Fix-erratic-device-offline-during-EH.patch.
- Delete
  patches.drivers/mptfusion-Bump-driver-vesion-to-v4.28.00.01suse.patch.
- Delete patches.drivers/mptfusion-Update-to-4.28.00.00suse.patch.
- Delete patches.fixes/dm-initialize-flush_rq.patch.
- commit dd9b104
* Wed Jul  2 2014 jbeulich@suse.com
- Update Xen patches to 3.12.23.
- x86/smep:  Be more informative when signalling an SMEP fault.
- commit 1fc97d1
* Wed Jul  2 2014 hare@suse.de
- scsi_dh_alua: Use per-LUN or per-LUN-Group association
  (bnc#877514).
- scsi_dh_alua: optimize_stpg functionality broken (bnc#877514).
- Refresh
  patches.drivers/RDMA-cxgb4-Add-missing-padding-at-end-of-struct-c4iw.patch.
- Update patches.suse/dm-mpath-accept-failed-paths to fixup logging message
- commit e3e6757
* Wed Jul  2 2014 jlee@suse.com
- Refresh MODSIGN patch after removed firmware signature support
  Refresh
  patches.suse/0001-MODSIGN-check-hash-of-kernel-module-in-blacklist.patch.
  import linux/module.h
- commit 26a071f
* Wed Jul  2 2014 neilb@suse.de
- NFSD: Don't hand out delegations for 30 seconds after recalling
  them (bnc#880370).
- commit 1c95be4
* Wed Jul  2 2014 jlee@suse.com
- Update config files, remove CONFIG_FIRMWARE_SIG.
  Remove support of firmware signature check.
- commit 5f760e2
* Wed Jul  2 2014 jlee@suse.com
- Remove Kernel firmware sign patches
  Remove Kernel firmware sign patches (FATE#314574),
  and refresh some MODSIGN patches.
- Refresh
  patches.suse/0001-MODSIGN-check-hash-of-kernel-module-in-blacklist.patch.
- Refresh patches.suse/0001-X.509-Fix-certificate-gathering.patch.
- Refresh patches.suse/0001_V3_Add_secure_modules_call.patch.
- Refresh
  patches.suse/0002-Add-an-EFI-signature-blob-parser-and-key-loader.patch.
- Refresh
  patches.suse/0003-KEYS-Add-a-system-blacklist-keyring.patch.
- Refresh
  patches.suse/0003_V3_x86_Lock_down_IO_port_access_when_module_security_is_enabled.patch.
- Refresh
  patches.suse/0004-MODSIGN-Import-certificates-from-UEFI-Secure-Boot.patch.
- Delete
  patches.suse/0001-firmware_Add_the_firmware_signing_support_to_scripts_sign-file.patch.
- Delete
  patches.suse/0003-firmware_Add_support_for_signature_checks.patch.
- Delete
  patches.suse/0004-firmware_Install_firmware_signature_files_automatically.patch.
- Delete patches.suse/firmware-dont-spew-errors-in-normal-boot.
- commit c0f6073
* Wed Jul  2 2014 bpoirier@suse.de
- RDMA/cxgb4: Add missing padding at end of struct
  c4iw_create_cq_resp.
- IB/mlx4: fix unitialised variable is_mcast (bnc#868011).
- IB/cm: Fix missing unlock on error in cm_init_qp_rtr_attr()
  (bnc#868011).
- macvlan: Add support for 'always_on' offload features
  (bnc#846984 bnc#857401 FATE#315668).
- net: sctp: check proc_dointvec result in proc_sctp_do_auth.
- ipv4: ipv6: better estimate tunnel header cut for correct
  ufo handling.
- inet: fix a UFO regression.
- net: ip: push gso skb forwarding handling down the stack.
- commit 82f42e7
* Tue Jul  1 2014 bpoirier@suse.de
- Update tags to reflect upstream status
- commit 432de69
* Tue Jul  1 2014 bpoirier@suse.de
- Move some patch files to their appropriate directory
- commit 33575ff
* Tue Jul  1 2014 mmarek@suse.cz
- Documentation: Fix DocBook build with relative $(srctree).
- kbuild: Fix tar-pkg with relative $(objtree).
- deb-pkg: Fix for relative paths.
- commit c5f44bf
* Tue Jul  1 2014 mmarek@suse.cz
- kbuild: move "quote" to Kbuild.include to be consistent.
- commit 256661c
* Tue Jul  1 2014 eich@suse.de
- drm/mgag200: Initialize data needed to map fbdev memory
  (bnc #806990).
- Refresh
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch.
- Refresh
  patches.drivers/drm-mgag200-Add-support-for-MATROX-PCI-device-IDs-0x520-and-0x521.patch.
- Refresh
  patches.drivers/drm-mgag200-Consolidate-depth-bpp-handling.patch.
- Refresh
  patches.drivers/drm-mgag200-Don-t-use-crtc_-parameters-for-validation.patch.
- Refresh patches.drivers/drm-mgag200-Implement-basic-PM-support.
- Refresh
  patches.drivers/drm-mgag200-Reject-modes-when-hdisplay-is-no-multiple-of-8.patch.
- Refresh
  patches.drivers/drm-mgag200-Remove-connector-in-sysfs-when-unloading-the-driver.patch.
- Refresh
  patches.drivers/drm-mgag200-Simplify-function-mgag200_ttm_placement.patch.
- Delete
  patches.drivers/drm-mgag200-Initialized-data-needed-to-map-fbdev-memory.patch.
- commit 3f3fb41
* Tue Jul  1 2014 mhocko@suse.cz
- res_coutner: add placeholders for min/low/high limits
  (fate#312101).
- commit a701c0d
* Tue Jul  1 2014 bpoirier@suse.de
- patches.fixes/net-core-explicitly-select-a-txq-before-doing-l2-for.patch
  Rename and add a missing hunk
- commit 9abd586
* Mon Jun 30 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-clean-up-unused-code-lines.patch.
- commit d56937a
* Mon Jun 30 2014 trenn@suse.de
- ACPI / PAD: call schedule() when need_resched() is true
  (bnc#866911).
- commit 5cdb910
* Mon Jun 30 2014 jslaby@suse.cz
- Refresh
  patches.fixes/sched-Check-TASK_DEAD-rather-than-EXIT_DEAD-in-schedule_debug.patch.
  add commit-id
- commit 9d549f4
* Mon Jun 30 2014 hare@suse.de
- bnx2fc: fix memory leak in bnx2fc_allocate_hash_table()
  (bnc#884925).
- bnx2fc: fix memory leak and potential NULL pointer dereference
  (bnc#884925).
- bnx2fc: remove unused variable hash_table_size (bnc#884925).
- scsi_error: set DID_TIME_OUT correctly (bnc#884925).
- scsi_error: fix invalid setting of host byte (bnc#884925).
- sd: medium access timeout counter fails to reset (bnc#884925).
- don't reference freed command in scsi_prep_return (bnc#884925).
- don't reference freed command in scsi_init_sgtable (bnc#884925).
- scsi: Make sure cmd_flags are 64-bit (bnc#884925).
- remove a useless get/put_device pair in scsi_requeue_command
  (bnc#884925).
- remove a useless get/put_device pair in scsi_next_command
  (bnc#884925).
- do not manipulate device reference counts in (bnc#884925).
- avoid useless free_list lock roundtrips (bnc#884925).
- sd: don't fail if the device doesn't recognize SYNCHRONIZE
  (bnc#884925).
- avoid taking host_lock in scsi_run_queue unless nessecary
  (bnc#884925).
- Add timeout to avoid infinite command retry (bnc#884925).
- scsi: handle command allocation failure in scsi_reset_provider
  (bnc#884925).
- sym53c8xx_2: Set DID_REQUEUE return code when aborting squeue
  (bnc#884925).
- isci: update version to 1.2 (bnc#884925).
- isci: fix needless ata reset escalations (bnc#884925).
- commit 3bfacf9
* Mon Jun 30 2014 mgalbraith@suse.de
- sched/numa: Fix use of spin_{un}lock_irq() when interrupts are disabled
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Move task_numa_free() to __put_task_struct()
  (Automatic NUMA Balancing (fate#315482)).
- commit 4aaaf98
* Mon Jun 30 2014 schwab@suse.de
- rpm/kernel-obs-build.spec.in: add support for aarch64
  Use Image for kernel_name on aarch64 and add virtio_mmio to KERNEL_MODULES.
- commit 6024dc9
* Sat Jun 28 2014 bpoirier@suse.de
- Update Patch-mainline tags for some patches which used to be "Queued in subsystem maintainer repository"
- Refresh
  patches.drivers/be2net-0027-be2net-disable-RSS-when-number-of-RXQs-is-reduced-to.patch.
- Refresh
  patches.drivers/be2net-0028-be2net-increase-the-timeout-value-for-loopback-test-.patch.
- Refresh
  patches.drivers/be2net-0029-be2net-fix-max_evt_qs-calculation-for-BE3-in-SR-IOV-.patch.
- Refresh
  patches.drivers/be2net-0030-net-emulex-benet-calls-skb_set_hash.patch.
- Refresh
  patches.drivers/be2net-0031-net-benet-slight-optimization-of-addr-compare.patch.
- Refresh
  patches.drivers/be2net-0032-be2net-Use-MCC_CREATE_EXT_V1-cmd-for-Skyhawk-R.patch.
- Refresh
  patches.drivers/be2net-0033-be2net-don-t-set-pport-field-when-querying-pvid.patch.
- Refresh
  patches.drivers/be2net-0034-be2net-Log-the-profile-id-used-by-FW-during-driver-i.patch.
- Refresh
  patches.drivers/be2net-0035-be2net-do-not-call-be_set-get_fw_log_level-on-Skyhaw.patch.
- Refresh
  patches.drivers/be2net-0036-be2net-ignore-mac-addr-set-call-for-an-already-progr.patch.
- Refresh
  patches.drivers/be2net-0037-be2net-fix-incorrect-setting-of-cmd_privileges-for-V.patch.
- Refresh
  patches.drivers/be2net-0038-be2net-Remove-10Gbps-from-driver-description-string.patch.
- Refresh
  patches.drivers/be2net-0039-be2net-do-not-use-frag-index-in-the-RX-compl-entry.patch.
- Refresh
  patches.drivers/be2net-0040-be2net-use-GET_MAC_LIST-cmd-to-query-mac-address-fro.patch.
- Refresh
  patches.drivers/be2net-0041-be2net-cleanup-wake-on-lan-code.patch.
- Refresh
  patches.drivers/be2net-0042-be2net-update-driver-version-to-10.0.x.patch.
- Refresh
  patches.drivers/bna-0004-net-bna-remove-unnecessary-pci_set_drvdata.patch.
- Refresh
  patches.drivers/bna-0005-bnad-make-local-variable-static.patch.
- Refresh
  patches.drivers/bna-0006-bna-Add-software-timestamping-support.patch.
- Refresh patches.drivers/bna-0007-bna-Set-Get-IOC-fw-State.patch.
- Refresh patches.drivers/bna-0008-bna-Fix-Filter-Add-Del.patch.
- Refresh
  patches.drivers/bna-0009-bna-RX-Filter-Enhancements.patch.
- Refresh
  patches.drivers/bna-0010-bna-Enable-Multi-Buffer-RX.patch.
- Refresh
  patches.drivers/bna-0011-bna-RX-Processing-and-Config-Changes.patch.
- Refresh patches.drivers/bna-0012-bna-CQ-Read-Fix.patch.
- Refresh
  patches.drivers/bna-0013-bna-Add-NULL-Check-Before-Dereferencing-TCB.patch.
- Refresh
  patches.drivers/bna-0014-bna-Handle-the-TX-Setup-Failures.patch.
- Refresh
  patches.drivers/bna-0015-bna-Embed-SKB-Length-in-TX-Vector.patch.
- Refresh
  patches.drivers/bna-0016-bna-Firmware-Patch-Simplification.patch.
- Refresh
  patches.drivers/bna-0017-bna-Update-the-Driver-Version-to-3.2.23.0.patch.
- Refresh
  patches.drivers/bna-0018-bna-Fix-build-due-to-missing-use-of-dma_unmap_len_se.patch.
- Refresh patches.drivers/bna-0019-bnad-code-cleanup.patch.
- Refresh
  patches.drivers/bnx2x-0065-bnx2x-Fix-UNDI-driver-unload.patch.
- Refresh
  patches.drivers/cnic-0006-cnic-Don-t-take-rcu_read_lock-in-cnic_rcv_netevent.patch.
- Refresh
  patches.drivers/cnic-0007-cnic-Don-t-take-cnic_dev_lock-in-cnic_alloc_uio_ring.patch.
- Refresh
  patches.drivers/cnic-0008-cnic-Fix-missing-ISCSI_KEVENT_IF_DOWN-message.patch.
- Refresh
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-wit.patch.
- Refresh
  patches.drivers/e1000e-0007-e1000e-Implement-the-SIOCGHWTSTAMP-ioctl.patch.
- Refresh
  patches.drivers/ixgbe-0026-ixgbe-Convert-to-use-devm_hwmon_device_register_with.patch.
- Refresh
  patches.drivers/ixgbe-0027-ixgbe-Start-temperature-sensor-attribute-index-with-.patch.
- Refresh
  patches.drivers/ixgbe-0029-net-ixgbe-slight-optimization-of-addr-compare.patch.
- Refresh
  patches.drivers/ixgbe-0031-ixgbe-Indicate-removal-state-explicitly.patch.
- Refresh
  patches.drivers/ixgbe-0032-ixbge-Protect-ixgbe_down-with-__IXGBE_DOWN-bit.patch.
- Refresh
  patches.drivers/ixgbe-0033-ixgbe-Use-static-inlines-instead-of-macros.patch.
- Refresh
  patches.drivers/ixgbe-0034-ixgbe-Make-ethtool-register-test-use-accessors.patch.
- Refresh
  patches.drivers/ixgbe-0035-ixgbe-Check-register-reads-for-adapter-removal.patch.
- Refresh
  patches.drivers/ixgbe-0036-ixgbe-Check-for-adapter-removal-on-register-writes.patch.
- Refresh
  patches.drivers/ixgbe-0037-ixgbe-Additional-adapter-removal-checks.patch.
- Refresh
  patches.drivers/ixgbe-0038-ixgbe-Force-QDE-via-PFQDE-for-VFs-during-reset.patch.
- Refresh
  patches.drivers/ixgbe-0039-ixgbe-Clear-head-write-back-registers-on-VF-reset.patch.
- Refresh
  patches.drivers/ixgbe-0040-ixgbe-reinit_locked-should-be-called-with-rtnl_lock.patch.
- Refresh
  patches.drivers/ixgbe-0041-ixgbe-Fix-incorrect-logic-for-fixed-fiber-eeprom-wri.patch.
- Refresh
  patches.drivers/ixgbe-0042-ixgbe-define-IXGBE_MAX_VFS_DRV_LIMIT-macro-and-clean.patch.
- Refresh
  patches.drivers/ixgbe-0043-ixgbe-set-driver_max_VFs-should-be-done-before-enabl.patch.
- Refresh
  patches.drivers/ixgbe-0044-ixgbe-add-braces-around-else-condition-in-ixgbe_qv_l.patch.
- Refresh
  patches.drivers/ixgbe-0045-ixgbe-bump-version-number.patch.
- Refresh
  patches.drivers/ixgbevf-0018-ixgbe-Focus-config-of-head-tail-ntc-and-ntu-all-into.patch.
- Refresh
  patches.drivers/ixgbevf-0019-ixgbevf-add-DCB-configuration-into-queue-setup.patch.
- Refresh
  patches.drivers/ixgbevf-0020-ixgbevf-set-the-disable-state-when-ixgbevf_qv_disabl.patch.
- Refresh
  patches.drivers/ixgbevf-0021-ixgbevf-use-pci-drvdata-correctly-in-ixgbevf_suspend.patch.
- Refresh
  patches.drivers/ixgbevf-0022-ixgbevf-Convert-ring-storage-form-pointer-to-an-arra.patch.
- Refresh
  patches.drivers/ixgbevf-0023-ixgbevf-create-function-for-all-of-ring-init.patch.
- Refresh patches.drivers/ixgbevf-0024-ixgbevf-bump-version.patch.
- Refresh
  patches.drivers/ixgbevf-0025-ixgbevf-make-use-of-the-dev-pointer-in-the-ixgbevf_r.patch.
- Refresh
  patches.drivers/ixgbevf-0026-ixgbevf-move-ring-specific-stats-into-ring-specific-.patch.
- Refresh
  patches.drivers/ixgbevf-0027-ixgbevf-remove-counters-for-Tx-Rx-checksum-offload.patch.
- Refresh
  patches.drivers/ixgbevf-0028-ixgbevf-add-tx-counters.patch.
- Refresh
  patches.drivers/ixgbevf-0029-ixgbevf-make-the-first-tx_buffer-a-repository-for-mo.patch.
- Refresh
  patches.drivers/ixgbevf-0030-ixgbevf-redo-dma-mapping-using-the-tx-buffer-info.patch.
- Refresh
  patches.drivers/ixgbevf-0031-ixgbevf-merge-ixgbevf_tx_map-and-ixgbevf_tx_queue-in.patch.
- Refresh
  patches.drivers/mlx-0052-IB-core-extended-command-an-improved-infrastructure-.patch.
- Refresh
  patches.drivers/mlx-0056-mlx4_core-Roll-back-round-robin-bitmap-allocation-co.patch.
- Refresh
  patches.drivers/mlx-0057-net-mlx4_core-Remove-zeroed-out-of-explicit-QUERY_FU.patch.
- Refresh
  patches.drivers/mlx-0058-net-mlx4_core-Rename-QUERY_FUNC_CAP-fields.patch.
- Refresh
  patches.drivers/mlx-0059-net-mlx4_core-Introduce-nic_info-new-flag-in-QUERY_F.patch.
- Refresh
  patches.drivers/mlx-0060-net-mlx4_core-Expose-physical-port-id-as-PF-VF-capab.patch.
- Refresh
  patches.drivers/mlx-0061-net-mlx4_en-Implement-ndo_get_phys_port_id.patch.
- Refresh
  patches.drivers/mlx-0062-net-mlx4_en-Configure-the-XPS-queue-mapping-on-drive.patch.
- Refresh
  patches.drivers/mlx-0063-net-mlx4_core-Set-CQE-EQE-size-to-64B-by-default.patch.
- Refresh
  patches.drivers/mlx-0064-net-mlx4_en-Ignore-irrelevant-hypervisor-events.patch.
- Refresh
  patches.drivers/mlx-0065-net-mlx4_en-Add-NAPI-support-for-transmit-side.patch.
- Refresh
  patches.drivers/mlx-0066-net-mlx4_core-Check-port-number-for-validity-before-.patch.
- Refresh
  patches.drivers/mlx-0067-net-mlx4_core-Add-basic-support-for-TCP-IP-offloads-.patch.
- Refresh
  patches.drivers/mlx-0068-net-mlx4_en-Add-netdev-support-for-TCP-IP-offloads-o.patch.
- Refresh
  patches.drivers/mlx-0075-net-mlx4-slight-optimization-of-addr-compare.patch.
- Refresh
  patches.drivers/mlx-0076-mlx4_en-Add-PTP-hardware-clock.patch.
- Refresh
  patches.drivers/mlx-0077-mlx4_en-Only-cycle-port-if-HW-timestamp-config-chang.patch.
- Refresh
  patches.drivers/mlx-0078-net-mlx4_core-Warn-if-device-doesn-t-have-enough-PCI.patch.
- Refresh
  patches.drivers/mlx-0079-IB-mlx5-Remove-unused-code-in-mr.c.patch.
- Refresh
  patches.drivers/mlx-0080-IB-mlx5-Fix-micro-UAR-allocator.patch.
- Refresh
  patches.drivers/mlx-0081-IB-mlx5-Clear-out-struct-before-create-QP-command.patch.
- Refresh
  patches.drivers/mlx-0082-mlx5_core-Use-mlx5-core-style-warning.patch.
- Refresh
  patches.drivers/mlx-0083-IB-mlx5-Make-sure-doorbell-record-is-visible-before-.patch.
- Refresh
  patches.drivers/mlx-0084-IB-mlx5-Implement-modify-CQ.patch.
- Refresh
  patches.drivers/mlx-0085-IB-mlx5-Add-support-for-resize-CQ.patch.
- Refresh
  patches.drivers/mlx-0086-mlx5_core-Improve-debugfs-readability.patch.
- Refresh
  patches.drivers/mlx-0087-mlx5_core-Fix-PowerPC-support.patch.
- Refresh
  patches.drivers/mlx-0088-IB-mlx5-Allow-creation-of-QPs-with-zero-length-work-.patch.
- Refresh
  patches.drivers/mlx-0089-IB-mlx5-Abort-driver-cleanup-if-teardown-hca-fails.patch.
- Refresh
  patches.drivers/mlx-0090-IB-mlx5-Remove-old-field-for-create-mkey-mailbox.patch.
- Refresh
  patches.drivers/mlx-0091-IB-mlx5-Verify-reserved-fields-are-cleared.patch.
- Refresh
  patches.drivers/mlx-0092-net-mlx4_core-Remove-unnecessary-validation-for-port.patch.
- Refresh
  patches.drivers/sfc-0009-sfc-Use-TX-PIO-for-sufficiently-small-packets.patch.
- Refresh
  patches.drivers/sfc-0023-sfc-Implement-the-SIOCGHWTSTAMP-ioctl.patch.
- Refresh
  patches.drivers/sfc-0024-sfc-Demote-MC-Scheduler-error-messages.patch.
- Refresh
  patches.drivers/sfc-0025-sfc-Update-MCDI-protocol-definitions.patch.
- Refresh
  patches.drivers/sfc-0026-net-sfc-remove-unnecessary-pci_set_drvdata.patch.
- Refresh
  patches.drivers/sfc-0027-sfc-Add-MC-BISTs-to-ethtool-offline-self-test-on-EF1.patch.
- Refresh
  patches.drivers/sfc-0028-sfc-Tighten-the-check-for-RX-merged-completion-event.patch.
- Refresh
  patches.drivers/sfc-0029-sfc-Make-initial-fill-of-RX-descriptors-synchronous.patch.
- Refresh
  patches.drivers/sfc-0030-sfc-Correct-RX-dropped-count-for-drops-while-interfa.patch.
- Refresh
  patches.drivers/sfc-0031-sfc-Report-units-in-sensor-warnings.patch.
- Refresh
  patches.drivers/sfc-0032-sfc-Revise-sensor-names-to-be-more-understandable-an.patch.
- Refresh patches.drivers/sfc-0033-sfc-Add-new-sensor-names.patch.
- Refresh
  patches.drivers/sfc-0034-sfc-Log-all-unexpected-MCDI-errors.patch.
- Refresh
  patches.drivers/sfc-0035-sfc-Map-MCDI-error-MC_CMD_ERR_ENOTSUP-to-Linux-EOPNO.patch.
- Refresh
  patches.drivers/sfc-0036-sfc-Fold-efx_flush_all-into-efx_stop_port-and-update.patch.
- Refresh
  patches.drivers/sfc-0037-sfc-Expose-NVRAM_PARTITION_TYPE_LICENSE-on-EF10.patch.
- Refresh
  patches.drivers/sfc-0038-sfc-Return-EBUSY-for-filter-insertion-on-EF10-matchi.patch.
- Refresh
  patches.drivers/sfc-0039-sfc-Split-PTP-multicast-filter-insertion-removal-out.patch.
- Refresh
  patches.drivers/sfc-0040-sfc-Remove-dependency-of-PTP-on-having-a-dedicated-c.patch.
- Refresh
  patches.drivers/sfc-0041-sfc-Store-flags-from-MC_CMD_DRV_ATTACH-for-later-use.patch.
- Refresh
  patches.drivers/sfc-0042-sfc-Do-not-use-MAC-address-as-clock-name.patch.
- Refresh
  patches.drivers/sfc-0043-sfc-Initialise-efx_ptp_data-phc_clock_info-from-a-st.patch.
- Refresh
  patches.drivers/sfc-0044-sfc-Remove-kernel-doc-for-efx_ptp_data-fields-not-pr.patch.
- Refresh
  patches.drivers/sfc-0045-sfc-PTP-tidy-up-unused-useless-variables.patch.
- Refresh
  patches.drivers/sfc-0046-sfc-Tidy-up-PTP-synchronization-code.patch.
- Refresh
  patches.drivers/sfc-0047-sfc-Add-support-for-SFC9100-timestamp-format.patch.
- Refresh
  patches.drivers/sfc-0048-sfc-split-setup-of-hardware-timestamping-into-NIC-ty.patch.
- Refresh
  patches.drivers/sfc-0049-sfc-Copy-RX-prefix-into-skb-head-area-in-efx_rx_mk_s.patch.
- Refresh
  patches.drivers/sfc-0050-sfc-Add-RX-packet-timestamping-for-EF10.patch.
- Refresh
  patches.drivers/sfc-0051-sfc-Store-VPD-serial-number-at-probe-time.patch.
- Refresh
  patches.drivers/sfc-0052-sfc-Associate-primary-and-secondary-functions-of-con.patch.
- Refresh
  patches.drivers/sfc-0053-sfc-Enable-PTP-clock-and-timestamping-for-all-functi.patch.
- Refresh
  patches.drivers/sfc-0054-sfc-Don-t-clear-timestamps-in-efx_ptp_rx.patch.
- Refresh
  patches.drivers/sfc-0055-sfc-Remove-unnecessary-condition-for-processing-the-.patch.
- Refresh
  patches.drivers/sfc-0056-sfc-Add-more-information-to-many-warnings-using-WARN.patch.
- Refresh
  patches.drivers/sfc-0057-sfc-Change-efx_nic_type-rx_push_indir_table-to-push-.patch.
- Refresh
  patches.drivers/sfc-0058-sfc-Change-priority-and-flags-for-automatic-MAC-filt.patch.
- Refresh
  patches.drivers/sfc-0059-sfc-Don-t-refer-to-stack-in-filter-implementation.patch.
- Refresh
  patches.drivers/sfc-0060-sfc-Allow-filter-removal-only-with-exactly-matching-.patch.
- Refresh
  patches.drivers/sfc-0061-sfc-Implement-efx_nic_type-filter_clear_rx-operation.patch.
- Refresh
  patches.drivers/sfc-0062-sfc-remove-unused-refcnt-from-efx_rx_page_state.patch.
- Refresh
  patches.drivers/sfc-0063-sfc-remove-unused-enum-efx_rx_alloc_method.patch.
- Refresh
  patches.drivers/sfc-0064-sfc-Changed-the-statistic-name-emerg_-fetch-wait-to-.patch.
- Refresh
  patches.drivers/sfc-0065-sfc-Add-PTP-counters-to-ethtool-stats.patch.
- Refresh
  patches.drivers/sfc-0066-sfc-Fix-RX-drop-filters-for-EF10.patch.
- Refresh
  patches.drivers/sfc-0067-net-sfc-calls-skb_set_hash.patch.
- Refresh
  patches.drivers/sfc-0068-sfc-fix-sparse-non-static-symbol-warning.patch.
- Refresh
  patches.drivers/sfc-0072-Call-efx_set_channels-before-efx-type-dimension_reso.patch.
- Refresh patches.fixes/net-Add-function-to-set-the-rxhash.patch.
- Refresh
  patches.fixes/net-Do-not-enable-tx-nocache-copy-by-default.patch.
- Refresh
  patches.fixes/net-compat-Fix-minor-information-leak-in-siocdevpriv.patch.
- Refresh
  patches.fixes/net-compat-Merge-multiple-implementations-of-ifreq-i.patch.
- Refresh
  patches.fixes/net_tstamp-Add-SIOCGHWTSTAMP-ioctl-to-match-SIOCSHWT.patch.
- Refresh
  patches.fixes/net_tstamp-Improve-kernel-doc-for-struct-hwtstamp_co.patch.
- commit 11ce577
* Fri Jun 27 2014 tiwai@suse.de
- ALSA: hda - hdmi: call overridden init on resume (bnc#883081).
- commit b76e6b6
* Fri Jun 27 2014 tiwai@suse.de
- ACPI / video: clean up DMI table for initial black screen
  problem (bnc#883081).
- commit 5e9b77c
* Fri Jun 27 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Compress vmlinux after find-debuginfo.sh (bnc#884459)
- commit 381a192
* Fri Jun 27 2014 oneukum@suse.de
- xhci: Use correct SLOT ID when handling a reset device command
  (bnc#884747).
- commit b30594c
* Thu Jun 26 2014 mgorman@suse.de
- sched,numa: rework best node setting in task_numa_migrate
  (Automatic NUMA Balancing (fate#315482)).
- sched,numa: examine a task move when examining a task swap
  (Automatic NUMA Balancing (fate#315482)).
- sched,numa: simplify task_numa_compare (Automatic NUMA Balancing
  (fate#315482)).
- sched,numa: move power adjustment into load_too_imbalanced
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Always try to migrate to preferred node at
  task_numa_placement() time (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Ensure task_numa_migrate() checks the preferred node
  (Automatic NUMA Balancing (fate#315482)).
- sched/fair: Disambiguate existing/remaining "capacity" usage
  (Automatic NUMA Balancing (fate#315482)).
- sched/fair: Change "has_capacity" to "has_free_capacity"
  (Automatic NUMA Balancing (fate#315482)).
- sched/fair: Remove "power" from 'struct numa_stats' (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Fix task_numa_free() lockdep splat (Automatic NUMA
  Balancing (fate#315482)).
- sched/numa: Update migrate_improves/degrades_locality()
  (Automatic NUMA Balancing (fate#315482)).
- commit edcbe4f
* Thu Jun 26 2014 oneukum@suse.de
- Update
  patches.drivers/0067-usb-quiet-peer-failure-warning-disable-poweroff.patch
  (FATE#315518 bnc#879018).
- Delete
  patches.drivers/0047-USB-Avoid-runtime-suspend-loops-for-HCDs-that-can-t-.patch.
- Delete
  patches.drivers/0064-xhci-delete-endpoints-from-bandwidth-list-before-fre.patch.
- commit bd9868e
* Thu Jun 26 2014 tiwai@suse.de
- Update references
  patches.drivers/alsa-0002-control-Fix-replacing-user-controls
  (CVE-2014-4654,CVE-2014-4655,bnc#883795).
- commit 4df5381
* Thu Jun 26 2014 tiwai@suse.de
-  Update references with CVE
  patches.drivers/alsa-0001-control-Protect-user-controls-against-concurren
  (CVE-2014-4652,bnc#883795)
  patches.drivers/alsa-0002-control-Fix-replacing-user-controls
  (CVE-2014-4654,bnc#883795)
  patches.drivers/alsa-0003-control-Don-t-access-controls-outside-of-protec
  (CVE-2014-4653,bnc#883795)
  patches.drivers/alsa-0004-control-Handle-numid-overflow
  (CVE-2014-4656,bnc#883795)
  patches.drivers/alsa-0005-control-Make-sure-that-id-index-does-not-overfl
  (CVE-2014-4656,bnc#883795)
- commit 45181f2
* Thu Jun 26 2014 ohering@suse.de
- hyperv: fix apparent cut-n-paste error in send path teardown.
- commit 4ff1570
* Thu Jun 26 2014 jlee@suse.com
- Fix Patch-mainline
  Fix Patch-mainline: 3.15-rc1
- Refresh
  patches.suse/0001-Fix-module-signature-vs-tracepoints-add-new-TAINT_UNSIGNED_MODULE.patch.
- Refresh
  patches.suse/0002-Use-E-instead-of-X-for-unsigned-module-taint-flag.patch.
- commit 7597b3f
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Obsolete kernel-trace-base by kernel-default
  (bnc#884364)
- commit 568f3cc
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Explicitly list subpackages to obsolete
- commit 5595ce2
* Thu Jun 26 2014 jlee@suse.com
- KEYS: fix uninitialized persistent_keyring_register_sem
  (fate#314574).
- commit 9f77a72
* Thu Jun 26 2014 jlee@suse.com
- PNP / ACPI: Do not return errors if _DIS or _SRS are not present
  (fate#316836).
- ACPI / dock: Make 'docked' sysfs attribute work as documented
  (fate#316836).
- ACPI / container: Fix error code path in
  container_device_attach() (fate#316836).
- ACPI / dock: Use acpi_device_enumerated() to check if dock is
  present (fate#316836).
- ACPI / hotplug: Fix panic on eject to ejected device
  (fate#316836).
- ACPI / scan: Clear match_driver flag in acpi_bus_trim()
  (fate#316836).
- ACPI / scan: Use direct recurrence for device hierarchy walks
  (fate#316836).
- ACPI: Introduce acpi_set_device_status() (fate#316836).
- ACPI / hotplug: Drop unfinished global notification handling
  routines (fate#316836).
- commit 0d0672f
* Wed Jun 25 2014 spargaonkar@suse.com
- Update
  patches.drivers/hpsa-driver-vers-update-to-3.4.4-126.patch
  (bnc#884422).
  Fixed incorrect bnc#
- commit 6df433d
* Wed Jun 25 2014 spargaonkar@suse.com
- hpsa: Additional two new disk controller card ids (bnc#884420).
- commit 22c0041
* Wed Jun 25 2014 spargaonkar@suse.com
- hpsa: update driver version to 3.4.4-126 (bnc#867753).
- commit 99fb671
* Wed Jun 25 2014 mgorman@suse.de
- Refresh
  patches.suse/hugetlb-ensure-hugepage-access-is-denied-if-hugepages-are-not-supported.patch.
  patches.suse/mm-filemap-Avoid-unnecessary-barriers-and-waitqueue-lookups-in-unlock_page-fastpath.patch.
  patches.suse/mm-numa-Initialse-numa-balancing-after-jump-label-initialisation.patch.
- Delete
  patches.suse/mm-filemap-Avoid-unnecessary-barriers-and-waitqueue-lookups-fix.patch.
- commit 18c1b89
* Wed Jun 25 2014 mgorman@suse.de
- mm: madvise: fix MADV_WILLNEED on shmem swapouts
- mm: exclude memoryless nodes from zone_reclaim (bnc#863526).
- x86/mm: In the PTE swapout page reclaim case clear the accessed bit instead of flushing the TLB
  (VM/FS Performance).
- sched/numa: fix setting of cpupid on page migration twice
- mm: numa: recheck for transhuge pages under lock during protection changes
- mm/numa: Remove BUG_ON() in __handle_mm_fault()
  (Automatic NUMA Balancing (fate#315482)).
- mm: vmscan: do not throttle based on pfmemalloc reserves if node has no ZONE_NORMAL
  (bnc#870496).
- Delete
  patches.suse/mm-numa-Recheck-for-transhuge-pages-under-lock-during-protection-changes-fix.patch.
  patches.suse/mm-shmem.c-don-t-run-init_page_accessed-against-an-uninitialised-pointer.patch.
  patches.suse/mm-vmstat-Do-not-display-stats-for-TLB-flushes-unless-debugging.patch.
- Refresh
  patches.suse/callers-of-iov_copy_from_user_atomic-don-t-need-pagecache_disable.patch.
  patches.suse/cfq-Increase-default-value-of-target_latency.patch.
  patches.suse/fs-buffer-Do-not-use-unnecessary-atomic-operations-when-discarding-buffers.patch.
  patches.suse/fs-superblock-Avoid-locking-counting-inodes-and-dentries-before-reclaiming-them.patch.
  patches.suse/fs-superblock-Unregister-sb-shrinker-before-kill_sb.patch.
  patches.suse/jump_label-Expose-the-reference-count.patch.
  patches.suse/lib-plist-add-helper-functions.patch.
  patches.suse/lib-plist-add-plist_requeue.patch.
  patches.suse/lib-radix-tree-add-radix_tree_delete_item.patch.
  patches.suse/locking-rwsem-Fix-checkpatch.pl-warnings.patch.
  patches.suse/locking-rwsem-Fix-warnings-for-CONFIG_RWSEM_GENERIC_SPINLOCK.patch.
  patches.suse/mm-Avoid-unnecessary-atomic-operations-during-end_page_writeback.patch.
  patches.suse/mm-Do-not-use-atomic-operations-when-releasing-pages.patch.
  patches.suse/mm-Do-not-use-unnecessary-atomic-operations-when-adding-pages-to-the-LRU.patch.
  patches.suse/mm-Non-atomically-mark-page-accessed-during-page-cache-allocation-where-possible.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines-prep.patch.
  patches.suse/mm-Rearrange-zone-fields-into-read-only-page-alloc-statistics-and-page-reclaim-lines.patch.
  patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch.
  patches.suse/mm-disable-zone_reclaim_mode-by-default.patch.
  patches.suse/mm-filemap-move-radix-tree-hole-searching-here.patch.
  patches.suse/mm-fs-prepare-for-non-page-entries-in-page-cache-radix-trees.patch.
  patches.suse/mm-numa-Initialse-numa-balancing-after-jump-label-initialisation.patch.
  patches.suse/mm-numa-add-migrated-transhuge-pages-to-LRU-the-same-way-as-base-pages.patch.
  patches.suse/mm-numa-avoid-unnecessary-disruption-of-NUMA-hinting-during-migration-pmd-locking.patch.
  patches.suse/mm-numa-serialise-parallel-get_user_page-against-THP-migration-pmd-locking.patch.
  patches.suse/mm-page_alloc-Calculate-classzone_idx-once-from-the-zonelist-ref.patch.
  patches.suse/mm-page_alloc-Convert-hot-cold-parameter-and-immediate-callers-to-bool.patch.
  patches.suse/mm-page_alloc-Do-not-treat-a-zone-that-cannot-be-used-for-dirty-pages-as-full.patch.
  patches.suse/mm-page_alloc-Do-not-update-zlc-unless-the-zlc-is-active.patch.
  patches.suse/mm-page_alloc-Only-check-the-alloc-flags-and-gfp_mask-for-dirty-once.patch.
  patches.suse/mm-page_alloc-Only-check-the-zone-id-check-if-pages-are-buddies.patch.
  patches.suse/mm-page_alloc-Reduce-cost-of-dirty-zone-balancing.patch.
  patches.suse/mm-page_alloc-Reduce-cost-of-the-fair-zone-allocation-policy.patch.
  patches.suse/mm-page_alloc-Take-the-ALLOC_NO_WATERMARK-check-out-of-the-fast-path.patch.
  patches.suse/mm-page_alloc-Use-jump-labels-to-avoid-checking-number_of_cpusets.patch.
  patches.suse/mm-page_alloc-Use-unsigned-int-for-order-in-more-places.patch.
  patches.suse/mm-page_alloc-use-word-based-accesses-for-get-set-pageblock-bitmaps.patch.
  patches.suse/mm-pagemap-Avoid-unnecessary-overhead-when-tracepoints-are-deactivated.patch.
  patches.suse/mm-remove-read_cache_page_async.patch.
  patches.suse/mm-shmem-Avoid-atomic-operation-during-shmem_getpage_gfp.patch.
  patches.suse/mm-shmem-save-one-radix-tree-lookup-when-truncating-swapped-pages.patch.
  patches.suse/mm-vmscan-Do-not-reclaim-from-lower-zones-if-they-are-balanced.patch.
  patches.suse/mm-vmscan-Use-proportional-scanning-during-direct-reclaim-and-full-scan-at-DEF_PRIORITY.patch.
  patches.suse/rwsem-Support-optimistic-spinning.patch.
  patches.suse/sched-Move-wait-code-from-core.c-to-wait.c.patch.
  patches.suse/sched-numa-count-pages-on-active-node-as-local.patch.
  patches.suse/sched-numa-do-not-set-preferred_node-on-migration-to-a-second-choice-node.patch.
  patches.suse/sched-numa-retry-placement-more-frequently-when-misplaced.patch.
  patches.suse/swap-change-swap_info-singly-linked-list-to-list_head.patch.
  patches.suse/swap-change-swap_list_head-to-plist-add-swap_avail_head.patch.
  patches.suse/x86-Require-x86-64-for-automatic-NUMA-balancing.patch.
  patches.suse/x86-mm-Account-for-TLB-flushes-only-when-debugging.patch.
- commit 569575a
* Wed Jun 25 2014 jack@suse.cz
- printk: Remove spinning on console_sem (bnc#881681).
- commit 4cc82cc
* Wed Jun 25 2014 mmarek@suse.cz
- patches.kabi/kgr-0100-kabi-add-reserved-fields.patch: Rename fields to suse_kabi_padding
- commit ad035bb
* Wed Jun 25 2014 jkosina@suse.cz
- Refresh
  patches.arch/x86-be-more-informative-when-signalling-an-SMEP-fault.patch.
  Update mainline reference.
- commit 172cf8b
* Wed Jun 25 2014 mhocko@suse.cz
- Refresh
  patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
- commit 846728e
* Wed Jun 25 2014 duwe@suse.de
- Refresh
  patches.arch/powernv-192-Remove-superflous-function-descriptors-in-assembly-only-code.
- Refresh
  patches.arch/powernv-194-Fix-SMP-issues-with-ppc64le-ABIv2.
- Refresh patches.arch/powernv-210-Remove-PNV_EEH_STATE_REMOVED.
- Refresh
  patches.arch/powernv-211-Move-PNV_EEH_STATE_ENABLED-around.
- Refresh patches.arch/powernv-214-Use-EEH-PCI-config-accessors.
- Refresh
  patches.arch/ppc-Check-paca-psize-is-up-to-date-for-huge-mappings.
- Refresh
  patches.arch/ppc-Exported-functions-__clear_user-and-copy_page-use-r2.
- Refresh
  patches.arch/ppc-Fix-endian-issues-in-kexec-and-crash-dump.
- Refresh patches.arch/ppc-module-fix-.TOC.-symbol-CRC.
- Refresh patches.arch/ppc-no-R_PPC64_TOCSAVE-relocs.
- Refresh
  patches.arch/ppc-perf-01-create-bin_attribute-under-requested-group.
- Refresh patches.arch/ppc-perf-02-add-24x7-and-gpci-hvcalls.
- Refresh patches.arch/ppc-perf-03-add-hv_gpci-interface-header.
- Refresh patches.arch/ppc-perf-04-add-24x7-interface-headers.
- Refresh
  patches.arch/ppc-perf-05-add-gpci-shared-interface-for-version-and-caps.
- Refresh
  patches.arch/ppc-perf-06-add-event-fields-and-format-macros.
- Refresh patches.arch/ppc-perf-07-add-hv-gpci-support.
- Refresh patches.arch/ppc-perf-08-add-hv-24x7-support.
- Refresh patches.arch/ppc-perf-09-add-hypervisor-counter-kconfig.
- Refresh patches.arch/ppc-perf-10-add-dev-attr-documentation.
- Refresh
  patches.arch/ppc-perf-11-hv_24x7-probe-errors-changed-to-pr_debug.
- Refresh
  patches.arch/ppc-perf-12-hv_gpci-probe-failures-use-pr_debug.
- Refresh patches.arch/ppc-perf-13-gpci-make-device-attr-static.
- Refresh
  patches.arch/ppc-perf-14-24x7-use-unsigned-long-not-u32-value.
- Refresh
  patches.arch/ppc-perf-15-24x7-remove-static-4096-sparse-choke.
- Refresh patches.arch/ppc-selftests-for-previous-THP-bug.
- Refresh patches.arch/ppc64-boot-fix-do_div-wrapper.
- Refresh
  patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function.
- Refresh
  patches.arch/ppc64le-ELFv2-0008-Don-t-use-a-function-descriptor-for-system-call-table.
- Refresh
  patches.arch/ppc64le-ELFv2-0009-Remove-some-unnecessary-uses-of-_GLOBAL-and-_STATIC.
- Refresh
  patches.arch/ppc64le-ELFv2-0010-Remove-_INIT_GLOBAL-_STATIC-and-_INIT_STATIC.
- Refresh
  patches.arch/ppc64le-ELFv2-0011-Remove-dot-symbol-usage-in-exception-macros.
- Refresh
  patches.arch/ppc64le-ELFv2-0012-Create-DOTSYM-to-wrap-dot-symbol-usage.
- Refresh
  patches.arch/ppc64le-ELFv2-0013-Remove-function-descriptors-and-dot-symbols-on-new-ABI.
- Refresh
  patches.arch/ppc64le-ELFv2-0014-ABIv2-function-calls-must-place-target-address-in-r12.
- Refresh patches.arch/ppc64le-ELFv2-0015-Ignore-TOC-relocations.
- Refresh
  patches.arch/ppc64le-ELFv2-0016-Add-ABIv2-support-to-ppc_function_entry.
- Refresh
  patches.arch/ppc64le-ELFv2-0017-Use-ppc_function_entry-instead-of-open-coding-it.
- Refresh
  patches.arch/ppc64le-ELFv2-0018-Fix-branch-patching-code-for-ABIv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0019-Fix-kernel-thread-creation-on-ABIv2.
- Refresh patches.arch/ppc64le-ELFv2-0022-tm-Use-STK_PARAM.
- Refresh
  patches.arch/ppc64le-ELFv2-0023-tm-Fix-GOT-save-offset-for-ABIv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0024-tracing-TRACE_WITH_FRAME_BUFFER-creates-invalid-stack-frames.
- Refresh
  patches.arch/ppc64le-ELFv2-0026-Fix-ABIv2-issue-with-dereference_function_descriptor.
- Refresh
  patches.arch/ppc64le-ELFv2-0027-make-module-stub-code-endian-independent.
- Refresh
  patches.arch/ppc64le-ELFv2-0028-modules-implement-R_PPC64_TOCSAVE-relocation..
- Refresh patches.arch/ppc64le-ELFv2-0029-EXPORT_SYMBOL-.TOC..
- Refresh
  patches.arch/ppc64le-ELFv2-0030-module-handle-MODVERSION-for-.TOC..
- Refresh
  patches.arch/ppc64le-ELFv2-0031-Fix-up-TOC.-for-modules..
- Refresh
  patches.arch/ppc64le-ELFv2-0032-Handle-new-ELFv2-module-relocations.
- Refresh
  patches.arch/ppc64le-ELFv2-0033-modules-comment-about-de-dotifying-symbols-when-using-the-ELFv2-ABI..
- Refresh
  patches.arch/ppc64le-ELFv2-0034-modules-change-r2-save-restore-offset-for-ELFv2-ABI..
- Refresh
  patches.arch/ppc64le-ELFv2-0035-modules-use-r12-for-stub-jump-address..
- Refresh
  patches.arch/ppc64le-ELFv2-0036-modules-skip-r2-setup-for-ELFv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0037-modules-implement-stubs-for-ELFv2-ABI..
- Refresh
  patches.arch/ppc64le-ELFv2-0038-Build-little-endian-ppc64-kernel-with-ABIv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0040-Add-_GLOBAL_TOC-for-ABIv2-assembly-functions-exported-to-modules.
- Refresh
  patches.arch/ppc64le-ELFv2-0041-ftrace_caller-_mcount-is-exported-to-modules-so-needs-_GLOBAL_TOC.
- Refresh
  patches.arch/ppc64le-ELFv2-0042-kprobes-Fix-ABIv2-issues-with-kprobe_lookup_name.
- Refresh
  patches.arch/ppc64le-ELFv2-0043-modules-Create-is_module_trampoline.
- Refresh
  patches.arch/ppc64le-ELFv2-0044-modules-Create-module_trampoline_target.
- Refresh
  patches.arch/ppc64le-ELFv2-0045-ftrace-Use-module-loader-helpers-to-parse-trampolines.
- Refresh
  patches.arch/ppc64le-ELFv2-0046-ftrace-Fix-ABIv2-issues-with-__ftrace_make_call.
- Refresh patches.arch/ppc64le-userspace-bigendian-rtas-args.
- Refresh
  patches.arch/pseries-add-Gen3-definitions-for-PCIE-link-speed.
- Refresh patches.arch/pseries-expose-kernel-DT-update-to-drmgr.
- Refresh patches.arch/pseries-migrate-update-DT-only-once.
- Refresh patches.arch/pseries-resume-update-dynamic-cache-nodes.
- Refresh
  patches.drivers/bnx2x-Adapter-not-recovering-from-EEH-error-injection.
- Refresh
  patches.drivers/bnx2x-Fix-kernel-crash-and-data-miscompare-after-EEH-recovery.
- Refresh patches.drivers/ipr-add-grand-canyon-PCIIDs.
- Refresh patches.drivers/ipr-format-HCAM-overlay-0x21.
- Refresh patches.fixes/pci-hotplug-rphahp-fix-endianess-issues.
- Refresh patches.fixes/ppc-reenable-sendfile64.
- Refresh
  patches.fixes/pseries-exported-hcall-functions-need-_GLOBAL_TOC.
- Refresh patches.suse/disallow-ansi_cprng-for-FIPS-140-2.
- Refresh patches.suse/s390-hwrng-enable.
- commit dfd7fa6
* Wed Jun 25 2014 jbeulich@suse.com
- patches.fixes/bridge-module-get-put.patch,
  patches.suse/stack-unwind: Update Patch-mainline tag.
- commit 1e845b7
* Wed Jun 25 2014 jack@suse.cz
- Update headers:
  patches.suse/dmapi-xfs-printk-fix.patch.
  patches.suse/kernel-Avoid-softlockups-in-stop_machine-during-heav.patch.
  patches.suse/mm-dax-fault-futureproof.patch.
  patches.suse/printk-Hand-over-printing-to-console-if-printing-too.patch.
  patches.suse/printk-console_flush-fixup.diff.
- commit 03ef8c1
* Wed Jun 25 2014 jslaby@suse.cz
- Refresh
  patches.fixes/shmem-fix-faulting-into-a-hole-while-its-punched.patch.
  add upstream commit
- commit 1265456
* Wed Jun 25 2014 jslaby@suse.cz
- Update config files.
  Fix ppcle build. Nobody needed SENSORS_NTC_THERMISTOR until now, so I
  kept it N.
- commit 67eb30b
* Wed Jun 25 2014 oneukum@suse.de
- drivers: usb: core: hcd: moved asterix to variable
  (FATE#315518).
- drivers: usb: core: hcd: Whitespace fixes (FATE#315518).
- drivers: usb: core: hcd: replaced C99 // comments (FATE#315518).
- drivers: usb: core: hcd: removed braces for return statements
  (FATE#315518).
- drivers: usb: core: hcd: if-else-braces fixed (FATE#315518).
- usb: Remove unnecessary semicolons (FATE#315518).
- drivers: usb: core: hcd.c: converted busmap from struct to
  bitmap (FATE#315518).
- drivers: usb: core: hub.c: Comments shouldnt be C99 // comment
  style (FATE#315518).
- drivers: usb: core: devio.c: Spaces to tabs for
  proc_reapurbnonblock() (FATE#315518).
- drivers: usb: core: devio.c: Spaces to tabs for
  proc_control_compat() (FATE#315518).
- usb: hub_activate kill an 'else' (FATE#315518).
- usb: core: Remove superfluous name casts (FATE#315518).
- USB: core: correct spelling mistakes in comments and warning
  (FATE#315518).
- usb:hub set hub->change_bits when over-current happens
  (FATE#315518).
- usb: core: add sanity checks when using bInterfaceClass with
  new_id (FATE#315518).
- usb: core: allow a reference device for new_id (FATE#315518).
- usb: core: bail out if user gives an unknown RefId when using
  new_id (FATE#315518).
- usb: core: check for valid id_table when using the RefId feature
  (FATE#315518).
- usb: core: Fix potential memory leak adding dyn USBdevice IDs
  (FATE#315518).
- usb: core: let dynamic ids override static ids (FATE#315518).
- usb: move hub init and LED blink work to power efficient
  workqueue (FATE#315518).
- USB: complain if userspace resets an active endpoint
  (FATE#315518).
- usb: hub: usb_ext_cap_descriptor.bmAttributes is le32
  (FATE#315518).
- staging: usbip: claim ports used by shared devices
  (FATE#315518).
- usbcore: rename struct dev_state to struct usb_dev_state
  (FATE#315518).
- USB: disable reset-resume when USB_QUIRK_RESET is set
  (FATE#315518).
- usb: usb-common: fix typo for usb_state_string (FATE#315518).
- usb: remove redundant D0 power state set (FATE#315518).
- usb: move usb/usb-common.c to usb/common/usb-common.c
  (FATE#315518).
- USB: separate usb_address0 mutexes for each bus (FATE#315518).
- usb: pci_quirks: fix sparse 'symbol not declared' warning
  (FATE#315518).
- USB: mutual exclusion for resetting a hub and power-managing
  a port (FATE#315518).
- ACPI / bind: Simplify child device lookups (FATE#315518).
- PCI / ACPI: Use acpi_find_child_device() for child devices
  lookup (FATE#315518).
- ACPI: Eliminate the DEVICE_ACPI_HANDLE() macro (FATE#315518).
- ACPI: Eliminate the DEVICE_ACPI_HANDLE() macro (FATE#315518).
- ACPI / bind: Rework struct acpi_bus_type (FATE#315518).
- usb: hcd: Remove USB phy if needed (FATE#315518).
- usb: hcd: Initialize USB phy if needed (FATE#315518).
- usb: hcd: move controller wakeup setting initialization to
  individual driver (FATE#315518).
- usb: xhci: change enumeration scheme to 'new scheme' by default
  (FATE#315518).
- xhci: clarify logging in xhci_setup_device (FATE#315518).
- USB: core: remove CONFIG_USB_DEBUG usage (FATE#315518).
- hub: debug message for failing to enable device (FATE#315518).
- xhci: Prevent runtime pm from autosuspending during
  initialization (FATE#315518).
- staging: usbip: claim ports used by shared devices
  (FATE#315518).
- usbcore: rename struct dev_state to struct usb_dev_state
  (FATE#315518).
- USB: Avoid runtime suspend loops for HCDs that can't handle
  suspend/resume (FATE#315518).
- usb: disable port power control if not supported in
  wHubCharacteristics (FATE#315518).
- usb: rename usb_port device objects (FATE#315518).
- usb: cleanup setting udev->removable from port_dev->connect_type
  (FATE#315518).
- usb: assign default peer ports for root hubs (FATE#315518).
- usb: assign usb3 external hub port peers (FATE#315518).
- usb: find internal hub tier mismatch via acpi (FATE#315518).
- usb: sysfs link peer ports (FATE#315518).
- usb: make usb_port flags atomic, rename did_runtime_put to
  child_usage (FATE#315518).
- usb: block suspension of superspeed port while hispeed peer
  is active (FATE#315518).
- usb: don't clear FEAT_C_ENABLE on usb_port_runtime_resume
  failure (FATE#315518).
- usb: usb3 ports do not support FEAT_C_ENABLE (FATE#315518).
- usb: refactor port handling in hub_events() (FATE#315518).
- usb: synchronize port poweroff and khubd (FATE#315518).
- usb: introduce port status lock (FATE#315518).
- usb: hub_handle_remote_wakeup() depends on CONFIG_PM_RUNTIME=y
  (FATE#315518).
- usb: resume child device when port is powered on (FATE#315518).
- xhci: delete endpoints from bandwidth list before freeing
  whole device (FATE#315518).
- usb: hub_handle_remote_wakeup() only exists for CONFIG_PM=y
  (FATE#315518).
- usb: improve "not suspended yet" message in hub_suspend()
  (FATE#315518).
- usb: quiet peer failure warning, disable poweroff (FATE#315518).
- usb: fix hub-port pm_runtime_enable() vs runtime pm transitions
  (FATE#315518).
- noveau: Fix up nouveau_acpi (FATE#315518).
- Delete
  patches.drivers/0001-let-PortPowerOff-compile-without-CONFIG_PM.patch.
- Delete
  patches.drivers/0001-usb-assign-default-peer-ports-for-root-hubs.patch.
- Delete
  patches.drivers/0001-usb-assign-usb3-external-hub-port-peers.patch.
- Delete
  patches.drivers/0002-usb-find-internal-hub-tier-mismatch-via-acpi.patch.
- Delete patches.drivers/0003-usb-sysfs-link-peer-ports.patch.
- Delete
  patches.drivers/0004-usb-defer-suspension-of-superspeed-port-while-peer-i.patch.
- Delete
  patches.drivers/0005-usb-don-t-clear-FEAT_C_ENABLE-on-usb_port_runtime_re.patch.
- Delete
  patches.drivers/0006-usb-usb3-ports-do-not-support-FEAT_C_ENABLE.patch.
- Delete
  patches.drivers/0007-usb-refactor-port-handling-in-hub_events.patch.
- Delete
  patches.drivers/0008-usb-synchronize-port-poweroff-and-khubd.patch.
- Delete
  patches.drivers/0009-xhci-cancel-in-flight-resume-requests-when-the-port-.patch.
- Delete
  patches.drivers/0010-usb-introduce-port-status-lock.patch.
- Delete
  patches.drivers/0011-usb-guarantee-child-device-resume-on-port-poweron.patch.
- Delete
  patches.drivers/0012-usb-force-warm-reset-to-break-resume-livelock.patch.
- commit 0999023
* Wed Jun 25 2014 jslaby@suse.cz
- Linux 3.12.23 (CVE-2014-0131 CVE-2014-3917 Functionality VM
  bnc#867723 bnc#879258 bnc#880484 bnc#881535).
- Refresh
  patches.drivers/0141-target-silence-GCC-warning-in-target_alua_state_chec.patch.
- Refresh
  patches.drivers/0151-IB-isert-Initialize-T10-PI-resources.patch.
- Refresh
  patches.drivers/iommu-vt-d-clean-up-and-fix-page-table-clear-free-behaviour.patch.
- Refresh
  patches.drivers/iommu-vt-d-clean-up-size-handling-for-intel_iommu_unmap.patch.
- Refresh
  patches.drivers/qlcnic-0007-qlcnic-dcb-code-cleanup-and-refactoring.patch.
- Refresh
  patches.drivers/rtnetlink-provide-api-for-getting-and-setting-slave-.patch.
- Refresh patches.fixes/mei-revamp-mei-reset-state-machine.
- Refresh patches.fixes/net-generalize-skb_segment.patch.
- Refresh patches.xen/xen-clockevents.
- Delete
  patches.drivers/0001-xhci-extend-quirk-for-Renesas-cards.patch.
- Delete
  patches.fixes/0001-md-always-set-MD_RECOVERY_INTR-when-aborting-a-resha.patch.
- Delete
  patches.fixes/0002-md-always-set-MD_RECOVERY_INTR-when-interrupting-a-r.patch.
- Delete
  patches.fixes/auditsc-audit_krule-mask-accesses-need-bounds-checking.patch.
- Delete
  patches.fixes/floppy-do-not-corrupt-bio.bi_flags-when-reading-bloc.patch.
- Delete
  patches.fixes/sched-Fix-hotplug-vs-set_cpus_allowed_ptr.patch.
- Delete
  patches.fixes/sched-Use-CPUPRI_NR_PRIORITIES-instead-of-MAX_RT_PRIO-in-cpupri-check.patch.
- Delete
  patches.fixes/skbuff-skb_segment-orphan-frags-before-copying.patch.
- Delete patches.fixes/skbuff-skb_segment-s-frag-nskb_frag.patch.
- Delete patches.fixes/skbuff-skb_segment-s-fskb-list_skb.patch.
- Delete patches.fixes/skbuff-skb_segment-s-skb-head_skb.patch.
- Delete patches.fixes/skbuff-skb_segment-s-skb_frag-frag.patch.
- Delete
  patches.suse/btrfs-0243-fix-defrag-32-bit-integer-overflow.patch.
- Delete
  patches.suse/mm-compaction-detect-when-scanners-meet-in-isolate_freepages.patch.
- Delete
  patches.suse/mm-compaction-make-isolate_freepages-start-at-pageblock-boundary.patch.
- Delete
  patches.suse/mm-compaction-reset-cached-scanner-pfn-s-before-reading-them.patch.
- commit 4484b1d
* Wed Jun 25 2014 tiwai@suse.de
- ALSA: control: Make sure that id->index does not overflow
  (bnc#883795).
- ALSA: control: Handle numid overflow (bnc#883795).
- ALSA: control: Don't access controls outside of protected
  regions (bnc#883795).
- ALSA: control: Fix replacing user controls (bnc#883795).
- ALSA: control: Protect user controls against concurrent access
  (bnc#883795).
- commit 9201ee8
* Wed Jun 25 2014 jkosina@suse.cz
- Refresh patches.arch/x86-cpu-Allow-higher-NR_CPUS-values.patch.
- Refresh
  patches.arch/x86-cpu-Increase-max-CPU-count-to-8192.patch.
  Fix upstream references.
- commit 40ca1d8
* Wed Jun 25 2014 mgorman@suse.de
- mm: get rid of unnecessary pageblock scanning in setup_zone_migrate_reserve
- mm: Rearrange zone fields into read-only, page alloc, statistics and page reclaim lines -post
- mm: Rearrange zone fields into read-only, page alloc, statistics and page reclaim lines
- mm: Rearrange zone fields into read-only, page alloc, statistics and page reclaim lines -prep
- mm: vmscan: Do not reclaim from lower zones if they are balanced
- mm: page_alloc: Reduce cost of the fair zone allocation policy
- Update
  patches.suse/mm-pagemap-Avoid-unnecessary-overhead-when-tracepoints-are-deactivated.patch
  patches.suse/mm-page_alloc-Reduce-cost-of-dirty-zone-balancing.patch
  patches.suse/cfq-Increase-default-value-of-target_latency.patch
- Delete
  patches.suse/mm-page_alloc-Reset-fair-zone-allocation-policy-only-when-batch-counts-are-expired.patch.
- commit 0f2ba87
* Wed Jun 25 2014 pmladek@suse.cz
- Update headers:
  patches.fixes/printk-ignore-too-long-messages.patch.
  patches.fixes/printk-return-really-stored-message-length.patch.
  patches.fixes/printk-shrink-too-long-messages.patch.
  patches.fixes/printk-split-code-for-making-free-space-in-the-log-b.patch.
  patches.fixes/printk-split-message-size-computation.patch.
- commit 250d4e7
* Wed Jun 25 2014 pmladek@suse.cz
- Update header:
  patches.fixes/ftrace-x86-call-text_ip_addr-instead-of-the-duplicat.patch.
- commit 221d66c
* Wed Jun 25 2014 dchang@suse.com
- Refresh Patch-mainline tags:
  patches.drivers/be2net-0007-be2net-Log-a-kernel-message-when-UE-is-detected-in-B.patch.
  patches.drivers/be2net-0008-be2net-Update-copyright-year.patch.
  patches.drivers/cxgb4-0020-net-cxgb4-use-remove-handler-as-shutdown-handler.patch.
  patches.drivers/igb-0011-igb-Add-media-switching-feature-for-i354-PHY-s.patch.
  patches.drivers/igb-0012-igb-Support-ports-mapped-in-64-bit-PCI-space.patch.
  patches.drivers/igb-0013-igb-Add-new-feature-Media-Auto-Sense-for-82580-devic.patch.
  patches.drivers/igb-0014-igb-Convert-to-use-devm_hwmon_device_register_with_g.patch.
  patches.drivers/igb-0015-igb-Start-temperature-sensor-attribute-index-with-1.patch.
  patches.drivers/igb-0016-igb-Fix-queue-allocation-method-to-accommodate-chang.patch.
  patches.drivers/igb-0017-igb-Change-to-use-statically-allocated-array-for-MSI.patch.
  patches.drivers/igbvf-0006-net-igbvf-slight-optimization-of-addr-compare.patch.
  patches.drivers/mlx5-0005-net-IB-mlx-Bump-all-Mellanox-driver-versions.patch.
  patches.drivers/qlcnic-0005-qlcnic-cleanup-qlcnic_enable_msix-return-values.
  patches.drivers/qlcnic-0006-qlcnic-re-factor-firmware-minidump-template-header-handling.
  patches.drivers/qlcnic-0007-qlcnic-updates-to-qlogic-application-driver-interface-for-virtual-nic-configuration.
  patches.drivers/qlcnic-0008-qlcnic-enhance-driver-message-in-failed-state.
  patches.drivers/qlcnic-0009-qlcnic-allow-vlan0-traffic.
  patches.drivers/qlcnic-0010-qlcnic-Reset-firmware-API-lock-at-driver-load-time.patch.
  patches.drivers/qlcnic-0010-qlcnic-enhance-semaphore-lock-access-failure-error-message.
  patches.drivers/qlcnic-0011-qlcnic-Fix-memory-leak.patch.
  patches.drivers/qlcnic-0011-qlcnic-update-version-to-5-3-56.
  patches.drivers/qlcnic-0026-qlcnic-Disable-DCB-operations-from-SR-IOV-VFs.patch.
  patches.drivers/qlcnic-0027-qlcnic-Issue-INIT_NIC-command-only-once.patch.
  patches.drivers/qlcnic-0028-qlcnic-Refactor-initialize-nic-code-path.patch.
  patches.drivers/qlcnic-0029-qlcnic-Allow-single-Tx-Rx-queue-for-all-adapters.patch.
  patches.drivers/qlcnic-0030-qlcnic-VLAN-enhancement-for-84XX-adapters.patch.
  patches.drivers/qlcnic-0031-qlcnic-Support-for-16-virtual-NIC-functions.patch.
  patches.drivers/qlcnic-0032-qlcnic-update-version-to-5.3.53.patch.
- commit c861da4
* Wed Jun 25 2014 mhocko@suse.cz
- Refresh
  patches.suse/mm-exclude-memory-less-nodes-from-zone_reclaim.patch.
- commit 4ab30f1
* Wed Jun 25 2014 mhocko@suse.cz
- Refresh
  patches.suse/mm-disable-zone_reclaim_mode-by-default.patch.
- commit c150762
* Wed Jun 25 2014 acho@suse.com
- Update headers:
  patches.drivers/bnx2x-0001-bnx2x-utilize-FW-7.8.19.patch
  patches.drivers/tg3-0001-tg3-Override-clock-link-aware-and-link-idle-mode-dur.patch
- commit cac7ca1
* Wed Jun 25 2014 neilb@suse.de
- nfsd4: fix FREE_STATEID lockowner leak.
- Refresh patches.kernel.org/patch-3.12.3-4.
  Found by checking back-references to patches we already have.
- commit dea9518
* Tue Jun 24 2014 jack@suse.cz
- Update headers:
  patches.fixes/ext4-Fix-block-zeroing-when-punching-holes-in-indire.patch.
  patches.fixes/ext4-Fix-buffer-double-free-in-ext4_alloc_branch.patch.
  patches.fixes/ext4-Fix-hole-punching-for-files-with-indirect-block.patch.
  patches.fixes/ocfs2-Avoid-blocking-in-ocfs2_mark_lockres_freeing-i.patch.
  patches.fixes/ocfs2-Implement-delayed-dropping-of-last-dquot-refer.patch.
  patches.fixes/ocfs2-Move-dquot_initialize-in-ocfs2_delete_inode-so.patch.
  patches.fixes/ocfs2-Remove-OCFS2_INODE_SKIP_DELETE-flag.patch.
  patches.fixes/ocfs2-Revert-iput-deferring-code-in-ocfs2_drop_dentr.patch.
  patches.fixes/printk-fix-lockdep-instrumentation.patch.
  patches.fixes/quota-Provide-function-to-grab-quota-structure-refer.patch.
  patches.suse/fs-change-direct_access-calling-convention.patch.
  patches.suse/kernel-Avoid-softlockups-in-stop_machine-during-heav.patch.
  patches.suse/printk-Enable-interrupts-before-calling-console_tryl.patch.
  patches.suse/printk-Hand-over-printing-to-console-if-printing-too.patch.
  patches.suse/printk-Release-lockbuf_lock-before-calling-console_t.patch.
  patches.suse/printk-Remove-outdated-comment.patch.
  patches.suse/printk-Remove-separate-printk_sched-buffers-and-use-.patch.
  patches.suse/printk-console_flush-fixup.diff.
  Remove
  patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch.
  since we already have a different version of it from commit
  08142579b6ca35883c1ed066a2681de6f6917062.
- commit d06637a
* Tue Jun 24 2014 jbohac@suse.cz
- drivers/rtc/interface.c: fix infinite loop in initializing
  the alarm (bnc#871676).
- commit bfdd742
* Tue Jun 24 2014 mfasheh@suse.de
- Update patches.suse/btrfs-0404-account-shared-subtrees.patch
  (bnc#865621, bnc#884001).
- commit a90e13a
* Tue Jun 24 2014 ptesarik@suse.cz
- Refresh patches.suse/kexec-save-pg_head_mask-in-vmcoreinfo.
- commit 42c567f
* Tue Jun 24 2014 jack@suse.cz
- block: free q->flush_rq in blk_init_allocated_queue error paths.
- commit c560948
* Tue Jun 24 2014 duwe@suse.de
- Delete
  patches.arch/ppc64le-0021-Little-endian-fix-for-arch-powerpc-platforms.
  is identical to powernv-102... -- found by jslaby
- commit b11c463
* Tue Jun 24 2014 jroedel@suse.de
- intel_idle: fix IVT idle state table setting (bnc#881797).
- Refresh
  patches.arch/kvm-vmx-really-fix-lazy-fpu-on-nested-guest.patch.
- Refresh
  patches.drivers/intel_idle-fine-tune-ivt-residency-targets.
- commit 8759017
* Tue Jun 24 2014 jeffm@suse.de
- Patch-mainline updates.
- commit f0b0d9a
* Tue Jun 24 2014 mgorman@suse.de
- Wrong page freed on preallocate_pmds() failure exit
  (Automatic NUMA Balancing (fate#315482)).
- commit 929dab6
* Tue Jun 24 2014 jbohac@suse.cz
- Update Patch-mainline header:
- Refresh patches.arch/x86_64-hpet-64bit-timer.patch.
- Refresh
  patches.suse/0044-tipc-explicitly-include-core.h-in-addr.h.patch.
- Refresh
  patches.suse/0045-tipc-stricter-behavior-of-message-reassembly-functio.patch.
- Refresh
  patches.suse/0046-tipc-move-code-for-resetting-links-from-bearer.c-to-.patch.
- Refresh
  patches.suse/0047-tipc-move-code-for-deleting-links-from-bearer.c-to-l.patch.
- Refresh
  patches.suse/0048-tipc-redefine-started-flag-in-struct-link-to-bitmap.patch.
- Refresh
  patches.suse/0049-tipc-remove-links-list-from-tipc_bearer-struct.patch.
- Refresh
  patches.suse/0050-tipc-change-reception-of-tunnelled-duplicate-packets.patch.
- Refresh
  patches.suse/0051-tipc-change-reception-of-tunnelled-failover-packets.patch.
- Refresh
  patches.suse/0052-tipc-change-signature-of-tunnelling-reception-functi.patch.
- Refresh
  patches.suse/0053-tipc-more-cleanup-of-tunnelling-reception-function.patch.
- Refresh
  patches.suse/0054-tipc-rename-stack-variables-in-function-tipc_link_tu.patch.
- Refresh
  patches.suse/0055-tipc-changes-to-general-packet-reception-algorithm.patch.
- Refresh
  patches.suse/0056-tipc-delay-delete-of-link-when-failover-is-needed.patch.
- Refresh
  patches.suse/0057-tipc-remove-bearer_lock-from-tipc_bearer-struct.patch.
- Refresh
  patches.suse/0058-tipc-add-node_lock-protection-to-link-lookup-functio.patch.
- Refresh patches.suse/0059-tipc-fix-a-loop-style-problem.patch.
- Refresh
  patches.suse/0060-tipc-correct-usage-of-spin_lock-vs-spin_lock_bh.patch.
- Refresh
  patches.suse/0061-tipc-align-tipc-function-names-with-common-naming-pr.patch.
- Refresh
  patches.suse/0062-tipc-failed-transmissions-should-return-error.patch.
- Refresh
  patches.suse/0070-tipc-replace-reference-table-rwlock-with-spinlock.patch.
- Refresh
  patches.suse/0071-tipc-remove-redundant-peer_name-field-in-struct-tipc.patch.
- Refresh
  patches.suse/0072-tipc-aggregate-port-structure-into-socket-structure.patch.
- Refresh
  patches.suse/0073-tipc-eliminate-upcall-function-pointers-between-port.patch.
- Refresh
  patches.suse/0074-tipc-eliminate-redundant-locking.patch.
- Refresh
  patches.suse/0075-tipc-align-usage-of-variable-names-and-macros-in-soc.patch.
- Refresh
  patches.suse/0076-tipc-eliminate-redundant-lookups-in-registry.patch.
- Refresh patches.suse/netfilter-ip_conntrack_slp.patch.
- commit 3563a8c
* Tue Jun 24 2014 duwe@suse.de
- powerpc: module: fix TOC symbol CRC (bnc#881750).
- commit 17d489a
* Tue Jun 24 2014 mgorman@suse.de
- sched/numa: Drop sysctl_numa_balancing_settle_count sysctl
  (Automatic NUMA Balancing (fate#315482)).
- slab_common: fix the check for duplicate slab names (VM Functionality).
- Refresh
  patches.suse/thp-close-race-between-split-and-zap-huge-pages.patch.
- commit 284c7a6
* Tue Jun 24 2014 ddiss@suse.de
- Refresh patch-mainline tags
  patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
  patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- commit e6571a4
* Tue Jun 24 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-migrate.c-fix-setting-of-cpupid-on-page-migration-twice-against-normal-page.patch.
- commit 1f5ddd9
* Tue Jun 24 2014 mgorman@suse.de
- futex: update documentation for ordering guarantees
  (bnc#851603).
- commit ed4ee18
* Tue Jun 24 2014 hare@suse.de
- hpsa: Update patch tags
- Refresh
  patches.drivers/hpsa-0002-do-not-attempt-to-flush-the-cache-on-locked-up-.patch.
- Refresh
  patches.drivers/hpsa-0003-add-5-second-delay-after-doorbell-reset.patch.
- Refresh
  patches.drivers/hpsa-0004-remove-unneeded-include-of-seq_file.h.patch.
- Refresh
  patches.drivers/hpsa-0005-fix-memory-leak-in-CCISS_BIG_PASSTHRU-ioctl.patch.
- Refresh
  patches.drivers/hpsa-0006-add-MSA-2040-to-list-of-external-target-devices.patch.
- Refresh
  patches.drivers/hpsa-0009-cap-CCISS_PASSTHRU-at-20-concurrent-commands.patch.
- Refresh patches.drivers/hpsa-0010-prevent-stalled-i-o.patch.
- Refresh patches.drivers/hpsa-0011-remove-P822se-PCI-ID.patch.
- hpsa: add new Smart Array PCI IDs (May 2014)
  (bnc#857800,FATE#315359).
- Refresh
  patches.drivers/hpsa-0023-use-extended-report-luns-command-for-HP-SSD-Sma.patch.
- Refresh
  patches.drivers/hpsa-0024-mark-last-scatter-gather-element-as-the-last.patch.
- Refresh
  patches.drivers/hpsa-0025-add-support-for-fastpath-i-o.patch.
- Refresh
  patches.drivers/hpsa-0026-only-allow-REQ_TYPE_FS-to-use-fast-path.patch.
- Refresh
  patches.drivers/hpsa-0027-fix-task-management-for-mode-1-ioaccell-path.patch.
- Refresh
  patches.drivers/hpsa-0028-add-ioaccell-mode-1-RAID-offload-support.patch.
- Refresh
  patches.drivers/hpsa-0029-update-raid-offload-status-on-device-rescan.patch.
- Refresh
  patches.drivers/hpsa-0030-poll-controller-to-detect-device-change-event.patch.
- Refresh
  patches.drivers/hpsa-0031-do-not-rescan-controllers-known-to-be-locked-up.patch.
- Refresh
  patches.drivers/hpsa-0032-add-hp_ssd_smart_path_enabled-sysfs-attribute.patch.
- Refresh
  patches.drivers/hpsa-0033-complain-if-physical-or-logical-aborts-are-not-.patch.
- Refresh
  patches.drivers/hpsa-0034-add-ioaccel-mode-2-structure-definitions.patch.
- hpsa: Acknowledge controller events in ioaccell mode 2 as well
  as mode 1 (FATE#315359).
- Refresh
  patches.drivers/hpsa-0036-do-ioaccel-mode-2-resource-allocations.patch.
- hpsa: get physical device handles for io accel mode 2 as well
  as mode 1 (FATE#315359).
- Refresh
  patches.drivers/hpsa-0038-initialize-controller-to-perform-io-accelerator.patch.
- Refresh
  patches.drivers/hpsa-0039-get-ioaccel-mode-2-i-o-working.patch.
- Refresh
  patches.drivers/hpsa-0040-teach-hpsa_device_reset-to-do-either-target-or-.patch.
- Refresh
  patches.drivers/hpsa-0041-add-task-management-for-ioaccel-mode-2.patch.
- Refresh
  patches.drivers/hpsa-0042-make-device-update-copy-the-raid-map-also.patch.
- Refresh
  patches.drivers/hpsa-0043-complete-the-ioaccel-raidmap-code.patch.
- Refresh
  patches.drivers/hpsa-0044-allow-user-to-disable-accelerated-i-o-path.patch.
- Refresh
  patches.drivers/hpsa-0045-rescan-devices-on-ioaccel2-error.patch.
- Refresh
  patches.drivers/hpsa-0046-allow-VPD-page-zero-to-be-queried.patch.
- Refresh
  patches.drivers/hpsa-0047-do-not-inquire-for-unsupported-ioaccel-status-v.patch.
- Refresh
  patches.drivers/hpsa-0048-retry-certain-ioaccel-error-cases-on-the-RAID-p.patch.
- Refresh
  patches.drivers/hpsa-0049-update-source-file-copyrights.patch.
- hpsa: add controller base data-at-rest encryption compatibility
  ioaccel2 (FATE#315359).
- hpsa: when switching out of accel mode await only accel command
  completions (FATE#315359).
- Refresh
  patches.drivers/hpsa-0052-only-do-device-rescan-for-certain-events.patch.
- Refresh
  patches.drivers/hpsa-0053-improve-error-messages-for-driver-initiated-com.patch.
- Refresh
  patches.drivers/hpsa-0054-add-sysfs-debug-switch-for-raid-map-debugging-m.patch.
- Refresh
  patches.drivers/hpsa-0055-pci-add-HP-3PAR-vendor-id-to-pci_ids.h.patch.
- hpsa: Add support for a few HP Storage controllers
  (FATE#315359).
- Refresh
  patches.drivers/hpsa-0057-remove-unused-kthread.h-header.patch.
- Refresh
  patches.drivers/hpsa-0058-bring-format-in-progress-drives-online-when-rea.patch.
- hpsa: increase the probability of a reported success after a
  device reset (FATE#315359).
- Refresh
  patches.drivers/hpsa-0061-Add-hba-mode-to-the-hpsa-driver.patch.
- Refresh
  patches.drivers/hpsa-0062-Do-not-zero-fields-of-ioaccel2-command-structur.patch.
- Refresh
  patches.drivers/hpsa-0063-fix-bad-endif-placement-in-RAID-5-mapper-code.patch.
- commit f830f54
* Tue Jun 24 2014 ddiss@suse.de
- Refresh patch-mainline tags
  patches.fixes/cifs-Check-SMB3-dialects-against-downgrade-attacks.patch
- commit 52316a6
* Tue Jun 24 2014 jroedel@suse.de
- Refresh Patch-Mainline tags
  patches.drivers/iommu-amd-fix-enabling-exclusion-range-for-an-exact-device.
  patches.drivers/iommu-amd-handle-parallel-invalidate_range_start-end-calls-correctly.
  patches.drivers/iommu-amd-take-mmap_sem-when-calling-get_user_pages.
- commit a29f438
* Tue Jun 24 2014 mq@suse.cz
- Fix patch tags
- commit 54b6cac
* Tue Jun 24 2014 tiwai@suse.de
- Refresh patch-mainline tags
  patches.drivers/drm-i915-HD-audio-Don-t-continue-probing-when-nomode
  patches.drivers/hda-0036-Add-dock-pin-setups-for-Thinkpad-T440
  patches.fixes/cpumask.h-silence-warning-with-Wsign-compare
  patches.fixes/fbdev-fb.h-silence-warning-with-Wsign-compare
  patches.fixes/media-ivtv-Fix-Oops-when-no-firmware-is-loaded
  patches.fixes/pvpanic-Set-high-notifier-priority
- commit b3524e7
* Tue Jun 24 2014 mq@suse.cz
- removed an excessive blank line in a patch
- commit f8df74a
* Tue Jun 24 2014 bp@suse.de
- ACPI: Fix bug when ACPI reset register is implemented in system
  memory (bnc#882900).
- commit 507cf9d
* Tue Jun 24 2014 hare@suse.de
- fnic: Update patch tags and replace with upstream patch
- fnic: NoFIP solicitation frame in NONFIP mode and changed IO
  Throttle count (bnc#863364,FATE#315811).
- Refresh
  patches.drivers/fnic-Failing-to-queue-aborts-due-to-Q-full-cause-ter.patch.
- Refresh patches.drivers/fnic-Fnic-Ctlr-Path-Trace-Utility.patch.
- Refresh
  patches.drivers/fnic-Incremented-driver-version-to-1.6.0.10.patch.
- Delete
  patches.drivers/fnic-Changing-the-IO-Throttle-count-from-2048-to-256.patch.
- Delete
  patches.drivers/fnic-HDS-VMware-host-not-recovering-path-after-switc.patch.
- Delete
  patches.drivers/fnic-Sending-single-FIP-solicitation-frame-in-non-FI.patch.
- commit 1c8017b
* Tue Jun 24 2014 hare@suse.de
- Update patch tags
- Refresh
  patches.drivers/bfa-Driver-version-upgrade-to-3.2.23.0.patch.
- Refresh patches.drivers/bfa-Firmware-patch-simplification.patch.
- Refresh
  patches.drivers/bfa-Fix-for-bcu-or-hcm-faa-query-hang.patch.
- Refresh
  patches.drivers/bfa-LUN-discovery-issue-in-direct-attach-mode.patch.
- Refresh
  patches.drivers/bfa-Observed-auto-D-port-mode-instead-of-manual.patch.
- Refresh
  patches.drivers/bfa-Register-port-with-SCSI-even-on-port-init-f.patch.
- Refresh patches.drivers/bfa-change-FC_ELS_TOV-to-20sec.patch.
- Refresh patches.drivers/bfa-set-correct-scsi-returncode.
- commit 39aaf66
* Tue Jun 24 2014 dsterba@suse.cz
- Update patch tags.
- Refresh
  patches.suse/btrfs-0403-btrfs-add-trace-for-qgroup-accounting.patch.
- Refresh
  patches.suse/btrfs-8021-dev-delete-should-remove-sysfs-entry.patch.
- Refresh
  patches.suse/btrfs-8022-dev-add-should-add-its-sysfs-entry.patch.
- Refresh
  patches.suse/btrfs-8023-dev-replace-should-replace-the-sysfs-entry.patch.
- Refresh patches.suse/btrfs-update-message-levels.patch.
- commit 6f7f4a2
* Tue Jun 24 2014 bp@suse.de
- Refresh
  patches.arch/x86-boot-cleanup-header-s-by-removing-some-ifdefs.patch.
- Refresh
  patches.arch/x86-efi-check-status-field-to-validate-bgrt-header.patch.
- Refresh
  patches.arch/x86-efi-delete-dead-code-when-checking-for-non-native.patch.
- Refresh patches.arch/x86-efi-quirk-out-sgi-uv.patch.
- Refresh
  patches.arch/x86-mm-pageattr-always-dump-the-right-page-table-in-an-oops.patch.
- Refresh patches.arch/x86-tools-consolidate-ifdef-code.patch.
- Refresh
  patches.arch/x86-uv-set-n_lshift-based-on-gam_gr_config-mmr-for-uv3.patch.
- Refresh patches.fixes/printk-kmsg-Ratelimit-it.patch.
- commit d1e0ffb
* Tue Jun 24 2014 jroedel@suse.de
- iommu/vt-d: fix bug in handling multiple RMRRs for the same
  PCI device (bnc#879482).
- iommu/amd: Fix small race between invalidate_range_end/start
  (bnc#880670).
- commit 16aca10
* Tue Jun 24 2014 mgorman@suse.de
- x86, bitops: Correct the assembly constraints to testing bitops
  (Locking scalability).
- commit b8487f5
* Tue Jun 24 2014 mgorman@suse.de
- Refresh
  patches.suse/x86-Use-asm-goto-to-implement-better-modify_and_test-functions.patch.
- commit ab17ab5
* Tue Jun 24 2014 ohering@suse.de
- Refresh patch header
  patches.drivers/cxgb4-0036-RDMA-cxgb4-add-missing-padding-at-end-of-struct-c4iw.patch.
- commit a10e770
* Tue Jun 24 2014 neilb@suse.de
- SUNRPC: Don't create a gss auth cache unless rpc.gssd is
  running.
- commit b61d937
* Mon Jun 23 2014 mfasheh@suse.de
- Refresh
  patches.suse/btrfs-0403-btrfs-add-trace-for-qgroup-accounting.patch.
- Refresh patches.suse/btrfs-0404-account-shared-subtrees.patch.
- commit bf0f47e
* Mon Jun 23 2014 duwe@suse.de
- Refresh from upstream
  patches.arch/ppc64le-ELFv2-0020-Fix-ABIv2-issues-with-stack-offsets-in-assembly-code.
- Refresh from upstream
  patches.arch/ppc64le-ELFv2-0021-Fix-unsafe-accesses-to-parameter-area-in-ELFv2.
  => fixing bnc#883500
- commit 3bd6f76
* Mon Jun 23 2014 mmarek@suse.cz
- rpm/post.sh: Also check for grub2 config
- commit 0844541
* Mon Jun 23 2014 mmarek@suse.cz
- Port ppc64le packaging fixes from 'SLE12' to 'packaging'
- commit c233eb3
* Mon Jun 23 2014 ddiss@suse.de
- fs/cifs: Fix broken pathnames with mapchars (bnc#883750).
- commit 3c97bee
* Mon Jun 23 2014 vbabka@suse.cz
- shmem: fix faulting into a hole while it's punched (bnc#883518,
  CVE-2014-4171).
- commit d6fdb04
* Sun Jun 22 2014 bpoirier@suse.de
- RDMA/cxgb4: add missing padding at end of struct
  c4iw_alloc_ucontext_resp (bnc#863619 FATE#315951).
- commit 117c9a3
* Sun Jun 22 2014 bpoirier@suse.de
- ipv6: release dst properly in ipip6_tunnel_xmit (bnc#853494
  FATE#315918).
- ipv6: sit: update mtu check to take care of gso packets
  (bnc#853494 FATE#315918).
- inet: restore gso for vxlan (bnc#853494 FATE#315918).
- commit 250b180
* Sun Jun 22 2014 bpoirier@suse.de
- rename and move network core patches
- commit 882aac8
* Sun Jun 22 2014 bpoirier@suse.de
- mlx4_core: Fix incorrect FLAGS1 bitmap test in
  mlx4_QUERY_FUNC_CAP (bnc#858727 FATE#315946).
- net/mlx4_core: Don't issue PCIe speed/width checks for VFs
  (bnc#858727 FATE#315946).
- commit 48332f0
* Sat Jun 21 2014 bpoirier@suse.de
- macvlan: fix netdev feature propagation from lower device
  (bnc#846984 bnc#857401 FATE#315668).
- commit 451868e
* Sat Jun 21 2014 bpoirier@suse.de
- Refresh
  patches.drivers/macvlan-resolve-ENOENT-errors-on-creation.patch.
- Update
  patches.fixes/net-Add-layer-2-hardware-acceleration-operations-for.patch
  (bnc#846984 bnc#857401 FATE#315668).
- Delete
  patches.fixes/macvlan-introduce-IFF_MACVLAN-flag-and-helper-functi.patch.
  We accidentally did two partial backports of mainline commit a6cc0cfa7. Merge
  them together.
- commit 0d1556f
* Fri Jun 20 2014 bpoirier@suse.de
- sfc: PIO:Restrict to 64bit arch and use 64-bit writes
  (bnc#878114).
- Delete
  patches.drivers/sfc-0073-sfc-use-64-bit-writes-for-PIO.patch.
- Delete
  patches.drivers/sfc-0074-sfc-Restrict-PIO-to-64-bit-architectures.patch.
  Replace patches as first submitted upstream with version finally merged.
- commit 4bcb31a
* Fri Jun 20 2014 eich@suse.de
- drm/mgag200: Consolidate depth/bpp handling (bnc#882324).
- Delete
  patches.drivers/drm-mgag200-on-cards-with-2MB-VRAM-default-to-16-bit.patch.
- Add
  patches.drivers/drm-mgag200-Consolidate-depth-bpp-handling.patch
- commit 26dd00c
* Fri Jun 20 2014 jslaby@suse.cz
- Refresh patches.kabi/kgr-0100-kabi-add-reserved-fields.patch.
  Add a field to task_struct.
- commit 9381d07
* Fri Jun 20 2014 jslaby@suse.cz
- kabi: kgr, add reserved fields (fate#313296).
- Delete patches.suse/kgr-0100-kabi-add-reserved-fields.patch.
  Move to the appropriate dir (patches.kabi).
- commit 2984859
* Fri Jun 20 2014 mgalbraith@suse.de
- Disable CONFIG_RCU_FAST_NO_HZ
  Update config files.
- commit 4a301dd
* Fri Jun 20 2014 jslaby@suse.cz
- Refresh
  patches.fixes/sched-Make-scale_rt_power-deal-with-backward-clocks.patch.
- Refresh
  patches.suse/hugetlb-ensure-hugepage-access-is-denied-if-hugepages-are-not-supported.patch.
  Update upstream status
- commit 0915104
* Fri Jun 20 2014 mgalbraith@suse.de
- sched: Fix clock_gettime(CLOCK__CPUTIME_ID) monotonicity (bnc#880357).
- commit fab0e3c
* Fri Jun 20 2014 dchang@suse.com
- i40e: potential array underflow in i40e_vc_process_vf_msg()
  (bnc#857397 FATE#315659).
- commit f119f50
* Fri Jun 20 2014 dchang@suse.com
- ixgbevf: fix handling of tx checksumming (bnc#857402
  FATE#315667).
- commit 4d1d447
* Fri Jun 20 2014 dchang@suse.com
- net: allow netdev_all_upper_get_next_dev_rcu with rtnl lock held
  (bnc#857401 FATE#315668).
- commit 67afaeb
* Fri Jun 20 2014 dchang@suse.com
- igb: Unset IGB_FLAG_HAS_MSIX-flag when falling back to msi-only
  (bnc#857394 FATE#315661).
- igb: Fix Null-pointer dereference in igb_reset_q_vector
  (bnc#857394 FATE#315661).
- commit ac26d3d
* Fri Jun 20 2014 tonyj@suse.de
- perf: Document the new transaction sample type (FATE# 315534).
- commit 9ca2779
* Thu Jun 19 2014 bpoirier@suse.de
- skbuff: skb_segment: orphan frags before copying (bnc#867723
  CVE-2014-0131).
- skbuff: skb_segment: s/fskb/list_skb/ (bnc#867723
  CVE-2014-0131).
- skbuff: skb_segment: s/skb/head_skb/ (bnc#867723 CVE-2014-0131).
- skbuff: skb_segment: s/skb_frag/frag/ (bnc#867723
  CVE-2014-0131).
- skbuff: skb_segment: s/frag/nskb_frag/ (bnc#867723
  CVE-2014-0131).
- commit 162182d
* Thu Jun 19 2014 bpoirier@suse.de
- rename and move patch to "Networking Core" section
- commit 2874635
* Thu Jun 19 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-update-message-levels.patch.
  Adjust message levels to meet the real meaning, notably
  'skinny-metadata' is not an error.
- commit 875cc8f
* Thu Jun 19 2014 jslaby@suse.cz
- kabi: kgr, add reserved fields (fate#313296).
- commit 2dbb02b
* Thu Jun 19 2014 jslaby@suse.cz
- kgr: add MAINTAINERS entry (fate#313296).
- kgr: x86: refuse to build without fentry support (fate#313296).
- kgr: add procfs interface for per-process 'kgr_in_progress'
  (fate#313296).
- kgr: make a per-process 'in progress' flag a single bit
  (fate#313296).
- kgr: add support for missing functions (fate#313296).
- kgr: exercise non-present function (fate#313296).
- kgr: fix race of stub and patching (fate#313296).
- kgr: expose global 'in_progress' state through procfs
  (fate#313296).
- kgr: rephrase the "kGraft failed" message (fate#313296).
- kgr: x86: optimize handling of CPU-bound tasks (fate#313296).
- Refresh
  patches.suse/kgr-0001-ftrace-Add-function-to-find-fentry-of-function.patch.
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh patches.suse/kgr-0006-kgr-add-Documentation.patch.
- Refresh
  patches.suse/kgr-0008-kgr-sched.h-introduce-kgr_task_safe-helper.patch.
- Refresh
  patches.suse/kgr-0009-kgr-mark-task_safe-in-some-kthreads.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Delete patches.suse/kgr-0012-kgr-add-tools.patch.
- Delete patches.suse/kgr-0013-kgr-add-MAINTAINERS-entry.patch.
- Delete
  patches.suse/kgr-0014-kgr-x86-refuse-to-build-without-fentry-support.patch.
- Delete
  patches.suse/kgr-0015-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Delete
  patches.suse/kgr-0016-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Delete
  patches.suse/kgr-0017-kgr-add-support-for-missing-functions.patch.
- Delete
  patches.suse/kgr-0018-kgr-exercise-non-present-function.patch.
- Delete
  patches.suse/kgr-0019-kgr-fix-race-of-stub-and-patching.patch.
- Delete
  patches.suse/kgr-0020-kgr-expose-global-in_progress-state-through-procfs.patch.
  Update to the latest snapshot.
- commit 27ddce4
* Thu Jun 19 2014 bp@suse.de
- mm/memory-failure.c: support use of a dedicated thread to
  handle SIGBUS(BUS_MCEERR_AO) (bnc#882991).
- mm/memory-failure.c: don't let collect_procs() skip over
  processes for MF_ACTION_REQUIRED (bnc#882991).
- mm/memory-failure.c-failure: send right signal code to correct
  thread (bnc#882991).
- commit 6bf9a80
* Thu Jun 19 2014 mhocko@suse.cz
- Refresh patches.suse/memcg-change-oom_info_lock-to-mutex.patch.
- commit 03d0670
* Thu Jun 19 2014 mhocko@suse.cz
- cgroup: don't recycle cgroup id until all csses' have been
  destroyed (memcg changes).
- commit fdab0a1
* Thu Jun 19 2014 brogers@suse.com
- Refresh
  patches.arch/kvm-vmx-really-fix-lazy-fpu-on-nested-guest.patch.
- commit 6d2e813
* Wed Jun 18 2014 jack@suse.cz
- ext4: Fix hole punching for files with indirect blocks
  (bnc#881730).
- ext4: Fix block zeroing when punching holes in indirect block
  files (bnc#881730).
- commit 954ded5
* Wed Jun 18 2014 jbohac@suse.cz
- tipc: Let tipc_release() return 0 (fate#317088).
- neigh: set nud_state to NUD_INCOMPLETE when probing router
  (bnc#853162).
- commit 5e64d35
* Wed Jun 18 2014 jack@suse.cz
- block: fix q->flush_rq NULL pointer crash on dm-mpath flush.
- commit 16b7148
* Wed Jun 18 2014 jack@suse.cz
- block: change flush sequence list addition back to front add.
- xfs: keep sb_bad_features2 the same a sb_features2.
- xfs: truncate_setsize should be outside transactions.
- xfs: fix Q_XQUOTARM ioctl.
- xfs: xfs_readsb needs to check for magic numbers.
- xfs: bulletfproof xfs_qm_scall_trunc_qfiles().
- commit fdd883d
* Wed Jun 18 2014 pmladek@suse.cz
- printk: correct detection of the continuous buffer size (bnc#883067)
- commit 5509dc5
* Wed Jun 18 2014 duwe@suse.de
- powerpc/powernv: Pass buffer size to OPAL validate flash call
  (bnc#878240).
- powerpc: Fix 32-bit frames for signals delivered when
  transactional (bnc#863212).
- Refresh patches.arch/pseries-fix-regression-on-PCI-link-speed.
  (Add Commit ID)
- commit 4bb8949
* Wed Jun 18 2014 tiwai@suse.de
- Drop wrong fixes for ppc64le qemu VGA fb (bnc#882674)
  patches.drivers/0002-offb-Add-palette-hack-for-little-endian.patch
  patches.drivers/offb-Fix-little-endian-support
- commit 3c95105
* Wed Jun 18 2014 oneukum@suse.de
- uas: fix deadlocky memory allocations (FATE#315595).
- uas: fix error handling during scsi_scan() (FATE#315595).
- uas: fix GFP_NOIO under spinlock (FATE#315595).
- commit 8b2f293
* Wed Jun 18 2014 hare@suse.de
- Remove patches vetoed from upstream
- Delete
  patches.fixes/scsi-Do-not-complete-timed-out-command.patch.
- Delete
  patches.fixes/scsi_error-set-DID_TIME_OUT-correctly.patch.
- commit 4540c98
* Wed Jun 18 2014 hare@suse.de
- scsi/libiscsi: Fix static checker warning on bh locking.
- Refresh
  patches.drivers/qla4xxx-overflow-in-qla4xxx_set_chap_entry.
- commit a7c4bf3
* Wed Jun 18 2014 mgorman@suse.de
- mm: page_alloc: Reduce cost of dirty zone balancing (VM/FS
  Performance).
- mm: pagemap: Avoid unnecessary overhead when tracepoints are
  deactivated (VM/FS Performance).
- cfq: Increase default value of target_latency (VM/FS
  Performance).
- commit 0724082
* Wed Jun 18 2014 mgorman@suse.de
- mm: page_alloc: Reset fair zone allocation policy when batch counts are expired
  (VM/FS Performance).
- commit a6711dd
* Wed Jun 18 2014 jlee@suse.com
- rtc-efi: check for invalid data coming back from UEFI
  (bnc#879464).
- drivers/rtc/rtc-efi.c: avoid subtracting day twice when
  computing year days (bnc#879464).
- commit d053252
* Wed Jun 18 2014 mkubecek@suse.cz
- bonding: fix out of range parameters for bond_intmax_tbl
  (fate#316924 bnc#875631 bnc#876145).
- commit cf5bfb7
* Tue Jun 17 2014 mmarek@suse.cz
- Update patch headers
- patches.fixes/floppy-do-not-corrupt-bio.bi_flags-when-reading-bloc.patch
- commit 6a067f6
* Tue Jun 17 2014 jack@suse.cz
- fsnotify: Allocate overflow events with proper type
  (bnc#865838).
- fanotify: Handle overflow in case of permission events
  (bnc#865838).
- fsnotify: Fix detection whether overflow event is queued
  (bnc#865838).
- inotify: Fix reporting of cookies for inotify events
  (bnc#865838).
- fanotify: Fix use after free for permission events (bnc#865838).
- fsnotify: Do not return merged event from
  fsnotify_add_notify_event() (bnc#865838).
- fanotify: Fix use after free in mask checking (bnc#865838).
- fsnotify: remove pointless NULL initializers (bnc#865838).
- fsnotify: remove .should_send_event callback (bnc#865838).
- fsnotify: do not share events between notification groups
  (bnc#865838).
- inotify: provide function for name length rounding (bnc#865838).
- commit 26f1512
* Tue Jun 17 2014 tiwai@suse.de
- mei: me: do not reset when less than expected data is received
  (bnc#821619,bnc#852656).
- commit dbc174c
* Tue Jun 17 2014 tiwai@suse.de
- iwlwifi: mvm: BT Coex - fix Look Up Table (FATE#316958).
- iwlwifi: mvm: disable scheduled scan (FATE#316958).
- commit c121c43
* Tue Jun 17 2014 mmarek@suse.cz
- Fix: tracing: use 'E' instead of 'X' for unsigned module tain flag
- commit ef88b44
* Tue Jun 17 2014 dsterba@suse.cz
- Update patch tags
- Refresh patches.suse/btrfs-0400-rework-qgroup-accounting.patch.
- Refresh
  patches.suse/btrfs-0401-free-tmp-ulist-for-qgroup-rescan.patch.
- Refresh
  patches.suse/btrfs-0402-add-sanity-tests-for-new-qgroup-accounting-cod.patch.
- Refresh
  patches.suse/btrfs-8002-retrieve-more-info-from-FS_INFO-ioctl.patch.
- Refresh
  patches.suse/btrfs-8003-export-more-from-FS_INFO-to-sysfs.patch.
- Refresh
  patches.suse/btrfs-8004-make-DEV_INFO-ioctl-available-to-anyone.patch.
- Refresh
  patches.suse/btrfs-8005-make-FS_INFO-ioctl-available-to-anyone.patch.
- Refresh
  patches.suse/btrfs-8006-Add-ctime-mtime-update-for-btrfs-device-add-re.patch.
- Refresh
  patches.suse/btrfs-8007-output-warning-instead-of-error-when-loading-f.patch.
- Refresh
  patches.suse/btrfs-8008-Add-check-to-avoid-cleanup-roots-already-in-fs.patch.
- Refresh
  patches.suse/btrfs-8009-fix-wrong-max-system-array-size-check-in-kerne.patch.
- Refresh
  patches.suse/btrfs-8010-add-dev-maxs-limit-for-__btrfs_alloc_chunk-in-.patch.
- Refresh
  patches.suse/btrfs-8011-use-bitfield-instead-of-integer-data-type-for-.patch.
- Refresh
  patches.suse/btrfs-8012-btrfs_rm_device-should-zero-mirror-SB-as-well.patch.
- Refresh
  patches.suse/btrfs-8013-fix-possible-memory-leak-in-btrfs_create_tree.patch.
- Refresh
  patches.suse/btrfs-8014-make-sure-there-are-not-any-read-requests-befo.patch.
- Refresh
  patches.suse/btrfs-8015-fix-joining-same-transaction-handle-more-than-.patch.
- Refresh
  patches.suse/btrfs-8016-remove-OPT_acl-parse-when-acl-disabled.patch.
- Refresh
  patches.suse/btrfs-8017-fix-double-free-in-find_lock_delalloc_range.patch.
- Refresh
  patches.suse/btrfs-8018-usage-error-should-not-be-logged-into-system-l.patch.
- Refresh
  patches.suse/btrfs-8019-allocate-raid-type-kobjects-dynamically.patch.
- Refresh
  patches.suse/btrfs-8024-free-delayed-node-outside-of-root-inode_lock.patch.
- Refresh
  patches.suse/btrfs-8033-fix-use-of-uninit-ret-in-end_extent_writepage.patch.
- commit 6dbc95d
* Tue Jun 17 2014 mmarek@suse.cz
- Expand Git-commit: headers to full 40-digit commit ids
- commit d05c92f
* Tue Jun 17 2014 mmarek@suse.cz
- Fix some malformed Git-commit: headers
- commit 7fcdf2a
* Mon Jun 16 2014 eich@suse.de
- drm/ast: Initialize data needed to map fbdev memory (bmc#880007).
- Delete
  patches.drivers/drm-ast-Initialized-data-needed-to-map-fbdev-memory.patch.
- commit b95ad78
* Mon Jun 16 2014 jbeulich@suse.com
- Refresh patches.arch/x86_64-unwind-annotations (drop a bogus
  duplicate unwind statement).
- commit 8ac8303
* Mon Jun 16 2014 jdelvare@suse.de
- supported.conf: Remove all PCMCIA drivers
  We no longer build the PCMCIA drivers so they don't need a support
  status.
- commit 32eb02d
* Mon Jun 16 2014 duwe@suse.de
- Enable zcrypt hwrng for new API (fate#316346).
- commit 950c9f2
* Mon Jun 16 2014 tiwai@suse.de
- drm/i915, HD-audio: Don't continue probing when nomodeset is
  given (bnc#882648).
- commit 27f6211
* Mon Jun 16 2014 mmarek@suse.cz
- dlm: keep listening connection alive with sctp mode (bnc#881939)
- commit a7b7c46
* Mon Jun 16 2014 duwe@suse.de
  (fate#316346).
- patches.suse/hwrng-01-add-random-pool-input.
- patches.suse/hwrng-02-create-filler-thread.
- patches.suse/hwrng-03-make-khwrngd-configurable.
  + Move to patches.drivers
  + update to version accepted upstream
- commit 3305066
* Mon Jun 16 2014 jack@suse.cz
- Updated headers for
  patches.fixes/xfs-Fix-rounding-in-xfs_alloc_fix_len.patch
- commit 136f8c2
* Mon Jun 16 2014 ohering@suse.de
- hv: use correct order when freeing monitor_pages.
- Add support for netvsc build without CONFIG_SYSFS flag.
- commit 26c6067
* Mon Jun 16 2014 ohering@suse.de
- hv: update patch header, add mainline tags
- commit a5a28d1
* Fri Jun 13 2014 duwe@suse.de
- Move processing of MCE queued event out from syscall exit path (bnc#878240).
- Refresh patches.arch/powernv-136-Machine-check-exception-handling.
  Context changed because of the previous add.
- Refresh patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function
  - > move back closer to the original commit, with more changes (un-backport)-:
- commit ee1c2a2
* Fri Jun 13 2014 hare@suse.de
- scsi_dh_alua: use sdev_printk() for all messages (bnc#877544).
- commit 1fb4fc9
* Fri Jun 13 2014 mmarek@suse.cz
- Update config files: Disable serial joystick drivers (fate#317709)
- commit 9d1c7d4
* Fri Jun 13 2014 hare@suse.de
- scsi: Do not complete timed-out command (bnc#875415).
- scsi_error: set DID_TIME_OUT correctly (bnc#875415).
- scsi: set correct completion code in scsi_send_eh_cmnd()
  (bnc#875415).
- More USB deadlock fixes (bnc#875415).
- commit e4d5f6a
* Fri Jun 13 2014 jdelvare@suse.de
- supported.conf: Drop gameport drivers
  We no longer build these.
- commit 6dc93b1
* Fri Jun 13 2014 hare@suse.de
- Fix USB deadlock caused by SCSI error handling (bnc#875415).
- Fix command result state propagation (bnc#875415).
- Fix spurious request sense in error handling (bnc#875415).
- commit beb1439
* Fri Jun 13 2014 mmarek@suse.cz
- Update config files: Disable serial touch drivers (fate#317709)
- commit c080538
* Fri Jun 13 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build in a subdirectory of the source tree
  So that the build can use relative paths.
- commit 8eb070a
* Fri Jun 13 2014 mmarek@suse.cz
- powerpc: Avoid circular dependency with zImage.%%.
- um: Fix for relative objtree when generating x86 headers.
- kbuild: Use relative path when building in a subdir of the
  source tree.
- kbuild: Use relative path when building in the source tree.
- kbuild: Use relative path for $(objtree).
- firmware: Use $(quote) in the Makefile.
- commit 7de467b
* Fri Jun 13 2014 mmarek@suse.cz
- firmware: Simplify directory creation.
- Refresh
  patches.suse/0004-firmware_Install_firmware_signature_files_automatically.patch.
- commit af2d775
* Fri Jun 13 2014 mkubecek@suse.cz
- xfrm: fix race between netns cleanup and state expire
  notification (bnc#879957).
- commit 1d4fa36
* Fri Jun 13 2014 mkubecek@suse.cz
- teaming: fix vlan_features computing (bnc#872634).
- bonding: fix vlan_features computing (bnc#872634).
- vlan: more careful checksum features handling (bnc#872634).
- commit 1b56a64
* Fri Jun 13 2014 duwe@suse.de
- powerpc/book3s: Split the common exception prolog logic into
  two section (bnc#878240).
- commit 9220d86
* Fri Jun 13 2014 dsterba@suse.cz
- btrfs: fix use of uninit "ret" in end_extent_writepage().
- Btrfs: fix scrub_print_warning to handle skinny metadata
  extents.
- Btrfs: use right type to get real comparison.
- Btrfs: don't check nodes for extent items.
- Btrfs: fix leaf corruption after __btrfs_drop_extents.
- commit ec1b81c
* Fri Jun 13 2014 duwe@suse.de
- powerpc/book3s: Add flush_tlb operation in cpu_spec
  (bnc#878240).
- Refresh
  patches.arch/ppc-book3s-Introduce-early-machine-check-hook-in-cpu_spec.
- Refresh
  patches.arch/ppc-mce-1-book3s-Flush-SLB-TLBs-if-we-get-SLB-TLB-machine-check-errors-on-power7.
- Refresh
  patches.arch/ppc-mce-2-book3s-Flush-SLB-TLBs-if-we-get-SLB-TLB-machine-check-errors-on-power8.
- commit fd62bd2
* Fri Jun 13 2014 hare@suse.de
- hpsa: fix bug in figure_lunaddrbytes() (bnc#881621).
- commit 73d86f5
* Fri Jun 13 2014 duwe@suse.de
- Refresh
  patches.arch/ppc64le-0014-Alignment-handler-shouldn-t-access-VSX-regis.
  Missed the change from merge commit 3ad26e5c4459d3793ad65bc8929037c70515df83
- commit 8d27f9c
* Fri Jun 13 2014 hare@suse.de
- [SCSI] Derive the FLUSH_TIMEOUT from the basic I/O timeout
  (bnc#881409).
- commit 87ebdb4
* Fri Jun 13 2014 mgorman@suse.de
- numa,sched: fix load_to_imbalanced logic inversion
  (Scheduler scalability).
- commit 245fb52
* Fri Jun 13 2014 lduncan@suse.de
- libiscsi: Reduce locking contention in fast path. (bnc#871219)
- commit 737be8b
* Thu Jun 12 2014 tonyj@suse.de
- auditsc: audit_krule mask accesses need bounds checking
  (bnc#880484, CVE-2014-3917).
- commit 6a3ed21
* Thu Jun 12 2014 mgorman@suse.de
- x86: Use asm goto to implement better modify_and_test() functions
  (Locking scalability).
- commit ac7ba2f
* Thu Jun 12 2014 duwe@suse.de
- Refresh
  patches.fixes/pseries-exported-hcall-functions-need-_GLOBAL_TOC.
  Add commit ID
- commit 9e61330
* Thu Jun 12 2014 mgorman@suse.de
- locking/rwsem: Fix checkpatch.pl warnings (Locking scalability).
- locking/rwsem: Fix warnings for CONFIG_RWSEM_GENERIC_SPINLOCK
  (Locking scalability).
- commit d701f71
* Thu Jun 12 2014 mszeredi@suse.cz
- lock_parent: don't step on stale ->d_parent of all-but-freed
  one (bnc#874025, bnc#881085).
- commit 43cca15
* Thu Jun 12 2014 duwe@suse.de
- Refresh
  patches.drivers/bnx2x-Adapter-not-recovering-from-EEH-error-injection.
- commit e5da9bf
* Thu Jun 12 2014 duwe@suse.de
- bnx2x: Fix kernel crash and data miscompare after EEH recovery
  (bnc#881872).
- bnx2x: Adapter not recovery from EEH error injection
  (bnc#881872).
- commit 107f10f
* Thu Jun 12 2014 mmarek@suse.cz
- rpm/old-flavors: Drop ia64 and ppc/ppc64 entries
- commit aea75a4
* Thu Jun 12 2014 eich@suse.de
- drm/mgag200: on cards with < 2MB VRAM default to 16-bit (bnc#882324).
- commit 57b3e16
* Thu Jun 12 2014 duwe@suse.de
- selftests/powerpc: Test the THP bug we fixed in the previous
  commit (bnc#881903).
- powerpc/mm: Check paca psize is up to date for huge mappings
  (bnc#881903).
- powerpc: 64bit sendfile is capped at 2GB (bnc#881304).
- powerpc: Exported functions __clear_user and copy_page use r2
  so need _GLOBAL_TOC() (bnc#880938).
- commit 473bae5
* Thu Jun 12 2014 mgalbraith@suse.de
- sched: Add better debug output for might_sleep().
- commit 1a427f3
* Thu Jun 12 2014 mgorman@suse.de
- Don't trigger congestion wait on dirty-but-not-writeout pages
- Refresh patches.suse/NFS_LOOP_1_reclaim_throttle.patch.
  (VM Performance).
- commit 0816a25
* Thu Jun 12 2014 mmarek@suse.cz
- Drop PCMCIA (not CardBus) support (fate#317053)
- commit cd44ea7
* Thu Jun 12 2014 jlee@suse.com
- Update config files.
  Set CONFIG_EFI_VARS=m on x86_64 debug/default/vanilla. Put
  /usr/lib/efivars.conf to systemd rpm instead of build-in efivars
  kernel module. (bnc#881559)
- commit 3b873c8
* Thu Jun 12 2014 jkosina@suse.cz
- x86/smep:  Be more informative when signalling an SMEP fault.
- commit 3c17ee1
* Thu Jun 12 2014 mgalbraith@suse.de
- Scheduler audit
- Update config files
- Patches added:
  math64: Add mul_u64_u32_shr() (bnc#880357).
  sched/fair: Rework sched_fair time accounting (bnc#880357).
  sched: Adjust p->sched_reset_on_fork when nothing else changes.
  sched: Check TASK_DEAD rather than EXIT_DEAD in schedule_debug().
  sched: Check for idle task in might_sleep().
  sched: Consider pi boosting in setscheduler().
  sched: Fix hotplug vs. set_cpus_allowed_ptr().
  sched: Fix the rq->next_balance logic in rebalance_domains() and idle_balance().
  sched: Init idle->on_rq in init_idle().
  sched: Queue RT tasks to head when prio drops.
  sched: Remove double calculation in fix_small_imbalance().
  sched/cpupri: Replace NR_CPUS arrays.
  sched/fair: Fix tg_set_cfs_bandwidth() deadlock on rq->lock.
  sched, nohz: Exclude isolated cores from load balancing.
  sched/rt: Add accessors rq_of_rt_se().
  sched/rt: Do not try to push tasks if pinned task switches to RT.
  sched/rt: Substract number of tasks of throttled queues from rq->nr_running.
  sched/rt: Sum number of all children tasks in hierarhy at ->rt_nr_running.
  sched/numa: Fix period_slot recalculation (Automatic NUMA Balancing (fate#315482)).
  sched/numa: Use wrapper function task_faults_idx to calculate index in group_faults (Automatic NUMA Balancing (fate#315482)).
- Patches Refreshed:
  patches.suse/sched-fair-Stop-searching-for-tasks-in-newidle-balance-if-there-are-runnable-tasks.patch.
  patches.suse/sched-numa-count-pages-on-active-node-as-local.patch.
  patches.suse/sched-numa-do-not-set-preferred_node-on-migration-to-a-second-choice-node.patch.
  patches.suse/sched-numa-retry-placement-more-frequently-when-misplaced.patch.
  patches.suse/x86-Require-x86-64-for-automatic-NUMA-balancing.patch.
- commit 2fc379c
* Thu Jun 12 2014 jslaby@suse.cz
- Delete patches.fixes/md-strange-spin.fix.
  It is not needed after 0f62fb220aa4ebabe8547d3a9ce4a16d3c045f21, which
  came in through stable-3.12. See bnc#875386#c10.
- commit ebf5a63
* Thu Jun 12 2014 jjolly@suse.de
- Refresh
  patches.suse/pagecache-limit-fix-get_nr_swap_pages.patch.
- commit bce7760
* Thu Jun 12 2014 jjolly@suse.de
- Fix !CONFIG_SWAP build error with nr_swap_pages.
- commit 3f3fa7d
* Wed Jun 11 2014 eich@suse.de
- drm/ast: Add an crtc_disable callback to the crtc helper funcs.
- drm/ast: Simplify function ast_bo_unpin().
- drm/ast: Make local function ast_bo_unref() static.
- drm/ast: Initialized data needed to map fbdev memory
  (bmc#880007).
- drm/ast: Free container instead of member in
  ast_user_framebuffer_destroy().
- drm/ast: Fix memleaks in error path in ast_fb_create().
- drm/ast: Fix memleak in error path in ast_bo_create().
- commit 7b9113c
* Wed Jun 11 2014 spargaonkar@suse.com
- bnx2fc: Do not log error for netevents that need no action
  (bnc#880792).
- commit 366562d
* Wed Jun 11 2014 jack@suse.cz
- ext4: Fix buffer double free in ext4_alloc_branch() (bnc#880599
  bnc#876981).
- commit 77e28c6
* Wed Jun 11 2014 mhocko@suse.cz
- mm: add !pte_present() check on existing hugetlb_entry callbacks
  (bnc#881101, CVE-2014-3940).
- commit 404dfc4
* Wed Jun 11 2014 jslaby@suse.cz
- Linux 3.12.22 (bnc#855126 bnc#868315 bnc#870618 bnc#873061
  bnc#879452 bnc#880613 fixes oom).
- Refresh
  patches.arch/ACPI-Blacklist-Win8-OSI-for-some-HP-laptop-2013-mode.
- Refresh patches.arch/powernv-214-Use-EEH-PCI-config-accessors.
- Refresh patches.fixes/futex-Clean-up-various-details.patch.
- Refresh patches.fixes/md-strange-spin.fix.
- Delete
  patches.drivers/0001-USB-OHCI-fix-problem-with-global-suspend-on-ATI-cont.patch.
- Delete
  patches.drivers/drm-i915-Break-encoder-crtc-link-separately-in-intel_sanitize_crtc.patch.
- Delete
  patches.drivers/hda-0037-Fix-onboard-audio-on-Intel-H97-Z97-chipsets.
- Delete
  patches.drivers/iommu-amd-fix-interrupt-remapping-for-aliased-devices.
- Delete
  patches.fixes/ipmi-reset-the-KCS-timeout-when-starting-error-recovery.patch.
- Delete
  patches.fixes/timer-prevent-overflow-in-apply_slack.patch.
- Delete
  patches.suse/introduce-for_each_thread-to-replace-the-buggy-while.patch.
- Delete
  patches.suse/mm-oom-prefer-thread-group-leaders-for-display-purpo.patch.
- Delete
  patches.suse/oom_kill-add-rcu_read_lock-into-find_lock_task_mm.patch.
- Delete
  patches.suse/oom_kill-change-oom_kill.c-to-use-for_each_thread.patch.
- Delete
  patches.suse/oom_kill-has_intersects_mems_allowed-needs-rcu_read_.patch.
- commit ab77562
* Tue Jun 10 2014 jkosina@suse.cz
- Refresh
  patches.drivers/mlx4-use-GFP_NOFS-during-ipoib-tx-path.patch: update
  upstream references.
- commit a0c9183
* Tue Jun 10 2014 jjolly@suse.de
- Update
  patches.fixes/kernel-provide-a-__smp_call_function_single-stub-for-config_smp.patch
  (bnc#882104).
- commit 7c1d705
* Tue Jun 10 2014 jjolly@suse.de
- kernel-provide-a-__smp_call_function_single-stub-for-config_smp-fix.
- Refresh patches.fixes/flush-call-function-queue.
- commit 678a49c
* Tue Jun 10 2014 jjolly@suse.de
- sched: Move rtsched_debug parameter into CONFIG_SMP
  (bnc#882096).
- commit 22485ae
* Tue Jun 10 2014 jroedel@suse.de
- intel_idle: fine-tune IVT residency targets (bnc#881797).
- commit b409c9c
* Tue Jun 10 2014 duwe@suse.de
- Refresh
  patches.arch/ppc64le-0004-PTRACE_PEEKUSR-PTRACE_POKEUSER-of-FPR-regist.
  It broke in the huge PowerNV merge.
- Delete
  patches.arch/powernv-190-Adapt-opal-elog-and-opal-dump-to-new-sysfs_remove_file_self.
  It serves solely the adaption to the new sysfs API, which we don't have.
- commit 68f9f0c
* Tue Jun 10 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-reset-cached-scanner-pfn-s-before-reading-them.patch.
- Refresh
  patches.suse/mm-compaction-trace-compaction-begin-and-end.patch.
- commit 571b61b
* Tue Jun 10 2014 jbeulich@suse.com
- privcmd: actually batch hypercalls for batch ioctls.
- swiotlb: don't assume PA 0 is invalid (bnc#865882).
- Update Xen patches to 3.12.21.
- commit 69251d0
* Tue Jun 10 2014 neilb@suse.de
- md: always set MD_RECOVERY_INTR when interrupting a reshape
  thread (bnc#881535).
- md: always set MD_RECOVERY_INTR when aborting a reshape or other
  "resync" (bnc#881535).
- commit 8c65f88
* Mon Jun  9 2014 mmarek@suse.cz
- Disable GAMEPORT support and controller drivers that depend on it
  Gameport cards are nearly nonexistent nowadays. USB adapters for the
  controllers exist, but these appear as a standard HID device to the OS.
- commit 03de848
* Mon Jun  9 2014 mmarek@suse.cz
- supported.conf: Move drivers/input/joystick/* to kernel-*-extra
- commit 3ee8c0f
* Mon Jun  9 2014 mmarek@suse.cz
- supported.conf: Move serio touchscreen drivers to kernel-extra
  (bnc#868821)
- commit 520b8fa
* Sat Jun  7 2014 mgorman@suse.de
- sched/numa: Decay ->wakee_flips instead of zeroing (Scheduler
  scalability).
- sched: Fix exec_start/task_hot on migrated tasks (Scheduler
  scalability).
- sched/fair: Stop searching for tasks in newidle balance if
  there are runnable tasks (Scheduler scalability).
- sched/numa: Initialize newidle balance stats in sd_numa_init()
  (Scheduler scalability).
- sched/numa: Allow task switch if load imbalance improves
  (Scheduler scalability).
- commit 0a48739
* Fri Jun  6 2014 duwe@suse.de
- powerpc/book3s: Introduce a early machine check hook in cpu_spec
  (bnc#878240).
- commit 19bee89
* Fri Jun  6 2014 duwe@suse.de
- powerpc/book3s: Introduce exclusive emergency stack for machine
  check exception (bnc#878240).
- commit d1058f4
* Fri Jun  6 2014 duwe@suse.de
- Update config files:
  disable all PATA chips on ppc64le
- commit a3fb051
* Fri Jun  6 2014 duwe@suse.de
- powerpc: add explicit OF includes (bnc#878240,FATE#315784).
- powerpc: Little endian fixes for platforms/powernv/opal.c
  (bnc#878240,FATE#315784).
- powerpc: Little endian fix for
  arch/powerpc/platforms/powernv/pci.c (bnc#878240,FATE#315784).
- powerpc: Little endian fix for
  arch/powerpc/platforms/powernv/pci-p5ioc2.c
  (bnc#878240,FATE#315784,bnc#856774 fate#315275, LTC#92305).
- powerpc: Little endian sparse clean up for
  arch/powerpc/platforms/powernv/pci-ioda.c
  (bnc#878240,FATE#315784,bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix endian issues in OPAL RTC driver
  (bnc#878240,FATE#315784).
- powerpc/powernv: Make OPAL NVRAM device tree accesses endian
  safe (bnc#878240,FATE#315784).
- powerpc/powernv: Fix endian issues in powernv PCI code
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix endian issues in OPAL console and udbg
  backend (bnc#878240,FATE#315784).
- powerpc/powernv: Fix OPAL entry and exit in little endian mode
  (bnc#878240,FATE#315784).
- powerpc/powernv: Don't register exception handlers in little
  endian mode (bnc#878240,FATE#315784).
- powerpc/powernv: More little endian issues in OPAL RTC driver
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix some PCI sparse errors and one LE bug
  (bnc#878240,FATE#315784).
- powerpc: Implement arch_get_random_long/int() for powernv
  (bnc#878240,FATE#315784).
- powerpc/powernv: Add scom support under OPALv3
  (bnc#878240,FATE#315784).
- powerpc/powernv: Enable EEH for PHB3 (bnc#878240,FATE#315784).
- powerpc/powernv: Support inbound error injection
  (bnc#878240,FATE#315784).
- powerpc/eeh: Output error number (bnc#878240,FATE#315784).
- powerpc/powernv: Double size of log blob
  (bnc#878240,FATE#315784).
- powerpc/eeh: Output PHB3 diag-data (bnc#878240,FATE#315784).
- powerpc: add real mode support for dma operations on powernv
  (bnc#878240,FATE#315784).
- powerpc: Add includes to fix powernv/rng.c build
  (bnc#878240,FATE#315784).
- powerpc: Use 32 bit loads and stores when operating on condition
  register values (bnc#878240,FATE#315784,bnc#863764 fate#315275,
  LTC#103998).
- powerpc/powernv: Create opal sysfs directory
  (bnc#878240,FATE#315784).
- powerpc/powernv: Code update interface (bnc#878240,FATE#315784).
- powerpc/scom: Enable 64-bit addresses (bnc#878240,FATE#315784).
- powerpc/powernv: Add support for indirect XSCOM via debugfs
  (bnc#878240,FATE#315784).
- powerpc/powernv: Reserve the correct PE number
  (bnc#878240,FATE#315784).
- powerpc: Make cpu_to_chip_id() available when SMP=n
  (bnc#878240,FATE#315784).
- powerpc/powernv: Replace CONFIG_POWERNV_MSI with just
  CONFIG_PPC_POWERNV (bnc#878240,FATE#315784).
- powerpc/book3s: Decode and save machine check event
  (bnc#878240,FATE#315784).
- powerpc/book3s: Queue up and process delayed MCE events
  (bnc#878240,FATE#315784).
- powerpc/powernv: Remove machine check handling in OPAL
  (bnc#878240,FATE#315784).
- powerpc/powernv: Machine check exception handling
  (bnc#878240,FATE#315784).
- powerpc/powernv: Infrastructure to read opal messages in
  generic format (bnc#878240,FATE#315784).
- powerpc/powernv: Move SG list structure to header file
  (bnc#878240,FATE#315784).
- PPC: POWERNV: move iommu_add_device earlier
  (bnc#878240,FATE#315784).
- powerpc/powernv: Move PHB-diag dump functions around
  (bnc#878240,FATE#315784).
- powerpc/eeh: Output PHB diag-data (bnc#878240,FATE#315784).
- powernv: Remove get/set_rtc_time when they are not present
  (bnc#878240,FATE#315784).
- powerpc/powernv: Get FSP memory errors and plumb into memory
  poison infrastructure (bnc#878240,FATE#315784).
- powernv: Fix VFIO support with PHB3 (bnc#878240,FATE#315784).
- powerpc/powernv: Fix endian issue in opal_xscom_read
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix OPAL LPC access in Little Endian
  (bnc#878240,FATE#315784).
- powernv/eeh: Add buffer for P7IOC hub error data
  (bnc#878240,FATE#315784).
- powerpc/iommu: Update constant names to reflect their hardcoded
  page size (bnc#878240,FATE#315784).
- powerpc/iommu: Add it_page_shift field to determine iommu page
  size (bnc#878240,FATE#315784).
- powerpc/iommu: Update the generic code to use dynamic iommu
  page sizes (bnc#878240,FATE#315784).
- powerpc: Delete non-required instances of include <linux/init.h>
  (bnc#878240,FATE#315784).
- powerpc/powernv: Remove unnecessary assignment
  (bnc#878240,FATE#315784).
- powerpc/eeh: Add restore_config operation
  (bnc#878240,FATE#315784).
- powerpc/eeh: Call opal_pci_reinit() on powernv for restoring
  config space (bnc#878240,FATE#315784).
- powerpc/powernv: Increase candidate fw image size
  (bnc#878240,FATE#315784).
- powerpc/eeh: Escalate error on non-existing PE
  (bnc#878240,FATE#315784).
- powerpc/powernv: Call OPAL sync before kexec'ing
  (bnc#878240,FATE#315784).
- powerpc/powernv/cpuidle: Back-end cpuidle driver for powernv
  platform (bnc#878240,FATE#315784).
- powerpc/powernv: Add iommu DMA bypass support for IODA2
  (bnc#878240,FATE#315784).
- powerpc/eeh: Cleanup on eeh_subsystem_enabled
  (bnc#878240,FATE#315784).
- powerpc/eeh: Disable EEH on reboot (bnc#878240,FATE#315784).
- cpuidle/powernv: Remove redundant cpuidle_idle_call()
  (bnc#878240,FATE#315784).
- powerpc/powernv: Dump PHB diag-data immediately
  (bnc#878240,FATE#315784).
- powerpc/powernv: Refactor PHB diag-data dump
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix indirect XSCOM unmangling
  (bnc#878240,FATE#315784).
- powerpc/powernv: Add OPAL call to resync timebase on wakeup
  (bnc#878240,FATE#315784).
- powerpc/book3s: Recover from MC in sapphire on SCOM read via
  MMIO (bnc#878240,FATE#315784).
- powerpc/powernv: Read OPAL error log and export it through sysfs
  (bnc#878240,FATE#315784).
- powerpc/powernv Platform dump interface
  (bnc#878240,FATE#315784).
- powerpc/powernv: Infrastructure to support OPAL async completion
  (bnc#878240,FATE#315784).
- powerpc/powernv: Enable reading and updating of system
  parameters (bnc#878240,FATE#315784).
- powerpc/powernv: Enable fetching of platform sensor data
  (bnc#878240,FATE#315784,bnc#875242).
- powerpc/powernv: Add opal_notifier_unregister() and export to
  modules (bnc#878240,FATE#315784).
- powerpc/powernv: Fix endian issues with OPAL async code
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix endian issues with sensor code
  (bnc#878240,FATE#315784).
- powerpc/book3s: Fix mc_recoverable_range buffer overrun issue
  (bnc#878240,FATE#315784).
- powerpc/powernv: Add OPAL message log interface
  (bnc#878240,FATE#315784).
- powerpc/powernv: Add invalid OPAL call (bnc#878240,FATE#315784).
- powerpc/powernv Adapt opal-elog and opal-dump to new
  sysfs_remove_file_self (bnc#878240,FATE#315784).
- powerpc: Remove superflous function descriptors in assembly
  (bnc#878240,FATE#315784).
- powerpc: Fix SMP issues with ppc64le ABIv2
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix sysparam sysfs error handling
  (bnc#878240,FATE#315784).
- powerpc/powernv: Use ssize_t for sysparam return values
  (bnc#878240,FATE#315784).
- powerpc/powernv: Check sysfs size before copying
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix typos in sysparam code
  (bnc#878240,FATE#315784).
- powerpc/powernv: Check sysparam size before creation
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix kexec races going back to OPAL
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix little endian issues in OPAL flash code
  (bnc#878240,FATE#315784).
- powerpc/powernv: Reduce multi-hit of iommu_add_device()
  (bnc#878240,FATE#315784).
- powerpc/powernv: Release the refcount for pci_dev
  (bnc#878240,FATE#315784).
- powerpc/powernv: Use uint64_t instead of size_t in OPAL APIs
  (bnc#878240,FATE#315784).
- powerpc/powernv: Fix little endian issues with opal_do_notifier
  calls (bnc#878240,FATE#315784).
- powerpc/powernv: Fix little endian issues in OPAL error log code
  (bnc#878240,FATE#315784).
- powerpc/powernv: Create OPAL sglist helper functions and fix
  endian issues (bnc#878240,FATE#315784).
- powerpc/powernv: Fix little endian issues in OPAL dump code
  (bnc#878240,FATE#315784).
- ppc/powernv: Set the runlatch bits correctly for offline cpus
  (bnc#878240,FATE#315784).
- powerpc/powernv: Remove PNV_EEH_STATE_REMOVED
  (bnc#878240,FATE#315784).
- powerpc/powernv: Move PNV_EEH_STATE_ENABLED around
  (bnc#878240,FATE#315784).
- powerpc/powernv: Use EEH PCI config accessors
  (bnc#878240,FATE#315784).
- powerpc/book3s: Return from interrupt if coming from evil
  context (bnc#878240,FATE#315784).
- powerpc/book3s: handle machine check in Linux host
  (bnc#878240,FATE#315784).
- powerpc/book3s: Flush SLB/TLBs if we get SLB/TLB machine check
  errors on power7 (bnc#878240,FATE#315784).
- powerpc/book3s: Flush SLB/TLBs if we get SLB/TLB machine check
  errors on power8 (bnc#878240,FATE#315784).
- powerpc: Fix "attempt to move .org backwards" error
  (bnc#878240,FATE#315784).
- powerpc/pseries/cpuidle: Move processor_idle.c to
  drivers/cpuidle (bnc#878240,FATE#315784).
- Update config files: add PowerNV + pseries cpuidle
- Refresh
  patches.arch/ppc-iommu-Dont-detach-device-without-IOMMU-group.
- Refresh
  patches.arch/ppc-put-FP_VSX-and-VR-state-into-structures.
- Refresh
  patches.arch/ppc64le-0003-Fix-offset-of-FPRs-in-VSX-registers-in-littl.
- Refresh
  patches.arch/ppc64le-0004-PTRACE_PEEKUSR-PTRACE_POKEUSER-of-FPR-regist.
- Refresh patches.arch/ppc64le-0011-Endian-safe-trampoline.
- Refresh
  patches.arch/ppc64le-0014-Alignment-handler-shouldn-t-access-VSX-regis.
- Refresh
  patches.arch/ppc64le-0015-Add-little-endian-support-to-alignment-handl.
- Refresh
  patches.arch/ppc64le-0016-Handle-VSX-alignment-faults-in-little-endian.
- Refresh
  patches.arch/ppc64le-0021-Little-endian-fix-for-arch-powerpc-platforms.
- Refresh
  patches.arch/ppc64le-ELFv2-0006-No-need-to-use-dot-symbols-when-branching-to-a-function.
- Refresh
  patches.arch/ppc64le-ELFv2-0009-Remove-some-unnecessary-uses-of-_GLOBAL-and-_STATIC.
- Update
  patches.arch/ppc64le-ELFv2-0011-Remove-dot-symbol-usage-in-exception-macros
  (bnc#863764 fate#315275,LTC#103998,).
- Refresh
  patches.arch/ppc64le-ELFv2-0019-Fix-kernel-thread-creation-on-ABIv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0020-Fix-ABIv2-issues-with-stack-offsets-in-assembly-code.
- Refresh
  patches.arch/ppc64le-ELFv2-0021-Fix-unsafe-accesses-to-parameter-area-in-ELFv2.
- Refresh
  patches.arch/ppc64le-ELFv2-0040-Add-_GLOBAL_TOC-for-ABIv2-assembly-functions-exported-to-modules.
- Refresh patches.fixes/ptrace-getsiginfo.
- Delete patches.arch/powerpc-powernv-Create-opal-sysfs-directory.
- Delete
  patches.arch/powerpc-powernv-Enable-fetching-of-platform-sensor-data.
- Delete
  patches.arch/powerpc-powernv-Enable-reading-and-updating-of-system-parameters.
- Delete
  patches.arch/powerpc-powernv-Fix-endian-issues-with-OPAL-async-code.
- Delete
  patches.arch/powerpc-powernv-Fix-endian-issues-with-sensor-code.
- Delete
  patches.arch/powerpc-powernv-Infrastructure-to-read-opal-messages-in-generic-format.
- Delete
  patches.arch/powerpc-powernv-Infrastructure-to-support-OPAL-async-completion.
- Delete
  patches.arch/ppc64le-0020-Little-endian-fixes-for-platforms-powernv-op.
- Delete
  patches.arch/ppc64le-0022-Little-endian-fix-for-arch-powerpc-platforms.
- Delete
  patches.arch/ppc64le-0023-Little-endian-sparse-clean-up-for-arch-power.
- Delete
  patches.arch/ppc64le-0024-powernv-Fix-endian-issues-in-OPAL-RTC-driver.
- Delete
  patches.arch/ppc64le-0026-powernv-Make-OPAL-NVRAM-device-tree-accesses.
- Delete
  patches.arch/ppc64le-0027-powernv-Fix-endian-issues-in-powernv-PCI-cod.
- Delete
  patches.arch/ppc64le-0028-powernv-Fix-endian-issues-in-OPAL-console-an.
- Delete
  patches.arch/ppc64le-0029-powernv-Fix-OPAL-entry-and-exit-in-little-en.
- Delete
  patches.arch/ppc64le-0030-powernv-Don-t-register-exception-handlers-in.
- Delete
  patches.arch/ppc64le-0031-powernv-More-little-endian-issues-in-OPAL-RT.
- Delete
  patches.arch/ppc64le-0032-powernv-Fix-some-PCI-sparse-errors-and-one-L.
- Delete
  patches.arch/ppc64le-ELFv2-0001-Use-32-bit-loads-and-stores-when-operating-o.
- Delete
  patches.arch/ppc64le-ELFv2-0007-Remove-superflous-function-descriptors-in-assembly-only-code.
- Delete
  patches.arch/ppc64le-ELFv2-0025-Fix-SMP-issues-with-ppc64le-ABIv2.
- commit 73a043a
* Fri Jun  6 2014 oneukum@suse.de
- Update
  patches.drivers/0001-USB-OHCI-fix-problem-with-global-suspend-on-ATI-cont.patch
  (bnc#868315).
- commit 40d844a
* Fri Jun  6 2014 oneukum@suse.de
- USB: OHCI: fix problem with global suspend on ATI controllers
  (bnc#881717).
- commit 078fd1e
* Fri Jun  6 2014 mszeredi@suse.cz
- get rid of s_files and files_lock (bnc#880612).
- uninline destroy_super(), consolidate alloc_super()
  (bnc#880612).
- commit 0c81a3d
* Fri Jun  6 2014 hare@suse.de
- scsi_scan: Fix stall during probing
  Refresh
  patches.fixes/scsi_scan-Send-TEST-UNIT-READY-to-LUN0-before-LUN-sc.patch.
- commit b5e29c4
* Thu Jun  5 2014 mfasheh@suse.de
- Btrfs: rework qgroup accounting (bnc#865621).
- Btrfs: free tmp ulist for qgroup rescan (bnc#865621).
- Btrfs: add sanity tests for new qgroup accounting code
  (bnc#865621).
- btrfs: add trace for qgroup accounting (bnc#865621).
- btrfs: qgroup: account shared subtrees during snapshot delete
  (bnc#865621).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 0ccf15d
* Thu Jun  5 2014 jack@suse.cz
- xfs: Fix rounding in xfs_alloc_fix_len() (bnc#875503).
- commit df84d6e
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/package-descriptions: Cleanup packages that are not part of SLE12
- commit 7225a95
* Thu Jun  5 2014 mmarek@suse.cz
- Remove x86 32bit-only conditionals from the specfiles
- commit 38bda8e
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/package-descriptions: kernel-vmi is gone
- rpm/mkspec: Obsolete $flavor-{devel,extra} $flavor-base is obsolete
  (bnc#881490)
- rpm/kernel-module-subpackage: Obsolete -trace KMPs (bnc#881490)
- rpm/old-flavors: Obsolete also kernel-trace-base (bnc#881490)
- commit 38d4d09
* Thu Jun  5 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-add-per-zone-migration-pfn-cache-for-async-compaction.patch.
- Refresh
  patches.suse/mm-compaction-avoid-rescanning-pageblocks-in-isolate_freepages.patch.
- Refresh
  patches.suse/mm-compaction-cleanup-isolate_freepages.patch.
- Refresh
  patches.suse/mm-compaction-do-not-count-migratepages-when-unnecessary.patch.
- Refresh
  patches.suse/mm-compaction-embed-migration-mode-in-compact_control.patch.
- Refresh
  patches.suse/mm-compaction-properly-signal-and-act-upon-lock-and-need_sched-contention.patch.
- Refresh
  patches.suse/mm-compaction-return-failed-migration-target-pages-back-to-freelist.patch.
- Refresh
  patches.suse/mm-compaction-terminate-async-compaction-when-rescheduling.patch.
- Refresh
  patches.suse/mm-migration-add-destination-page-freeing-callback.patch.
- Refresh
  patches.suse/mm-page_alloc-prevent-MIGRATE_RESERVE-pages-from-being-misplaced.patch.
- commit 50fb944
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require hmaccalc on 13.1 and earlier
- commit d7a84f7
* Thu Jun  5 2014 mgorman@suse.de
- rwsem: Support optimistic spinning (Locking scalability).
- asmlinkage: Mark rwsem functions that can be called from
  assembler asmlinkage (Locking scalability).
- commit ddf3ae8
* Thu Jun  5 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-cleanup-isolate_freepages.patch.
- Delete (fold into above)
  patches.suse/mm-compaction-cleanup-isolate_freepages-fix3.patch.
- commit 53d2b79
* Thu Jun  5 2014 mgorman@suse.de
- arch: Clean up asm/barrier.h implementations using asm-generic/barrier.h
- arch: Introduce smp_load_acquire(), smp_store_release()
- locking: Move mcs_spinlock.h into kernel/locking/
- locking/mutexes/mcs: Correct barrier usage
- locking/mutexes/mcs: Restructure the MCS lock defines and locking code into its own file
- Refresh
  patches.suse/locking-mutex-Fix-debug-checks.patch.
  patches.suse/locking-mutex-Fix-debug_mutexes.patch.
  patches.suse/locking-mutexes-Introduce-cancelable-MCS-lock-for-adaptive-spinning.patch.
  patches.suse/locking-mutexes-Modify-the-way-optimistic-spinners-are-queued.patch
  patches.suse/locking-mutexes-Return-false-if-task-need_resched-in-mutex_can_spin_on_owner.patch.
  patches.suse/locking-mutexes-Unlock-the-mutex-without-the-wait_lock.patch.
  patches.suse/mutexes-Give-more-informative-mutex-warning-in-the-lock-owner-case.patch.
  (Locking scalability).
- commit 5963795
* Thu Jun  5 2014 ptesarik@suse.cz
- ACPI / memhotplug: add parameter to disable memory hotplug
  (bnc#881091).
- Refresh patches.xen/xen-mem-hotplug.
- commit f6c6b61
* Thu Jun  5 2014 pmladek@suse.cz
- ftrace/x86/xen: use kernel identity mapping only when really
  needed (bnc#873195).
- commit d42672d
* Thu Jun  5 2014 hare@suse.de
- scsi: Handle power-on reset unit attention (FATE#315120,
  bnc#852358).
- scsi_scan: Send TEST UNIT READY to LUN0 before LUN scanning
  (bnc#843236).
- commit 5dede7b
* Wed Jun  4 2014 bpoirier@suse.de
- cnic: Fix missing ISCSI_KEVENT_IF_DOWN message (bnc#876696).
- cnic: Don't take cnic_dev_lock in cnic_alloc_uio_rings()
  (bnc#876696).
- cnic: Don't take rcu_read_lock in cnic_rcv_netevent()
  (bnc#876696).
- commit c43d942
* Wed Jun  4 2014 jeffm@suse.de
- hpsa: fix memory leak in hpsa_hba_mode_enabled (bnc#881202).
- commit c2fe940
* Wed Jun  4 2014 pmladek@suse.cz
- ftrace/x86: call text_ip_addr() instead of the duplicated code
  (bnc#873195).
- commit b056b56
* Wed Jun  4 2014 mgorman@suse.de
- locking: Move the lglocks code to kernel/locking/
- locking: Move the lockdep code to kernel/locking/
- locking: Move the mutex code to kernel/locking/
- locking: Move the percpu-rwsem code to kernel/locking/
- locking: Move the rtmutex code to kernel/locking/
- locking: Move the rwsem code to kernel/locking/
- locking: Move the semaphore core to kernel/locking/
- locking: Move the spinlock code to kernel/locking/
- Refresh
  patches.suse/locking-mutex-Fix-debug-checks.patch.
  patches.suse/locking-mutex-Fix-debug_mutexes.patch.
  patches.suse/locking-mutexes-Introduce-cancelable-MCS-lock-for-adaptive-spinning.patch.
  patches.suse/locking-mutexes-Modify-the-way-optimistic-spinners-are-queued.patch.
  patches.suse/locking-mutexes-Return-false-if-task-need_resched-in-mutex_can_spin_on_owner.patch.
  patches.suse/locking-mutexes-Unlock-the-mutex-without-the-wait_lock.patch.
  patches.suse/mutexes-Give-more-informative-mutex-warning-in-the-lock-owner-case.patch.
  patches.suse/0025-KEYS-Separate-the-kernel-signature-checking-keyring-.patch
  patches.xen/xen3-patch-2.6.30
- commit c59e2b3
* Wed Jun  4 2014 jslaby@suse.cz
- Refresh
  patches.suse/oom_kill-change-oom_kill.c-to-use-for_each_thread.patch.
  Fix SHA.
- commit 178041e
* Wed Jun  4 2014 mszeredi@suse.cz
- dcache: add missing lockdep annotation (bnc#874025, bnc#881085).
- dcache: don't need rcu in shrink_dentry_list() (bnc#874025,
  bnc#881085).
- dealing with the rest of shrink_dentry_list() livelock
  (bnc#874025, bnc#881085).
- dentry_kill() doesn't need the second argument now (bnc#874025,
  bnc#881085).
- dentry_kill(): don't try to remove from shrink list (bnc#874025,
  bnc#881085).
- don't remove from shrink list in select_collect() (bnc#874025,
  bnc#881085).
- expand dentry_kill(dentry, 0) in shrink_dentry_list()
  (bnc#874025, bnc#881085).
- expand the call of dentry_lru_del() in dentry_kill()
  (bnc#874025, bnc#881085).
- fold __d_shrink() into its only remaining caller (bnc#874025,
  bnc#881085).
- fold d_kill() and d_free() (bnc#874025, bnc#881085).
- fold try_prune_one_dentry() (bnc#874025, bnc#881085).
- fold try_to_ascend() into the sole remaining caller (bnc#874025,
  bnc#881085).
- lift the "already marked killed" case into shrink_dentry_list()
  (bnc#874025, bnc#881085).
- more graceful recovery in umount_collect() (bnc#874025,
  bnc#881085).
- new helper: dentry_free() (bnc#874025, bnc#881085).
- shrink_dentry_list(): take parent's ->d_lock earlier
  (bnc#874025, bnc#881085).
- split dentry_kill() (bnc#874025, bnc#881085).
- switch shrink_dcache_for_umount() to use of d_walk()
  (bnc#874025, bnc#881085).
- Delete patches.fixes/dcache-soft-lockup.fix.
- Delete
  patches.fixes/dentry_kill-dont-try-to-remove-from-shrink-list.patch.
- Delete
  patches.fixes/dont-remove-from-shrink-list-in-select_collect.patch.
- commit 29e40f2
* Wed Jun  4 2014 trenn@suse.de
- This already seem to be in the kernel:
  Delete patches.drivers/pcc_cpufreq_modalias.patch.
- commit 547564d
* Wed Jun  4 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Allow find-debuginfo.sh to create vmlinux.debug
- commit 9b3c48f
* Tue Jun  3 2014 bpoirier@suse.de
- Move
  patches.drivers/tg3-0001-tg3-Override-clock-link-aware-and-link-idle-mode-dur.patch
  together with the other tg3 patches
- commit 0e6268a
* Tue Jun  3 2014 mgalbraith@suse.de
- sched: Fix up /proc/sched_debug to print only runnable tasks again.
- commit 09cb207
* Tue Jun  3 2014 dsterba@suse.cz
- Delete patches.suse/btrfs-8020-ensure-readers-see-new-data-after-a-clone-oper.patch
- commit 27f93f7
* Mon Jun  2 2014 jjolly@suse.de
- net/mlx4_core: Defer VF initialization till PF is fully
  initialized (bnc#874501).
- commit af1b6ef
* Mon Jun  2 2014 mgorman@suse.de
- mm: filemap: Avoid unnecessary barriers and waitqueue lookups -fix
  (VM/FS Performance).
- commit c9f7e35
* Mon Jun  2 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit 50aa57c
* Mon Jun  2 2014 mmarek@suse.cz
- Drop the -trace flavor (fate#317165)
- commit 29a5c1e
* Mon Jun  2 2014 mmarek@suse.cz
- Obsolete kernel-trace by kernel-default
- commit 1eb3f59
* Mon Jun  2 2014 hare@suse.de
- virtio_scsi: fix race issue between tmf and command completion
  (bnc#875415).
- commit f8ac1ed
* Mon Jun  2 2014 jdelvare@suse.de
- supported.conf: Add mei-me as supported (fate#315504, bnc#865556)
- commit 669ac8e
* Mon Jun  2 2014 jslaby@suse.cz
- Linux 3.12.21 (FATE#315595 FATE#315918 bnc#853494).
- Refresh
  patches.drivers/bonding-add-netlink-attributes-to-slave-link-dev.patch.
- Refresh
  patches.drivers/bonding-convert-netlink-to-use-slave-data-info-api.patch.
- Refresh
  patches.drivers/bonding-push-Netlink-bits-into-separate-file.patch.
- Refresh
  patches.drivers/mlx-0018-net-mlx4_en-Datapath-resources-allocated-dynamically.patch.
- Refresh
  patches.drivers/mlx-0020-net-mlx4_en-Datapath-structures-are-allocated-per-NU.patch.
- Refresh
  patches.drivers/rtnetlink-provide-api-for-getting-and-setting-slave-.patch.
- Refresh
  patches.suse/mm-Use-ptep-pmdp_set_numa-for-updating-_PAGE_NUMA-bit.patch.
- Delete
  patches.drivers/0004-xhci-For-streams-the-css-flag-most-be-read-from-the-.patch.
- Delete
  patches.drivers/bnx2x-0024-list-introduce-list_next_entry-and-list_prev_entry.patch.
- Delete patches.fixes/scsi-dual-scan-thread-bug-fix.patch.
- Delete
  patches.fixes/scsi-fix-our-current-target-reap-infrastructure.patch.
- Delete
  patches.suse/mm-use-paravirt-friendly-ops-for-NUMA-hinting-ptes.patch.
- commit e06b089
* Mon Jun  2 2014 jdelvare@suse.de
- Update x86_64 config files: Disable CONFIG_XO15_EBOOK
  The xo15-ebook driver is only useful on (32-bit) OLPC machines.
- commit 181e76d
* Mon Jun  2 2014 mgorman@suse.de
- Refresh
  patches.drivers/bnx2x-0024-list-introduce-list_next_entry-and-list_prev_entry.patch.
  patches.suse/lib-plist-add-helper-functions.patch.
- commit 6d2a7f3
* Fri May 30 2014 hare@suse.de
- scsi_dh_alua: Use vpd_pg83 information (bnc#880356).
- ses: Use vpd information from scsi_device (bnc#880356).
- Add EVPD page 0x83 and 0x80 to sysfs (bnc#880356).
- Return VPD page length in scsi_vpd_inquiry() (bnc#880356).
- scsi_sysfs: Implement 'is_visible' callback (bnc#880356).
- commit bcc1e3a
* Fri May 30 2014 jack@suse.cz
- printk: fix lockdep instrumentation of console_sem.
- commit 3c43dc5
* Fri May 30 2014 ptesarik@suse.cz
- kexec: save PG_head_mask in VMCOREINFO (bnc#873232).
- Delete patches.suse/kdump-save-PG_compound.
- commit e9086e6
* Fri May 30 2014 dsterba@suse.cz
- btrfs: free delayed node outside of root->inode_lock
  (bnc#866864).
- btrfs: dev replace should replace the sysfs entry.
- btrfs: dev add should add its sysfs entry.
- btrfs: dev delete should remove sysfs entry.
- commit e8a5b28
* Fri May 30 2014 jroedel@suse.de
- iommu/amd: Handle parallel invalidate_range_start/end calls correctly (bnc#880670).
- commit b3bc423
* Fri May 30 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-page_alloc-Reset-fair-zone-allocation-policy-only-when-batch-counts-are-expired.patch.
- commit bac5afd
* Fri May 30 2014 tiwai@suse.de
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  (bnc#880613).
- commit d1e4994
* Fri May 30 2014 ohering@suse.de
- Update
  patches.suse/msft-hv-0619-x86-platform-hyperv-Handle-VMBUS-driver-being-a-modu.patch
  (bnc#879210).
- commit f6276c9
* Thu May 29 2014 dsterba@suse.cz
- Btrfs update
- btrfs: retrieve more info from FS_INFO ioctl.
- btrfs: export more from FS_INFO to sysfs.
- btrfs: make DEV_INFO ioctl available to anyone.
- btrfs: make FS_INFO ioctl available to anyone.
- btrfs: Add ctime/mtime update for btrfs device add/remove.
- Btrfs: output warning instead of error when loading free space
  cache failed.
- btrfs: Add check to avoid cleanup roots already in
  fs_info->dead_roots.
- btrfs: fix wrong max system array size check in kernel space.
- btrfs: add dev maxs limit for __btrfs_alloc_chunk in kernel
  space.
- Btrfs: use bitfield instead of integer data type for the some
  variants in btrfs_root.
- btrfs: btrfs_rm_device() should zero mirror SB as well.
- Btrfs: fix possible memory leak in btrfs_create_tree().
- Btrfs: make sure there are not any read requests before
  stopping workers.
- Btrfs: fix joining same transaction handle more than twice.
- Btrfs: remove OPT_acl parse when acl disabled.
- Btrfs: fix double free in find_lock_delalloc_range.
- btrfs: usage error should not be logged into system log.
- btrfs: allocate raid type kobjects dynamically.
- Btrfs: ensure readers see new data after a clone operation.
- Delete
  patches.suse/btrfs-8036-make-DEV_INFO-ioctl-available-to-anyone.patch.
- Delete
  patches.suse/btrfs-8037-make-FS_INFO-ioctl-available-to-anyone.patch.
- commit b9ca132
* Thu May 29 2014 mgorman@suse.de
- mm: page_alloc: Reset fair zone allocation policy only when batch counts are expired
  (VM/FS Performance).
- commit 3d1bf02
* Thu May 29 2014 ohering@suse.de
- x86/platform/hyperv: Handle VMBUS driver being a module.
- commit 9aaa1ca
* Thu May 29 2014 acho@suse.com
- tg3: Override clock, link aware and link idle mode during
  NVRAM dump (bnc#855657).
- commit 43940c9
* Thu May 29 2014 brogers@suse.com
- KVM: vmx: disable APIC virtualization in nested guests
  (bcn#871306).
- KVM: x86: Remove return code from enable_irq/nmi_window
  (bcn#871306).
- KVM: nVMX: Do not inject NMI vmexits when L2 has a pending
  interrupt (bcn#871306).
- KVM: nVMX: Fully emulate preemption timer (bcn#871306).
- KVM: nVMX: Rework interception of IRQs and NMIs (bcn#871306).
- kvm, vmx: Really fix lazy FPU on nested guest (bcn#871306).
- KVM: x86: Fix xsave cpuid exposing bug (bcn#871306).
- KVM: nVMX: Update guest activity state field on L2 exits
  (bcn#871306).
- KVM: nVMX: Fix nested_run_pending on activity state HLT
  (bcn#871306).
- KVM: nVMX: Clean up handling of VMX-related MSRs (bcn#871306).
- KVM: nVMX: Add tracepoints for nested_vmexit and
  nested_vmexit_inject (bcn#871306).
- KVM: nVMX: Pass vmexit parameters to nested_vmx_vmexit
  (bcn#871306).
- KVM: nVMX: Leave VMX mode on clearing of feature control MSR
  (bcn#871306).
- KVM: nVMX: Support direct APIC access from L2 (bcn#871306).
- KVM: nVMX: Add support for activity state HLT (bcn#871306).
- KVM: VMX: shadow VM_(ENTRY|EXIT)_CONTROLS vmcs field
  (bcn#871306).
- x86, cpufeature: Define the Intel MPX feature flag (bcn#871306).
- kvm, vmx: Fix lazy FPU on nested guest (bcn#871306).
- KVM: x86: fix KVM_SET_XCRS loop (bcn#871306).
- KVM: x86: fix KVM_SET_XCRS for CPUs that do not support XSAVE
  (bcn#871306).
- nVMX: Report CPU_BASED_VIRTUAL_NMI_PENDING as supported
  (bcn#871306).
- nVMX: Fix pick-up of uninjected NMIs (bcn#871306).
- KVM: nVMX: Report 2MB EPT pages as supported (bcn#871306).
- KVM: nVMX: Fully support nested VMX preemption timer
  (bcn#871306).
- KVM: x86: only copy XSAVE state for the supported features
  (bcn#871306).
- KVM: x86: prevent setting unsupported XSAVE states (bcn#871306).
- KVM: x86: mask unsupported XSAVE entries from leaf 0Dh index 0
  (bcn#871306).
- KVM: nVMX: Do not generate #DF if #PF happens during exception
  delivery into L2 (bcn#871306).
- KVM: nVMX: Check all exceptions for intercept during delivery
  to L2 (bcn#871306).
- KVM: nVMX: Do not put exception that caused vmexit to
  IDT_VECTORING_INFO (bcn#871306).
- KVM: nVMX: Amend nested_run_pending logic (bcn#871306).
- KVM: nVMX: Enable unrestricted guest mode support (bcn#871306).
- KVM: nVMX: Implement support for EFER saving on VM-exit
  (bcn#871306).
- KVM: nVMX: Do not set identity page map for L2 (bcn#871306).
- KVM: nVMX: Replace kvm_set_cr0 with vmx_set_cr0 in
  load_vmcs12_host_state (bcn#871306).
- commit d785949
* Wed May 28 2014 duwe@suse.de
- CPU hotplug, smp: Flush any pending IPI callbacks before CPU
  offline (bnc#878672).
- CPU hotplug, stop-machine: Plug race-window that leads to
  "IPI-to-offline-CPU" (bnc#878672).
- smp: Print more useful debug info upon receiving IPI on an
  offline CPU (bnc#878672).
- commit d8de731
* Wed May 28 2014 mhocko@suse.cz
- Update
  patches.suse/mm-disable-zone_reclaim_mode-by-default.patch
  (bnc#874971, fate#317506).
- commit c1b9bb9
* Wed May 28 2014 jkosina@suse.cz
- floppy: do not corrupt bio.bi_flags when reading block 0
  (bnc#879258).
- commit 10f0a70
* Wed May 28 2014 pmladek@suse.cz
- printk: safe printing in NMI context (bnc#831949)
  This is complete rework of the solution from SLE11-SP3. The idea is the same
  but the ring buffer handling has completely changed upstream. Whole messages
  are manipulated instead of single characters.
  First, add useful upstream fixes that reduce conflicts:
- printk: flush conflicting continuation line
- printk: use also the last bytes in the ring buffer
- printk: do not compute the size of the message twice
  Second, add useful fixes that reduce conflicts and are queued in a subsystem
  maintainer repository:
- printk: split code for making free space in the log buffer
- printk: ignore too long messages
- printk: split message size computation
- printk: shrink too long messages
- printk: return really stored message length
  Next, add the working solutions that was sent as RFC:
- printk: allow to handle more log buffers
- printk: add NMI ring and cont buffers
- printk: allow to modify NMI log buffer size using boot
- printk: NMI safe printk
- printk: right ordering of the cont buffers from NMI
- printk: try hard to print Oops message in NMI context
- printk: merge and flush NMI buffer predictably via IRQ
- printk: survive rotation of sequence numbers
- printk: avoid staling when merging NMI log buffer
  Finally, delete the obsolete patches from SLE11-SP3:
- Delete
  patches.fixes/fix-printk-oops-from-nmi.patch
- Delete
  patches.fixes/printk-add-nmi-ring-buffer.patch
- Delete
  patches.fixes/printk-do-not-call-unlock_console-from-nmi.patch
- Delete
  patches.fixes/printk-do-not-use-printk_cpu-from-finish_printk.patch
- Delete
  patches.fixes/printk-extract-ringbuffer-handling.patch
- Delete
  patches.fixes/printk-make-nmi-ringbuffer-length-independent.patch
- Delete
  patches.fixes/printk-safe-nmi-handling.patch
- commit 2cc9231
* Tue May 27 2014 bpoirier@suse.de
- sfc: Restrict PIO to 64-bit architectures (bnc#878114).
- sfc: use 64-bit writes for PIO (bnc#878114).
- commit ce19e30
* Tue May 27 2014 jdelvare@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-cm3xxx.h-include.patch.
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
- Delete patches.arch/arm-arndale-dma.patch.
- Delete patches.arch/arm-arndale-usb-phy.patch.
- Delete patches.arch/arm-arndale-usb.patch.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete patches.arch/arm-omapfb-fix.patch.
- Delete patches.arch/arm-refresh-mach-types.diff.
- Delete patches.arch/cubox-configuration.patch.
  We don't build SLE12 for these ARM platforms so these patches are not
  needed.
- commit 26689b6
* Tue May 27 2014 mgorman@suse.de
- mm: page_alloc: use word-based accesses for get/set pageblock bitmaps
  (VM/FS Performance).
- commit 2784793
* Tue May 27 2014 jdelvare@suse.de
- Update ppc64le config files: Disable useless drivers
  SLE12 on ppc64le aims server hardware only, so disable a bunch of
  drivers which are irrelevant there:
  * gameport and joystick drivers
  * tablet drivers
  * touchscreen drivers
  * misc input drivers
  * memorystick drivers
  * sound drivers
  * media drivers
  I also disabled 5 legacy PATA drivers, not needed on POWER8 hardware.
  This puts the ppc64le config more in line with the s390x config, which
  aims at the same hardware class.
- commit 7e03116
* Mon May 26 2014 eich@suse.de
- drm/mgag200: Add mode validation debugging code (bnc#876772).
- drm/mgag200: Don't use crtc_* parameters for validation
  (bnc#876772).
- commit 2717019
* Mon May 26 2014 ddiss@suse.de
- cifs: fix client guid reuse logic
  Client guid reuse across multiple protocol versions causes mount
  failures against Windows 2012 servers (bnc#879932).
- patches.fixes/cifs-Check-SMB3-dialects-against-downgrade-attacks.patch
- patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
- commit e59d737
* Mon May 26 2014 dsterba@suse.cz
- Btrfs: check for an extent_op on the locked ref
- Refresh
  patches.suse/btrfs-0336-abort-the-transaction-when-we-don-t-find-our-e.patch.
- Refresh
  patches.suse/btrfs-0339-use-correct-key-when-repeating-search-for-exte.patch.
- Refresh
  patches.suse/btrfs-0340-correctly-set-profile-flags-on-seqlock-retry.patch.
- Refresh
  patches.suse/btrfs-0357-fix-lockdep-warning-with-reclaim-lock-inversio.patch.
- commit 89950e4
* Mon May 26 2014 dsterba@suse.cz
- Btrfs update
- Btrfs: introduce btrfs_{start, end}_nocow_write() for each
  subvolume.
- Btrfs: fix early enospc due to the race of the two ordered
  extent wait.
- Btrfs: wake up the tasks that wait for the io earlier.
- Btrfs: just do dirty page flush for the inode with compression
  before direct IO.
- Btrfs: remove the unnecessary flush when preparing the pages.
- Btrfs: remove unnecessary lock in may_commit_transaction().
- Btrfs: reclaim delalloc metadata more aggressively.
- Btrfs: don't flush all delalloc inodes when we doesn't get
  s_umount lock.
- Btrfs: split the global ordered extents mutex.
- Btrfs: fix possible empty list access when flushing the
  delalloc inodes.
- Btrfs: cache extent states in defrag code path.
- Btrfs: fix race when updating existing ref head.
- Btrfs: do not reset last_snapshot after relocation.
- btrfs: fix lockdep warning with reclaim lock inversion.
- btrfs: make device scan less noisy.
- btrfs: Change the expanding write sequence to fix snapshot
  related bug.
- Btrfs: fix snapshot vs nocow writting.
- btrfs: filter invalid arg for btrfs resize.
- Btrfs: more efficient io tree navigation on wait_extent_bit.
- Btrfs: fix unlock in __start_delalloc_inodes().
- btrfs: allow mounting btrfs subvolumes with different ro/rw
  options.
- btrfs: fix use-after-free in mount_subvol().
- btrfs: Change the hole range to a more accurate value.
- Btrfs: fix possible memory leaks in open_ctree().
- Refresh
  patches.suse/btrfs-0332-return-EPERM-when-deleting-a-default-subvolume.patch.
- Refresh
  patches.suse/btrfs-0334-fix-a-crash-of-clone-with-inline-extents-s-spl.patch.
- Refresh
  patches.suse/btrfs-0335-fix-EINVAL-checks-in-btrfs_clone.patch.
- Refresh
  patches.suse/btrfs-0336-abort-the-transaction-when-we-don-t-find-our-e.patch.
- Refresh
  patches.suse/btrfs-0337-export-global-block-reserve-size-as-space_info.patch.
- Refresh
  patches.suse/btrfs-0338-replace-error-code-from-btrfs_drop_extents.patch.
- Refresh
  patches.suse/btrfs-0339-use-correct-key-when-repeating-search-for-exte.patch.
- Refresh
  patches.suse/btrfs-0341-fix-EIO-on-reading-file-after-ioctl-clone-work.patch.
- commit d231c1e
* Mon May 26 2014 ohering@suse.de
- Drivers: scsi: storvsc: Change the limits to reflect the values
  on the host.
- commit 15a0f73
* Mon May 26 2014 ohering@suse.de
- Add hash value into RNDIS Per-packet info.
- commit 332c1e2
* Mon May 26 2014 ohering@suse.de
- net: Add skb_get_hash_raw.
- commit 359476b
* Mon May 26 2014 ohering@suse.de
- net: Add utility functions to clear rxhash.
- commit 65e4108
* Mon May 26 2014 neilb@suse.de
- Refresh patches.suse/NFS_LOOP_5_NFS_no_loop-back_deadlock.patch.
  Make sure it compiled when CONFIG_FREEZER is disabled (bnc#879287)
- commit 86a54ff
* Fri May 23 2014 mgorman@suse.de
- sched: Move wait code from core.c to wait.c
  (VM/FS Performance).
- commit 9fd2166
* Fri May 23 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-filemap-Avoid-unnecessary-barriers-and-waitqueue-lookups-in-unlock_page-fastpath.patch.
- commit 99b8637
* Fri May 23 2014 mgorman@suse.de
- mm: filemap: Avoid unnecessary barriers and waitqueue lookups in unlock_page fastpath
  (VM/FS Performance).
- commit 47675d5
* Fri May 23 2014 dsterba@suse.cz
- Btrfs: stop joining the log transaction if sync log fails
- commit 70233ef
* Fri May 23 2014 dsterba@suse.cz
- Btrfs update
  sync with 3.15
- Btrfs: don't mix the ordered extents of all files together
  during logging the inodes.
- btrfs: Return EXDEV for cross file system snapshot.
- Btrfs: fix unprotected alloc list insertion during the finishing
  procedure of replace.
- Btrfs: fix use-after-free in the finishing procedure of the
  device replace.
- Btrfs: balance delayed inode updates.
- Btrfs: unlock extent and pages on error in cow_file_range.
- Btrfs: switch to btrfs_previous_extent_item().
- Btrfs: skip readonly root for snapshot-aware defragment.
- btrfs: always choose work from prio_head first.
- Btrfs: faster/more efficient insertion of file extent items.
- Btrfs: fix possible deadlock in btrfs_cleanup_transaction.
- Btrfs: avoid warning bomb of btrfs_invalidate_inodes.
- Btrfs: use ACCESS_ONCE to prevent the optimize accesses to
  - >last_trans_log_full_commit.
- Btrfs: fix the skipped transaction commit during the file sync.
- Btrfs: don't start the log transaction if the log tree init
  fails.
- Btrfs: use signed integer instead of unsigned long integer
  for log transid.
- Btrfs: fix skipped error handle when log sync failed.
- Btrfs: just wait or commit our own log sub-transaction.
- btrfs: wake up transaction thread upon remount.
- Btrfs: remove unnecessary ref heads rb tree search.
- Btrfs: correctly determine if blocks are shared in
  btrfs_compare_trees.
- Btrfs: fix a possible deadlock between scrub and transaction
  committing.
- Btrfs: device_replace: fix deadlock for nocow case.
- Btrfs: cancel scrub on transaction abortion.
- Btrfs: wake up @scrub_pause_wait as much as we can.
- Btrfs: remove unneeded field / smaller extent_map structure.
- Btrfs: more efficient split extent state insertion.
- Btrfs: more efficient btrfs_drop_extent_cache.
- Btrfs: fix wrong lock range and write size in check_can_nocow().
- Btrfs: fix preallocate vs double nocow write.
- Btrfs: correctly flush data on defrag when compression is
  enabled.
- Btrfs: make defrag not fragment files when using prealloc
  extents.
- Btrfs: return EPERM when deleting a default subvolume
  (bnc#869934).
- Btrfs: take into account total references when doing backref
  lookup.
- Btrfs: fix a crash of clone with inline extents's split
  (bnc#786750).
- Btrfs: fix EINVAL checks in btrfs_clone.
- Btrfs: abort the transaction when we don't find our extent ref.
- btrfs: export global block reserve size as space_info.
- btrfs: replace error code from btrfs_drop_extents.
- Btrfs: use correct key when repeating search for extent item.
- Btrfs: correctly set profile flags on seqlock retry.
- Btrfs: fix EIO on reading file after ioctl clone works on it
  (bnc#872934).
- Delete
  patches.suse/btrfs-8005-Return-EXDEV-for-cross-file-system-snapshot.patch.
- Delete
  patches.suse/btrfs-8006-fix-unprotected-alloc-list-insertion-during-th.patch.
- Delete
  patches.suse/btrfs-8007-fix-use-after-free-in-the-finishing-procedure-.patch.
- Delete
  patches.suse/btrfs-8008-balance-delayed-inode-updates.patch.
- Delete
  patches.suse/btrfs-8009-unlock-extent-and-pages-on-error-in-cow_file_r.patch.
- Delete
  patches.suse/btrfs-8011-always-choose-work-from-prio_head-first.patch.
- Delete
  patches.suse/btrfs-8012-fix-possible-deadlock-in-btrfs_cleanup_transac.patch.
- Delete
  patches.suse/btrfs-8013-avoid-warning-bomb-of-btrfs_invalidate_inodes.patch.
- Delete
  patches.suse/btrfs-8014-fix-the-skipped-transaction-commit-during-the-.patch.
- Delete
  patches.suse/btrfs-8015-wake-up-transaction-thread-upon-remount.patch.
- Delete
  patches.suse/btrfs-8016-fix-a-possible-deadlock-between-scrub-and-tran.patch.
- Delete
  patches.suse/btrfs-8017-device_replace-fix-deadlock-for-nocow-case.patch.
- Delete
  patches.suse/btrfs-8018-cancel-scrub-on-transaction-abortion.patch.
- Delete
  patches.suse/btrfs-8019-wake-up-scrub_pause_wait-as-much-as-we-can.patch.
- Delete
  patches.suse/btrfs-8020-remove-unneeded-field-smaller-extent_map-struc.patch.
- Delete
  patches.suse/btrfs-8021-btrfs-fix-wrong-lock-range-and-write-size-in-check_c.patch.
- Delete
  patches.suse/btrfs-8022-fix-preallocate-vs-double-nocow-write.patch.
- Delete
  patches.suse/btrfs-8024-make-defrag-not-fragment-files-when-using-prea.patch.
- Delete
  patches.suse/btrfs-8025-return-EPERM-when-deleting-a-default-subvolume.patch.
- Delete
  patches.suse/btrfs-8026-take-into-account-total-references-when-doing-.patch.
- Delete
  patches.suse/btrfs-8028-fix-a-crash-of-clone-with-inline-extents-s-spl.patch.
- Delete
  patches.suse/btrfs-8029-fix-EINVAL-checks-in-btrfs_clone.patch.
- Delete
  patches.suse/btrfs-8030-abort-the-transaction-when-we-don-t-find-our-e.patch.
- Delete
  patches.suse/btrfs-8031-export-global-block-reserve-size-as-space_info.patch.
- Delete
  patches.suse/btrfs-8032-replace-error-code-from-btrfs_drop_extents.patch.
- Delete
  patches.suse/btrfs-8033-use-correct-key-when-repeating-search-for-exte.patch.
- Delete
  patches.suse/btrfs-8034-correctly-set-profile-flags-on-seqlock-retry.patch.
- Delete
  patches.suse/btrfs-8038-fix-EIO-on-reading-file-after-ioctl-clone-work.patch.
- commit 6e79aed
* Fri May 23 2014 jdelvare@suse.de
- Delete patches.rpmify/lustre-lloop-dont-change-logical-size.
  There is no point in fixing a bug in a driver we don't build.
- commit ec70c40
* Fri May 23 2014 jdelvare@suse.de
- Delete patches.suse/ext4-rw-unsupported.patch.
  The patch was obsolete. Since kernel 3.11 modules no longer fail to
  load if an unsupported parameter is passed, there's just a warning
  printed in the kernel log.
- commit d0b9dc1
* Fri May 23 2014 jdelvare@suse.de
- supported.conf: acpi/ec_sys is unsupported
  After discussion, supporting acpi/ec_sys is too dangerous so we mark
  it as unsupported.
- commit 9ae8ec5
* Fri May 23 2014 ddiss@suse.de
- Update config files: enable CONFIG_CIFS_SMB2
  cifs.ko is currently built with support for the base SMB1/CIFS dialect
  only. SMB1/CIFS support can be disabled in Windows 8.1 and Windows
  Server 2012 R2, and is completely unsupported with the Microsoft Azure
  File service, leaving cifs.ko users unable to access files on such
  servers without this change (fate#317480).
- commit 914a49a
* Fri May 23 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-properly-signal-and-act-upon-lock-and-need_sched-contention.patch.
- commit 2525ec6
* Fri May 23 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-avoid-rescanning-pageblocks-in-isolate_freepages.patch.
- commit e536131
* Fri May 23 2014 mkubecek@suse.cz
- macvlan: unregister net device when netdev_upper_dev_link()
  fails (fate#316924 bnc#875631 bnc#876145).
- macvlan: resolve ENOENT errors on creation (fate#316924
  bnc#875631 bnc#876145).
- commit 0c2273e
* Thu May 22 2014 jack@suse.cz
- Refresh patches.suse/dmapi-support-for-xfs.patch.
- commit 26ff9d2
* Thu May 22 2014 jroedel@suse.de
- iommu/vt-d: fix bug in matching PCI devices with DRHD/RMRR
  descriptors (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Fix get_domain_for_dev() handling of upstream PCIe
  bridges (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: fix memory leakage caused by commit ea8ea46
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Fix error handling in ANDD processing (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: returning free pointer in get_domain_for_dev()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Only call dmar_acpi_dev_scope_init() if DRHD units
  present (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Check for NULL pointer in dmar_acpi_dev_scope_init()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Include ACPI devices in iommu=pt (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Finally enable translation for non-PCI devices
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Remove to_pci_dev() in intel_map_page() (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Remove pdev from intel_iommu_attach_device()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Remove pdev from iommu_no_mapping() (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Make domain_add_dev_info() take struct device
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make domain_remove_one_dev_info() take struct device
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Rename 'hwdev' variables to 'dev' now that that's
  the norm (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Remove some pointless to_pci_dev() calls (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Make get_valid_domain_for_dev() take struct device
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make iommu_should_identity_map() take struct device
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Handle RMRRs for non-PCI devices (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Make get_domain_for_dev() take struct device
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make domain_context_mapp{ed,ing}() take struct
  device (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make device_to_iommu() cope with non-PCI devices
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make identity_mapping() take struct device not
  struct pci_dev (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Remove segment from struct device_domain_info()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Store PCI segment number in struct intel_iommu
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Remove device_to_iommu() call from
  domain_remove_dev_info() (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Simplify iommu check in domain_remove_one_dev_info()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Always store iommu in device_domain_info (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Use domain_remove_one_dev_info() in
  domain_add_dev_info() error path (bnc#870687 bnc#879482
  fate#317112).
- iommu/vt-d: use dmar_insert_dev_info() from dma_add_dev_info()
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Stop dmar_insert_dev_info() freeing domains on
  losing race (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Pass iommu to domain_context_mapping_one() and
  iommu_support_dev_iotlb() (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Use struct device in device_domain_info, not struct
  pci_dev (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make dmar_insert_dev_info() take struct device
  instead of struct pci_dev (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Make iommu_dummy() take struct device instead of
  struct pci_dev (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Add ACPI devices into dmaru->devices array
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Change scope lists to struct device, bus, devfn
  (bnc#870687 bnc#879482 fate#317112).
- iommu/vt-d: Allocate space for ACPI devices (bnc#870687
  bnc#879482 fate#317112).
- iommu/vt-d: Parse ANDD records (bnc#870687 bnc#879482
  fate#317112).
- iommu/vt-d: Add ACPI namespace device reporting structures
  (bnc#870687 bnc#879482 fate#317112).
- commit 0ab9cdc
* Thu May 22 2014 jack@suse.cz
- xfs: add xfs_ilock_attr_map_shared.
- xfs: rename xfs_ilock_map_shared.
- xfs: remove xfs_iunlock_map_shared.
- xfs: no need to lock the inode in xfs_find_handle.
- commit 3b006b4
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: fix possible register corruption in
  strnlen_user_srst() (bnc#878391, LTC#110601).
- commit a54e0f9
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: rework uaccess code - fix locking issues
  (bnc#878391, LTC#110601).
- commit ef10c9b
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: introduce 'uaccesspt' kernel parameter
  (bnc#878391, LTC#110601).
- commit 6fac32b
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: remove dead kernel parameter 'user_mode='
  (bnc#878391, LTC#110601).
- commit b58b57b
* Thu May 22 2014 jjolly@suse.de
- s390/setup: get rid of MACHINE_HAS_MVCOS machine flag
  (bnc#878391, LTC#110601).
- commit f413bb6
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: consistent types (bnc#878391, LTC#110601).
- commit 692e4b6
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: get rid of indirect function calls (bnc#878391,
  LTC#110601).
- commit 9397b46
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: normalize order of parameters of indirect uaccess
  function calls (bnc#878391, LTC#110601).
- commit 303c1b3
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: remove dead extern declarations, make functions
  static (bnc#878391, LTC#110601).
- commit 9df394d
* Thu May 22 2014 jack@suse.cz
- Refresh
  patches.fixes/xfs-xfs_remove-deadlocks-due-to-inverted-AGF-vs-AGI.patch.
- Refresh patches.suse/dmapi-support-for-xfs.patch.
- commit 35f7b28
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: test if current->mm is set before walking page
  tables (bnc#878391, LTC#110601).
- commit 466fa17
* Thu May 22 2014 jjolly@suse.de
- s390/compat: fix PSW32_USER_BITS definition (bnc#878391,
  LTC#110601).
- commit 32f60a3
* Thu May 22 2014 jjolly@suse.de
- s390/compat: make psw32_user_bits a constant value again
  (bnc#878391, LTC#110601).
- commit 0fd208b
* Thu May 22 2014 jjolly@suse.de
- s390/uaccess: always run the kernel in home space (bnc#878391,
  LTC#110601).
- commit e5adaa6
* Thu May 22 2014 jack@suse.cz
- xfs: remote attribute overwrite causes transaction overrun.
- xfs: fully support v5 format filesystems.
- xfs: fix buffer use after free on IO error.
- xfs: wrong error sign conversion during failed DIO writes.
- xfs: unmount does not wait for shutdown during unmount.
- xfs: don't map ranges that span EOF for direct IO.
- xfs: xfs_vm_write_end truncates too much on failure.
- xfs: write failure beyond EOF truncates too much data.
- xfs: kill buffers over failed write ranges properly.
- xfs: extra semi-colon breaks a condition.
- xfs: inode log reservations are still too small.
- xfs: xfs_check_page_type buffer checks need help.
- xfs: avoid AGI/AGF deadlock scenario for inode chunk allocation.
- xfs: use NOIO contexts for vm_map_ram.
- xfs: don't leak EFSBADCRC to userspace.
- xfs: fix directory inode iolock lockdep false positive.
- xfs: modify verifiers to differentiate CRC from other errors.
- xfs: split dquot buffer operations out.
- xfs: print useful caller information in xfs_error_report.
- xfs: add xfs_verifier_error().
- xfs: add helper for updating checksums on xfs_bufs.
- xfs: add helper for verifying checksums on xfs_bufs.
- xfs: Use defines for CRC offsets in all cases.
- xfs: skip pointless CRC updates after verifier failures.
- xfs: limit superblock corruption errors to actual corruption.
- xfs: skip verification on initial "guess" superblock read.
- xfs: xfs_sb_read_verify() doesn't flag bad crcs on primary sb.
- xfs: return -E2BIG if hit the maximum size limits of ACLs.
- xfs: sanitize sb_inopblock in xfs_mount_validate_sb.
- xfs: use tr_qm_dqalloc log reservation for dquot alloc.
- xfs: allow logical-sector sized O_DIRECT.
- xfs: rename xfs_buftarg structure members.
- xfs: clean up xfs_buftarg.
- xfs: Calling destroy_work_on_stack() to pair with
  INIT_WORK_ONSTACK().
- xfs: fix off-by-one error in xfs_attr3_rmt_verify.
- xfs: assert that we hold the ilock for extent map access.
- xfs: use xfs_ilock_attr_map_shared in xfs_attr_list_int.
- xfs: use xfs_ilock_attr_map_shared in xfs_attr_get.
- xfs: use xfs_ilock_data_map_shared in xfs_qm_dqiterate.
- xfs: use xfs_ilock_data_map_shared in xfs_qm_dqtobp.
- xfs: take the ilock around xfs_bmapi_read in
  xfs_zero_remaining_bytes.
- xfs: reinstate the ilock in xfs_readdir.
- xfs: abort metadata writeback on permanent errors.
- xfs: swalloc doesn't align allocations properly.
- xfs: align initial file allocations correctly.
- xfs: fix calculation of freed inode cluster blocks.
- xfs: xfs_dir2_block_to_sf temp buffer allocation fails.
- xfs: fix assertion failure at xfs_setattr_nonsize.
- xfs: fix false assertion at xfs_qm_vop_create_dqattach.
- xfs: make quota metadata truncation behavior consistent to
  user space.
- xfs: fix memory leak in xfs_dir2_node_removename.
- xfs: free the list of recovery items on error.
- xfs: don't perform discard if the given range length is less
  than block size.
- xfs: increase inode cluster size for v5 filesystems.
- xfs: add tracepoints to AGF/AGI read operations.
- xfs: trace AIL manipulations.
- xfs: xfs_remove deadlocks due to inverted AGF vs AGI lock
  ordering.
- xfs: fix the extent count when allocating an new indirection
  array entry.
- xfs: fix possible NULL dereference in xlog_verify_iclog.
- xfs: prevent stack overflows from page cache allocation.
- xfs: don't break from growfs ag update loop on error.
- xfs: don't emit corruption noise on fs probes.
- xfs: remove newlines from strings passed to __xfs_printk.
- xfs: prevent deadlock trying to cover an active log.
- xfs: add the inode directory type support to XFS_IOC_FSGEOM.
- xfs: fix the wrong new_size/rnew_size at
  xfs_iext_realloc_direct().
- commit 72b7a0c
* Thu May 22 2014 mgorman@suse.de
- mm: vmscan: Use proportional scanning during direct reclaim
  and full scan at DEF_PRIORITY (VM/FS Performance).
- fs/superblock: Avoid locking counting inodes and dentries
  before reclaiming them (VM/FS Performance).
- fs/superblock: Unregister sb shrinker before ->kill_sb()
  (VM/FS Performance).
- commit e2b0e53
* Thu May 22 2014 mgorman@suse.de
- Delete
  patches.suse/mm-revisit-shrink_lruvecs-proportionality.patch.
- commit 747e6d7
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Mark asymmetric crypto modules as supported
- commit a6c6988
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Mark drivers/virtio/virtio_mmio as supported
- commit 7ca7583
* Thu May 22 2014 jjolly@suse.de
- af_iucv: wrong mapping of sent and confirmed skbs (bnc#878059,
  LTC#110452).
- commit 5648a91
* Thu May 22 2014 jjolly@suse.de
- kernel: fix floating-point-control register save and restore
  (bnc#878059, LTC#110315).
- commit 0ffa0b3
* Thu May 22 2014 jjolly@suse.de
- s390/mm: handle asce-type exceptions as normal page fault
  (bnc#878059, LTC#110271).
- commit 5aa80db
* Thu May 22 2014 jjolly@suse.de
- s390/mm,tlb: correct tlb flush on page table upgrade
  (bnc#878059, LTC#110271).
- commit 88e63ad
* Thu May 22 2014 jdelvare@suse.de
- series.conf: Cleanup
  Drop obsolete PS3 section, stray bug reference and duplicate blank
  line.
- commit 4c20380
* Thu May 22 2014 jroedel@suse.de
- iommu/amd: fix enabling exclusion range for an exact device
  (bnc#879452).
- iommu/amd: Take mmap_sem when calling get_user_pages
  (bnc#879452).
- iommu/amd: Fix interrupt remapping for aliased devices
  (bnc#879452).
- iommu/amd: Fix logic to determine and checking max PASID
  (bnc#879452).
- iommu/amd: Add include of <linux/irqreturn.h> (bnc#879452).
- commit 56b4a2b
* Thu May 22 2014 duwe@suse.de
- powerpc: Rate-limit users spamming kernel log buffer
  (bnc#878240).
- powerpc/mm: NUMA pte should be handled via slow path in
  get_user_pages_fast() (bnc#878240).
- powerpc/ftrace: bugfix for test_24bit_addr (bnc#878240).
- commit daaa0f3
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Mark acpi/ec_sys as supported
  Useful for ACPI debugging according to Joey Lee.
- commit 1579418
* Thu May 22 2014 dsterba@suse.cz
- Add git commit ids
- Refresh patches.suse/btrfs-8005-Return-EXDEV-for-cross-file-system-snapshot.patch.
- Refresh patches.suse/btrfs-8006-fix-unprotected-alloc-list-insertion-during-th.patch.
- Refresh patches.suse/btrfs-8007-fix-use-after-free-in-the-finishing-procedure-.patch.
- Refresh patches.suse/btrfs-8008-balance-delayed-inode-updates.patch.
- Refresh patches.suse/btrfs-8009-unlock-extent-and-pages-on-error-in-cow_file_r.patch.
- Refresh patches.suse/btrfs-8011-always-choose-work-from-prio_head-first.patch.
- Refresh patches.suse/btrfs-8012-fix-possible-deadlock-in-btrfs_cleanup_transac.patch.
- Refresh patches.suse/btrfs-8013-avoid-warning-bomb-of-btrfs_invalidate_inodes.patch.
- Refresh patches.suse/btrfs-8014-fix-the-skipped-transaction-commit-during-the-.patch.
- Refresh patches.suse/btrfs-8015-wake-up-transaction-thread-upon-remount.patch.
- Refresh patches.suse/btrfs-8016-fix-a-possible-deadlock-between-scrub-and-tran.patch.
- Refresh patches.suse/btrfs-8017-device_replace-fix-deadlock-for-nocow-case.patch.
- Refresh patches.suse/btrfs-8018-cancel-scrub-on-transaction-abortion.patch.
- Refresh patches.suse/btrfs-8019-wake-up-scrub_pause_wait-as-much-as-we-can.patch.
- Refresh patches.suse/btrfs-8020-remove-unneeded-field-smaller-extent_map-struc.patch.
- Refresh patches.suse/btrfs-8021-btrfs-fix-wrong-lock-range-and-write-size-in-check_c.patch.
- Refresh patches.suse/btrfs-8022-fix-preallocate-vs-double-nocow-write.patch.
- Refresh patches.suse/btrfs-8024-make-defrag-not-fragment-files-when-using-prea.patch.
- Refresh patches.suse/btrfs-8025-return-EPERM-when-deleting-a-default-subvolume.patch.
- Refresh patches.suse/btrfs-8026-take-into-account-total-references-when-doing-.patch.
- commit a0eb5ba
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Mark two Intel platform drivers as supported
  Mark intel-rst and intel-smartconnect as supported based on input
  from Oliver Neukum. There's FATE#315713 for intel-rst.
- commit d2e90c4
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Fix rapidio support status
  Forgot the minus sign, sorry.
- commit 4ebc0fe
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Unlisted USB network adapters are unsupported
- commit 674c4a2
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Update the support status of many drivers
  Update the support status of ATA, block, infiniband, md and rapidio
  drivers based on input from Hannes Reinecke.
- commit c63015e
* Thu May 22 2014 jdelvare@suse.de
- Update config files: Disable remaining R-CAR drivers
  Totally out of scope for SLE12.
- commit fc7e0df
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Teaming stack is unsupported
  This is related to fate#316916; we agreed to leave this turned on
  but unsupported so it's easier for develop and test the
  corresponding userspace.
- commit 851a183
* Thu May 22 2014 jdelvare@suse.de
- supported.conf: Update support status of bluetooth drivers
- commit 53ebe42
* Wed May 21 2014 lduncan@suse.com
- iscsi_ibft: search for broadcom specific ibft sign (bnc#876731).
- commit 93d19b6
* Wed May 21 2014 lduncan@suse.de
- cxgb4i: Use cxgb4_select_ntuple to correctly calculate ntuple fields.
- commit 19f6c10
* Wed May 21 2014 jeffm@suse.de
- reiserfs: call truncate_setsize under tailpack mutex
  (bnc#878115).
- commit ad898ec
* Wed May 21 2014 duwe@suse.de
- powerpc: Fix error return in rtas_flash module init
  (bnc#878240).
- powerpc: Bump COMMAND_LINE_SIZE to 2048 (bnc#878240).
- powerpc: Rename duplicate COMMAND_LINE_SIZE define (bnc#878240).
- powerpc: Only print PACATMSCRATCH in oops when TM is active
  (bnc#878240).
- powerpc: Remove a few lines of oops output (bnc#878240).
- powerpc: Print DAR and DSISR on machine check oopses
  (bnc#878240).
- commit a0ff663
* Wed May 21 2014 mgorman@suse.de
- mm/shmem.c: don't run init_page_accessed() against an uninitialised pointer
  (VM/FS Performance).
- commit afcbee7
* Wed May 21 2014 mgorman@suse.de
- mm: Avoid unnecessary atomic operations during end_page_writeback
  (VM/FS Performance).
- commit c90f918
* Wed May 21 2014 jdelvare@suse.de
- Update arm64 config file: Disable the rtc-moxart driver
  This driver is only needed on Moxa ART systems, which we do not
  support.
- commit e55d72f
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable unused RTC platform drivers
- commit bccf2ef
* Wed May 21 2014 jdelvare@suse.de
- Update arm64 config file: Disable rtc-pl030 and rtc-pl031
  We have no reason to believe these drivers will be needed on the
  target hardware so disable them for now.
- commit 9e4cd30
* Tue May 20 2014 jslaby@suse.cz
- kgr: fix race of stub and patching (fate#313296).
- kgr: expose global 'in_progress' state through procfs
  (fate#313296).
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh patches.suse/kgr-0006-kgr-add-Documentation.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh
  patches.suse/kgr-0008-kgr-sched.h-introduce-kgr_task_safe-helper.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh patches.suse/kgr-0012-kgr-add-tools.patch.
- Refresh
  patches.suse/kgr-0014-kgr-x86-refuse-to-build-without-fentry-support.patch.
- Refresh
  patches.suse/kgr-0015-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Refresh
  patches.suse/kgr-0016-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh
  patches.suse/kgr-0017-kgr-add-support-for-missing-functions.patch.
  Update the patchset to the latest version.
- commit 9121756
* Tue May 20 2014 jbeulich@suse.com
- supported.conf: Add a few entries for drivers built in by standard configs.
- commit e35b328
* Tue May 20 2014 jbeulich@suse.com
- supported.conf: Explicit entry for drivers/xen/tmem (unsupported).
- commit f58ef8d
* Tue May 20 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-page_alloc-Calculate-classzone_idx-once-from-the-zonelist-ref.patch.
- commit 149b863
* Tue May 20 2014 jdelvare@suse.de
- supported.conf: Add supported NFC drivers (bnc#877449)
  We had a few FATE requests for specific NFC drivers, so mark them
  as supported. The rest of the NFC drivers is currently unsupported,
  but individual drivers could be moved to the supported list upon
  request.
- commit d2ada5d
* Tue May 20 2014 jdelvare@suse.de
- Update config files: Disable drbd
  drbd will be shipped as a KMP in SLE12 HA only (not SLES nor SLED).
- commit c994d2f
* Mon May 19 2014 bp@suse.de
- supported.conf:
  Hold down some supported pieces explicitly.
- commit 4256d25
* Mon May 19 2014 bp@suse.de
- MCE, AMD: Check for userspace agent before decoding
  (bnc#871881).
- commit 905cd31
* Mon May 19 2014 bp@suse.de
- x86/mce: Fix CMCI preemption bugs (bnc#786450).
- x86, CMCI: Add proper detection of end of CMCI storms
  (bnc#786450).
- commit ecca4f8
* Mon May 19 2014 tiwai@suse.de
- supported.conf: Simplify sound/* entries using wildcards
  Also add snd-us122l as supported, as it's coupled with snd-usb-usx2y.
- commit 7ef9052
* Fri May 16 2014 jdelvare@suse.de
- supported.conf: Mark Intel ICH drivers as supported
  lpc_ich and gpio-ich are needed for full support of Intel ICH family
  of x86 south bridges.
- commit b84ae9f
* Fri May 16 2014 jdelvare@suse.de
- supported.conf: Add crypto/crct10dif_common+generic as supported
  These are built-in everywhere except in the ec2 config where they
  are modular.
- commit 5959d29
* Fri May 16 2014 jdelvare@suse.de
- Update config files: Disable all EG20T drivers
  EG20T (aka Topcliff PCH) is a chipset for 32-bit x86 processors, so
  we don't need these drivers in SLE12.
- commit bbb6770
* Fri May 16 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-embed-migration-mode-in-compact_control.patch.
- commit 1636e9b
* Fri May 16 2014 vbabka@suse.cz
- mm, compaction: properly signal and act upon lock and
  need_sched() contention (VM Performance).
- mm/compaction: avoid rescanning pageblocks in isolate_freepages
  (VM Performance).
- mm/compaction: do not count migratepages when unnecessary
  (VM Performance).
- mm, compaction: terminate async compaction when rescheduling
  (VM Performance).
- commit 8622989
* Fri May 16 2014 vbabka@suse.cz
- mm, compaction: embed migration mode in compact_control
  (VM Performance).
- Refresh
  patches.suse/mm-page_alloc-Calculate-classzone_idx-once-from-the-zonelist-ref.patch
- commit a9add64
* Fri May 16 2014 dsterba@suse.cz
- Btrfs: fix EIO on reading file after ioctl clone works on it (bnc#872934)
- commit 2524b23
* Fri May 16 2014 tiwai@suse.de
- cpumask.h: silence warning with -Wsign-compare (bnc#876357).
- commit 7681417
* Fri May 16 2014 jdelvare@suse.de
- supported.conf: Mark genwqe_card as supported by IBM (bnc#878090)
- commit 4c7e6f4
* Fri May 16 2014 mhocko@suse.cz
- memcg: deprecate memory.force_empty knob (bnc#878274).
- commit d94b459
* Fri May 16 2014 vbabka@suse.cz
- mm, compaction: add per-zone migration pfn cache for async
  compaction (VM Performance).
- mm, compaction: return failed migration target pages back to
  freelist (VM Performance).
- mm, migration: add destination page freeing callback (VM
  Performance).
- mm, compaction: ignore pageblock skip when manually invoking
  compaction (VM Functionality).
- commit b8917da
* Fri May 16 2014 vbabka@suse.cz
- mm-compaction-cleanup-isolate_freepages-fix3 (VM Functionality).
- mm/compaction: clean up unused code lines (VM Functionality).
- commit dcabb5a
* Fri May 16 2014 vbabka@suse.cz
- mm/compaction: cleanup isolate_freepages() (VM Functionality).
- commit b1830b4
* Fri May 16 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete kGraft patches for older kernels (fate#313296)
- commit 99e98de
* Fri May 16 2014 vbabka@suse.cz
- Refresh
  patches.suse/mm-compaction-make-isolate_freepages-start-at-pageblock-boundary.patch.
- commit b678efe
* Fri May 16 2014 jdelvare@suse.de
- supported.conf: Annotate IBM-supported drivers as such
- commit 066b1ed
* Thu May 15 2014 jdelvare@suse.de
- Update ppc64le config files: Disable DA903x support completely
  It makes no sense to support some sub-drivers and not the rest.
- commit f175371
* Thu May 15 2014 duwe@suse.de
- Update config files:
  x86_64/ppc64le disable:
  timeriomem-rng
  pwm-pca9685
  unsupported RTC drivers
  ssd1307fb/da903x_bl
  VME bus
- commit 215bfbc
* Thu May 15 2014 duwe@suse.de
- supported.conf:
  add dependent regmap modules,
  TPM RNGs, RTCs and
  some ppc- and s390-specific modules
- commit 6cb8b4e
* Thu May 15 2014 jslaby@suse.cz
- supported.conf: some tty+serial stuff
- commit 0c553e4
* Thu May 15 2014 jbohac@suse.cz
- supported.conf: mark pps-gpio, pps-ldisc and pps_parport as supported
- commit 75c56ff
* Thu May 15 2014 hare@suse.de
- hpsa: Update version to 3.4.4-125 (bnc#875556).
- commit d86a50e
* Thu May 15 2014 jdelvare@suse.de
- supported.conf: Add firewire/nosy as supported
  This driver is the replacement for the ieee1394/pcilynx driver,
  which was supported.
- commit f7a3cbe
* Thu May 15 2014 mkubecek@suse.cz
- supported.conf: add net/core/drop_monitor
  A diagnostic tool allowing to identify where in the code packets
  are dropped.
- commit da1784a
* Thu May 15 2014 jdelvare@suse.de
- Update x86_64 config files: Enable CAN support (FATE#317131)
  This FATE request isn't actually for SLE12 but after discussion we
  decided it would be a good idea to anticipate and enable CAN there
  too. For now this is enabled on x86-64 only, but it could be
  enabled on other architectures too on customer or partner request.
- commit deb0b0a
* Thu May 15 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0004-kgr-add-testing-kgraft-patch.patch.
  fix filename in Makefile.
- commit 2248508
* Thu May 15 2014 oneukum@suse.de
- supported.conf: adding newer USB<->Serial converters
- commit 2e85799
* Thu May 15 2014 mkubecek@suse.cz
- Refresh (update SLE12 comment)
  patches.drivers/net-add-netdev_adjacent-private-and-allow-to-use-it.patch.
- Delete (the patch only adds an unused function and compiler warning)
  patches.drivers/net-add-RCU-variant-to-search-for-netdev_adjacent-li.patch.
- commit 4ee1cdd
* Thu May 15 2014 jslaby@suse.cz
- Refresh patches.drivers/megaraid_sas-reduce-logging-noise.patch.
  fix build error
- commit ec4ae22
* Thu May 15 2014 jslaby@suse.cz
- Linux 3.12.20 (bnc#821619 bnc#827670 bnc#871252 bnc#871729
  bnc#873901 bnc#875242 bnc#875690 CVE-2014-0196 FATE#315518).
- Refresh
  patches.arch/ppc64le-ELFv2-0001-Use-32-bit-loads-and-stores-when-operating-o.
- Refresh
  patches.drivers/0002-storage-accept-some-UAS-devices-if-streams-are-unava.patch.
- Refresh
  patches.drivers/0003-storage-accept-some-UAS-devices-if-streams-are-unava.patch.
- Refresh
  patches.drivers/0004-xhci-For-streams-the-css-flag-most-be-read-from-the-.patch.
- Refresh
  patches.drivers/0060-ib_isert-Add-support-for-completion-interrupt-coales.patch.
- Refresh
  patches.drivers/0120-IB-isert-seperate-connection-protection-domains-and-.patch.
- Refresh
  patches.drivers/0121-IB-isert-Avoid-frwr-notation-user-fastreg.patch.
- Refresh
  patches.drivers/0124-iscsi-target-Convert-gfp_t-parameter-to-task-state-b.patch.
- Refresh
  patches.drivers/0139-iser-target-Fix-command-leak-for-tx_desc-comp_llnode.patch.
- Refresh
  patches.drivers/0151-IB-isert-Initialize-T10-PI-resources.patch.
- Refresh
  patches.drivers/0156-Target-iser-Consider-DIF-and-RDMA_READ-completions-w.patch.
- Refresh
  patches.drivers/0157-Target-iser-Move-check-signature-status-to-a-functio.patch.
- Refresh patches.drivers/mtip32xx-Add-SRSI-support.patch.
- Refresh patches.suse/dmapi-Make-NFSD-DMAPI-aware.patch.
- Refresh
  patches.suse/msft-hv-0551-hv-make-monitor_pages-a-real-pointer-array.patch.
- Delete patches.arch/ppc64le-name-32-bit-LE-ppcle.
- Delete
  patches.drivers/0001-xhci-Prevent-runtime-pm-from-autosuspending-during-i.patch.
- Delete
  patches.drivers/0159-iser-target-Match-FRMR-descriptors-to-available-sess.patch.
- Delete
  patches.drivers/0162-iser-target-Add-missing-se_cmd-put-for-WRITE_PENDING.patch.
- Delete
  patches.drivers/0164-iscsi-target-Fix-ERL-2-ASYNC_EVENT-connection-pointe.patch.
- Delete
  patches.drivers/0182-Target-sbc-Initialize-COMPARE_AND_WRITE-write_sg-sca.patch.
- Delete
  patches.drivers/0184-target-tcm_fc-Fix-use-after-free-of-ft_tpg.patch.
- Delete
  patches.fixes/dlm-Fix-return-value-from-lockspace_busy.patch.
- Delete
  patches.fixes/libata-ahci-accommodate-tag-ordered-controllers.patch.
- Delete
  patches.fixes/mei-me-do-not-load-the-driver-if-the-FW-doesnt-support.
- Delete
  patches.fixes/mm-try_to_unmap_cluster-should-lock_page-before-mlocking.patch.
- Delete
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
- Delete
  patches.suse/mm-page_alloc-spill-to-remote-nodes-before-waking-kswapd.patch.
- Delete
  patches.suse/msft-hv-0578-Drivers-hv-vmbus-Specify-the-target-CPU-that-should-.patch.
- Delete
  patches.suse/msft-hv-0617-Drivers-hv-vmbus-Negotiate-version-3.0-when-running-.patch.
- commit 65480f9
* Thu May 15 2014 oneukum@suse.de
- supported.conf: support cdc_eem as it is a standard driver
- commit 017af0d
* Thu May 15 2014 hare@suse.de
- megaraid_sas: reduce logging noise (bnc#877953).
- commit cd4dcd2
* Thu May 15 2014 mkubecek@suse.cz
- vlan: unlink the upper neighbour before unregistering
  (bnc#877776).
- vlan: link the upper neighbour only after registering
  (bnc#877776).
- net: add RCU variant to search for netdev_adjacent link
  (bnc#877776).
- commit 4c8f0d8
* Wed May 14 2014 mgorman@suse.de
- mm: Non-atomically mark page accessed during page cache
  allocation where possible (VM/FS Performance).
- callers of iov_copy_from_user_atomic() don't need
  pagecache_disable() (VM/FS Performance).
- mm: remove read_cache_page_async() (VM/FS Performance).
- mm + fs: prepare for non-page entries in page cache radix trees
  (VM/FS Performance).
- mm: filemap: move radix tree hole searching here (VM/FS
  Performance).
- mm: shmem: save one radix tree lookup when truncating swapped
  pages (VM/FS Performance).
- lib: radix-tree: add radix_tree_delete_item() (VM/FS
  Performance).
- fs: buffer: Do not use unnecessary atomic operations when
  discarding buffers (VM/FS Performance).
- commit 6d0fefb
* Wed May 14 2014 mgorman@suse.de
- Delete
  patches.suse/mm-filemap-Avoid-unnecessary-barries-and-waitqueue-lookup-in-unlock_page-fastpath.patch.
- commit 8ba3bec
* Wed May 14 2014 mgorman@suse.de
- jump_label: Expose the reference count (VM/FS Performance).
- commit 0217b89
* Wed May 14 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-page_alloc-Use-jump-labels-to-avoid-checking-number_of_cpusets.patch.
- commit 4165b38
* Wed May 14 2014 jslaby@suse.cz
- Update config files. (kgraft symbol changed)
- commit ac1f4c7
* Wed May 14 2014 jslaby@suse.cz
- kgr: add support for missing functions (fate#313296).
- kgr: exercise non-present function (fate#313296).
- Refresh
  patches.suse/kgr-0001-ftrace-Add-function-to-find-fentry-of-function.patch.
- Refresh
  patches.suse/kgr-0002-ftrace-Make-ftrace_is_dead-available-globally.patch.
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
- Refresh
  patches.suse/kgr-0004-kgr-add-testing-kgraft-patch.patch.
- Refresh
  patches.suse/kgr-0005-kgr-update-Kconfig-documentation.patch.
- Refresh patches.suse/kgr-0006-kgr-add-Documentation.patch.
- Refresh
  patches.suse/kgr-0007-kgr-trigger-the-first-check-earlier.patch.
- Refresh
  patches.suse/kgr-0008-kgr-sched.h-introduce-kgr_task_safe-helper.patch.
- Refresh patches.suse/kgr-0010-kgr-kthreads-support.patch.
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
- Refresh patches.suse/kgr-0012-kgr-add-tools.patch.
- Refresh patches.suse/kgr-0013-kgr-add-MAINTAINERS-entry.patch.
- Refresh
  patches.suse/kgr-0014-kgr-x86-refuse-to-build-without-fentry-support.patch.
- Refresh
  patches.suse/kgr-0015-kgr-add-procfs-interface-for-per-process-kgr_in_prog.patch.
- Refresh
  patches.suse/kgr-0016-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
- Refresh patches.xen/xen3-patch-3.10.
  Update to the latest snapshot.
- commit d2b750d
* Wed May 14 2014 jdelvare@suse.de
- supported.conf: Move masks at the end of their subsystem
  Masks must go after explicit modules in the same subsystem, otherwise
  they shadow said modules.
- commit ace09d3
* Wed May 14 2014 jbeulich@suse.com
- Refresh patches.xen/xen-blkfront-indirect (bnc#876786).
- commit b0910f2
* Tue May 13 2014 mgorman@suse.de
- swap: change swap_list_head to plist, add swap_avail_head
  (bnc#862957).
- lib/plist: add plist_requeue (bnc#862957).
- lib/plist: add helper functions (bnc#862957).
- swap: change swap_info singly-linked list to list_head
  (bnc#862957).
- commit ba797b7
* Tue May 13 2014 jdelvare@suse.de
- supported.conf: Sort all entries alphabetically
- commit 001425d
* Tue May 13 2014 duwe@suse.de
- powerpc/pseries: hcall functions are exported to modules,
  need _GLOBAL_TOC() (bnc#877077).
- commit 2aef0e4
* Tue May 13 2014 duwe@suse.de
- Revert "Revert ppc64le ABI v2 series (bnc#877077)"
  This reverts the workaround commit 6bae7f7895fc6e9acb9f48c5d070fa933263ccd4,
  in order to work on the real fix.
- commit 2c8faa1
* Tue May 13 2014 oneukum@suse.de
- xhci: extend quirk for Renesas cards (bnc#877497).
- commit 781d8bb
* Tue May 13 2014 mgorman@suse.de
- locking/mutexes: Introduce cancelable MCS lock for adaptive
  spinning (VM Performance).
- locking/mutexes: Modify the way optimistic spinners are queued
  (VM Performance).
- locking/mutex: Fix debug_mutexes (VM Performance).
- locking/mutex: Fix debug checks (VM Performance).
- mutexes: Give more informative mutex warning in the !lock->owner
  case (VM Performance).
- locking/mutexes: Unlock the mutex without the wait_lock
  (VM Performance).
- locking/mutexes: Return false if task need_resched() in
  mutex_can_spin_on_owner() (VM Performance).
- mm: don't pointlessly use BUG_ON() for sanity check (VM
  Performance).
- mm: per-thread vma caching (VM Performance).
- mm, hugetlb: improve page-fault scalability (VM Performance).
- commit 436f298
* Tue May 13 2014 tiwai@suse.de
- offb: Fix little-endian support (bnc#876757).
- commit 824d24a
* Tue May 13 2014 jdelvare@suse.de
- supported.conf: Add powerpc-specific modules as supported
  Add the following powerpc-specific modules as supported:
  * sha1-powerpc, for performance reasons. It was added in kernel 3.9,
  so it is new in SLES12.
  * oprofile, which gets supported anyway because arch/x86/oprofile/oprofile
  is listed and module utilities ignore paths. So we might as well list
  it explicitly to clarify that it is supported.
  * rtc_cmos_setup, which exists since kernel 2.6.23 but wasn't enabled
  on powerpc so far because CONFIG_RTC_CLASS wasn't set. I'm not 100%%
  certain we actually need that, but as long as it is enabled it
  should be supported for consistency.
- commit d0953d9
* Tue May 13 2014 neilb@suse.de
- nfsd4: fix delegation-unlink/rename race (bnc#876463).
- vfs: pull ext4's double-i_mutex-locking into common code
  (bnc#876463).
- vfs: don't use PARENT/CHILD lock classes for non-directories
  (bnc#876463).
- vfs: rename I_MUTEX_QUOTA now that it's not used for quotas
  (bnc#876463).
- vfs: take i_mutex on renamed file (bnc#876463).
- locks: introduce new FL_DELEG lock flag (bnc#876463).
- locks: implement delegations (bnc#876463).
- namei: minor vfs_unlink cleanup (bnc#876463).
- locks: break delegations on unlink (bnc#876463).
- locks: helper functions for delegation breaking (bnc#876463).
- locks: break delegations on rename (bnc#876463).
- locks: break delegations on link (bnc#876463).
- locks: break delegations on any attribute modification
  (bnc#876463).
- update overlayfs to account for changes to support NFSv4
  delegations (bnc#876463).
- Refresh
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- Refresh patches.suse/dmapi-Make-NFSD-DMAPI-aware.patch.
- Refresh
  patches.suse/ovl03-vfs-export-inode_permission-to-modules.patch.
  When nfsd hands out a delegation, it must reclaim it when the file is
  unlinked or renamed, etc.  This already happens if the unlink etc happens
  via NFS, not not if it happens via local filesystem operation.
  These patches make sure the delegation gets reclaimed when a file is changed
  by a local filesystem operation.
- commit 8fc7979
* Mon May 12 2014 bpoirier@suse.de
- bnx2x: Fix UNDI driver unload (bnc#853494 FATE#315918).
- commit a777ac9
* Mon May 12 2014 jjolly@suse.de
- net/mlx4_en: Fix selftest failing on non 10G link speed.
- commit f6da390
* Mon May 12 2014 tiwai@suse.de
- pvpanic: Set high notifier priority (bnc#875220).
- commit ed0b114
* Mon May 12 2014 tiwai@suse.de
- fbcon: Clean up fbcon data in fb_info on FB_EVENT_FB_UNBIND
  with 0 fbs (bnc#875687).
- commit 6521193
* Mon May 12 2014 jbeulich@suse.com
- Update Xen patches to 3.12.19.
- kgr: make a per-process 'in progress' flag a single bit
  (fate#313296).
- commit 4e084a3
* Mon May 12 2014 jjolly@suse.de
- spinlock: fix system hang with spin_retry <= 0 (bnc#877098,
  LTC#110189).
- commit a09cdc1
* Mon May 12 2014 jjolly@suse.de
- crypto: s390 - fix aes,des ctr mode concurrency finding
  (bnc#877098, LTC#110078).
- commit abfff61
* Mon May 12 2014 mkubecek@suse.cz
- bonding: make slave status notifications GFP_ATOMIC
  (bnc#875631).
- bonding: fix bond_arp_rcv() race of curr_active_slave
  (bnc#875631).
- commit eb79b7c
* Mon May 12 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not keep debug symbols in vmlinux-*.gz
  (bnc#877267)
- commit f928d60
* Sun May 11 2014 mkubecek@suse.cz
- Update (handle also callbacks in virtio_net and hyperv/netvsc_drv)
  patches.drivers/netdevice-add-queue-selection-fallback-handler-for-n.patch.
- commit 4ad490c
* Sat May 10 2014 mfasheh@suse.de
- dlm: Avoid that dlm_release_lockspace() incorrectly returns
  - EBUSY (https://bugzilla.novell.com/show_bug.cgi?id=827670#c43).
- commit 617b489
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: set error code on kmalloc() failure.
- commit a8298f8
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Disable DSGL use by default.
- commit cb7e2d6
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: rx_data() needs to hold the ep mutex.
- commit 3a83857
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Drop RX_DATA packets if the endpoint is gone.
- commit 3dcf850
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Lock around accept/reject downcalls.
- commit 4bfcbe6
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Update snd_seq when sending MPA messages.
- commit 8463703
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Connect_request_upcall fixes.
- commit fdd529e
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Ignore read reponse type 1 CQEs.
- commit 01530c1
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Fix possible memory leak in RX_PKT processing.
- commit fd9fdc5
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Don't leak skb in c4iw_uld_rx_handler().
- commit 9115504
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Save the correct map length for fast_reg_page_lists.
- commit 9ff144e
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Default peer2peer mode to 1.
- commit ce99d7e
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Mind the sq_sig_all/sq_sig_type QP attributes.
- commit 423ca82
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Fix incorrect BUG_ON conditions.
- commit 5066956
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Always release neigh entry.
- commit 3f10739
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Allow loopback connections.
- commit 6dceb4c
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Cap CQ size at T4_MAX_IQ_SIZE.
- commit c3429a7
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Add missing neigh_release in LE-Workaround path.
- commit ea260a9
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Fix gcc warning on 32-bit arch.
- commit ba5764c
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Use cxgb4_select_ntuple to correctly calculate
  ntuple fields.
- commit 06f61ae
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Server filters are supported only for IPv4.
- commit e2d3c05
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Calculate the filter server TID properly.
- commit 67bd406
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Make _c4iw_write_mem_dma() static.
- commit 3e5de21
* Fri May  9 2014 jjolly@suse.de
- IB/cxgb4: Fix formatting of physical address.
- commit 594c2de
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Fix four byte info leak in c4iw_create_cq().
- commit 601a240
* Fri May  9 2014 jjolly@suse.de
- RDMA/cxgb4: Fix underflows in c4iw_create_qp().
- commit 6b9fe24
* Fri May  9 2014 mkubecek@suse.cz
- bonding: correctly handle out of range parameters for
  lp_interval (fate#316924 bnc#875631 bnc#876145).
- bonding: disallow enslaving a bond to itself (bnc#599263
  fate#316924 bnc#875631 bnc#876145).
- bonding: fix a div error caused by the slave release path
  (fate#316924 bnc#875631 bnc#876145).
- bonding: Fix RTNL: assertion failed at net/core/rtnetlink.c
  for ab arp monitor (fate#316924 bnc#875631 bnc#876145).
- bonding: Fix RTNL: assertion failed at net/core/rtnetlink.c
  for 802.3ad mode (fate#316924 bnc#875631 bnc#876145).
- netdevice: add queue selection fallback handler for
  ndo_select_queue (fate#316924 bnc#875631 bnc#876145).
- net,bonding: fix bond_options.c direct rwlock.h include
  (fate#316924 bnc#875631 bnc#876145).
- bonding: Fix deadlock in bonding driver when using netpoll
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unwanted bond lock for enslave processing
  (fate#316924 bnc#875631 bnc#876145).
- bonding: fail_over_mac should only affect AB mode in
  bond_set_mac_address() (fate#316924 bnc#875631 bnc#876145).
- bonding: fail_over_mac should only affect AB mode at enslave
  and removal processing (fate#316924 bnc#875631 bnc#876145).
- bonding: fix locking in bond_loadbalance_arp_mon() (fate#316924
  bnc#875631 bnc#876145).
- bonding: restructure locking of bond_ab_arp_probe() (fate#316924
  bnc#875631 bnc#876145).
- bonding: RCUify bond_ab_arp_probe (fate#316924 bnc#875631
  bnc#876145).
- rtnetlink: remove IFLA_BOND_SLAVE definition (fate#316924
  bnc#875631 bnc#876145).
- bonding: fix u64 division (fate#316924 bnc#875631 bnc#876145).
- rtnetlink: add missing IFLA_BOND_AD_INFO_UNSPEC (fate#316924
  bnc#875631 bnc#876145).
- bonding: Don't allow bond devices to change network namespaces
  (fate#316924 bnc#875631 bnc#876145).
- rtnetlink: remove ndo_get_slave (fate#316924 bnc#875631
  bnc#876145).
- bonding: convert netlink to use slave data info api (fate#316924
  bnc#875631 bnc#876145).
- rtnetlink: provide api for getting and setting slave info
  (fate#316924 bnc#875631 bnc#876145).
- rtnetlink: put "BOND" into nl attribute names which are related
  to bonding (fate#316924 bnc#875631 bnc#876145).
- bonding: change name of sysfs dir for bonding slaves
  (fate#316924 bnc#875631 bnc#876145).
- bonding: clean the primary slave if there is no slave matching
  new primary (fate#316924 bnc#875631 bnc#876145).
- bonding: convert slaves to use the new option API (fate#316924
  bnc#875631 bnc#876145).
- bonding: convert lp_interval to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert resend_igmp to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert all_slaves_active to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert queue_id to use the new option API (fate#316924
  bnc#875631 bnc#876145).
- bonding: convert active_slave to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert use_carrier to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert primary_reselect to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert primary to use the new option API (fate#316924
  bnc#875631 bnc#876145).
- bonding: convert miimon to use the new option API (fate#316924
  bnc#875631 bnc#876145).
- bonding: convert num_peer_notif to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert ad_select to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert min_links to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert lacp_rate to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert updelay to use the new option API (fate#316924
  bnc#875631 bnc#876145).
- bonding: convert downdelay to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert arp_ip_target to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert arp_interval to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert fail_over_mac to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert arp_all_targets to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert arp_validate to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert xmit_hash_policy to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert packets_per_slave to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert mode setting to use the new option API
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add infrastructure for an option API (fate#316924
  bnc#875631 bnc#876145).
- reciprocal_divide: update/correction of the algorithm
  (fate#316924 bnc#875631 bnc#876145).
- net: introduce reciprocal_scale helper and convert users
  (fate#316924 bnc#875631 bnc#876145).
- random32: add prandom_u32_max and convert open coded users
  (fate#316924 bnc#875631 bnc#876145).
- bond: make slave_sysfs_ops static (fate#316924 bnc#875631
  bnc#876145).
- bonding: add netlink attributes to slave link dev (fate#316924
  bnc#875631 bnc#876145).
- bonding: add sysfs /slave dir for bond slave devices
  (fate#316924 bnc#875631 bnc#876145).
- bonding: handle slave's name change with primary_slave logic
  (fate#316924 bnc#875631 bnc#876145).
- bonding: use __dev_get_by_name instead of dev_get_by_name to
  find interface (fate#316924 bnc#875631 bnc#876145).
- bonding: fix __get_active_agg() RCU logic (fate#316924
  bnc#875631 bnc#876145).
- bonding: fix __get_first_agg RCU usage (fate#316924 bnc#875631
  bnc#876145).
- bonding: fix bond_3ad_set_carrier() RCU usage (fate#316924
  bnc#875631 bnc#876145).
- bonding: remove dead code from 3ad (fate#316924 bnc#875631
  bnc#876145).
- bonding: convert 3ad to use pr_warn instead of pr_warning
  (fate#316924 bnc#875631 bnc#876145).
- bonding: clean up style for bond_3ad.c (fate#316924 bnc#875631
  bnc#876145).
- bonding: fix kstrtou8() return value verification in
  num_peer_notif (fate#316924 bnc#875631 bnc#876145).
- bonding: add bounds checking for tbl params (fate#316924
  bnc#875631 bnc#876145).
- bonding: fix netlink msg size (fate#316924 bnc#875631
  bnc#876145).
- bonding: add ad_info attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add ad_select attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add lacp_rate attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: make more functions static (fate#316924 bnc#875631
  bnc#876145).
- bonding: use ether_addr_equal_64bits to instead of
  ether_addr_equal (fate#316924 bnc#875631 bnc#876145).
- bonding: remove the return value for bond_3ad_bind_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unwanted return value for bond_dev_queue_xmit()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: slight optimizztion for bond_slave_override()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: slight optimization for bond_alb_xmit() (fate#316924
  bnc#875631 bnc#876145).
- bonding: slight optimization for bond_3ad_xmit_xor()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: use ether_addr_equal_unaligned for bond addr compare
  (fate#316924 bnc#875631 bnc#876145).
- bonding: ust micro BOND_NO_USE_ARP to simplify the mode check
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add option lp_interval for loading module (fate#316924
  bnc#875631 bnc#876145).
- bonding: make local function static (fate#316924 bnc#875631
  bnc#876145).
- bonding: add packets_per_slave attribute netlink support
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add lp_interval attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add min_links attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add all_slaves_active attribute netlink support
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add num_grat_arp attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: protect port for bond_3ad_handle_link_change()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: protect port for bond_3ad_adapter_duplex_changed()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: protect port for bond_3ad_adapter_speed_changed()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add resend_igmp attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add xmit_hash_policy attribute netlink support
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add fail_over_mac attribute netlink support
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add primary_select attribute netlink support
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add primary attribute netlink support (fate#316924
  bnc#875631 bnc#876145).
- bondnl: use be32 nla put/get for be32 values (fate#316924
  bnc#875631 bnc#876145).
- bonding: rebuild the bond_resend_igmp_join_requests_delayed()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unwanted lock for bond_store_primaryxxx()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unwanted lock for bond_option_active_slave_set()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add RCU for bond_3ad_state_machine_handler()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unwanted lock for bond enslave and release
  (fate#316924 bnc#875631 bnc#876145).
- bonding: rebuild the lock use for bond_activebackup_arp_mon()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: create bond_first_slave_rcu() (fate#316924 bnc#875631
  bnc#876145).
- net: add a possibility to get private from netdev_adjacent->list
  (fate#316924 bnc#875631 bnc#876145).
- net: add for_each iterators through neighbour lower link's
  private (fate#316924 bnc#875631 bnc#876145).
- bonding: rebuild the lock use for bond_loadbalance_arp_mon()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: rebuild the lock use for bond_alb_monitor()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: rebuild the lock use for bond_mii_monitor()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove the no effect lock for
  bond_select_active_slave() (fate#316924 bnc#875631 bnc#876145).
- bonding: add arp_all_targets netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add arp_validate netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add arp_ip_target netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add arp_interval netlink support (fate#316924
  bnc#875631 bnc#876145).
- bonding: add use_carrier netlink support (fate#316924 bnc#875631
  bnc#876145).
- bonding: add downdelay netlink support (fate#316924 bnc#875631
  bnc#876145).
- bonding: add updelay netlink support (fate#316924 bnc#875631
  bnc#876145).
- bonding: add miimon netlink support (fate#316924 bnc#875631
  bnc#876145).
- bonding: Use RCU_INIT_POINTER() for better overhead and for
  sparse (fate#316924 bnc#875631 bnc#876145).
- ipv4: fix wildcard search with inet_confirm_addr() (fate#316924
  bnc#875631 bnc#876145).
- bonding: fix packets_per_slave showing (fate#316924 bnc#875631
  bnc#876145).
- drivers/net/*: Fix FSF address in file headers (fate#316924
  bnc#875631 bnc#876145).
- bonding: add arp_ip_target checks when install the module
  (fate#316924 bnc#875631 bnc#876145).
- bonding: disable arp and enable mii monitoring when bond change
  to no uses arp mode (fate#316924 bnc#875631 bnc#876145).
- bonding: add ip checks when store ip target (fate#316924
  bnc#875631 bnc#876145).
- bonding: extend round-robin mode with packets_per_slave
  (fate#316924 bnc#875631 bnc#876145).
- bonding: bond_get_size() returns wrong size (fate#316924
  bnc#875631 bnc#876145).
- Revert "Merge branch 'bonding_monitor_locking'" (fate#316924
  bnc#875631 bnc#876145).
- bonding: remove bond read lock for
  bond_3ad_state_machine_handler() (fate#316924 bnc#875631
  bnc#876145).
- bonding: remove bond read lock for bond_activebackup_arp_mon()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond read lock for bond_loadbalance_arp_mon()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond read lock for bond_alb_monitor()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond read lock for bond_mii_monitor()
  (fate#316924 bnc#875631 bnc#876145).
- net: fix rtnl notification in atomic context (fate#316924
  bnc#875631 bnc#876145).
- dev: always advertise rx_flags changes via netlink (fate#316924
  bnc#875631 bnc#876145).
- dev: update __dev_notify_flags() to send rtnl msg (fate#316924
  bnc#875631 bnc#876145).
- net: Separate the close_list and the unreg_list v2 (fate#316924
  bnc#875631 bnc#876145).
- bonding: move bond-specific init after enslave happens
  (fate#316924 bnc#875631 bnc#876145).
- bonding: Remove __exit tag from bond_netlink_fini() (fate#316924
  bnc#875631 bnc#876145).
- bonding: add Netlink support active_slave option (fate#316924
  bnc#875631 bnc#876145).
- bonding: add Netlink support mode option (fate#316924 bnc#875631
  bnc#876145).
- bonding: move active_slave getting into separate function
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond_ioctl_change_active() (fate#316924
  bnc#875631 bnc#876145).
- bonding: move active_slave setting into separate function
  (fate#316924 bnc#875631 bnc#876145).
- bonding: move mode setting into separate function (fate#316924
  bnc#875631 bnc#876145).
- bonding: push Netlink bits into separate file (fate#316924
  bnc#875631 bnc#876145).
- bonding: add rtnl lock and remove read lock for bond sysfs
  (fate#316924 bnc#875631 bnc#876145).
- bonding: use RCU protection for alb xmit path (fate#316924
  bnc#875631 bnc#876145).
- bonding: use RCU protection for 3ad xmit path (fate#316924
  bnc#875631 bnc#876145).
- bonding: ensure that TLB mode's active slave has correct mac
  filter (fate#316924 bnc#875631 bnc#876145).
- bonding: modify the old and add new xmit hash policies
  (fate#316924 bnc#875631 bnc#876145).
- flow_dissector: factor out the ports extraction in
  skb_flow_get_ports (fate#316924 bnc#875631 bnc#876145).
- bonding: trivial: remove forgotten bond_next_vlan() (fate#316924
  bnc#875631 bnc#876145).
- bonding: remove bond_next_slave() (fate#316924 bnc#875631
  bnc#876145).
- bonding: don't use bond_next_slave() in bond_info_seq_next()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove unused __get_next_agg() (fate#316924 bnc#875631
  bnc#876145).
- bonding: make bond_3ad_unbind_slave() use bond_for_each_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: make ad_agg_selection_logic() use bond_for_each_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: make __get_active_agg() use bond_for_each_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: make ad_port_selection_logic() use
  bond_for_each_slave() (fate#316924 bnc#875631 bnc#876145).
- bonding: remove __get_first_port() (fate#316924 bnc#875631
  bnc#876145).
- bonding: remove __get_next_port() (fate#316924 bnc#875631
  bnc#876145).
- bonding: verify if we still have slaves in
  bond_3ad_unbind_slave() (fate#316924 bnc#875631 bnc#876145).
- bonding: correctly verify for the first slave in bond_enslave
  (fate#316924 bnc#875631 bnc#876145).
- sysfs: make attr namespace interface less convoluted
  (fate#316924 bnc#875631 bnc#876145).
- net: create sysfs symlinks for neighbour devices (fate#316924
  bnc#875631 bnc#876145).
- net: expose the master link to sysfs, and remove it from bond
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove slave lists (fate#316924 bnc#875631 bnc#876145).
- bonding: use neighbours for bond_next_slave() (fate#316924
  bnc#875631 bnc#876145).
- bonding: add __bond_next_slave() which uses neighbours
  (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond_prev_slave() (fate#316924 bnc#875631
  bnc#876145).
- bonding: convert first/last slave logic to use neighbours
  (fate#316924 bnc#875631 bnc#876145).
- bonding: convert bond_has_slaves() to use the neighbour list
  (fate#316924 bnc#875631 bnc#876145).
- bonding: add bond_has_slaves() and use it (fate#316924
  bnc#875631 bnc#876145).
- bonding: remove unused bond_for_each_slave_from() (fate#316924
  bnc#875631 bnc#876145).
- bonding: rework bond_ab_arp_probe() to use bond_for_each_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: rework bond_find_best_slave() to use
  bond_for_each_slave() (fate#316924 bnc#875631 bnc#876145).
- bonding: rework rlb_next_rx_slave() to use bond_for_each_slave()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: rework bond_3ad_xmit_xor() to use bond_for_each_slave()
  only (fate#316924 bnc#875631 bnc#876145).
- bonding: use bond_for_each_slave() in bond_uninit() (fate#316924
  bnc#875631 bnc#876145).
- bonding: make bond_for_each_slave() use lower neighbour's
  private (fate#316924 bnc#875631 bnc#876145).
- bonding: remove bond_for_each_slave_continue_reverse()
  (fate#316924 bnc#875631 bnc#876145).
- bonding: modify bond_get_slave_by_dev() to use neighbours
  (fate#316924 bnc#875631 bnc#876145).
- bonding: populate neighbour's private on enslave (fate#316924
  bnc#875631 bnc#876145).
- commit 63ca74b
* Fri May  9 2014 mmarek@suse.cz
- Revert ppc64le ABI v2 series (bnc#877077)
- commit 6bae7f7
* Fri May  9 2014 spargaonkar@suse.com
- fnic: Correcting warnings given by Smatch and Sparse tool
  (bnc#876870).
- commit c9fbd0c
* Fri May  9 2014 spargaonkar@suse.com
- fnic: Assign FIP_ALL_FCF_MACS to fcoe_all_fcfs (bnc#876870).
- commit f08cdaf
* Fri May  9 2014 mkubecek@suse.cz
- remove the original bonding netlink series (to be replaced by
  a complete 3.12..3.14
- Delete
  patches.drivers/bonding-Remove-__exit-tag-from-bond_netlink_fini.patch.
- Delete
  patches.drivers/bonding-add-Netlink-support-active_slave-option.patch.
- Delete
  patches.drivers/bonding-add-Netlink-support-mode-option.patch.
- Delete
  patches.drivers/bonding-add-ad_info-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-ad_select-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-all_slaves_active-attribute-netlink-supp.patch.
- Delete
  patches.drivers/bonding-add-arp_all_targets-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-arp_interval-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-arp_ip_target-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-arp_validate-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-bond_has_slaves-and-use-it.patch.
- Delete
  patches.drivers/bonding-add-downdelay-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-fail_over_mac-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-ip-checks-when-store-ip-target.patch.
- Delete
  patches.drivers/bonding-add-lacp_rate-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-lp_interval-attribute-netlink-support.patch.
- Delete patches.drivers/bonding-add-miimon-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-min_links-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-netlink-attributes-to-slave-link-dev.patch.
- Delete
  patches.drivers/bonding-add-num_grat_arp-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-packets_per_slave-attribute-netlink-supp.patch.
- Delete
  patches.drivers/bonding-add-primary-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-primary_select-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-resend_igmp-attribute-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-sysfs-slave-dir-for-bond-slave-devices.patch.
- Delete
  patches.drivers/bonding-add-updelay-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-use_carrier-netlink-support.patch.
- Delete
  patches.drivers/bonding-add-xmit_hash_policy-attribute-netlink-suppo.patch.
- Delete
  patches.drivers/bonding-bond_get_size-returns-wrong-size.patch.
- Delete
  patches.drivers/bonding-change-name-of-sysfs-dir-for-bonding-slaves.patch.
- Delete
  patches.drivers/bonding-convert-netlink-to-use-slave-data-info-api.patch.
- Delete
  patches.drivers/bonding-correctly-verify-for-the-first-slave-in-bond.patch.
- Delete
  patches.drivers/bonding-disable-arp-and-enable-mii-monitoring-when-b.patch.
- Delete
  patches.drivers/bonding-extend-round-robin-mode-with-packets_per_sla.patch.
- Delete
  patches.drivers/bonding-fix-kstrtou8-return-value-verification-in-nu.patch.
- Delete
  patches.drivers/bonding-fix-locking-in-bond_loadbalance_arp_mon.patch.
- Delete patches.drivers/bonding-fix-netlink-msg-size.patch.
- Delete
  patches.drivers/bonding-fix-packets_per_slave-showing.patch.
- Delete
  patches.drivers/bonding-move-active_slave-getting-into-separate-func.patch.
- Delete
  patches.drivers/bonding-move-active_slave-setting-into-separate-func.patch.
- Delete
  patches.drivers/bonding-move-mode-setting-into-separate-function.patch.
- Delete
  patches.drivers/bonding-populate-neighbour-s-private-on-enslave.patch.
- Delete
  patches.drivers/bonding-push-Netlink-bits-into-separate-file.patch.
- Delete
  patches.drivers/bonding-remove-bond_ioctl_change_active.patch.
- Delete
  patches.drivers/bonding-verify-if-we-still-have-slaves-in-bond_3ad_u.patch.
- Delete
  patches.drivers/net-fix-rtnl-notification-in-atomic-context.patch.
- Delete
  patches.drivers/rtnetlink-add-missing-IFLA_BOND_AD_INFO_UNSPEC.patch.
- Delete
  patches.drivers/rtnetlink-provide-api-for-getting-and-setting-slave-.patch.
- Delete
  patches.drivers/rtnetlink-put-BOND-into-nl-attribute-names-which-are.patch.
- Delete
  patches.drivers/rtnetlink-remove-IFLA_BOND_SLAVE-definition.patch.
- Delete patches.drivers/rtnetlink-remove-ndo_get_slave.patch.
- Delete
  patches.fixes/bonding-disallow-enslaving-a-bond-to-itself.patch.
- commit c837aaf
* Fri May  9 2014 jslaby@suse.cz
- Linux 3.12.19 (FATE#310031 FATE#316958 SUSE39204 bnc#861528
  bnc#862389 bnc#862996 bnc#866173 bnc#870618 bnc#870880
  bnc#871899 bnc#872355).
- Delete
  patches.arch/amd64_edac-fix-logic-to-determine-channel-for-f15-m30h-processors.patch.
- Delete
  patches.arch/x86-quirks-add-workaround-for-amd-f16h-erratum792.patch.
- Delete
  patches.drivers/Bluetooth-Add-support-for-Intel-Bluetooth-device-808.
- Delete patches.fixes/bdi-Avoid-oops-on-device-removal.patch.
- Delete patches.fixes/bdi-Fix-hung-task-on-sync.patch.
- Delete patches.fixes/dev_mem-read-write-beyond-EOF.patch.
- Delete
  patches.fixes/iommu-amd-fix-pasid-format-in-invalidate_iotlb_pages-command.patch.
- Delete patches.fixes/ipmi-fix-a-race-restarting-the-timer.patch.
- Delete
  patches.fixes/tty-Set-correct-tty-name-in-active-sysfs-attribute.patch.
- Delete patches.fixes/tulip-quad-NIC-ifdown.
- Delete patches.fixes/virtio-prevent-baloon-soft-lockup.
- Delete
  patches.suse/btrfs-8010-skip-submitting-barrier-for-missing-device.patch.
- commit 9ad5f52
* Fri May  9 2014 jslaby@suse.cz
- Refresh patches.fixes/bdi-Avoid-oops-on-device-removal.patch.
- Refresh patches.fixes/bdi-Fix-hung-task-on-sync.patch.
  Add SHAs.
- commit 5fe946b
* Thu May  8 2014 tiwai@suse.de
- KEYS: correct alignment of system_certificate_list content in
  assembly file (bnc#876705).
- kernel/system_certificate.S: use real contents instead of
  macro GLOBAL() (bnc#876705).
- commit 607beab
* Thu May  8 2014 duwe@suse.de
- FIPS: remove .fips_allowed = 1 for ansi_cprng (bnc#875853).
- commit 8c14644
* Thu May  8 2014 duwe@suse.de
- Refresh
  patches.arch/ppc-perf-16-24x7-catalog-version-number-is-be64.
  Final mainline commit fixes format string warning.
- commit c57a9eb
* Thu May  8 2014 bp@suse.de
- x86/UV: Set n_lshift based on GAM_GR_CONFIG MMR for UV3
  (bnc#876176).
- commit 2464fa3
* Thu May  8 2014 jlee@suse.com
- x86: EFI stub support for large memory maps (bnc#876046).
- efi: use efi_get_memory_map() to get final map for x86
  (bnc#876046).
- efi: generalize efi_get_memory_map() (bnc#876046).
- efi: Rename __get_map() to efi_get_memory_map() (bnc#876046).
- efi: Rename memory allocation/free functions (bnc#876046).
- efi: Add system table pointer argument to shared functions
  (bnc#876046).
- efi: Move common EFI stub code from x86 arch code to common
  location (bnc#876046).
- commit 31792b0
* Wed May  7 2014 jdelvare@suse.de
- supported.conf: Remove outdated entries, part 2
  Remove the few remaining modules which no longer exist or we no
  longer build.
- commit a542e25
* Wed May  7 2014 bp@suse.de
- x86, tools: Fix up compiler warnings (bnc#876559).
- commit c7758b3
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package .vmlinuz-*.hmac as well
- commit 3375bd7
* Wed May  7 2014 duwe@suse.de
- scripts/mod/modpost.c: handle non ABS crc symbols (bnc#863764
  fate#315275, LTC#103998).
- powerpc/ftrace: Fix ABIv2 issues with __ftrace_make_call
  (bnc#863764 fate#315275, LTC#103998).
- powerpc/ftrace: Use module loader helpers to parse trampolines
  (bnc#863764 fate#315275, LTC#103998).
- powerpc/modules: Create module_trampoline_target() (bnc#863764
  fate#315275, LTC#103998).
- powerpc/modules: Create is_module_trampoline() (bnc#863764
  fate#315275, LTC#103998).
- powerpc/kprobes: Fix ABIv2 issues with kprobe_lookup_name
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: ftrace_caller, _mcount is exported to modules so
  needs _GLOBAL_TOC() (bnc#863764 fate#315275, LTC#103998).
- powerpc: Add _GLOBAL_TOC for ABIv2 assembly functions exported
  to modules (bnc#863764 fate#315275, LTC#103998).
- powerpc: Make ftrace endian-safe (bnc#863764 fate#315275,
  LTC#103998).
- powerpc: Build little endian ppc64 kernel with ABIv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc: modules: implement stubs for ELFv2 ABI (bnc#863764
  fate#315275, LTC#103998).
- powerpc: modules: skip r2 setup for ELFv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc: modules: use r12 for stub jump address (bnc#863764
  fate#315275, LTC#103998).
- powerpc: modules: change r2 save/restore offset for ELFv2 ABI
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: modules: comment about de-dotifying symbols when
  using the ELFv2 ABI (bnc#863764 fate#315275, LTC#103998).
- powerpc: Handle new ELFv2 module relocations (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Fix up TOC. for modules (bnc#863764 fate#315275,
  LTC#103998).
- powerpc: module: handle MODVERSION for .TOC (bnc#863764
  fate#315275, LTC#103998).
- powerpc: EXPORT_SYMBOL(.TOC.) (bnc#863764 fate#315275,
  LTC#103998).
- powerpc: modules implement R_PPC64_TOCSAVE relocation
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: make module stub code endian independent (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Fix ABIv2 issue with dereference_function_descriptor
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Fix SMP issues with ppc64le ABIv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc/tracing: TRACE_WITH_FRAME_BUFFER creates invalid stack
  frames (bnc#863764 fate#315275, LTC#103998).
- powerpc/tm: Fix GOT save offset for ABIv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc/tm: Use STK_PARAM (bnc#863764 fate#315275, LTC#103998).
- powerpc: Fix unsafe accesses to parameter area in ELFv2
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Fix ABIv2 issues with stack offsets in assembly code
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Fix kernel thread creation on ABIv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Fix branch patching code for ABIv2 (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Use ppc_function_entry instead of open coding it
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Add ABIv2 support to ppc_function_entry (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Ignore TOC relocations (bnc#863764 fate#315275,
  LTC#103998).
- powerpc: ABIv2 function calls must place target address in r12
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Remove function descriptors and dot symbols on new ABI
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Create DOTSYM to wrap dot symbol usage (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Remove dot symbol usage in exception macros (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Remove _INIT_GLOBAL(), _STATIC() and _INIT_STATIC()
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Remove some unnecessary uses of _GLOBAL() and _STATIC()
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Don't use a function descriptor for system call table
  (bnc#863764 fate#315275, LTC#103998).
- powerpc: Remove superflous function descriptors in assembly
  only code (bnc#863764 fate#315275, LTC#103998).
- powerpc: No need to use dot symbols when branching to a function
  (bnc#863764 fate#315275, LTC#103998).
- powerpc/85xx: add hardware automatically enter pw20 state
  (bnc#863764 fate#315275, LTC#103998).
- powerpc/85xx: add hardware automatically enter altivec idle
  state (bnc#863764 fate#315275, LTC#103998).
- powerpc/booke64: Add LRAT error exception handler (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Move the patch_exception to a common place (bnc#863764
  fate#315275, LTC#103998).
- powerpc: Use 32 bit loads and stores when operating on condition
  register values (bnc#863764 fate#315275, LTC#103998).
- commit de3a5d0
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Exclude /boot/symtypes* from the base/main package
  Also, get rid of the comparison of the base and devel filelist.
- commit f1e303f
* Wed May  7 2014 tiwai@suse.de
- [media] ivtv: Fix Oops when no firmware is loaded (bnc#875440).
- commit 70c49bd
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Add dock pin setups for Thinkpad T440 (bnc#876699).
- commit 426b6bb
* Wed May  7 2014 ohering@suse.de
- Drivers: hv: balloon: Ensure pressure reports are posted
  regularly.
- commit 53a03c9
* Wed May  7 2014 ohering@suse.de
- hv: Remove unnecessary comparison of unsigned against 0.
- commit 0db8018
* Wed May  7 2014 ohering@suse.de
- hyperv: Enable sendbuf mechanism on the send path.
- commit cbb77d5
* Wed May  7 2014 ptesarik@suse.cz
- Delete patches.suse/acpi-blacklist-dell-latitude-e6410.patch.
  (Proper fix is to handle Win+P in GNOME.)
- commit 9663e34
* Wed May  7 2014 ohering@suse.de
- hyperv: Simplify the send_completion variables.
- commit af50d38
* Wed May  7 2014 ohering@suse.de
- hyperv: Remove recv_pkt_list and lock.
- commit 724f977
* Wed May  7 2014 ptesarik@suse.cz
- Delete patches.suse/hid-drff-alias.patch.
- commit 5ce5581
* Wed May  7 2014 ohering@suse.de
- hyperv: Properly handle checksum offload.
- commit 005b68f
* Wed May  7 2014 ohering@suse.de
- Tools: hv: Handle the case when the target file exists
  correctly.
- commit b84025c
* Wed May  7 2014 ohering@suse.de
- add mainline tags for some hv patches
- commit caaa642
* Tue May  6 2014 bp@suse.de
- iommu/vt-d: Be less pessimistic about domain coherency where
  possible (fate#317112).
- iommu/vt-d: Honour intel_iommu=sp_off for non-VMM domains
  (fate#317112).
- iommu/vt-d: Clean up and fix page table clear/free behaviour
  (fate#317112).
- iommu/vt-d: Clean up size handling for intel_iommu_unmap()
  (fate#317112).
- iommu/vt-d: Update IOMMU state when memory hotplug happens
  (fate#317112).
- iommu/vt-d: Unify the way to process DMAR device scope array
  (fate#317112).
- iommu/vt-d: Update DRHD/RMRR/ATSR device scope caches when
  PCI hotplug happens (fate#317112).
- iommu/vt-d: Use RCU to protect global resources in interrupt
  context (fate#317112).
- iommu/vt-d: Introduce a rwsem to protect global data structures
  (fate#317112).
- iommu/vt-d: Introduce macro for_each_dev_scope() to walk device
  scope entries (fate#317112).
- iommu/vt-d: Fix error in detect ATS capability (fate#317112).
- iommu/vt-d: Check for NULL pointer when freeing IOMMU data
  structure (fate#317112).
- iommu/vt-d: Fix incorrect iommu_count for si_domain
  (fate#317112).
- iommu/vt-d: Reduce duplicated code to handle virtual machine
  domains (fate#317112).
- iommu/vt-d: Free resources if failed to create domain for PCIe
  endpoint (fate#317112).
- iommu/vt-d: Simplify function get_domain_for_dev()
  (fate#317112).
- iommu/vt-d: Move private structures and variables into
  intel-iommu.c (fate#317112).
- iommu/vt-d: Factor out dmar_alloc_dev_scope() for later reuse
  (fate#317112).
- iommu/vt-d: Avoid caching stale domain_device_info when
  hot-removing PCI device (fate#317112).
- iommu/vt-d: Avoid caching stale domain_device_info and fix
  memory leak (fate#317112).
- iommu/vt-d: Avoid double free of g_iommus on error recovery path
  (fate#317112).
- drivers/iommu/omap-iommu-debug.c: fix decimal permissions
  (fate#317112).
- iommu/amd: Use dev_is_pci() to check whether it is pci device
  (fate#317112).
- iommu/vt-d: Fix signedness bug in alloc_irte() (fate#317112).
- iommu/vt-d: free all resources if failed to initialize DMARs
  (fate#317112).
- iommu/vt-d, trivial: clean sparse warnings (fate#317112).
- iommu/vt-d: fix wrong return value of dmar_table_init()
  (fate#317112).
- iommu/vt-d: release invalidation queue when destroying IOMMU
  unit (fate#317112).
- iommu/vt-d: fix access after free issue in function
  free_dmar_iommu() (fate#317112).
- iommu/vt-d: keep shared resources when failed to initialize
  iommu devices (fate#317112).
- iommu/vt-d: fix invalid memory access when freeing DMAR irq
  (fate#317112).
- iommu/vt-d, trivial: simplify code with existing macros
  (fate#317112).
- iommu/vt-d, trivial: use defined macro instead of hardcoding
  (fate#317112).
- iommu/vt-d: mark internal functions as static (fate#317112).
- iommu/vt-d, trivial: clean up unused code (fate#317112).
- iommu/vt-d, trivial: check suitable flag in function
  detect_intel_iommu() (fate#317112).
- iommu/vt-d, trivial: print correct domain id of static identity
  domain (fate#317112).
- iommu/vt-d, trivial: refine support of 64bit guest address
  (fate#317112).
- iommu/vt-d: fix resource leakage on error recovery path in
  iommu_init_domains() (fate#317112).
- iommu/vt-d: fix a race window in allocating domain ID for
  virtual machines (fate#317112).
- iommu/vt-d: fix PCI device reference leakage on error recovery
  path (fate#317112).
- iommu/vt-d: use dedicated bitmap to track remapping entry
  allocation status (fate#317112).
- iommu/vt-d: Use dev_is_pci() to check whether it is pci device
  (fate#317112).
- iommu/vt-d: Mark function eoi_ioapic_pin_remapped() as static
  in irq_remapping.c (fate#317112).
- iommu/vt-d: Mark functions as static in intel_irq_remapping.c
  (fate#317112).
- iommu/vt-d: Mark functions as static in dmar.c (fate#317112).
- iommu/vt-d: Use list_for_each_entry_safe() for
  dmar_domain->devices traversal (fate#317112).
- iommu/vt-d: Use for_each_drhd_unit() instead of
  list_for_each_entry() (fate#317112).
- iommu: No need to pass '0x' when '%%pa' is used (fate#317112).
- ACPICA: Update DMAR table definitions (fate#317112).
- commit 9e48ef7
* Tue May  6 2014 bpoirier@suse.de
- cxgb4vf: Adds device Id for few more Chelsio adapters
  (bnc#863630 FATE#315956).
- commit 0208e4e
* Tue May  6 2014 bpoirier@suse.de
- cxgb4: use the correct max size for firmware flash (bnc#863619
  FATE#315951).
- cxgb4: Save the correct mac addr for hw-loopback connections
  in the L2T (bnc#863619 FATE#315951).
- cxgb4: Adds device ID for few more Chelsio Adapters (bnc#863619
  FATE#315951).
- cxgb4/iw_cxgb4: Doorbell Drop Avoidance Bug Fixes (bnc#863619
  FATE#315951).
- cxgb4/iw_cxgb4: Treat CPL_ERR_KEEPALV_NEG_ADVICE as negative
  advice (bnc#863619 FATE#315951).
- cxgb4: Calculate len properly for LSO path (bnc#863619
  FATE#315951).
- cxgb4: Updates for T5 SGE's Egress Congestion Threshold
  (bnc#863619 FATE#315951).
- cxgb4: Fix some small bugs in t4_sge_init_soft() when our Page
  Size is 64KB (bnc#863619 FATE#315951).
- cxgb4: Add more PCI device ids (bnc#863619 FATE#315951).
- cxgb4: Don't assume LSO only uses SGL path in t4_eth_xmit()
  (bnc#863619 FATE#315951).
- cxgb4: Remove unused registers and add missing ones (bnc#863619
  FATE#315951).
- cxgb4: Query firmware for T5 ULPTX MEMWRITE DSGL capabilities
  (bnc#863619 FATE#315951).
- cxgb4: LE-Workaround is not atomic in firmware (bnc#863619
  FATE#315951).
- cxgb4: Allow >10G ports to have multiple queues (bnc#863619
  FATE#315951).
- cxgb4: Add support to recognize 40G links (bnc#863619
  FATE#315951).
- commit 649b9f5
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix packaging of vmlinux debuginfo
  (bnc#875946)
  Add the uncompressed vmlinux image as ghost file to the main package, so
  that the vmlinux debuginfo generated by rpm natively and put into the
  right package.
- commit 26b7a64
* Tue May  6 2014 tiwai@suse.de
- fbdev/fb.h: silence warning with -Wsign-compare (bnc#876357).
- bitops: Fix signedness of compile-time hweight implementations
  (bnc#876357).
- commit 3144963
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Simplify filelist for files in /boot
- commit ef040ff
* Tue May  6 2014 duwe@suse.de
- powerpc/powernv: Fix endian issues with OPAL async code
  (bnc#875242).
- powerpc/powernv: Enable reading and updating of system
  parameters (bnc#875242).
- powerpc/powernv: Create opal sysfs directory (bnc#875242).
- powerpc/powernv: Infrastructure to support OPAL async completion
  (bnc#875242).
- powerpc/powernv: Infrastructure to read opal messages in
  generic format (bnc#875242).
- KVM: PPC: Book3S HV: Fix KVM hang with CONFIG_KVM_XICS=n
  (bnc#875242).
- KVM: PPC: Book3S: Introduce hypervisor call H_GET_TCE
  (bnc#875242).
- powerpc/powernv: Fix endian issues with sensor code
  (bnc#875242).
- powerpc/powernv: Enable fetching of platform sensor data
  (bnc#875242).
- commit 70b014c
* Tue May  6 2014 mmarek@suse.cz
- ACPI: Remove acpi_pci_slot_init() headers from internal.h.
- commit 3f1c8ec
* Tue May  6 2014 mszeredi@suse.cz
- don't remove from shrink list in select_collect() (bnc#874025).
- update "dentry_kill(): don't try to remove from shrink list"
- commit eb79b63
* Tue May  6 2014 jbohac@suse.cz
- timer: Prevent overflow in apply_slack (bnc#873061).
- commit 9a17ef7
* Tue May  6 2014 glin@suse.com
- libata/ahci: accommodate tag ordered controllers (bnc#871729)
- commit 80a53c7
* Tue May  6 2014 neilb@suse.de
- md: try to remove cause of a spinning md thread (bnc#875386).
- commit f7629c2
* Mon May  5 2014 bp@suse.de
- printk, kmsg: Ratelimit it
- commit bcda8bd
* Mon May  5 2014 duwe@suse.de
- virtio_balloon: don't softlockup on huge balloon changes
  (bnc#871899, bnc#872355).
- commit 8140046
* Mon May  5 2014 jdelvare@suse.de
- supported.conf: Remove outdated entries
  Remove all modules which no longer exist, or which we no longer
  build. I have carefully reviewed each of them to prevent any false
  positive, so hopefully this big cleanup won't break anything.
  Note: modular code which we decided to build into the kernel was not
  removed, on purpose, in case we change our mind later for whatever
  reason.
- commit d04f46d
* Mon May  5 2014 eich@suse.de
- Refresh
  patches.drivers/drm-cirrus-Create-a-sysfs-entry-for-connector.patch.
- commit 7636ec6
* Mon May  5 2014 trenn@suse.de
- Delete
  patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch.
- commit 65af230
* Mon May  5 2014 jslaby@suse.cz
- kvm: x86: ignore ioapic polarity (bnc#556564).
  Add SHA.
- commit abdd631
* Mon May  5 2014 jslaby@suse.cz
- Refresh
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
  Add commit SHA
- commit f8fd3fd
* Mon May  5 2014 jdelvare@suse.de
- supported.conf: generic_bl is supported
  Driver corgi_bl was renamed to generic_bl in kernel 2.6.29, adjust
  supported.conf accordingly.
- commit 6ed3065
* Mon May  5 2014 eich@suse.de
- drm/cirrus: Create a sysfs entry for connector (bnc#876305).
- commit 022e94b
* Mon May  5 2014 jslaby@suse.cz
- n_tty: Fix n_tty_write crash when echoing in raw mode
  (bnc#871252 bnc#875690 CVE-2014-0196).
- commit 7689916
* Sun May  4 2014 jslaby@suse.cz
- mark printing_task kthread with kgr_task_safe (bnc#744692,
  bnc#789311).
- commit 6e66826
* Sun May  4 2014 jslaby@suse.cz
- Refresh patches.suse/kgr-0011-kgr-handle-irqs.patch.
  Include hardirq.h
- commit 44416a0
* Sat May  3 2014 eich@suse.de
- drm/mgag200: Remove connector in sysfs when unloading the driver
  (bnc#876238).
- drm/mgag200: Cleanup cursor BOs properly (bnc#876097).
- drm/mgag200: Add support for MATROX PCI device IDs 0x520
  and 0x521.
- commit 0d2f22d
* Fri May  2 2014 mmarek@suse.cz
- Update xen, debug and vanilla configs wrt. tracing options (fate#317165)
- commit 2b79462
* Fri May  2 2014 mmarek@suse.cz
- Sync -default and -trace configs (fate#317165)
  CONFIG_SCHED_TRACER=y
  CONFIG_FTRACE_SYSCALLS=y
  CONFIG_STACK_TRACER=y
  CONFIG_IRQSOFF_TRACER=n
  CONFIG_DEBUG_ATOMIC_SLEEP=n
  CONFIG_MMIOTRACE=n
  CONFIG_FTRACE_STARTUP_TEST=n
- commit 7e3cc62
* Fri May  2 2014 jkosina@suse.cz
- KDB series cleanup -- all the required functionality is already merged
  (FATE#315262)
- Delete patches.suse/kdb-fix-cpumask-usage.patch.
- Delete patches.suse/kdb-modules-fix-lm.patch.
- Delete patches.suse/kdb-modules-fix-xfs.patch.
- Delete patches.suse/kdb-nmis-are-not-catastrophic.
- Delete patches.suse/kdb-restore-kdb-stack-trace.patch.
- Delete patches.suse/kdb-v4.4-3.1-common-1.
- Delete patches.suse/kdb-v4.4-3.1-x86-1.
- Delete patches.suse/kdb-x86-unlock-nmi-lock-after-kdb-ipi.patch.
- commit c5d0f07
* Fri May  2 2014 mmarek@suse.cz
- offb: Add palette hack for little endian (bnc#874464).
- offb: Little endian fixes (bnc#874464).
- commit 0f157c1
* Fri May  2 2014 mmarek@suse.cz
- Enable CONFIG_MODULE_SIG on ppc64le and s390x (needed for FIPS)
- commit d5fbd07
* Fri May  2 2014 mmarek@suse.cz
- powerpc/mm: fix ".__node_distance" undefined.
- commit 460a76a
* Fri May  2 2014 dsterba@suse.cz
- btrfs: make DEV_INFO ioctl available to anyone.
- btrfs: make FS_INFO ioctl available to anyone.
- commit 0c445f5
* Fri May  2 2014 dsterba@suse.cz
- Btrfs: fix a crash of clone with inline extents's split (bnc#786750).
- Btrfs: fix EINVAL checks in btrfs_clone.
- Btrfs: abort the transaction when we don't find our extent ref.
- btrfs: export global block reserve size as space_info.
- btrfs: replace error code from btrfs_drop_extents.
- Btrfs: use correct key when repeating search for extent item.
- Btrfs: correctly set profile flags on seqlock retry.
- Delete
  patches.suse/btrfs-8027-fix-a-crash-of-clone-with-inline-extents-s-spl.patch.
- commit be734cf
* Fri May  2 2014 mszeredi@suse.cz
- Dentry_kill(): don't try to remove from shrink list
  (bnc#874025).
- commit 0bd77f5
* Thu May  1 2014 mgorman@suse.de
- mm/readahead.c: fix readahead failure for memoryless NUMA nodes and limit readahead pages
  (VM/FS Performance).
- commit ed6707e
* Thu May  1 2014 mgorman@suse.de
- thp: close race between split and zap huge pages
  (Automatic NUMA Balancing (fate#315482)).
- commit 74aa5f7
* Thu May  1 2014 mgorman@suse.de
- mm: filemap: Avoid unnecessary barries and waitqueue lookup
  in unlock_page fastpath (VM/FS Performance).
- mm: Do not use unnecessary atomic operations when adding pages
  to the LRU (VM/FS Performance).
- mm: Do not use atomic operations when releasing pages (VM/FS
  Performance).
- mm: shmem: Avoid atomic operation during shmem_getpage_gfp
  (VM/FS Performance).
- mm: page_alloc: Convert hot/cold parameter and immediate
  callers to bool (VM/FS Performance).
- mm: page_alloc: Use unsigned int for order in more places
  (VM/FS Performance).
- mm: page_alloc: Take the ALLOC_NO_WATERMARK check out of the
  fast path (VM/FS Performance).
- mm: page_alloc: Only check the alloc flags and gfp_mask for
  dirty once (VM/FS Performance).
- mm: page_alloc: Only check the zone id check if pages are
  buddies (VM/FS Performance).
- mm: page_alloc: Calculate classzone_idx once from the zonelist
  ref (VM/FS Performance).
- mm: page_alloc: Use jump labels to avoid checking
  number_of_cpusets (VM/FS Performance).
- mm: page_alloc: Do not treat a zone that cannot be used for
  dirty pages as "full" (VM/FS Performance).
- mm: page_alloc: Do not update zlc unless the zlc is active
  (VM/FS Performance).
- commit 25029b6
* Thu May  1 2014 mgorman@suse.de
- Delete
  patches.suse/mm-filemap-Avoid-unnecessary-barries-and-waitqueue-lookup-in-unlock_page-fastpath.patch.
- commit 11e06d2
* Thu May  1 2014 jslaby@suse.cz
- Refresh
  patches.suse/kgr-0016-kgr-make-a-per-process-in-progress-flag-a-single-bit.patch.
  Apply cleanly.
- commit affd8ca
* Thu May  1 2014 jslaby@suse.cz
- Refresh patches.suse/kgr-0003-kgr-initial-code.patch.
  Fix build on other archs.
- commit d536094
* Wed Apr 30 2014 lduncan@suse.com
- qla4xxx: v5.04.00.00.12.0-k3 (FATE#315934 bnc#874282).
- qla4xxx: Fix smatch warning in func qla4xxx_conn_get_param
  (FATE#315934 bnc#874282).
- qla4xxx: Fix smatch warning in func qla4xxx_get_ep_param
  (FATE#315934 bnc#874282).
- qla4xxx: Fix memory leak for ha->saved_acb (FATE#315934
  bnc#874282).
- qla4xxx: Disable INTx interrupt for ISP82XX (FATE#315934
  bnc#874282).
- commit 3bb1aa3
* Wed Apr 30 2014 jslaby@suse.cz
- ftrace: Add private data to ftrace_ops (fate#313296).
- ftrace: Add function to find fentry of function (fate#313296).
- ftrace: Make ftrace_is_dead available globally (fate#313296).
- kgr: initial code (fate#313296).
- kgr: add testing kgraft patch (fate#313296).
- kgr: update Kconfig documentation (fate#313296).
- kgr: add Documentation (fate#313296).
- kgr: trigger the first check earlier (fate#313296).
- kgr: sched.h, introduce kgr_task_safe helper (fate#313296).
- kgr: mark task_safe in some kthreads (fate#313296).
- kgr: kthreads support (fate#313296).
- kgr: handle irqs (fate#313296).
- kgr: add tools (fate#313296).
- kgr: add MAINTAINERS entry (fate#313296).
- kgr: x86: refuse to build without fentry support (fate#313296).
- kgr: add procfs interface for per-process 'kgr_in_progress'
  (fate#313296).
- kgr: make a per-process 'in progress' flag a single bit
  (fate#313296).
- Refresh patches.xen/xen3-patch-3.10.
- Update config files.
- commit 6c89d39
* Wed Apr 30 2014 hare@suse.de
- ib_isert: Fixup merge error from stable backports (bnc#873901).
- target/tcm_fc: Fix use-after-free of ft_tpg (bnc#873901).
- percpu_ida: Make percpu_ida_alloc + callers accept task state
  (bnc#873901).
- Target/sbc: Initialize COMPARE_AND_WRITE write_sg scatterlist
  (bnc#873901).
- target/tcm_fc: Rename ft_tport_create to ft_tport_get
  (bnc#873901).
- target/tcm_fc: Rename ft_{add,del}_lport to {add,del}_wwn
  (bnc#873901).
- target/tcm_fc: Rename structs and list members for clarity
  (bnc#873901).
- target/tcm_fc: Limit to 1 TPG per wwn (bnc#873901).
- target/tcm_fc: Don't export ft_lport_list (bnc#873901).
- target: Add check to prevent Abort Task from aborting itself
  (bnc#873901).
- target: Enable READ_STRIP emulation in target_complete_ok_work
  (bnc#873901).
- target/sbc: Add sbc_dif_read_strip software emulation
  (bnc#873901).
- target: Enable WRITE_INSERT emulation in target_execute_cmd
  (bnc#873901).
- target/sbc: Add sbc_dif_generate software emulation
  (bnc#873901).
- target/sbc: Only expose PI read_cap16 bits when supported by
  fabric (bnc#873901).
- target/spc: Only expose PI mode page bits when supported by
  fabric (bnc#873901).
- target/spc: Only expose PI inquiry bits when supported by fabric
  (bnc#873901).
- target: Pass in transport supported PI at session initialization
  (bnc#873901).
- tcm_fc: Convert to per-cpu command map pre-allocation of ft_cmd
  (bnc#873901).
- target/iblock: Fix double bioset_integrity_free bug
  (bnc#873901).
- target/rd: T10-Dif: RAM disk is allocating more space than
  required (bnc#873901).
- iscsi-target: Fix ERL=2 ASYNC_EVENT connection pointer bug
  (bnc#873901).
- Target/iser: Use Fastreg only if device supports signature
  (bnc#873901).
- iser-target: Add missing se_cmd put for WRITE_PENDING in
  tx_comp_err (bnc#873901).
- target: Add TFO->abort_task for aborted task resources release
  (bnc#873901).
- target: Fix Task Aborted Status (TAS) handling (bnc#873901).
- iser-target: Match FRMR descriptors to available session tags
  (bnc#873901).
- Target/iser: Fail SCSI WRITE command if device detected
  integrity (bnc#873901).
- Target/iser: Move check signature status to a function
  (bnc#873901).
- Target/iser: Consider DIF and RDMA_READ completions when
  calculating (bnc#873901).
- Target/iser: Fix signature work requests accounting
  (bnc#873901).
- iscsi-target: Add missing NopOUT->flag (LMB) sanity check
  (bnc#873901).
- IB/isert: Support T10-PI protected transactions (bnc#873901).
- IB/isert: Accept RDMA_WRITE completions (bnc#873901).
- IB/isert: Initialize T10-PI resources (bnc#873901).
- IB/isert: Introduce isert_map/unmap_data_buf (bnc#873901).
- Target/sbc: add debug print (bnc#873901).
- Target/configfs: Expose iSCSI network portal group T10-PI
  support (bnc#873901).
- Target/iscsi: Add T10-PI indication for iscsi_portal_group
  (bnc#873901).
- Target/core: Remove prot_handover use for now (bnc#873901).
- Target/dif: Introduce protection-passthough-only mode
  (bnc#873901).
- Target/file: place escape values for protection information
  format (bnc#873901).
- Target/sbc: Set protection operation and relevant checks
  (bnc#873901).
- Target/transport: Allocate protection sg if needed (bnc#873901).
- target: silence GCC warning in target_alua_state_check
  (bnc#873901).
- Target/sbc: Fix sbc_copy_prot for offset scatters (bnc#873901).
- iser-target: Fix command leak for tx_desc->comp_llnode_batch
  (bnc#873901).
- vhost/scsi: Check LUN structure byte 0 is set to 1, per spec
  (bnc#873901).
- Target/sbc: Don't use sg as iterator in sbc_verify_read
  (bnc#873901).
- target: Add DIF sense codes in transport_generic_request_failure
  (bnc#873901).
- target/sbc: Fix sbc_dif_copy_prot addr offset bug (bnc#873901).
- Target/sbc: Fix protection copy routine (bnc#873901).
- IB/srpt: replace strict_strtoul() with kstrtoul() (bnc#873901).
- target: Simplify command completion by removing CMD_T_FAILED
  flag (bnc#873901).
- iser-target: Fix leak on failure in
  isert_conn_create_fastreg_pool (bnc#873901).
- iscsi-target: Fix SNACK Type 1 + BegRun=0 handling (bnc#873901).
- target: Fix missing length check in spc_emulate_evpd_83()
  (bnc#873901).
- qla2xxx: Remove last vestiges of qla_tgt_cmd.cmd_list
  (bnc#873901).
- target: Fix 32-bit + CONFIG_LBDAF=n link error w/ sector_div
  (bnc#873901).
- target: Fix percpu_ref_put race in transport_lun_remove_cmd
  (bnc#873901).
- target: Report bad sector in sense data for DIF errors
  (bnc#873901).
- iscsi-target: Convert gfp_t parameter to task state bitmask
  (bnc#873901).
- IB/isert: pass scatterlist instead of cmd to fast_reg_mr routine
  (bnc#873901).
- IB/isert: Move fastreg descriptor creation to a function
  (bnc#873901).
- IB/isert: Avoid frwr notation, user fastreg (bnc#873901).
- IB/isert: seperate connection protection domains and dma MRs
  (bnc#873901).
- tcm_loop: Enable DIF/DIX modes in SCSI host LLD (bnc#873901).
- target/rd: Add DIF protection into rd_execute_rw (bnc#873901).
- target/rd: Add support for protection SGL setup + release
  (bnc#873901).
- target/rd: Refactor rd_build_device_space +
  rd_release_device_space (bnc#873901).
- target/file: Add DIF protection support to fd_execute_rw
  (bnc#873901).
- target/file: Add DIF protection init/format support
  (bnc#873901).
- target/iblock: Add blk_integrity + BIP passthrough support
  (bnc#873901).
- target: Add protection SGLs to target_submit_cmd_map_sgls
  (bnc#873901).
- target/configfs: Expose protection device attributes
  (bnc#873901).
- target/spc: Expose ATO bit in control mode page (bnc#873901).
- target/sbc: Add P_TYPE + PROT_EN bits to READ_CAPACITY_16
  (bnc#873901).
- target/spc: Add protection related bits to INQUIRY EVPD=0x86
  (bnc#873901).
- target/spc: Add protection bit to standard INQUIRY output
  (bnc#873901).
- target/sbc: Add DIF TYPE1+TYPE3 read/write verify emulation
  (bnc#873901).
- target/sbc: Add DIF setup in sbc_check_prot + sbc_parse_cdb
  (bnc#873901).
- target: Add DIF CHECK_CONDITION ASC/ASCQ exception cases
  (bnc#873901).
- target: Add DIF related base definitions (bnc#873901).
- target: Convert inquiry temporary buffer to heap memory
  (bnc#873901).
- target_core_alua: check for buffer overflow (bnc#873901).
- drivers: target: Mark functions and structures as static in
  (bnc#873901).
- drivers: target: Mark functions as static in tcm_loop.c
  (bnc#873901).
- drivers: target: Mark function as static in target_core_iblock.c
  (bnc#873901).
- drivers: target: Move prototype declaration of function to
  header (bnc#873901).
- target_core_alua: Referrals configfs integration (bnc#873901).
- target_core_alua: Referrals infrastructure (bnc#873901).
- qla2xxx: Fix scsi_host leak on qlt_lport_register callback
  failure (bnc#873901).
- target: Remove extra percpu_ref_init (bnc#873901).
- target_core_spc: Include target device descriptor in VPD page 83
  (bnc#873901).
- target_core: simplify scsi_name_len calculation (bnc#873901).
- target_core_alua: Use workqueue for ALUA transitioning
  (bnc#873901).
- target_core_alua: store old and pending ALUA state (bnc#873901).
- target_core_alua: Allocate ALUA metadata on demand (bnc#873901).
- target_core_alua: validate ALUA state transition (bnc#873901).
- target: Don't use void* when passing dev in core_tpg_add_lun
  (bnc#873901).
- target: Rename core_tpg_{pre,post}_addlun for clarity
  (bnc#873901).
- target: Refer to u32 luns as unpacked_lun (bnc#873901).
- target: Fix sizeof in kmalloc for some default_groups arrays
  (bnc#873901).
- target: Allocate more room for port default groups (bnc#873901).
- target: Remove unused ua_dev_list member in struct se_ua
  (bnc#873901).
- target: Remove write-only stats fields and lock from struct
  (bnc#873901).
- iscsi-target: return -EINVAL on oversized configfs parameter
  (bnc#873901).
- iscsi-target: Expose default_erl as TPG attribute (bnc#873901).
- target_core_configfs: split up ALUA supported states
  (bnc#873901).
- target_core_alua: Make supported states configurable
  (bnc#873901).
- target_core_alua: Store supported ALUA states (bnc#873901).
- target_core_alua: Rename ALUA_ACCESS_STATE_OPTIMIZED
  (bnc#873901).
- target_core_alua: spellcheck (bnc#873901).
- target core: rename (ex,im)plict -> (ex,im)plicit (bnc#873901).
- percpu-refcount: Add percpu-refcount.o to obj-y (bnc#873901).
- iscsi-target: Do not reject non-immediate CmdSNs exceeding
  MaxCmdSN (bnc#873901).
- iscsi-target: Convert iscsi_session statistics to atomic_long_t
  (bnc#873901).
- target: Convert se_device statistics to atomic_long_t
  (bnc#873901).
- iscsi-target: Reject unsupported multi PDU text command sequence
  (bnc#873901).
- target: Core does not need blkdev.h (bnc#873901).
- target: Pass through I/O topology for block backstores
  (bnc#873901).
- target: Add per device xcopy_lun for copy offload I/O
  (bnc#873901).
- target: Drop left-over se_lun->lun_cmd_list shutdown code
  (bnc#873901).
- target: Add percpu refcounting for se_lun access (bnc#873901).
- iscsi-target: Do not generate REJECTs for zero-length DataOUT
  (bnc#873901).
- ib_isert: Add support for completion interrupt coalescing
  (bnc#873901).
- iscsi-target: Implement demo_mode_discovery logic (bnc#873901).
- target: Export symbol core_tpg_check_initiator_node_acl
  (bnc#873901).
- iscsi-target: Add new TPG attribute (bnc#873901).
- tcm_loop: Implement target reset (bnc#873901).
- tcm_loop: TCQ and command abort support (bnc#873901).
- tcm_loop: separate out tcm_loop_issue_tmr (bnc#873901).
- tcm_loop: Implement transport offline (bnc#873901).
- tcm_loop: Check for valid hba in tcm_loop_drop_nexus()
  (bnc#873901).
- target/qla2xxx: Remove QLA_TPG_ATTRIB macro (bnc#873901).
- target/iscsi: Remove macros that contain typecasts (bnc#873901).
- target/iscsi: Remove iscsi dereferencing macros (bnc#873901).
- target: Remove TF_CIT_TMPL macro (bnc#873901).
- commit f59e834
* Wed Apr 30 2014 duwe@suse.de
- PCI: rphahp: Fix endianess issues (bnc#867789).
- commit 2bcee78
* Wed Apr 30 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-numa-remove-BUG_ON-in-__handle_mm_fault.patch.
- commit 9a9dd07
* Wed Apr 30 2014 tiwai@suse.de
- drm/mgag200: Implement basic PM support (bnc#872213).
- commit 030f51d
* Wed Apr 30 2014 jbeulich@suse.com
- x86: Add proper vector accounting for
  HYPERVISOR_CALLBACK_VECTOR.
- Refresh Xen patches (bnc#873865).
- Update EC2 config file (INPUT_KEYBOARD and SERIO off).
- commit e73d758
* Wed Apr 30 2014 neilb@suse.de
- NFS: Be more aggressive in using readdirplus for 'ls -l'
  situations (bnc#857926).
- commit 48f1b25
* Tue Apr 29 2014 hare@suse.de
- SCSI/libiscsi: Add check_protection callback for transports
  (bnc#873901).
- IB/srp: Fix a race condition between failing I/O and I/O
  completion (bnc#873901).
- IB/srp: Avoid that writing into "add_target" hangs due to a
  cable (bnc#873901).
- IB/srp: Make writing into the "add_target" sysfs attribute
  (bnc#873901).
- IB/srp: Avoid duplicate connections (bnc#873901).
- IB/srp: Add more logging (bnc#873901).
- IB/srp: Check ib_query_gid return value (bnc#873901).
- scsi_transport_srp: Fix two kernel-doc warnings (bnc#873901).
- scsi_transport_srp: Fix kernel-doc warnings (bnc#873901).
- scsi_transport_srp: Add rport state diagram (bnc#873901).
- scsi_transport_srp: Fix a race condition (bnc#873901).
- scsi_transport_srp: Block rport upon TL error even with
  (bnc#873901).
- IB/srp: Add change_queue_depth and change_queue_type support
  (bnc#873901).
- IB/srp: Make queue size configurable (bnc#873901).
- IB/srp: Introduce srp_alloc_req_data() (bnc#873901).
- IB/srp: Export sgid to sysfs (bnc#873901).
- IB/srp: Add periodic reconnect functionality (bnc#873901).
- scsi_transport_srp: Add periodic reconnect support (bnc#873901).
- IB/srp: Start timers if a transport layer error occurs
  (bnc#873901).
- IB/srp: Use SRP transport layer error recovery (bnc#873901).
- scsi_transport_srp: Add transport layer error handling
  (bnc#873901).
- IB/srp: Keep rport as long as the IB transport layer
  (bnc#873901).
- IB/srp: Make transport layer retry count configurable
  (bnc#873901).
- IB/iser: Publish T10-PI support to SCSI midlayer (bnc#873901).
- IB/iser: Implement check_protection (bnc#873901).
- IB/iser: Support T10-PI operations (bnc#873901).
- IB/iser: Initialize T10-PI resources (bnc#873901).
- IB/iser: Introduce pi_enable, pi_guard module parameters
  (bnc#873901).
- IB/iser: Generalize fall_to_bounce_buf routine (bnc#873901).
- IB/iser: Generalize iser_unmap_task_data and (bnc#873901).
- IB/iser: Replace fastreg descriptor valid bool with indicators
  (bnc#873901).
- IB/iser: Keep IB device attributes under iser_device
  (bnc#873901).
- IB/iser: Move fast_reg_descriptor initialization to a function
  (bnc#873901).
- IB/iser: Push the decision what memory key to use into
  fast_reg_mr (bnc#873901).
- IB/iser: Avoid FRWR notation, use fastreg instead (bnc#873901).
- IB/iser: Suppress completions for fast registration work
  requests (bnc#873901).
- IB/iser: Fix use after free in iser_snd_completion()
  (bnc#873901).
- IB/mlx5: Expose support for signature MR feature (bnc#873901).
- IB/mlx5: Collect signature error completion (bnc#873901).
- IB/mlx5: Support IB_WR_REG_SIG_MR (bnc#873901).
- IB/mlx5: Keep mlx5 MRs in a radix tree under device
  (bnc#873901).
- IB/mlx5: Remove MTT access mode from umr flags helper function
  (bnc#873901).
- IB/mlx5: Break up wqe handling into begin & finish routines
  (bnc#873901).
- IB/mlx5: Initialize mlx5_ib_qp signature-related members
  (bnc#873901).
- mlx5: Implement create_mr and destroy_mr (bnc#873901).
- IB/core: Introduce signature verbs API (bnc#873901).
- IB/core: Introduce protected memory regions (bnc#873901).
- commit 379ef81
* Tue Apr 29 2014 duwe@suse.de
- Update config files for ppc64le:
  CONFIG_NETFILTER_ADVANCED=n
  (bnc#875242)
- commit de0acbc
* Tue Apr 29 2014 duwe@suse.de
- powerpc/compat: 32-bit little endian machine name is ppcle,
  not ppc (bnc#875242).
- powerpc: Fix xmon disassembler for little-endian (bnc#875242).
- powerpc/le: Enable RTAS events support (bnc#875242).
- powerpc: Add lq/stq emulation (bnc#875242).
- KVM: PPC: Book3S HV: Fix incorrect userspace exit on ioeventfd
  write (bnc#875242).
- commit 400df66
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm64 config file: Disabled 5 unneeded drivers
  Align the arm64 config file with the rest of the config files:
  CONFIG_ATMEL_SSC is not set
  CONFIG_FB_TMIO is not set
  CONFIG_FB_GOLDFISH is not set
  CONFIG_MMC_SDHCI_PXAV3 is not set
  CONFIG_MMC_SDHCI_PXAV2 is not set
- commit 6f565c1
* Tue Apr 29 2014 tiwai@suse.de
- mei: limit the number of consecutive resets
  (bnc#821619,bnc#852656).
- mei: revamp mei reset state machine (bnc#821619,bnc#852656).
- mei: do not run reset flow from the interrupt thread
  (bnc#821619,bnc#852656).
- mei: remove flash_work_queue (bnc#821619,bnc#852656).
- commit b019fa4
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm64 config file: Enable CONFIG_USB_SERIAL_QT2
  It is enabled in every other configuration file and I can't see why
  arm64 would need this one less than any other USB-to-serial driver.
- commit 99c2051
* Tue Apr 29 2014 jdelvare@suse.de
- Update config files: Enable CONFIG_USB_SERIAL_SIMPLE
  This is a unified driver replacing several drivers we were shipping
  and supporting so far, so we should ship and support it too.
- commit fc4d3e5
* Tue Apr 29 2014 hare@suse.de
- patches.drivers/nvme-0029-Retry-failed-commands-with-non-fatal-errors.patch: Fixup compilation error
- commit ed71734
* Tue Apr 29 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on x86_64 (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit 5507b02
* Tue Apr 29 2014 mgorman@suse.de
- Update config files.
- commit 7e6b04f
* Tue Apr 29 2014 mgorman@suse.de
- Update config files to disable CONFIG_DEBUG_ATOMIC_SLEEP.
  might_sleep shows up consistently in profiles mostly due to to indirect
  calls to irqs_disabled.
- commit 3cb856f
* Tue Apr 29 2014 hare@suse.de
- NVMe: Retry failed commands with non-fatal errors (bnc#873252).
- NVMe: Add getgeo to block ops (bnc#873252).
- NVMe: Start-stop nvme_thread during device add-remove
  (bnc#873252).
- NVMe: Make I/O timeout a module parameter (bnc#873252).
- NVMe: CPU hot plug notification (bnc#873252).
- NVMe: per-cpu io queues (bnc#873252).
- NVMe: Replace DEFINE_PCI_DEVICE_TABLE (bnc#873252).
- NVMe: Fix divide-by-zero in nvme_trans_io_get_num_cmds
  (bnc#873252).
- NVMe: IOCTL path RCU protect queue access (bnc#873252).
- NVMe: RCU protected access to io queues (bnc#873252).
- NVMe: Initialize device reference count earlier (bnc#873252).
- NVMe: Add CONFIG_PM_SLEEP to suspend/resume functions
  (bnc#873252).
- nvme: don't use PREPARE_WORK (bnc#873252).
- NVMe: Namespace use after free on surprise removal (bnc#873252).
- NVMe: Correct uses of INIT_WORK (bnc#873252).
- NVMe: Include device and queue numbers in interrupt name
  (bnc#873252).
- NVMe: Add a pci_driver shutdown method (bnc#873252).
- commit 760075c
* Mon Apr 28 2014 brogers@suse.com
- supported.conf: Add drivers/platform/x86/pvpanic as supported (FATE#316292)
- commit 2ab4868
* Mon Apr 28 2014 duwe@suse.de
- powerpc/perf/hv-24x7: catalog version number is be64, not be32
  (bnc#874585).
- powerpc/perf/hv-24x7: remove [static 4096], sparse chokes on it
  (bnc#874585).
- powerpc/perf/hv-24x7: use (unsigned long) not (u32) values
  when calling plpar_hcall_norets() (bnc#874585).
- powerpc/perf/hv-gpci: make device attr static (bnc#874585).
- powerpc/perf/hv_gpci: probe failures use pr_debug(), and
  padding reduced (bnc#874585).
- powerpc/perf/hv_24x7: probe errors changed to pr_debug(),
  padding fixed (bnc#874585).
- commit 3daa2f1
* Mon Apr 28 2014 jdelvare@suse.de
- Refresh
  patches.fixes/ipmi-reset-the-KCS-timeout-when-starting-error-recovery.patch.
  Add upstream reference.
- commit df1e7be
* Mon Apr 28 2014 jslaby@suse.cz
- Refresh patches.fixes/dev_mem-read-write-beyond-EOF.patch.
- Refresh
  patches.fixes/iommu-amd-fix-pasid-format-in-invalidate_iotlb_pages-command.patch.
- Refresh
  patches.fixes/ipmi-fix-a-race-restarting-the-timer.patch.
- Refresh
  patches.fixes/tty-Set-correct-tty-name-in-active-sysfs-attribute.patch.
- Refresh patches.fixes/tulip-quad-NIC-ifdown.
  Update commit IDs.
- commit 73bb535
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Require only perl-Bootloader
- commit 573fc1b
* Mon Apr 28 2014 tiwai@suse.de
- mei: me: do not load the driver if the FW doesn't support MEI
  interface (bnc#821619).
- commit 3b39564
* Mon Apr 28 2014 dchang@suse.com
- qlcnic: Update version to 5.3.57.1 (bnc#853685 FATE#315935).
- qlcnic: Fix memory leak (bnc#853685 FATE#315935).
- qlcnic: Reset firmware API lock at driver load time (bnc#853685
  FATE#315935).
- qlcnic: Fix MSI-X initialization code (bnc#853685 FATE#315935).
- qlcnic: Do not disable SR-IOV when VFs are assigned to VMs
  (bnc#853685 FATE#315935).
- qlcnic: Fix QLogic application/driver interface for virtual
  NIC configuration (bnc#853685 FATE#315935).
- qlcnic: Fix PVID configuration on eSwitch port (bnc#853685
  FATE#315935).
- qlcnic: Fix max ring count calculation (bnc#853685 FATE#315935).
- qlcnic: Fix to send INIT_NIC_FUNC as first mailbox (bnc#853685
  FATE#315935).
- qlcnic: Fix panic due to uninitialzed delayed_work struct in
  use (bnc#853685 FATE#315935).
- net: qlcnic: include irq.h for irq definitions (bnc#853685
  FATE#315935).
- qlcnic: Remove casts of pointer to same type (bnc#853685
  FATE#315935).
- commit 4f9b570
* Mon Apr 28 2014 mgorman@suse.de
- mm,numa: remove BUG_ON in __handle_mm_fault
  (Automatic NUMA Balancing (fate#315482)).
- commit a13ccef
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Use per-flavor path for the logfile
- commit 717e968
* Mon Apr 28 2014 mgorman@suse.de
- Refresh
  patches.suse/hugetlb-ensure-hugepage-access-is-denied-if-hugepages-are-not-supported.patch.
- commit b63d44d
* Fri Apr 25 2014 duwe@suse.de
- powerpc/iommu: Don't detach device without IOMMU group
  (bnc#875108).
- powerpc: Fix up the kdump base cap to 128M (bnc#874784).
- commit 1bce5d3
* Fri Apr 25 2014 eich@suse.de
- Refresh
  patches.drivers/drm-i915-Break-encoder-crtc-link-separately-in-intel_sanitize_crtc.patch.
- commit 7f1a0aa
* Fri Apr 25 2014 mgorman@suse.de
- sched,numa: do not set preferred_node on migration to a second
  choice node (Automatic NUMA Balancing (fate#315482)).
- sched,numa: retry placement more frequently when misplaced
  (Automatic NUMA Balancing (fate#315482)).
- sched,numa: count pages on active node as local (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Use wrapper function task_node to get node which
  task is on (Automatic NUMA Balancing (fate#315482)).
- mm: numa: add migrated transhuge pages to LRU the same way as
  base pages (Automatic NUMA Balancing (fate#315482)).
- commit 5fb6923
* Fri Apr 25 2014 eich@suse.de
- drm/i915: Break encoder->crtc link separately in
  intel_sanitize_crtc() (bnc#855126).
- commit c5b144b
* Thu Apr 24 2014 eich@suse.de
- drm/ast: rename the mindwm/moutdwm and deinline them
  (bnc#871134).
- commit e40ab2d
* Thu Apr 24 2014 jdelvare@suse.de
- supported.conf: Add powerpc/rtas_flash as supported
  arch/powerpc/kernel/rtas_flash is now built as a module, so add it to
  the supported list.
- commit 61bb389
* Thu Apr 24 2014 eich@suse.de
- drm/ast: Use correct structure member for mode validation
  (bnc#871134).
- commit 00fea52
* Thu Apr 24 2014 duwe@suse.de
- Update config files:
  Marcus Meissner <meissner@suse.de>:
  [kernel] CONFIG_CRYPTO_TEST=m is needed for FIPS
  run_oldconfig.sh
- commit 34ac8b5
* Thu Apr 24 2014 mhocko@suse.cz
- mm: disable zone_reclaim_mode by default (bnc#874971).
- commit 9a7d29f
* Thu Apr 24 2014 eich@suse.de
- drm/ast: add AST 2400 support (bnc#871134).
- drm/ast: resync the dram post code with upstream (bnc#871134).
- drm/ast: add widescreen + rb modes from X.org driver
  (bnc#871134).
- commit 9c3c484
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not store the buildroot in the .hmac file
- commit ce5bd7a
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add hmaccalc to buildrequires
- commit 9cca2fa
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Generate a hmac singature for the kernel
  (fate#316930, bnc#856310)
- commit 2659f6f
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop conditionals for -kdump and -ps3
- commit 01fab08
* Wed Apr 23 2014 jslaby@suse.cz
- Linux 3.12.18 (FATE#315916 FATE#315917 FATE#317088 bnc#773058
  bnc#833820 bnc#845503 bnc#852650 bnc#853231 bnc#853350
  bnc#856760 bnc#864288 bnc#864657 bnc#866937 bnc#868900
  bnc#868903 bnc#872428).
- Update config files.
- Refresh
  patches.fixes/futex-Avoid-taking-the-hb-lock-if-there-is-nothing-to-wake-up.patch.
- Refresh
  patches.fixes/futex-Document-multiprocessor-ordering-guarantees.patch.
- Refresh
  patches.fixes/futex-Fix-futex_hashsize-initialization.patch.
- Refresh
  patches.fixes/futex-Increase-hash-table-size-for-better-performance.patch.
- Refresh
  patches.fixes/futex-revert-back-to-the-explicit-waiter-counting-code.patch.
- Refresh
  patches.suse/0018-tipc-protect-handler_enabled-variable-with-qitem_loc.patch.
- Refresh
  patches.suse/0063-tipc-remove-all-enabled-flags-from-all-tipc-componen.patch.
- Delete
  patches.drivers/bnx2-0001-bnx2-Fix-shutdown-sequence.patch.
- Delete
  patches.drivers/drm-Prefer-noninterlace-cmdline-mode-unless-explicit.
- Delete
  patches.drivers/drm-cirrus-Fix-cirrus-drm-driver-for-fbdev-qemu.
- Delete patches.drivers/drm-i915-Undo-the-PIPEA-quirk-for-i845.
- Delete patches.drivers/drm-radeon-change-audio-enable-logic.
- Delete
  patches.drivers/drm-radeon-enable-speaker-allocation-setup-on-dce3.2.
- Delete
  patches.drivers/floppy-bail-out-in-open-if-drive-is-not-responding-to-block0.patch.
- Delete
  patches.drivers/tg3-0028-tg3-Do-not-include-vlan-acceleration-features-in-vla.patch.
- Delete
  patches.fixes/NFSv3-Fix-return-value-of-nfs3_proc_setacls.patch.
- Delete
  patches.fixes/SUNRPC-Fix-potential-memory-scribble-in-xprt_free_bc.patch.
- Delete patches.fixes/drm-add-drm_set_preferred_mode.patch.
- Delete
  patches.fixes/drm-cirrus-use-drm_set_preferred_mode.patch.
- Delete patches.fixes/ext4-Speedup-WB_SYNC_ALL-pass.patch.
- Delete
  patches.fixes/fb-reorder-the-lock-sequence-to-fix-potential-dead-l.
- Delete
  patches.fixes/fbdev-Make-the-switch-from-generic-to-native-driver-.
- Delete
  patches.fixes/nfs-initialize-the-ACL-support-bits-to-zero.patch.
- Delete
  patches.fixes/video-fb-Propagate-error-code-from-failing-to-unregi.
- Delete
  patches.suse/0064-tipc-allow-connection-shutdown-callback-to-be-invoke.patch.
- Delete
  patches.suse/0065-tipc-fix-connection-refcount-leak.patch.
- Delete
  patches.suse/0067-tipc-drop-subscriber-connection-id-invalidation.patch.
- Delete
  patches.suse/0068-tipc-fix-memory-leak-during-module-removal.patch.
- Delete
  patches.suse/0069-tipc-don-t-log-disabled-tasklet-handler-errors.patch.
- commit d91c2cc
* Wed Apr 23 2014 adrian@suse.de
- require kernel-obs-build
  It must be also configured as VMinstall, but is a build requires
  as well to avoid that qa and build package build parallel after kernel-default
  or kernel-xen have changed.
- commit 7a16a4e
* Wed Apr 23 2014 trenn@suse.de
- CPUFREQ: Try to load pcc driver on HP ProLiants automatically
  (bnc#874496).
- commit 04d496c
* Wed Apr 23 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_NFC on non-x86
  NFC support was only requested on x86, and makes no sense on servers
  anyway, so disable CONFIG_NFC in all non-x86 configuration files.
- commit 8dfcdbc
* Wed Apr 23 2014 adrian@suse.de
- improve error logging in case the kernel module could not get loaded
- commit 3811667
* Wed Apr 23 2014 adrian@suse.de
- add block device modules for xen kernel-obs-build image
- commit 04fbb81
* Wed Apr 23 2014 jdelvare@suse.de
- supported.conf: Mark drivers/video/cfbimgblt as supported
  CONFIG_FB_CFB_IMAGEBLIT is an automatic tristate, it can be y or m
  depending on other kernel options and we have no control on the
  result. So play it safe and list cfbimgblt.ko as supported.
- commit 73e9940
* Wed Apr 23 2014 mkubecek@suse.cz
- netfilter: xt_hashlimit: fix proc entry leak in netns destroy
  path (bnc#871634).
- commit 02f1056
* Wed Apr 23 2014 vbabka@suse.cz
- mm: try_to_unmap_cluster() should lock_page() before mlocking
  (VM Functionality).
- commit ae71276
* Wed Apr 23 2014 neilb@suse.de
- Delete
  patches.fixes/nfs-slow-down-state-manager-after-an-unhandled-error.patch.
- Delete patches.fixes/sunrpc-increase-max-slot-table.patch.
  Two sp3_review patches that are definitely not needed as 3.12
  includes the functionality already.
- commit 86d4996
* Wed Apr 23 2014 neilb@suse.de
- Remove some series.conf section heading that are not relevant any more.
- commit 1b9bac7
* Wed Apr 23 2014 neilb@suse.de
- MM: avoid throttling reclaim for loop-back nfsd threads
  (fate#315220).
- SUNRPC: track whether a request is coming from a loop-back
  interface (fate#315220).
- nfsd: Only set PF_LESS_THROTTLE when really needed
  (fate#315220).
- SUNRPC: track when a client connection is routed to the local
  host (fate#315220).
- NFS: avoid deadlocks with loop-back mounted NFS filesystems
  (fate#315220).
- Refresh patches.suse/dmapi-Make-NFSD-DMAPI-aware.patch.
  Add support for loop-back NFS mounts.
- commit 20588a4
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_RTC_DRV_HID_SENSOR_TIME
  It forcibly selects CONFIG_IIO, which we don't want.
- commit 2f7ad07
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_CAN
  It is disabled in all other configuration files.
- commit 8992fa9
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_IIO
  It is disabled in all other configuration files.
- commit bcf1f0f
* Tue Apr 22 2014 vbabka@suse.cz
- mm/compaction: make isolate_freepages start at pageblock
  boundary (VM Functionality).
- commit 0b348df
* Tue Apr 22 2014 mmarek@suse.cz
- Delete patches.drivers/ipoib-sp1-compatible-options.patch.
- Delete patches.drivers/srp-sp1-compatible-options.patch.
- Delete
  patches.suse/0001-ir-kbd-i2c-add-back-dummy-module-parameter.patch.
  Since 3.11, the module loader no longer fails if an unknown parameter is
  specified.
- commit e0cab36
* Tue Apr 22 2014 mmarek@suse.cz
- Delete patches.fixes/linux-3.0.0-fix-strim.txt - upstream patch
- commit 743bfed
* Tue Apr 22 2014 mmarek@suse.cz
- Delete patches.suse/ocfs2-kapi-compat.patch - backport helper only
- commit a3a05fe
* Tue Apr 22 2014 duwe@suse.de
- supported.conf: mark s390 modules as supported (bnc#873162)
- commit 0706cfa
* Tue Apr 22 2014 jdelvare@suse.de
- Update ec2 config file: Disable CONFIG_CAN
  CAN support is disabled everywhere else, so disable it in ec2 too.
- commit 7b6643b
* Tue Apr 22 2014 mgorman@suse.de
- mm: vmscan: Do not throttle based on pfmemalloc reserves if node has no ZONE_NORMAL
  (bnc#870496).
- commit bbc4c79
* Mon Apr 21 2014 jjolly@suse.de
- s390/pci: add kmsg man page (bnc#872979, LTC#109224).
- commit 8aecbf9
* Mon Apr 21 2014 jjolly@suse.de
- qeth: postpone freeing of qdio memory (bnc#872979, LTC#107873).
- commit 814a952
* Fri Apr 18 2014 mkubecek@suse.cz
- packet: allow to transmit +4 byte in TX_RING slot for VLAN case
  (bnc#874131).
- packet: deliver VLAN TPID to userspace (bnc#874131).
- packet: fill the gap of TPACKET_ALIGNMENT with zeros
  (bnc#874131).
- commit ca78cea
* Wed Apr 16 2014 mhocko@suse.cz
- Refresh
  patches.fixes/drop_caches-add-some-documentation-and-info-message.patch.
  use the upstream variant
- commit 2f4ca29
* Wed Apr 16 2014 jdelvare@suse.de
- ipmi: Reset the KCS timeout when starting error recovery
  (bnc#870618).
- ipmi: Fix a race restarting the timer (bnc#870618).
- commit 92f16b1
* Tue Apr 15 2014 jdelvare@suse.de
- supported.conf: Remove all webcam drivers except uvcvideo
  As discussed on the kernel list, in SLE12 we will only offer support
  for webcams using the uvcvideo driver. Other drivers go to the -extra
  kernel package and get no L3 support.
- commit 072ac1c
* Tue Apr 15 2014 mgalbraith@suse.de
- sched: Make scale_rt_power() deal with backward clocks (bnc#865310).
- commit e8ef807
* Tue Apr 15 2014 mgalbraith@suse.de
- sched: Use CPUPRI_NR_PRIORITIES instead of MAX_RT_PRIO in cpupri check (bnc#871861).
- commit e44c7ef
* Tue Apr 15 2014 mgalbraith@suse.de
- sched: update_rq_clock() must skip ONE update (bnc#868528, bnc#869033).
- commit 16b4aaa
* Mon Apr 14 2014 mmarek@suse.cz
- Add kernel-obs-qa-xen.spec
- commit f73cebd
* Mon Apr 14 2014 jdelvare@suse.de
- Update arm64 config file: Disable Cadence ethernet drivers
  These drivers aren't needed on arm64 either so disable them there
  too.
- commit 1b98e36
* Mon Apr 14 2014 jdelvare@suse.de
- Update x86_64 config files: Disable all synclink drivers
  It is believed that our customers do not need the synclink drivers,
  so stop building them and supporting them.
- commit 2d14868
* Mon Apr 14 2014 mkubecek@suse.cz
- ipv6: do not overwrite inetpeer metrics prematurely
  (bnc#867362).
- commit 7709a1b
* Mon Apr 14 2014 ohering@suse.de
- X86: Probe for PIC and set legacy_pic appropriately
  (bnc#872838).
- commit 52eb86a
* Mon Apr 14 2014 tiwai@suse.de
- Update patch-mainline tags
- commit 7158540
* Mon Apr 14 2014 jdelvare@suse.de
- Delete patches.suse/dm-raid45-26-Nov-2009.patch.
- Delete patches.suse/dm-raid45-split-dependencies.
- Delete patches.suse/dmraid45-api-updates.
  These patches were no longer applied, driver is obsolete.
- commit 5387049
* Mon Apr 14 2014 jdelvare@suse.de
- Move video-output patches to patches.rpmify
  That way we can disable CONFIG_VIDEO_OUTPUT_CONTROL in vanilla
  kernels too.
- commit 4a3f489
* Mon Apr 14 2014 hare@suse.de
- megaraid_sas: merge fix for bnc#870440
- Refresh
  patches.drivers/megaraid-sas-boot-hangs-while-LD-is-offline.patch.
- Delete
  patches.drivers/megaraid_sas-present-JBOD-devices-to-the-OS.patch.
- commit 559772e
* Mon Apr 14 2014 hare@suse.de
- megaraid_sas: present JBOD devices to the OS (bnc#870440).
- commit 0960054
* Mon Apr 14 2014 neilb@suse.de
- Refresh patches.suse/md-raid10-tracepoints.
  Check ->queue for NULL before using to avoid crash with dm-raid
  (bnc#866843)
- commit 4994aef
* Fri Apr 11 2014 mgorman@suse.de
- Delete patches.xen/xen-x86_64-paravirt-mmu.
- commit 4d59561
* Fri Apr 11 2014 mgorman@suse.de
- use paravirt mmu ops on xen kernels
- commit ba486fd
* Fri Apr 11 2014 jbohac@suse.cz
- tipc: move code for resetting links from bearer.c to link.c
  (fate#317088).
- tipc: move code for deleting links from bearer.c to link.c
  (fate#317088).
- tipc: redefine 'started' flag in struct link to bitmap
  (fate#317088).
- tipc: remove 'links' list from tipc_bearer struct (fate#317088).
- tipc: change reception of tunnelled duplicate packets
  (fate#317088).
- tipc: change reception of tunnelled failover packets
  (fate#317088).
- tipc: change signature of tunnelling reception function
  (fate#317088).
- tipc: more cleanup of tunnelling reception function
  (fate#317088).
- tipc: rename stack variables in function tipc_link_tunnel_rcv
  (fate#317088).
- tipc: changes to general packet reception algorithm
  (fate#317088).
- tipc: delay delete of link when failover is needed
  (fate#317088).
- tipc: remove bearer_lock from tipc_bearer struct (fate#317088).
- tipc: add node_lock protection to link lookup function
  (fate#317088).
- tipc: fix a loop style problem (fate#317088).
- tipc: correct usage of spin_lock() vs spin_lock_bh()
  (fate#317088).
- tipc: align tipc function names with common naming practice
  in the (fate#317088).
- tipc: failed transmissions should return error (fate#317088).
- tipc: remove all enabled flags from all tipc components
  (fate#317088).
- tipc: allow connection shutdown callback to be invoked in
  advance (fate#317088).
- tipc: fix connection refcount leak (fate#317088).
- tipc: avoid to unnecessary process switch under non-block mode
  (fate#317088).
- tipc: drop subscriber connection id invalidation (fate#317088).
- tipc: fix memory leak during module removal (fate#317088).
- tipc: don't log disabled tasklet handler errors (fate#317088).
- tipc: replace reference table rwlock with spinlock
  (fate#317088).
- tipc: remove redundant 'peer_name' field in struct tipc_sock
  (fate#317088).
- tipc: aggregate port structure into socket structure
  (fate#317088).
- tipc: eliminate upcall function pointers between port and socket
  (fate#317088).
- tipc: eliminate redundant locking (fate#317088).
- tipc: align usage of variable names and macros in socket
  (fate#317088).
- tipc: eliminate redundant lookups in registry (fate#317088).
- Refresh
  patches.suse/0044-tipc-explicitly-include-core.h-in-addr.h.patch.
- Refresh
  patches.suse/0045-tipc-stricter-behavior-of-message-reassembly-functio.patch.
- commit 35a796f
* Fri Apr 11 2014 jbohac@suse.cz
- tipc: stricter behavior of message reassembly function
  (fate#317088).
- commit 0bde74c
* Fri Apr 11 2014 jbohac@suse.cz
- tipc: explicitly include core.h in addr.h (fate#317088).
- commit 201c314
* Fri Apr 11 2014 jbohac@suse.cz
- tipc: fix message corruption bug for deferred packets
  (fate#317088).
- net: add build-time checks for msg->msg_name size (fate#317088).
- tipc: standardize recvmsg routine (fate#317088).
- tipc: standardize sendmsg routine of connected socket
  (fate#317088).
- tipc: standardize sendmsg routine of connectionless socket
  (fate#317088).
- tipc: standardize accept routine (fate#317088).
- tipc: standardize connect routine (fate#317088).
- tipc: spelling fixes (fate#317088).
- tipc: make link start event synchronous (fate#317088).
- tipc: introduce new spinlock to protect struct link_req
  (fate#317088).
- tipc: remove 'has_redundant_link' flag from STATE link protocol
  (fate#317088).
- tipc: rename functions related to link failover and improve
  comments (fate#317088).
- tipc: correctly unlink packets from deferred packet queue
  (fate#317088).
- tipc: remove unused code (fate#317088).
- tipc: make local function static (fate#317088).
- tipc: make the code look more readable (fate#317088).
- tipc: fix deadlock during socket release (fate#317088).
- tipc: change lock_sock order in connect() (fate#317088).
- tipc: Use <linux/uaccess.h> instead of <asm/uaccess.h>
  (fate#317088).
- tipc: kill unnecessary goto's (fate#317088).
- tipc: remove unnecessary variables and conditions (fate#317088).
- tipc: remove unused 'blocked' flag from tipc_link struct
  (fate#317088).
- tipc: improve naming and comment consistency in media layer
  (fate#317088).
- tipc: initiate media type array at compile time (fate#317088).
- tipc: eliminate redundant code with kfree_skb_list routine
  (fate#317088).
- tipc: protect handler_enabled variable with qitem_lock spin lock
  (fate#317088).
- tipc: correct the order of stopping services at rmmod
  (fate#317088).
- tipc: remove interface state mirroring in bearer (fate#317088).
- tipc: fix dereference before check warning (fate#317088).
- tipc: reassembly failures should cause link reset (fate#317088).
- tipc: message reassembly using fragment chain (fate#317088).
- tipc: don't reroute message fragments (fate#317088).
- tipc: remove two indentation levels in tipc_recv_msg routine
  (fate#317088).
- net: misc: Remove extern from function prototypes (fate#317088).
- tipc: simplify the link lookup routine (fate#317088).
- tipc: correct return value of link_cmd_set_value routine
  (fate#317088).
- tipc: correct return value of recv_msg routine (fate#317088).
- tipc: avoid unnecessary lookup for tipc bearer instance
  (fate#317088).
- tipc: make bearer and media naming consistent (fate#317088).
- tipc: silence sparse warnings (fate#317088).
- tipc: remove iovec length parameter from all sending functions
  (fate#317088).
- commit 3f13a0b
* Fri Apr 11 2014 jbohac@suse.cz
- tipc: don't use memcpy to copy from user space (fate#317088).
- commit a831d99
* Fri Apr 11 2014 jdelvare@suse.de
- Update config files: Disable 3 deprecated drivers
  Disable the following deprecated drivers:
  * PRISM54: replaced by p54pci
  * USB_SN9C102: replaced by gscpa_sonixb/j
  * VIDEO_V4L2_INT_DEVICE: unneeded helper module
- commit 571426e
* Fri Apr 11 2014 duwe@suse.de
- hwrng: update patches to latest LKML submission
- commit 5a6f0ce
* Fri Apr 11 2014 ohering@suse.de
- Drivers: hv: vmbus: Implement per-CPU mapping of relid to
  channel.
- Drivers: hv: Eliminate the channel spinlock in the callback
  path.
- Drivers: net: hyperv: Address UDP checksum issues.
- Drivers: net: hyperv: Negotiate suitable ndis version for
  offload support.
- Drivers: net: hyperv: Allocate memory for all possible
  per-pecket information.
- hyperv: Add support for virtual Receive Side Scaling (vRSS).
- Drivers: net: hyperv: Enable large send offload.
- Drivers: net: hyperv: Enable send side checksum offload.
- Drivers: net: hyperv: Enable receive side IP checksum offload.
- Drivers: net: hyperv: Enable offloads on the host.
- Drivers: net: hyperv: Cleanup the send path.
- Drivers: net: hyperv: Enable scatter gather I/O.
- Drivers: hv: vmbus: Increase the limit on the number of pfns
  we can handle.
- commit 86b813c
* Fri Apr 11 2014 ohering@suse.de
- drm/cirrus: bind also to qemu-xen-traditional (bnc#864657,
  bnc#864288).
- drm/cirrus: use drm_set_preferred_mode (bnc#864657, bnc#864288).
- drm: add drm_set_preferred_mode (bnc#864657, bnc#864288).
- commit 6ee4f34
* Fri Apr 11 2014 ohering@suse.de
- x86: hyperv: Fixup the (brain) damage caused by the irq cleanup.
- x86: hyperv: Fix brown paperbag typos reported by Fenguangs
  build robot.
- x86: hyperv: Make it build with CONFIG_HYPERV=m again.
- x86: Hyperv: Cleanup the irq mess.
- x86: hardirq: Make irq_hv_callback_count available for
  CONFIG_HYPERV=m  as well.
- x86: Add proper vector accounting for
  HYPERVISOR_CALLBACK_VECTOR.
- commit 74548e2
* Fri Apr 11 2014 mgalbraith@suse.de
- futex: avoid race between requeue and wake (bnc#851603).
- commit bc7a87c
* Fri Apr 11 2014 tiwai@suse.de
- fbdev: Make the switch from generic to native driver less
  alarming (bnc#872428).
- video/fb: Propagate error code from failing to unregister
  conflicting fb (bnc#872428).
- fb: reorder the lock sequence to fix potential dead lock
  (bnc#872428).
- commit c36e609
* Thu Apr 10 2014 jkosina@suse.cz
- Update config files: fix vanilla configs wrt. ftrace (FATE#317165)
- commit a97a4ff
* Thu Apr 10 2014 spargaonkar@suse.com
- qla2xxx: Fixup looking for a space in the outstanding_cmds
  array in qla2x00_alloc_iocbs() (bnc#872954).
- commit 897f9f0
* Thu Apr 10 2014 duwe@suse.de
- powerpc/le: Avoid creatng R_PPC64_TOCSAVE relocations for
  modules (bnc#861250).
- commit 44e663d
* Thu Apr 10 2014 ohering@suse.de
- Drivers: hv: fcopy_open() can be static.
- commit a6672a0
* Thu Apr 10 2014 ohering@suse.de
- Tools: hv: vssdaemon: Ignore VFAT mounts during the Freeze
  operation.
- commit f9a9bcc
* Thu Apr 10 2014 jkosina@suse.cz
- Update config files: enable ftrace in -default (FATE#317165)
- commit 2d63a7e
* Thu Apr 10 2014 ohering@suse.de
- hv: Add hyperv.h to uapi headers.
- Update the following change to mainline variant:
- Drivers: hv: Implement the file copy service.
- commit dd610b1
* Thu Apr 10 2014 ohering@suse.de
- hyperv: add upstream tags to various patches
- commit 71542fd
* Thu Apr 10 2014 mmarek@suse.cz
- supported.conf: Remove the icom driver (fate#315776)
- commit ecbe28d
* Thu Apr 10 2014 mmarek@suse.cz
- Generate kernel-obs-*.spec from templates
- commit b2e5f7c
* Thu Apr 10 2014 mmarek@suse.cz
- Disable the icom driver on POWER (fate#315776)
- commit aa7545f
* Thu Apr 10 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-compaction-detect-when-scanners-meet-in-isolate_freepages.patch.
  patches.suse/mm-compaction-do-not-mark-unmovable-pageblocks-as-skipped-in-async-compaction.patch.
  patches.suse/mm-compaction-encapsulate-defer-reset-logic.patch.
  patches.suse/mm-compaction-reset-cached-scanner-pfn-s-before-reading-them.patch.
  patches.suse/mm-compaction-reset-scanner-positions-immediately-when-they-meet.patch.
  patches.suse/mm-compaction-trace-compaction-begin-and-end.patch.
  patches.suse/mm-migrate.c-fix-setting-of-cpupid-on-page-migration-twice-against-normal-page.patch.
  patches.suse/mm-numa-Recheck-for-transhuge-pages-under-lock-during-protection-changes.patch.
  patches.suse/mm-numa-reorganize-change_pmd_range.patch.
  patches.suse/move-mmu-notifier-call-from-change_protection-to-change_pmd_range.patch.
  patches.suse/sched-numa-Build-per-numa_group-active-node-mask-from-numa_faults_cpu-statistics.patch.
  patches.suse/sched-numa-Do-statistics-calculation-using-local-variables-only.patch.
  patches.suse/sched-numa-Normalize-faults_cpu-stats-and-weigh-by-CPU-use.patch.
  patches.suse/sched-numa-Rename-p-numa_faults-to-numa_faults_memory.patch.
  patches.suse/sched-numa-Rename-variables-in-task_numa_fault.patch.
  patches.suse/sched-numa-Track-from-which-nodes-NUMA-faults-are-triggered.patch.
  patches.suse/sched-numa-Turn-some-magic-numbers-into-defines.patch.
  patches.suse/sched-numa-mm-Remove-p-numa_migrate_deferred.patch.
  patches.suse/sched-numa-mm-Use-active_nodes-nodemask-to-limit-numa-migrations.patch.
- commit a99caa1
* Thu Apr 10 2014 jdelvare@suse.de
- supported.conf: Fix se401 webcam driver name
  The original se401 driver was supported until SLED11 SP1. It was
  removed from upstream kernel 2.6.39 but support came back under a
  different name as part of the gspca family in kernel 3.1. So SLED11
  SP2 and SP3 lack support for that device but we can support it again
  in SLED12.
- commit 240a5ed
* Thu Apr 10 2014 mgorman@suse.de
- Refresh patches.suse/paravirt-Split-paravirt-MMU-ops.patch.
- commit 5b67bb9
* Thu Apr 10 2014 mgorman@suse.de
- mm, compaction: determine isolation mode only once (VM
  functionality).
- mm/compaction: clean-up code on success of ballon isolation
  (VM functionality).
- mm/compaction: check pageblock suitability once per pageblock
  (VM functionality).
- mm/compaction: change the timing to check to drop the spinlock
  (VM functionality).
- mm/compaction: do not call suitable_migration_target() on
  every page (VM functionality).
- mm/compaction: disallow high-order page for migration target
  (VM functionality).
- commit 4d798e3
* Thu Apr 10 2014 mgorman@suse.de
- Update patches.suse/mm-page_alloc-spill-to-remote-nodes-before-waking-kswapd.patch
  (VM functionality).
- commit 646013a
* Thu Apr 10 2014 mgorman@suse.de
- Refresh
  patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch.
  patches.suse/mm-compaction-avoid-isolating-pinned-pages.patch.
  patches.suse/mm-swap-add-a-simple-detector-for-inappropriate-swapin-readahead.patch.
  patches.suse/numa-use-LAST_CPUPID_SHIFT-to-calculate-LAST_CPUPID_MASK.patch.
- commit 1d7fb80
* Thu Apr 10 2014 mgorman@suse.de
- Refresh
  patches.suse/mm-compaction-avoid-isolating-pinned-pages.patch.
- commit 19f788a
* Thu Apr 10 2014 tonyj@suse.de
- audit: allow unsetting the loginuid (with priv) (FATE#316917,
  bnc#862374).
- audit: audit feature to only allow unsetting the loginuid
  (FATE#316917, bnc#862374).
- audit: audit feature to set loginuid immutable (FATE#316917,
  bnc#862374).
- audit: change decimal constant to macro for invalid uid
  (FATE#316917, bnc#862374).
- audit: fix type of sessionid in audit_set_loginuid()
  (FATE#316917, bnc#862374).
- audit: implement generic feature setting and retrieving
  (FATE#316917, bnc#862374).
- audit: loginuid functions coding style (FATE#316917,
  bnc#862374).
- audit: remove CONFIG_AUDIT_LOGINUID_IMMUTABLE (FATE#316917,
  bnc#862374).
- Update config files.
- commit bb800dd
* Wed Apr  9 2014 jack@suse.cz
- mm: Add spare entry into struct vm_fault.
- fs: Change direct_access calling convention.
- commit b6347f3
* Wed Apr  9 2014 ohering@suse.de
- disable "hyperv: When on Hyper-v use NULL legacy PIC." (bnc#872838)
- commit a916c1c
* Wed Apr  9 2014 vbabka@suse.cz
- mm/page_alloc: prevent MIGRATE_RESERVE pages from being
  misplaced (VM Performance).
- Delete
  patches.suse/mm-page_alloc-fix-freeing-of-MIGRATE_RESERVE-migratetype-pages.patch.
- commit e2289e6
* Wed Apr  9 2014 mgorman@suse.de
- Update config files to disable PARAVIRT_MMU.
- commit c0d558d
* Wed Apr  9 2014 mgorman@suse.de
- paravirt: Split paravirt MMU ops
  (bnc#556135, bnc#754690, FATE#306453).
- commit fcac095
* Wed Apr  9 2014 mgorman@suse.de
- Delete
  patches.arch/paravirt-only-export-pv_mmu_ops-if-PARAVIRT_MMU.patch.
  patches.arch/paravirt-split-paravirt-MMU-ops.patch.
- commit b6278e6
* Wed Apr  9 2014 jbeulich@suse.com
- Update Xen patches to 3.12.17 (build fix).
- Refresh Xen patches (bnc#870874, bnc#872080).
- commit 9c1ea28
* Wed Apr  9 2014 tiwai@suse.de
- iwlwifi: mvm: add missing include (bnc#872659).
- commit 328eb02
* Wed Apr  9 2014 mgorman@suse.de
- ppc64le: Add automatic NUMA balancing but disable by default.
- commit 1649467
* Wed Apr  9 2014 mgorman@suse.de
- mm: use paravirt friendly ops for NUMA hinting ptes
  (Automatic NUMA Balancing (fate#315482)).
- x86: Require x86-64 for automatic NUMA balancing
  (Automatic NUMA Balancing (fate#315482)).
- numa: use LAST_CPUPID_SHIFT to calculate LAST_CPUPID_MASK
  (Automatic NUMA Balancing ppc64le (fate#315482)).
- mm: Use ptep/pmdp_set_numa() for updating _PAGE_NUMA bit
  (Automatic NUMA Balancing ppc64le (fate#315482)).
- mm: Dirty accountable change only apply to non prot numa case
  (Automatic NUMA Balancing ppc64le (fate#315482)).
- powerpc/mm: Add new "set" flag argument to pte/pmd update
  function (Automatic NUMA Balancing ppc64le (fate#315482)).
- mm: Move change_prot_numa outside
  CONFIG_ARCH_USES_NUMA_PROT_NONE (Automatic NUMA Balancing
  ppc64le (fate#315482)).
- powerpc/mm: Enable _PAGE_NUMA for book3s (Automatic NUMA
  Balancing ppc64le (fate#315482)).
- powerpc/mm: Only check for _PAGE_PRESENT in set_pte/pmd
  functions (Automatic NUMA Balancing ppc64le (fate#315482)).
- powerpc/mm: Free up _PAGE_COHERENCE for numa fault use later
  (Automatic NUMA Balancing ppc64le (fate#315482)).
- powerpc/mm: Use HPTE constants when updating hpte bits
  (Automatic NUMA Balancing ppc64le (fate#315482)).
- commit adc1b13
* Wed Apr  9 2014 duwe@suse.de
- powerpc/xmon: Don't signal we've entered until we're finished
  printing (bnc#872696).
- powerpc/xmon: Fix timeout loop in get_output_lock()
  (bnc#872696).
- powerpc/xmon: Don't loop forever in get_output_lock()
  (bnc#872696).
- powerpc: Use unstripped VDSO image for more accurate profiling
  data (bnc#872695).
- powerpc: Link VDSOs at 0x0 (bnc#872695).
- commit 3728af0
* Wed Apr  9 2014 mgorman@suse.de
- hugetlb: ensure hugepage access is denied if hugepages are not supported
  (PowerKVM crash when mounting hugetlbfs without hugepage support (bnc#870498)).
- commit 5520e24
* Wed Apr  9 2014 tiwai@suse.de
- iwlwifi: mvm: send udev event upon firmware error to dump logs
  (bnc#872659).
- commit dbe632f
* Wed Apr  9 2014 jdelvare@suse.de
- Update debug config files: enable TTY_PRINTK
  Enabled only in debug kernels, as it can't be built as a module.
- commit e9a49b4
* Wed Apr  9 2014 acho@suse.com
- bnx2: Fix shutdown sequence (bnc#853231 FATE#315917).
- commit 5b38247
* Tue Apr  8 2014 jeffm@suse.com
- hpsa: handle unsupported devices more gracefully (FATE#316683).
- Delete
  patches.drivers/hpsa-0017-enable-hpsa_allow_any-per-default.patch.
- commit ead0f0a
* Tue Apr  8 2014 jeffm@suse.com
- hpsa: allow hpsa to claim Compaq SmartArray devices (bnc#869383).
- commit b2a3fdd
* Tue Apr  8 2014 mgorman@suse.de
- Update
  patches.suse/fs-proc-page.c-add-PageAnon-check-to-surely-detect-thp.patch
  patches.suse/mm-close-PageTail-race.patch
  patches.suse/mm-hugetlbfs-move-the-put-get_page-slab-and-hugetlbfs-optimization-in-a-faster-path.patch
  patches.suse/mm-hugetlbfs-use-__compound_tail_refcounted-in-__get_page_tail-too.patch
  patches.suse/mm-swap.c-reorganize-put_compound_page.patch
  patches.suse/mm-tail-page-refcounting-optimization-for-slab-and-hugetlbfs.patch
  patches.suse/mm-thp-optimize-compound_trans_huge.patch
- Delete
  patches.suse/mm-page_alloc-make-first_page-visible-before-PageTail.patch.
  (Bring close PageTail race patch in line with upstream)
- commit 59f6382
* Tue Apr  8 2014 jdelvare@suse.de
- Delete patches.rpmify/chipidea-clean-up-dependencies.
  Irrelevant on SLE12 as no config has CONFIG_USB_CHIPIDEA enabled.
- commit 782ec6f
* Tue Apr  8 2014 mgorman@suse.de
- mm: numa: Recheck for transhuge pages under lock during -fix
  (Automatic NUMA Balancing (fate#315482)).
- commit c4c7aef
* Tue Apr  8 2014 mgorman@suse.de
- Refresh
  patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch.
  patches.suse/ACPI-tables-Check-if-id-is-NULL-in-acpi_table_parse.patch.
  patches.suse/ACPI-tables-Return-proper-error-codes-from-acpi_table_parse-and-fix-comment.patch.
  patches.suse/mm-Remove-bogus-warning-in-copy_huge_pmd.patch.
  patches.suse/mm-compaction-avoid-isolating-pinned-pages.patch.
  patches.suse/mm-fix-GFP_THISNODE-callers-and-clarify.patch.
  patches.suse/mm-numa-add-sysctl-for-numa-balancing.patch.
  patches.suse/mm-numa-do-not-automatically-migrate-KSM-pages.patch.
  patches.suse/mm-numa-limit-scope-of-lock-for-NUMA-migrate-rate-limiting.patch.
  patches.suse/mm-numa-make-NUMA-migrate-related-functions-static.patch.
  patches.suse/mm-numa-trace-tasks-that-fail-migration-due-to-rate-limiting.patch.
  patches.suse/sched-add-tracepoints-related-to-NUMA-task-migration.patch.
  patches.suse/sched-calculate-effective-load-even-if-weight-0.patch.
  patches.suse/stop_machine-Fix-2-race-between-stop_two_cpus-and-stop_cpus.patch.
  patches.suse/x86-mm-Account-for-TLB-flushes-only-when-debugging.patch.
  patches.suse/x86-mm-Clean-up-inconsistencies-when-flushing-TLB-ranges.patch.
  patches.suse/x86-mm-Eliminate-redundant-page-table-walk-during-TLB-range-flushing.patch.
  patches.suse/x86-mm-numa-Fix-32-bit-kernel-NUMA-boot.patch.
- Delete
  patches.arch/mm-avoid-bad-page-on-lru-fix.patch.
  patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-fix.patch.
  patches.fixes/fs-sysfs-do-dcache-related-updates-to-sysfs-under-sysfs_mutex.patch.
  patches.fixes/mm-hugetlbfs-Correctly-detect-if-page-tables-have-just-been-shared.patch.
  patches.fixes/mm-page-allocator-do-not-drain-per-cpu-lists-via-IPI-from-page-allocator-context.patch.
  patches.fixes/mm-page-allocator-drain-local-per-cpu-lists.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix-2.patch.
  patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix.patch.
  patches.suse/mm-netvm-propagate-page--pfmemalloc-from-netdev_alloc_page-to-skb.patch.
  (Git-commit tag updates)
- commit 7fba9d8
* Tue Apr  8 2014 jack@suse.cz
- Fix compilation warnings in xfs dmapi patch.
- commit 3a61c76
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm64 config file: Disable exynos support
  We don't support Exynos with that kernel.
- commit 133dd97
* Tue Apr  8 2014 mq@suse.cz
- USB: storage: fix compile warning (FATE#315595).
- commit e79455a
* Tue Apr  8 2014 jslaby@suse.cz
- Update references in patches.kernel.org/patch-3.12.15-16 (bnc#842459
  bnc#854594 bnc#862612 bnc#863031 bnc#866247 bnc#869735).
- commit 8e0c856
* Tue Apr  8 2014 jslaby@suse.cz
- Linux 3.12.17 (CVE-2014-2523 FATE#315629 bnc#787843 bnc#854594
  bnc#855885 bnc#856848 bnc#863178 bnc#868653 bnc#868876
  bnc#868881 bnc#868882 bnc#868891 bnc#868897 bnc#868898
  bnc#871665).
- Refresh
  patches.suse/fs-proc-page.c-add-PageAnon-check-to-surely-detect-thp.patch.
- Refresh
  patches.suse/mm-hugetlbfs-move-the-put-get_page-slab-and-hugetlbfs-optimization-in-a-faster-path.patch.
- Refresh
  patches.suse/mm-hugetlbfs-use-__compound_tail_refcounted-in-__get_page_tail-too.patch.
- Refresh
  patches.suse/mm-swap.c-reorganize-put_compound_page.patch.
- Delete
  patches.arch/arch-x86-mm-srat-Skip-NUMA_NO_NODE-while-parsing-SLI.patch.
- Delete
  patches.arch/s390-time-vdso-fix-clock_gettime-for-CLOCK_MONOTONIC.patch.
- Delete
  patches.drivers/0001-sha256_ssse3-also-test-for-BMI2.patch.
- Delete patches.drivers/hda-0010-Fix-inconsistent-Mic-mute-LED.
- Delete
  patches.drivers/i2c-i801-add-device-ids-for-intel-wildcat.patch.
- Delete
  patches.drivers/intel_idle_support_intel_atom_c2000.patch.
- Delete
  patches.fixes/FS-Cache-Handle-removal-of-unadded-object-to-the-fsc.patch.
- Delete
  patches.fixes/NFS-Fix-races-in-nfs_revalidate_mapping.patch.
- Delete
  patches.fixes/NFS-fix-the-handling-of-NFS_INO_INVALID_DATA-flag-in.patch.
- Delete
  patches.fixes/NFSv4.1-Prevent-a-3-way-deadlock-between-layoutretur.patch.
- Delete
  patches.fixes/NFSv4.1-free-slot-before-resending-I-O-to-MDS.patch.
- Delete
  patches.fixes/SUNRPC-do-not-fail-gss-proc-NULL-calls-with-EACCES.patch.
- Delete patches.fixes/X.509-time-h-include.
- Delete
  patches.fixes/dlm-set-zero-linger-time-on-sctp-socket.patch.
- Delete
  patches.fixes/ipvs-fix-AF-assignment-in-ip_vs_conn_new.patch.
- Delete
  patches.fixes/netfilter-nf_conntrack_dccp-fix-skb_header_pointer-api-usages.
- Delete
  patches.fixes/nfs-add-memory-barriers-around-NFS_INO_INVALID_DATA-.patch.
- Delete
  patches.fixes/nfs-defer-inode_dio_done-call-until-size-update-is-d.patch.
- Delete patches.fixes/nfs-fix-dead-code-of-ipv6_addr_scope.patch.
- Delete patches.fixes/nfs-fix-size-updates-for-aio-writes.patch.
- Delete
  patches.fixes/nfs-increment-i_dio_count-for-reads-too.patch.
- Delete
  patches.fixes/nfs-use-IS_ROOT-not-DCACHE_DISCONNECTED.patch.
- Delete
  patches.fixes/pnfs-fix-BUG-in-filelayout_recover_commit_reqs.patch.
- Delete
  patches.rpmify/nouveau-make-vga_switcheroo-code-depend-on-vga_switcheroo.
- Delete
  patches.suse/fbmem-really-support-wildcard-video-options-for-all-.patch.
- Delete patches.suse/mm-close-PageTail-race.patch.
- Delete
  patches.suse/mm-page_alloc-make-first_page-visible-before-PageTail.patch.
- Delete patches.suse/mm-thp-optimize-compound_trans_huge.patch.
- commit f426d1a
* Tue Apr  8 2014 hare@suse.de
- ch: add refcounting (bnc#867517).
- commit 5a92892
* Tue Apr  8 2014 jlee@suse.com
- kexec: Disable at runtime if the kernel enforces module loading
  restrictions (fate#314486, bnc#845167).
  Base on bnc#845167, lock down kexec when secure boot until upstream
  solution worked out.
- commit c9a2dc1
* Mon Apr  7 2014 bpoirier@suse.de
- mlx4_en: Implement the SIOCGHWTSTAMP ioctl (bnc#858727
  FATE#315946).
- net: mlx4 calls skb_set_hash (bnc#858727 FATE#315946).
- net/mlx4_en: fix error return code in mlx4_en_get_qp()
  (bnc#858727 FATE#315946).
- mlx4_en: Select PTP_1588_CLOCK (bnc#858727 FATE#315946).
- net/mlx4_en: call gro handler for encapsulated frames
  (bnc#858727 FATE#315946).
- mlx5_core: Remove dead code (bnc#858727 FATE#315946).
- net/mlx4_core: clean up cq_res_start_move_to() (bnc#858727
  FATE#315946).
- net/mlx4_core: clean up srq_res_start_move_to() (bnc#858727
  FATE#315946).
- mlx5_core: Fix out arg size in access_register command
  (bnc#858727 FATE#315946).
- net/mlx4: Support shutdown() interface (bnc#858727 FATE#315946).
- net/mlx4_core: Fix memory access error in
  mlx4_QUERY_DEV_CAP_wrapper() (bnc#858727 FATE#315946).
- net/mlx4_en: Handle vxlan steering rules for mac address changes
  (bnc#858727 FATE#315946).
- net/mlx4_core: Load the IB driver when the device supports IBoE
  (bnc#858727 FATE#315946).
- net/mlx4_en: Deregister multicast vxlan steering rules when
  going down (bnc#858727 FATE#315946).
- Refresh
  patches.drivers/mlx-0068-net-mlx4_en-Add-netdev-support-for-TCP-IP-offloads-o.patch.
- commit 4aa90a4
* Mon Apr  7 2014 bpoirier@suse.de
- Reorder Mellanox-related SLE12 patches in series.conf
  groups them all together
  sorts them according to upstream oder
  cleans some Git-commit tags
- Refresh
  patches.arch/s390-sles12-00-03-pci-ofed-uverbs_add_kwrite-mmio-v2.patch.
- Refresh
  patches.drivers/0001-IB-core-Add-flow-steering-support-for-IPoIB-UD-traff.patch.
- Refresh
  patches.drivers/0002-IB-core-Add-support-for-IB-L2-device-managed-steerin.patch.
- Refresh
  patches.drivers/0003-mlx4_core-Add-support-for-steerable-IB-UD-QPs.patch.
- Refresh
  patches.drivers/0005-IB-mlx4-Enable-device-managed-steering-support-for-I.patch.
- Refresh
  patches.drivers/0006-IB-mlx4-Add-mechanism-to-support-flow-steering-over-.patch.
- Refresh
  patches.drivers/mlx-0052-IB-core-extended-command-an-improved-infrastructure-.patch.
- Refresh
  patches.drivers/mlx-0053-IB-core-Re-enable-create_flow-destroy_flow-uverbs.patch.
- Refresh
  patches.drivers/mlx5-0005-net-IB-mlx-Bump-all-Mellanox-driver-versions.patch.
- commit 9e32ff1
* Mon Apr  7 2014 mgorman@suse.de
- Delete patches.suse/mm-swap-use-files-priority-order.patch.
- commit a479f94
* Mon Apr  7 2014 bp@suse.de
- amd64_edac: Fix condition to verify max channels allowed for
  F15 M30h (bnc#870880).
- amd64_edac: Fix logic to determine channel for F15 M30h
  processors (bnc#870880).
- x86/quirks: Add workaround for AMD F16h Erratum792 (bnc#870880).
- commit e367ab5
* Mon Apr  7 2014 tiwai@suse.de
- drm: Prefer noninterlace cmdline mode unless explicitly
  specified (bnc#853350).
- commit f63ba66
* Mon Apr  7 2014 ohering@suse.de
- x86/platform/hyperv: When on Hyper-v use NULL legacy PIC.
- commit 79caf6e
* Mon Apr  7 2014 ohering@suse.de
- Drivers: hv: vmbus: Negotiate version 3.0 when running on
  ws2012r2 hosts.
- commit 3e55f7a
* Mon Apr  7 2014 jlee@suse.com
- Delete
  patches.suse/0008_V3_kexec_Disable_at_runtime_if_the_kernel_enforces_module_loading_restrictions.patch.
  (bnc#845167)
  Enable kexec when secure boot ON.
- commit 40844aa
* Fri Apr  4 2014 bpoirier@suse.de
- qlcnic: dcb: a couple off by one bugs (bnc#853685 FATE#315935).
- qlcnic: Fix number of rings when we fall back from msix to
  legacy (bnc#853685 FATE#315935).
- qlcnic: Allow any VLAN to be configured from VF (bnc#853685
  FATE#315935).
- qlcnic: Fix usage of use_msi and use_msi_x module parameters
  (bnc#853685 FATE#315935).
- qlcnic: Fix function return error check (bnc#853685
  FATE#315935).
- commit 83a32a9
* Fri Apr  4 2014 bpoirier@suse.de
- qlge: Do not propaged vlan tag offloads to vlans (bnc#853684
  FATE#315936).
- commit 18563aa
* Fri Apr  4 2014 bpoirier@suse.de
- netxen: Correct off-by-one errors in bounds checks (bnc#853679
  FATE#315937).
- commit c333bf7
* Fri Apr  4 2014 mmarek@suse.cz
- rpm/kernel-module-subpackage: Regenerated the initrd in %%posttrans
  (fate#313506)
- commit c0b6219
* Fri Apr  4 2014 hare@suse.de
- megaraid_sas: Evaluate return status from megasas_issue_polled()
  (bnc#872028).
- megaraid_sas: Fallback to older scanning if not disks are found
  (bnc#870440).
- commit 79848b0
* Fri Apr  4 2014 tiwai@suse.de
- mfd: lpc_ich: Add support for Intel Bay Trail SoC (bnc#871908).
- mfd: lpc_ich: Add support for NM10 GPIO (bnc#871908).
- mfd: lpc_ich: Change Avoton to iTCO v3 (bnc#871908).
- watchdog: iTCO_wdt: Add support for v3 silicon (bnc#871908).
- mfd: lpc_ich: Add support for iTCO v3 (bnc#871908).
- mfd: lpc_ich: Remove lpc_ich_cfg struct use (bnc#871908).
- mfd: lpc_ich: Only configure watchdog or GPIO when present
  (bnc#871908).
- mfd: lpc_ich: Fix ACPI enable bitmask (bnc#871908).
- mfd: lpc_ich: Add support for Intel Avoton GPIOs (bnc#871908).
- mfd: lpc_ich: Convert ICH GPIOs IDs to enum (bnc#871908).
- commit d3d4c3f
* Fri Apr  4 2014 jdelvare@suse.de
- Update upstream status
  The following patches are upstream now:
  patches.fixes/video-output-01-acpi-drop-dependency.patch
  patches.fixes/video-output-02-gpu-drm-drop-selects.patch
  patches.fixes/video-output-03-acer_wmi-drop-select.patch
- commit a804485
* Fri Apr  4 2014 jdelvare@suse.de
- fujitsu-laptop: Drop unneeded include.
  This fixes the newly introduced warnings:
  In file included from ##C##/drivers/platform/x86/fujitsu-laptop.c:##L##:
  include/linux/video_output.h: warning: 'video_output_register' defined but not used [-Wunused-function]
  static struct output_device *video_output_register(const char *name,
    ^
  include/linux/video_output.h: warning: 'video_output_unregister' defined but not used [-Wunused-function]
  static void video_output_unregister(struct output_device *dev)
    ^
- commit d0464bd
* Fri Apr  4 2014 jdelvare@suse.de
- supported.conf: mark w83977f_wdt as supported
  Watchdog component in a generic Super-I/O chip.
- commit b99e7db
* Fri Apr  4 2014 jdelvare@suse.de
- Update x86_64 config files: disable CONFIG_SBC8360_WDT
  The sbc8360 driver is for a Socket 370-based single-board computer,
  I'm not sure any customer would run SLES12 on that kind of hardware,
  and I'm fairly certain that none would do so on such an old piece of
  32-bit x86 hardware.
- commit 3afe007
* Fri Apr  4 2014 adrian@suse.de
- fix building initrd for SLE 12
  It does provided and load the critical kernel modules
  for building some kiwi images and cross architecture
  builds like used for aarch64.
  The kernel-obs-build.spec still contains the bits to allow
  to use it also for SLE 11.
- commit e9868b7
* Fri Apr  4 2014 jbeulich@suse.com
- Update Xen patches to 3.12.15.
- Refresh Xen patches (bnc#868968, bnc#870874).
- commit 5facbd9
* Fri Apr  4 2014 bpoirier@suse.de
- Fix fnic driver update reference
- Update
  patches.drivers/fnic-Changing-the-IO-Throttle-count-from-2048-to-256.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-Driver-Timeout-debug-messages-are-removed-from-.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-Failing-to-queue-aborts-due-to-Q-full-cause-ter.patch
  (bnc#863364,FATE#315811).
- Update patches.drivers/fnic-Fnic-Ctlr-Path-Trace-Utility.patch
  (bnc#863364,FATE#315811).
- Update patches.drivers/fnic-Fnic-Statistics-Collection.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-HDS-VMware-host-not-recovering-path-after-switc.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-Incremented-driver-version-to-1.5.0.45.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-Incremented-driver-version-to-1.6.0.10.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-Sending-single-FIP-solicitation-frame-in-non-FI.patch
  (bnc#863364,FATE#315811).
- Update
  patches.drivers/fnic-host-reset-returns-nonzero-value-errno-on-.patch
  (bnc#863364,FATE#315811).
- Update
  patches.fixes/fcoe-Reduce-fcoe_sysfs_fcf_add-stack-usage.patch
  (bnc#863364,FATE#315811).
- Update
  patches.fixes/libfcoe-Make-fcoe_sysfs-optional-fix-fnic-NULL-excep.patch
  (bnc#863364,FATE#315811).
- commit 03fcd0c
* Fri Apr  4 2014 bpoirier@suse.de
- e1000e: Fix compilation warning when !CONFIG_PM_SLEEP
  (bnc#857399 FATE#315648).
- commit b816eca
* Thu Apr  3 2014 bpoirier@suse.de
- cnic: Update version to 2.5.20 and copyright year (bnc#859297
  FATE#315915).
- cnic,bnx2i,bnx2fc: Fix inconsistent use of page size (bnc#859297
  FATE#315915).
- cnic: Use proper ulp_ops for per device operations (bnc#859297
  FATE#315915).
- commit c58242d
* Thu Apr  3 2014 bpoirier@suse.de
- series.conf: Group bnx2x patches together
- commit 7ca36c0
* Thu Apr  3 2014 bpoirier@suse.de
- tg3: Do not include vlan acceleration features in vlan_features
  (bnc#852650 FATE#315916).
- commit 181219c
* Thu Apr  3 2014 bpoirier@suse.de
- bna: Replace large udelay() with mdelay() (bnc#855232
  FATE#315938).
- bna: fix vlan tag stripping and implement its toggling
  (bnc#855232 FATE#315938).
- commit 6075658
* Thu Apr  3 2014 bpoirier@suse.de
- Call efx_set_channels() before efx->type->dimension_resources()
  (bnc#856380 FATE#315942).
- commit dab9cf2
* Thu Apr  3 2014 guillaume.gardet@oliseo.fr
- Refresh patches.rpmify/chipidea-clean-up-dependencies
  Replace OF_DEVICE by OF (OF_DEVICE does not exist anymore.)
- commit f97ad85
* Thu Apr  3 2014 duwe@suse.de
- Refresh patches.suse/pstore-backend-autoaction.
  Fix valid gcc warnings about an unitialised return code
  and printf format problems.
- commit 2a3797e
* Thu Apr  3 2014 jdelvare@suse.de
- Update config files: disable all of Timberdale support
  Timberdale is a companion chip for Atom CPUs in embedded in-car
  infotainment systems. We don't need that in SLE, really.
- commit 2ff7ca7
* Thu Apr  3 2014 bpoirier@suse.de
- drivers/net: fix build warning in ethernet/sfc/tx.c (bnc#856380
  FATE#315942).
- sfc: Fix transposed ptp_{under, over}size_sync_windows
  statistics (bnc#856380 FATE#315942).
- sfc: Change efx_mcdi_reset_port to use ENTITY_RESET MC command
  (bnc#856380 FATE#315942).
- commit 37a34f9
* Wed Apr  2 2014 jslaby@suse.cz
- s390/time,vdso: fix clock_gettime for CLOCK_MONOTONIC
  (bnc#871665).
- commit 69c2ea8
* Wed Apr  2 2014 jdelvare@suse.de
- supported.conf: Adjust radio-si470x module name
  In kernel 2.6.32, module radio-si470x was split into two distinct
  modules, radio-usb-si470x for the USB access and radio-i2c-si470x for
  I2C access. USB access is what the original module was implementing so
  we should keep supporting radio-usb-si470x. I2C access was not
  implemented before and I suspect it's only needed on embedded systems
  so we shouldn't build it at all.
- commit 38a0702
* Wed Apr  2 2014 mgorman@suse.de
- x86: clearing access bit should not flush tlb
  (VM Performance).
- commit 50bebc6
* Wed Apr  2 2014 jslaby@suse.cz
- Linux 3.12.16 (bnc#854594 bnc#863031 bnc#866247 bnc#869735).
- Refresh
  patches.drivers/0009-iwlwifi-mvm-fix-locking-in-iwl_mvm_bt_rssi_event.
- Refresh
  patches.drivers/0020-iwlwifi-mvm-BT-Coex-use-data-from-firmware.
- Delete
  patches.drivers/0001-xhci-Fix-resume-issues-on-Renesas-chips-in-Samsung-l.patch.
- Delete
  patches.drivers/hda-0004-add-device-ID-for-Broadwell-display-audio-c.
- Delete
  patches.drivers/hda-0005-add-codec-ID-for-Broadwell-display-audio-co.
- Delete
  patches.drivers/hda-0009-hdmi-apply-all-Haswell-fix-ups-to-Broadwell.
- Delete
  patches.drivers/ibmveth-fix-endian-issues-with-MAC-addresses.
- Delete
  patches.fixes/cgroup-protect-modifications-to-cgroup_idr-with-cgroup_mutex.patch.
- Delete patches.rpmify/iscsi-iser-target-fix-build-warning.patch.
- commit ae2933c
* Wed Apr  2 2014 jslaby@suse.cz
- Refresh
  patches.drivers/0001-sha256_ssse3-also-test-for-BMI2.patch.
- Refresh patches.drivers/hda-0010-Fix-inconsistent-Mic-mute-LED.
- Refresh
  patches.fixes/dlm-set-zero-linger-time-on-sctp-socket.patch.
- Refresh
  patches.fixes/ocfs2-Move-dquot_initialize-in-ocfs2_delete_inode-so.patch.
  update upstream status.
- commit 595f0e2
* Wed Apr  2 2014 mmarek@suse.cz
- rpm/kernel-syms.spec.in: Require pesign-obs-integration for signing KMPs
- commit e68d5fc
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: CONFIG_CRYPTO_TWOFISH_COMMON=m
  Missing dependency, sorry.
- commit 8fdec8e
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: re-enable twofish crypto support
  Software twofish crypto support was disabled in several architectures
  since SLES11 GA. For x86_64 it was on purpose, because
  hardware-accelerated alternatives exist. However for some other
  architectures it was by accident.
  Additionally, in SLES11 SP2, the software twofish implementation was
  renamed from twofish to twofish_generic, but supported.conf was not
  updated accordingly, so S/390 was without a supported twofish crypto
  implementation as well.
  Re-enable software twofish crypto support in all configuration files,
  to guarantee that at least one implementation is always available,
  and adjust supported.conf to reflect the name change (bnc#871325).
- commit bcf4843
* Tue Apr  1 2014 mgorman@suse.de
- arch/x86/mm/numa.c: fix array index overflow when
  synchronizing nid to memblock.reserved (Memory node hot-remove
  (fate#316483,bnc#870684,bnc#871180)).
- arch/x86/mm/numa.c: initialize numa_kernel_nodes in
  numa_clear_kernel_node_hotplug() (Memory node hot-remove
  (fate#316483,bnc#870684,bnc#871180)).
- commit ad52b19
* Tue Apr  1 2014 jslaby@suse.cz
- Delete patches.arch/arm-omap3isp.patch.
  superseded by 31036441d785359999e45bf410c778f64ffcab64
- commit 7dbd398
* Tue Apr  1 2014 ohering@suse.de
- Fix typo in netfront, in type check of unplug code
- commit 5949714
* Tue Apr  1 2014 agraf@suse.de
- Update ppc64le config files to disable the GX bus which is never
  present on POWER8 and above systems.
- commit db71719
* Tue Apr  1 2014 agraf@suse.de
- powerpc: Use 64k io pages when we never see an HEA (bnc#871334).
- commit d766504
* Tue Apr  1 2014 jdelvare@suse.de
- Delete patches.suse/elousb-fix-api-usage.patch.
  The elousb driver is gone (replaced upstream by hid-elo.)
- commit a988223
* Tue Apr  1 2014 mgorman@suse.de
- Refresh patches.suse/mm-close-PageTail-race.patch.
- commit fdfa378
* Tue Apr  1 2014 jlee@suse.com
- Add external support and no support module to bad taint
  (bnc#870450).
- Use 'E' instead of 'X' for unsigned module taint flag
  (bnc#870450).
- Fix: module signature vs tracepoints: add new
  TAINT_UNSIGNED_MODULE (bnc#870450).
- commit 19b269f
* Mon Mar 31 2014 jdelvare@suse.de
- supported.conf: update gpio drivers
  Remove drivers we no longer build, and update the rest to take driver
  renames into account.
- commit ae131b0
* Mon Mar 31 2014 mfasheh@suse.de
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Delete
  patches.suse/btrfs-8000-introduce-lock_ref-unlock_ref.patch.
- Delete patches.suse/btrfs-8001-rework-qgroup-accounting.patch.
- Delete
  patches.suse/btrfs-8002-add-sanity-tests-for-new-qgroup-accounting-cod.patch.
- commit 73b2154
* Mon Mar 31 2014 hare@suse.de
- s390/con3270: optionally disable auto update (bnc#868409).
- commit d7fe1a7
* Fri Mar 28 2014 jdelvare@suse.de
- supported.conf: delete more old ppc modules
  Efika mpc52xx is long unsupported.
- commit 718e40e
* Fri Mar 28 2014 jdelvare@suse.de
- supported.conf: delete ia64 modules
  With SLE12, we no longer support ia64.
- commit 6e34334
* Fri Mar 28 2014 jdelvare@suse.de
- supported.conf: delete old ppc modules
  Remove all ppc-specific modules which are no longer built.
- commit 74290f1
* Fri Mar 28 2014 jdelvare@suse.de
- Update ppc64le config files: Disable fault injection
  The fault injection framework should only be enabled in debug
  kernels.
- commit 01981e5
* Fri Mar 28 2014 jdelvare@suse.de
- Update ppc64le config files: adjust filesystems modularity
  Build reiserfs, fat and vfat support as modules as we do on every
  other architecture. Also align the reiserfs debugging features on
  x86_64.
- commit fe1d212
* Fri Mar 28 2014 jjolly@suse.de
- kernel: crash due to multiple reset requests (bnc#870658,
  LTC#107919).
- commit 666e672
* Fri Mar 28 2014 mmarek@suse.cz
- Fix vanilla configs
- commit 197345b
* Fri Mar 28 2014 mmarek@suse.cz
- Enable the tipc module (fate#305033 / bnc#869157)
- commit 3bb1977
* Fri Mar 28 2014 duwe@suse.de
- Update ppc64le config files. (bnc#870125)
- commit 1871853
* Fri Mar 28 2014 hare@suse.de
- mpt2sas: Bump mpt2sas driver version to 18.100.00.00
  (FATE#315931,bnc#854824).
- mpt2sas: Added module parameter 'unblock_io' to unblock IO's
  during disk addition (FATE#315931,bnc#854824).
- mpt2sas: Get IOC_FACTS information using handshake protocol
  only after HBA card gets into READY or Operational state
  (FATE#315931,bnc#854824).
- mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array support
  (FATE#315931,bnc#854824).
- mpt2sas: For >2TB volumes, DirectDrive support sends
  I/Os with LBA bit 31 to IR FW instead of DirectDrive
  (FATE#315931,bnc#854824).
- mpt2sas: Bump mpt2sas driver version to 17.100.00.00
  (FATE#315931,bnc#854824).
- mpt2sas: Clear PFA Status on SGPIO when PFA Drive is Removed
  or Replaced (FATE#315931,bnc#854824).
- mpt2sas: Copyright in driver sources is updated for year the
  2014 (FATE#315931,bnc#854824).
- mpt2sas: MPI2 Rev Y (2.00.17) and Rev Z (2.00.18) specifications
  (FATE#315931,bnc#854824).
- mpt2sas: Added new driver module Parameter disable_eedp to
  Disable EEDP Support (FATE#315931,bnc#854824).
- mpt2sas: Added driver module parameter max_msix_vectors
  (FATE#315931,bnc#854824).
- commit c4dd936
* Fri Mar 28 2014 hare@suse.de
- mpt3sas: Bump mpt3sas driver version to v04.100.00.00
  (FATE#315932,bnc#854817).
- mpt3sas: Added Reply Descriptor Post Queue (RDPQ) Array support
  (FATE#315932,bnc#854817).
- mpt3sas: Added OEM branding Strings (FATE#315932,bnc#854817).
- mpt3sas: Copyright in driver sources is updated for year the
  2014 (FATE#315932,bnc#854817).
- mpt3sas: MPI2.5 Rev H (2.5.3) specifications
  (FATE#315932,bnc#854817).
- mpt3sas: Bump mpt3sas driver version to v03.100.00.00
  (FATE#315932,bnc#854817).
- mpt3sas: Clear PFA Status on SGPIO when PFA Drive is Removed
  or Replaced (FATE#315932,bnc#854817).
- mpt3sas: MPI2.5 Rev G (2.5.2) specifications
  (FATE#315932,bnc#854817).
- mpt3sas: Added new driver module Parameter disable_eedp to
  Disable EEDP Support (FATE#315932,bnc#854817).
- commit 5f1cce3
* Fri Mar 28 2014 jdelvare@suse.de
- Add git references
  Add git-commit and git-repo tags to:
  patches.fixes/video-output-01-acpi-drop-dependency.patch
  patches.fixes/video-output-02-gpu-drm-drop-selects.patch
  patches.fixes/video-output-03-acer_wmi-drop-select.patch
- commit 781bf56
* Fri Mar 28 2014 rgoldwyn@suse.de
- Update config files: Disable DLM
  DLM is provided by ocfs2-kmp module.
- commit 7524f09
* Fri Mar 28 2014 jlee@suse.com
- KEYS: Make the keyring cycle detector ignore other keyrings
  of the same name (bnc#866842, CVE-2014-0102).
- commit 2eea580
* Fri Mar 28 2014 jjolly@suse.de
- ib/ipoib: Move QP to ERROR only when the QP is not at REST state
  (bnc#868011).
- commit 68ec41b
* Fri Mar 28 2014 jjolly@suse.de
- IB/core: Don't resolve passive side RoCE L2 address in cma
  req handler (bnc#868011).
- commit 5c8d811
* Fri Mar 28 2014 jjolly@suse.de
- IB/iser: Avoid dereferencing iscsi_iser conn object when not
  bound to iser connection (bnc#868011).
- commit 681271f
* Fri Mar 28 2014 jjolly@suse.de
- IB: Report using RoCE IP based gids in port caps (bnc#868011).
- commit 0f95169
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Build the port IBoE GID table properly under bonding
  (bnc#868011).
- commit 0d82d5f
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Do IBoE GID table resets per-port (bnc#868011).
- commit f86865c
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Do IBoE locking earlier when initializing the GID table
  (bnc#868011).
- commit 06c147b
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Move rtnl locking to the right place (bnc#868011).
- commit 1555cdd
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Make sure GID index 0 is always occupied (bnc#868011).
- commit c398424
* Fri Mar 28 2014 jjolly@suse.de
- IB/core: Resolve Ethernet L2 addresses when modifying QP
  (bnc#868011).
- commit 17b7b53
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Handle Ethernet L2 parameters for IP based GID
  addressing (bnc#868011).
- commit ae04c20
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Use IBoE (RoCE) IP based GIDs in the port GID table
  (bnc#868011).
- commit 33df9a2
* Fri Mar 28 2014 jjolly@suse.de
- IB/cma: IBoE (RoCE) IP-based GID addressing (bnc#868011).
- commit b29a9e1
* Fri Mar 28 2014 jjolly@suse.de
- IB/core: Ethernet L2 attributes in verbs/cm structures
  (bnc#868011).
- commit ce5dc6f
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Don't allocate range of steerable UD QPs for
  Ethernet-only device (bnc#868011).
- commit ba4d137
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Add support for steerable IB UD QPs (bnc#868011).
- commit e26c2c6
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Add mechanism to support flow steering over IB links
  (bnc#868011).
- commit a938cfc
* Fri Mar 28 2014 jjolly@suse.de
- IB/mlx4: Enable device-managed steering support for IB ports
  too (bnc#868011).
- commit d1bfefa
* Fri Mar 28 2014 jjolly@suse.de
- net/mlx4_core: Fix wrong vxlan offloads device capability
  (bnc#868011).
- commit 353ba8d
* Fri Mar 28 2014 jjolly@suse.de
- mlx4_core: Add support for steerable IB UD QPs (bnc#868011).
- commit 9b58440
* Fri Mar 28 2014 jjolly@suse.de
- IB/core: Add support for IB L2 device-managed steering
  (bnc#868011).
- commit 816aaef
* Fri Mar 28 2014 jjolly@suse.de
- IB/core: Add flow steering support for IPoIB UD traffic
  (bnc#868011).
- commit a741c37
* Fri Mar 28 2014 dchang@suse.com
- be2net: Removed unecessary log for uknown grp5 event (bnc#855062
  FATE#315961, bnc#867583).
- be2net: Changed version number to suffix with 's' for SLES
  (bnc#855062 FATE#315961).
- be2net: Update copyright year (bnc#855062 FATE#315961).
- be2net: Log a kernel message when UE is detected in BE &
  Skyhawk (bnc#855062 FATE#315961).
- be2net: isolate TX workarounds not applicable to Skyhawk-R
  (bnc#855062 FATE#315961).
- be2net: Fix skb double free in be_xmit_wrokarounds() failure
  path (bnc#855062 FATE#315961).
- be2net: clear promiscuous bits in adapter->flags while disabling
  promiscuous mode (bnc#855062 FATE#315961).
- be2net: Fix to reset transparent vlan tagging (bnc#855062
  FATE#315961).
- be2net: Fix be_vlan_add/rem_vid() routines (bnc#855062
  FATE#315961).
- be2net: add dma_mapping_error() check for dma_map_page()
  (bnc#855062 FATE#315961).
- commit 13eadc3
* Thu Mar 27 2014 mhocko@suse.cz
- Update config files.
  enable DEBUG_ATOMIC_SLEEP to warn about scheduling from atomic contexts
  which is very helpful for debugging a class of deadlocks. The hotpath of
  the check and preempt_{en,dis}bale shouldn't add a noticable overhead
  because x86_64 uses per CPU preempt counter.
- commit 3df0ed2
* Thu Mar 27 2014 jdelvare@suse.de
- supported.conf: Remove useless wildcard masks
  These wildcard masks no longer match any driver so they can be
  omitted.
- commit 0edc07f
* Thu Mar 27 2014 dsterba@suse.cz
- Update patches.suse/btrfs-8027-fix-a-crash-of-clone-with-inline-extents-s-spl.patch (bnc#786750).
- commit e65c068
* Thu Mar 27 2014 dsterba@suse.cz
- Btrfs: fix a crash of clone with inline extents's split (bnc#857699).
- commit 1082984
* Thu Mar 27 2014 jdelvare@suse.de
- supported.conf: Update module paths
  Many modules moved to different directories over time.
  Also fix comment alignment on touched lines, and drop comments which
  do not add value.
- commit b9fa99a
* Thu Mar 27 2014 duwe@suse.de
- sysfs: create bin_attributes under the requested group
  (bnc#870365,fate#315738).
- powerpc: Add hvcalls for 24x7 and gpci (Get Performance Counter
  Info) (bnc#870365,fate#315738).
- powerpc/perf: Add hv_gpci interface header
  (bnc#870365,fate#315738).
- powerpc/perf: Add 24x7 interface headers
  (bnc#870365,fate#315738).
- powerpc/perf: Add a shared interface to get gpci version and
  capabilities (bnc#870365,fate#315738).
- powerpc/perf: Add macros for defining event fields & formats
  (bnc#870365,fate#315738).
- powerpc/perf: Add support for the hv gpci (get performance
  counter info) interface (bnc#870365,fate#315738).
- powerpc/perf: Add support for the hv 24x7 interface
  (bnc#870365,fate#315738).
- powerpc/perf: Add kconfig option for hypervisor provided
  counters (bnc#870365,fate#315738).
- powerpc/perf/hv_{gpci, 24x7}: Add documentation of device
  attributes (bnc#870365,fate#315738).
- Update config files.
- commit b26a0e2
* Thu Mar 27 2014 jslaby@suse.cz
- iscsi/iser-target: fix build warning.
- commit 7e895f1
* Thu Mar 27 2014 acho@suse.com
- bnx2x: Add missing bit in default Tx switching (bnc#853494
  FATE#315918).
- bnx2x: utilize FW 7.8.19 (bnc#853494 FATE#315918).
- commit 931ba33
* Wed Mar 26 2014 jdelvare@suse.de
- supported.conf: Merge consecutive blank lines
- commit c118bb7
* Wed Mar 26 2014 jeffm@suse.com
- config: sync s390x/vanilla to s390x/default
- commit a32d18b
* Wed Mar 26 2014 jdelvare@suse.de
- Update x86_64 config files: enable CONFIG_HID_BATTERY_STRENGTH
  Looks like a cool feature to support on desktop systems.
- commit 26ab092
* Wed Mar 26 2014 tiwai@suse.de
- ACPI / scan: Set flags.match_driver in acpi_bus_scan_fixed()
  (bnc#864949).
- commit 6bc2ea0
* Wed Mar 26 2014 jslaby@suse.cz
- Linux 3.12.15 (bnc#794824 bnc#821259 bnc#833968 bnc#838623
  bnc#842239 bnc#845621 bnc#846790 bnc#849463 bnc#851603
  bnc#852591 bnc#852852 bnc#853493 bnc#853496 bnc#853497
  bnc#853689 bnc#854594 bnc#856294 bnc#858404 bnc#860346
  bnc#860346 bnc#866937 bnc#867333 bnc#869414 FATE#315933
  LTC#100284 LTC#100323 LTC#100340 LTC#103493).
- Refresh
  patches.drivers/0001-usb-core-implement-AMD-remote-wakeup-quirk.patch.
- Refresh
  patches.drivers/hda-0005-add-codec-ID-for-Broadwell-display-audio-co.
- Refresh
  patches.drivers/hda-0029-block-HDMI-jack-reports-while-repolling.
- Refresh
  patches.suse/sched-numa-Use-a-system-wide-search-to-find-swap-migration-candidates.patch.
- Delete patches.arch/ACPI-update-win8-OSI-blacklist.
- Delete
  patches.arch/s390-sles12-01-01-3270-fix-missing-device_destroy-call.patch.
- Delete patches.arch/s390-sles12-01-02-update-vsyscall.patch.
- Delete patches.arch/s390-sles12-01-03-direct-ktime.patch.
- Delete
  patches.arch/s390-sles12-01-04-appldata-init_virt_timer.patch.
- Delete
  patches.drivers/0001-usb-ehci-use-amd_chipset_type-to-filter-for-usb-subs.patch.
- Delete
  patches.drivers/0001-usb-pci-quirks-refactor-AMD-quirk-to-abstract-AMD-ch.patch.
- Delete
  patches.drivers/0002-usb-ohci-use-amd_chipset_type-to-filter-for-SB800-pr.patch.
- Delete
  patches.drivers/drm-ttm-don-t-oops-if-no-invalidate_caches.
- Delete
  patches.drivers/hda-0001-Add-Device-IDs-for-Intel-Wildcat-Point-LP-P.
- Delete
  patches.drivers/hda-0002-add-device-IDs-for-AMD-Evergreen-Northern-I.
- Delete
  patches.drivers/hda-0003-Name-Haswell-HDMI-controllers-better.
- Delete
  patches.drivers/hda-0006-add-codec-ID-for-Valleyview2-display-codec.
- Delete
  patches.drivers/hda-0007-not-choose-assigned-converters-for-unused-p.
- Delete
  patches.drivers/hda-0008-rename-function-not_share_unassigned_cvt.
- Delete
  patches.drivers/hda-0012-hdmi-Fix-incorrect-default-channel-mapping-.
- Delete
  patches.drivers/hda-0013-hdmi-Fix-programmed-active-channel-count.
- Delete
  patches.drivers/hda-0014-hdmi-Fix-unused-slots-being-enabled-in-manu.
- Delete
  patches.drivers/hda-0015-hdmi-Fix-channel-maps-with-less-common-spea.
- Delete
  patches.drivers/hda-0016-hdmi-Fix-available-channel-maps-missing-fro.
- Delete
  patches.drivers/hda-0017-hdmi-Tweak-debug-messages-to-be-more-useful.
- Delete
  patches.drivers/hda-0018-Fix-possible-races-in-HDMI-driver.
- Delete
  patches.drivers/hda-0019-Move-mutex-from-hda_eld-to-per_pin-in-HDMI-.
- Delete patches.drivers/hda-0020-Fix-typos-in-patch_hdmi.c.
- Delete
  patches.drivers/hda-0027-Delay-HDMI-presence-reports-while-waiting-f.
- Delete
  patches.drivers/hda-0036-Explicitly-keep-codec-powered-up-in-hdmi_pr.
- Delete
  patches.drivers/qla2xxx-0039-Fix-multiqueue-MSI-X-registration.patch.
- Delete
  patches.fixes/SUNRPC-close-a-rare-race-in-xs_tcp_setup_socket.patch.
- Delete
  patches.fixes/blktrace-Send-BLK_TN_PROCESS-events-to-all-running-t.patch.
- Delete
  patches.fixes/efifb-prevent-null-deref-when-iterating-dmi_list.patch.
- Delete
  patches.fixes/futex-Move-user-address-verification-up-to-common-code.patch.
- Delete
  patches.fixes/mm-include-vm_mixedmap-flag-in-the-vm_special-list-to-avoid-munlocking.patch.
- Delete
  patches.fixes/nohz-check-for-nohz-active-instead-of-nohz-enabled.patch.
- Delete
  patches.fixes/nohz-fix-another-inconsistency-between-CONFIG_NO_HZ.patch.
- Delete patches.fixes/ocfs2-Fix-quota-file-corruption.patch.
- Delete
  patches.fixes/pci-drop-warning-about-drivers-that-dont-use-pci_set_master.patch.
- Delete patches.fixes/ppc-fix-fatal-SLB-miss-when-restoring-PPR.
- Delete patches.fixes/ppc-fix-power7-asymmetric-scheduling.
- Delete
  patches.fixes/rcu-Throttle-invoke_rcu_core-invocations-due-to-non-lazy-callbacks.patch.
- Delete
  patches.fixes/rcu-Throttle-rcu_try_advance_all_cbs-execution.patch.
- Delete
  patches.fixes/sched-Assign-correct-scheduling-domain-to-sd_llc.patch.
- Delete
  patches.fixes/sched-Avoid-NULL-dereference-on-sd_busy.patch.
- Delete
  patches.fixes/sched-Initialize-power_orig-for-overlapping-groups.patch.
- Delete
  patches.fixes/sched-Remove-unnecessary-iteration-over-sched-domain.patch.
- Delete patches.fixes/sched-rt-Add-missing-rmb.patch.
- Delete
  patches.fixes/sched-rt-Remove-redundant-nr_cpus_allowed-test.patch.
- Delete
  patches.fixes/tcp-syncookies-reduce-cookie-lifetime-to-128-seconds.patch.
- Delete
  patches.fixes/tcp-syncookies-reduce-mss-table-to-four-values.patch.
- Delete
  patches.fixes/x86-dumpstack-Fix-printk_address-for-direct-addresse.patch.
- Delete
  patches.fixes/xfrm-prevent-ipcomp-scratch-buffer-race-condition.patch.
- Delete
  patches.suse/0001-SELinux-Reduce-overhead-of-mls_level_isvalid-functio.patch.
- Delete
  patches.suse/0002-SELinux-Increase-ebitmap_node-size-for-64-bit-config.patch.
- Delete
  patches.suse/epoll-do-not-take-global-epmutex-for-simple-topologi.patch.
- Delete
  patches.suse/epoll-do-not-take-the-nested-ep-mtx-on-epoll_ctl_del.patch.
- Delete
  patches.suse/epoll-optimize-epoll_ctl_del-using-rcu.patch.
- Delete
  patches.suse/memcg-fix-endless-loop-in-__mem_cgroup_iter_next.patch.
- Delete
  patches.suse/memcg-reparent-charges-of-children-before-processing-parent.patch.
- Delete
  patches.suse/mm-compaction-break-out-of-loop-on-PageBuddy-in-isolate_freepages_block.patch.
- Delete
  patches.suse/mm-do-not-walk-all-of-system-memory-during-show_mem.patch.
- Delete
  patches.suse/mm-page_alloc-exempt-GFP_THISNOD-allocations-fair-zone-allocation-policy.patch.
- Delete
  patches.suse/msft-hv-0583-SCSI-storvsc-NULL-pointer-dereference-fix.patch.
- Update config files.
- commit ef1bbc7
* Wed Mar 26 2014 jslaby@suse.cz
- Refresh
  patches.drivers/qla2xxx-0039-Fix-multiqueue-MSI-X-registration.patch.
- Refresh
  patches.fixes/cgroup-protect-modifications-to-cgroup_idr-with-cgroup_mutex.patch.
- Refresh
  patches.suse/memcg-reparent-charges-of-children-before-processing-parent.patch.
  Update upstream IDs.
- commit bd7aed7
* Wed Mar 26 2014 jdelvare@suse.de
- Update ec2 config file: disable HID device drivers
  I don't think the HID drivers for non-standard keyboards and mice
  are needed at all on EC2.
- commit 6246d41
* Tue Mar 25 2014 jdelvare@suse.de
- Update ec2 config file: disable CONFIG_INPUT_FF_MEMLESS
  This helper module is useless on EC2.
- commit a96b538
* Tue Mar 25 2014 duwe@suse.de
- powerpc/pseries: Expose in kernel device tree update to drmgr
  (bnc#869931).
- powerpc/pseries: Update dynamic cache nodes for suspend/resume
  operation (bnc#869931).
- powerpc/pseries: Device tree should only be updated once after
  suspend/migrate (bnc#869931).
- powerpc/le: Big endian arguments for ppc_rtas() (bnc#869983).
- commit ef8d48e
* Tue Mar 25 2014 bp@suse.de
- ACPI, eMCA: Combine eMCA/EDAC event reporting priority
  (fate#315508).
- EDAC: Add an edac_report parameter to EDAC (fate#315508).
- commit cc93d5a
* Tue Mar 25 2014 dchang@suse.com
- qlcnic: Update version to 5.3.56 (bnc#853685 FATE#315935).
- qlcnic: Enhance semaphore lock access failure error message
  (bnc#853685 FATE#315935).
- qlcnic: Allow vlan0 traffic (bnc#853685 FATE#315935).
- qlcnic: Enhance driver message in failed state (bnc#853685
  FATE#315935).
- qlcnic: Updates to QLogic application/driver interface for
  virtual NIC configuration (bnc#853685 FATE#315935).
- qlcnic: Re-factor firmware minidump template header handling
  (bnc#853685 FATE#315935).
- qlcnic: Cleanup qlcnic_enable_msix() return values (bnc#853685
  FATE#315935).
- qlcnic: Fix loopback test failure (bnc#853685 FATE#315935).
- qlcnic: Fix tx timeout (bnc#853685 FATE#315935).
- qlcnic: Fix initialization of vlan list (bnc#853685
  FATE#315935).
- qlcnic: Correct off-by-one errors in bounds checks (bnc#853685
  FATE#315935).
- commit 80d95e7
* Tue Mar 25 2014 acho@suse.com
- net/mlx4_core: mlx4_init_slave() shouldn't access comm channel
  before PF is ready (bnc#868011 FATE#315946).
- commit 9f07bbb
* Tue Mar 25 2014 neilb@suse.de
- Delete patches.fixes/nfs-sock-timeout.fix.
  Received testing results from customer (bnc#852488) confirming
  that this part of the fix was not needed, so now removing it.
- commit bf2ae59
* Mon Mar 24 2014 dsterba@suse.cz
- Btrfs: take into account total references when doing backref
  lookup.
- Btrfs: return EPERM when deleting a default subvolume
  (bnc#869934).
- Btrfs: make defrag not fragment files when using prealloc
  extents.
- commit c9d02b4
* Mon Mar 24 2014 duwe@suse.de
- ipr: Format HCAM overlay ID 0x21 (bnc#867753).
- ipr: Add new CCIN definition for new hardware support
  (bnc#867753).
- ibmveth: Fix endian issues with MAC addresses (bnc#869735).
- commit b5388b5
* Mon Mar 24 2014 jeffm@suse.com
- netfilter: nf_conntrack_dccp: fix skb_header_pointer API usages
  (bnc#868653 CVE-2014-2523).
- commit be3eaea
* Mon Mar 24 2014 tiwai@suse.de
- acpi: add acpi_osi win8 blacklist for HP ProBoook 2012 models
  (bnc#869573).
- commit 1a8131f
* Mon Mar 24 2014 mgalbraith@suse.de
- Fix POWER7 futex regression introduced by bnc#851603 scalability fixes.
  futex: revert back to the explicit waiter counting code (bnc#851603).
- commit 5177490
* Mon Mar 24 2014 neilb@suse.de
- NFS: add support for multiple sec= mount options (bnc#868928).
- NFS: stop using NFS_MOUNT_SECFLAVOUR server flag (bnc#868928).
- NFS: cache parsed auth_info in nfs_server (bnc#868928).
- NFS: separate passed security flavs from selected (bnc#868928).
- NFSv4: make nfs_find_best_sec static (bnc#868928).
- SUNRPC: Fix RPC call retransmission statistics (bnc#868923).
- NFSv4: Ensure that we disable the resend timeout for NFSv4
  (bnc#868923).
- SUNRPC: Add RPC task and client level options to disable the
  resend timeout (bnc#868923).
- SUNRPC: Clean up - convert xprt_prepare_transmit to return a
  bool (bnc#868923).
- SUNRPC: Clear the request rq_bytes_sent field in
  xprt_release_write (bnc#868923).
- SUNRPC: Don't set the request connect_cookie until a successful
  transmit (bnc#868923).
- SUNRPC: Only update the TCP connect cookie on a successful
  connect (bnc#868923).
- SUNRPC: Enable the keepalive option for TCP sockets
  (bnc#868923).
- SUNRPC: Fix potential memory scribble in xprt_free_bc_request()
  (bnc#868903).
- nfs: initialize the ACL support bits to zero (bnc#868900).
- NFSv3: Fix return value of nfs3_proc_setacls (bnc#868900).
- NFSv4.1 free slot before resending I/O to MDS (bnc#868898).
- nfs: add memory barriers around NFS_INO_INVALID_DATA and
  NFS_INO_INVALIDATING (bnc#868897).
- NFS: Fix races in nfs_revalidate_mapping (bnc#868897).
- NFS: fix the handling of NFS_INO_INVALID_DATA flag in
  nfs_revalidate_mapping (bnc#868897).
- pnfs: fix BUG in filelayout_recover_commit_reqs (bnc#868891).
- nfs: page cache invalidation for dio (bnc#868891).
- nfs: take i_mutex during direct I/O reads (bnc#868891).
- nfs: merge nfs_direct_write into nfs_file_direct_write
  (bnc#868891).
- nfs: merge nfs_direct_read into nfs_file_direct_read
  (bnc#868891).
- nfs: increment i_dio_count for reads, too (bnc#868891).
- nfs: defer inode_dio_done call until size update is done
  (bnc#868891).
- nfs: fix size updates for aio writes (bnc#868891).
- nfs: fix dead code of ipv6_addr_scope (bnc#868891).
- NFSv4.1: Prevent a 3-way deadlock between layoutreturn, open
  and state recovery (bnc#868882).
- SUNRPC: do not fail gss proc NULL calls with EACCES
  (bnc#868881).
- nfs: use IS_ROOT not DCACHE_DISCONNECTED (bnc#868876).
- commit b9d797e
* Sun Mar 23 2014 tiwai@suse.de
- printk: Fixup console_flush() to avoid infinite loop
  (bnc#869632).
- commit ef19906
* Fri Mar 21 2014 jjolly@suse.de
- supported.conf: Added drivers/infiniband/ulp/isert/ib_isert.ko
- commit c6a29f4
* Fri Mar 21 2014 ohering@suse.de
- Drivers: hv: vmbus: Support per-channel driver state.
- commit bc61198
* Fri Mar 21 2014 mhocko@suse.cz
- Update config files.
  Enabled CONFIG_KSM for remaining architectures (bnc#869195).
- commit 4545e61
* Fri Mar 21 2014 jdelvare@suse.de
- Update xen config file: enable X86_INTEL_LPSS
  All other x86_64 config files but ec2 have CONFIG_X86_INTEL_LPSS=y,
  so do the same in the xen config file for consistency. Also enable
  CONFIG_RFKILL_GPIO=m for the same reason.
- commit 77171f5
* Thu Mar 20 2014 mgorman@suse.de
- mm: page_alloc: spill to remote nodes before waking kswapd
  (VM Functionality).
- commit ca4006b
* Thu Mar 20 2014 jjolly@suse.de
- Delete patches.drivers/rds-no-bug-in-xmit-for-loopback.patch. (bnc#767610, CVE-2012-2372)
- commit 777e447
* Thu Mar 20 2014 tiwai@suse.de
- drm/ttm: don't oops if no invalidate_caches() (bnc#869414).
- commit fa92ac7
* Thu Mar 20 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_INPUT_FF_MEMLESS
  It was set by mistake, obviously.
- commit 7719fb4
* Wed Mar 19 2014 jbeulich@suse.com
- efi: Move facility flags to struct efi (fate#315017).
- x86/efi: Dump the EFI page table (fate#315017).
- x86/efi: Quirk out SGI UV (fate#315017).
- x86/mm/pageattr: Always dump the right page table in an oops
  (fate#315017).
- x86, pageattr: Export page unmapping interface (fate#315017).
- x86, ptdump: Add the functionality to dump an arbitrary
  pagetable (fate#315017).
- Refresh patches.xen/xen-x86-EFI (build fix, fate#315017).
- Refresh other Xen patches.xen (drop 32-bit code).
- commit 8d8583b
* Wed Mar 19 2014 bp@suse.de
- iommu/amd: Fix PASID format in INVALIDATE_IOTLB_PAGES command
  (bnc#866173).
- commit 137db5a
* Wed Mar 19 2014 jkosina@suse.cz
- Update config files: for sake of consistency, enable MAXSMP for x86_64 also
  for -trace, -debug and -vanilla (FATE#316883)
- commit 25ed980
* Wed Mar 19 2014 hare@suse.de
- qla4xxx: do not block during initialisation (bnc#868390).
- commit 904e30e
* Tue Mar 18 2014 ohering@suse.de
- storvsc: NULL pointer dereference fix.
- commit e90cefb
* Tue Mar 18 2014 ohering@suse.de
- hyperv: Move state setting for link query.
- commit 37a65b1
* Tue Mar 18 2014 ohering@suse.de
- HID: hyperv: make sure input buffer is big enough.
- commit 078db5b
* Tue Mar 18 2014 ohering@suse.de
- hyperv: Fix the carrier status setting.
- commit 66b75dd
* Tue Mar 18 2014 jdelvare@suse.de
- Update x86_64/vanilla config file
  We can't disable CONFIG_VIDEO_OUTPUT_CONTROL in vanilla yet, because
  of the broken dependencies.
- commit bbe7f2b
* Tue Mar 18 2014 ohering@suse.de
- add mainline tag to a hv_netvsc patch
- commit 37c489b
* Tue Mar 18 2014 jdelvare@suse.de
- Update x86_64/vanilla config file: enable console rotation
  It's enabled in all other kernel flavors so it should be enabled in
  vanilla too.
- commit 5cbf32d
* Tue Mar 18 2014 duwe@suse.de
- Update config files.
  ppc64le/default CONFIG_GENWQE n -> m
  to match debug and trace configs
- commit 0a7ef45
* Tue Mar 18 2014 jdelvare@suse.de
- Align the x86_64 trace config file on the default config
- commit 2ce9ef0
* Tue Mar 18 2014 jlee@suse.com
- Update config files. (CONFIG_EFIVAR_FS=m)
  Due to systemd can auto-load efivarfs.ko, so wet CONFIG_EFIVAR_FS to
  module on x86_64.
- commit bfcadf3
* Mon Mar 17 2014 jack@suse.cz
- Remove bogus warning from
  patches.suse/printk-Hand-over-printing-to-console-if-printing-too.patch
  (bnc#868685)
- commit dc3f34f
* Mon Mar 17 2014 jdelvare@suse.de
- Update config files: disable CONFIG_VIDEO_OUTPUT_CONTROL
  This is dead code, no driver is calling this interface.
- commit 60d5ee7
* Mon Mar 17 2014 jdelvare@suse.de
- acer-wmi: Stop selecting VIDEO_OUTPUT_CONTROL.
- gpu/drm: Stop selecting VIDEO_OUTPUT_CONTROL.
- ACPI: fix ACPI_VIDEO dependencies.
- commit 68fb483
* Mon Mar 17 2014 jkosina@suse.cz
- x86/cpu: Allow higher NR_CPUS values (FATE#316883).
- x86/cpu: Increase max CPU count to 8192 (FATE#316883).
- Update config files: set NR_CPUS to 8192 for x86_64 -default
  (FATE#316883).
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- Refresh patches.xen/xen3-patch-2.6.30.
- commit 121c7d3
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit e5ce836
* Mon Mar 17 2014 hare@suse.de
- qla2xxx: Revert "Only enable link up on the correct interrupt
  event." (bnc#866608).
- commit 21397de
* Sat Mar 15 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  This makes it much easier to validate that the debug config file only
  diverges from default by debug and testing options.
- commit ec1f45b
* Fri Mar 14 2014 jdelvare@suse.de
- Update x86_64 config files: Restore CONFIG_SC1200_WDT=m
  You'd think a driver named sc1200wdt would be for the SC1200
  chipset... well, you'd be wrong, and so was I. Sorry for the noise.
- commit c4e670c
* Fri Mar 14 2014 jdelvare@suse.de
- Update x86_64 config files: Disable AMD Elan SC520 drivers
  The AMD Elan SC520 is a 32-bit x86 processor, related drivers are
  useless on SLE12.
- commit 9c33513
* Fri Mar 14 2014 jbeulich@suse.com
- Update Xen patches to 3.12.14  and c/s 1255.
- blkback: allow using indirect request segment descriptors
  (fate#316871).
- blkfront: allow using indirect request segment descriptors
  (fate#316871).
- x86, ramdisk: Export relocated ramdisk VA (fate#315602).
- Update Xen config file.
- Delete patches.xen/kexec-move-segment-code-i386.patch.
- Delete patches.xen/xen3-auto-arch-i386.diff.
- commit 9937d48
* Fri Mar 14 2014 jdelvare@suse.de
- Update x86_64 config files: Disable SC1200 drivers
  The SC1200 is a SoC based on the Geode GX1 32-bit x86 processor, so
  its drivers are useless on SLE12.
- commit a33e003
* Fri Mar 14 2014 mgorman@suse.de
- mm: revisit shrink_lruvec's attempt at proportionality
  (VM Performance).
- commit ca4b7ab
* Fri Mar 14 2014 hare@suse.de
- Fixup compilation issue in
  patches.arch/s390-con3270-optionally-disable-auto-update.patch.
- commit 0108d4b
* Fri Mar 14 2014 mmarek@suse.cz
- supported.conf: Drop now disabled webcam drivers
- commit 9a2d8a8
* Fri Mar 14 2014 hare@suse.de
- con3270: optionally disable auto update (bnc#868409).
- commit abbe072
* Thu Mar 13 2014 jack@suse.cz
- blk-mq: add REQ_SYNC early (fate#315209).
- rt,blk,mq: Make blk_mq_cpu_notify_lock a raw spinlock
  (fate#315209).
- blk-mq: support partial I/O completions (fate#315209).
- blk-mq: merge blk_mq_insert_request and blk_mq_run_request
  (fate#315209).
- blk-mq: remove blk_mq_alloc_rq (fate#315209).
- commit f057060
* Thu Mar 13 2014 bp@suse.de
- x86/efi: Delete dead code when checking for non-native
  (fate#315017).
- commit 2bf0d54
* Thu Mar 13 2014 bp@suse.de
- x86/mm/pageattr: Always dump the right page table in an oops
  (fate#315017).
- commit 244b7f8
* Thu Mar 13 2014 bp@suse.de
- x86, tools: Consolidate #ifdef code (fate#315017).
- commit b740dc1
* Thu Mar 13 2014 bp@suse.de
- x86/boot: Cleanup header.S by removing some #ifdefs
  (fate#315017).
- commit 6484911
* Thu Mar 13 2014 bp@suse.de
- x86/efi: Quirk out SGI UV (fate#315017).
- commit e9aab6d
* Thu Mar 13 2014 duwe@suse.de
- Update config files:
  CONFIG_HOTPLUG_PCI_RPA=m (bnc#867789)
- commit 8caf890
* Thu Mar 13 2014 jack@suse.cz
- Replace original printk softlockup patch with current version of the
  series:
- kernel: Avoid softlockups in stop_machine() during heavy
  printing (bnc#744692, bnc#789311).
- printk: Enable interrupts before calling
  console_trylock_for_printk() (bnc#744692, bnc#789311).
- printk: Hand over printing to console if printing too long
  (bnc#744692, bnc#789311).
- printk: Release lockbuf_lock before calling
  console_trylock_for_printk() (bnc#744692, bnc#789311).
- printk: Remove outdated comment (bnc#744692, bnc#789311).
- printk: Remove separate printk_sched buffers and use printk
  buf instead (bnc#744692, bnc#789311).
- Delete
  patches.fixes/printk-fix-softlockups-during-heavy-printing.patch.
- commit 58967f9
* Thu Mar 13 2014 duwe@suse.de
- hwrng: make khwrngd configurable (fate#316346).
- commit 58086a2
* Thu Mar 13 2014 bp@suse.de
- x86/efi: Check status field to validate BGRT header
  (fate#315017).
- commit 2f8ea18
* Thu Mar 13 2014 mgorman@suse.de
- mm: __rmqueue_fallback() should respect pageblock type
- mm: get rid of unnecessary overhead of trace_mm_page_alloc_extfrag()
- mm/page_alloc: fix freeing of MIGRATE_RESERVE migratetype pages
  (VM Performance).
- commit da2a07d
* Thu Mar 13 2014 bp@suse.de
- efi: Use NULL instead of 0 for pointer (fate#315017).
- commit 2f74639
* Thu Mar 13 2014 hare@suse.de
- hpsa: fix bad endif placement in RAID 5 mapper code
  (FATE#315359).
- hpsa: Do not zero fields of ioaccel2 command structure twice
  (FATE#315359).
- hpsa: Add hba mode to the hpsa driver (FATE#315359).
- hpsa: remove unused struct request from CommandList
  (FATE#315359).
- hpsa: increase the probability of a reported success after a
  device (FATE#315359).
- hpsa: bring format-in-progress drives online when ready
  (FATE#315359).
- hpsa: remove unused kthread.h header (FATE#315359).
- hpsa: Add support for a few HP Storage controllers (hand-edited
  by (FATE#315359).
- pci: add HP/3PAR vendor id to pci_ids.h (FATE#315359).
- hpsa add sysfs debug switch for raid map debugging messages
  (FATE#315359).
- hpsa: improve error messages for driver initiated commands
  (FATE#315359).
- hpsa: only do device rescan for certain events (FATE#315359).
- hpsa: when switching out of accel mode await only accel command
  (FATE#315359).
- hpsa: add controller base data-at-rest encryption compatibility
  (FATE#315359).
- hpsa: update source file copyrights (FATE#315359).
- hpsa: retry certain ioaccel error cases on the RAID path
  (FATE#315359).
- hpsa: do not inquire for unsupported ioaccel status vpd page
  (FATE#315359).
- hpsa: allow VPD page zero to be queried (FATE#315359).
- hpsa: rescan devices on ioaccel2 error (FATE#315359).
- hpsa: allow user to disable accelerated i/o path (FATE#315359).
- hpsa: complete the ioaccel raidmap code (FATE#315359).
- hpsa: make device update copy the raid map also (FATE#315359).
- hpsa: add task management for ioaccel mode 2 (FATE#315359).
- hpsa: teach hpsa_device_reset to do either target or lun reset
  (FATE#315359).
- hpsa: get ioaccel mode 2 i/o working (FATE#315359).
- hpsa: initialize controller to perform io accelerator mode 2
  (FATE#315359).
- hpsa: get physical device handles for io accel mode 2 as well as
  (FATE#315359).
- hpsa: do ioaccel mode 2 resource allocations (FATE#315359).
- hpsa: Acknowledge controller events in ioaccell mode 2 as well
  as (FATE#315359).
- hpsa: add ioaccel mode 2 structure definitions (FATE#315359).
- hpsa: complain if physical or logical aborts are not supported
  (FATE#315359).
- hpsa: add hp_ssd_smart_path_enabled sysfs attribute
  (FATE#315359).
- hpsa: do not rescan controllers known to be locked up
  (FATE#315359).
- hpsa: poll controller to detect device change event
  (FATE#315359).
- hpsa: update raid offload status on device rescan (FATE#315359).
- hpsa: add ioaccell mode 1 RAID offload support (FATE#315359).
- hpsa: fix task management for mode-1 ioaccell path
  (FATE#315359).
- hpsa: only allow REQ_TYPE_FS to use fast path (FATE#315359).
- hpsa: add support for 'fastpath' i/o (FATE#315359).
- hpsa: mark last scatter gather element as the last
  (FATE#315359).
- hpsa: use extended report luns command for HP SSD SmartPath
  (FATE#315359).
- commit 46cfb95
* Thu Mar 13 2014 hare@suse.de
- hpsa: use workqueue instead of kernel thread for lockup
  detection (FATE#315359).
- hpsa: rename scsi prefetch field (FATE#315359).
- hpsa: enable unit attention reporting (FATE#315359).
- hpsa: do not require board "not ready" status after hard reset
  (FATE#315359).
- hpsa: allow SCSI mid layer to handle unit attention
  (FATE#315359).
- Refresh
  patches.drivers/hpsa-0009-cap-CCISS_PASSTHRU-at-20-concurrent-commands.patch.
- Delete
  patches.drivers/hpsa-0007-hide-logical-drives-with-format-in-progress-fro.patch.
- Delete
  patches.drivers/hpsa-0008-bring-logical-drives-online-when-format-complet.patch.
- commit bed7ae5
* Thu Mar 13 2014 mgorman@suse.de
- swap: add a simple detector for inappropriate swapin readahead
  (VM Functionality).
- commit 9654d1a
* Thu Mar 13 2014 mgorman@suse.de
- mm/page_alloc: fix freeing of MIGRATE_RESERVE migratetype pages
  (VM Performance).
- commit 90548e9
* Thu Mar 13 2014 jslaby@suse.cz
- Refresh
  patches.fixes/tty-Set-correct-tty-name-in-active-sysfs-attribute.patch.
  Update to the latest version.
- commit 6a6897f
* Thu Mar 13 2014 jdelvare@suse.de
- Update debug config files: mac80211 debug options
  Enable all mac80211 debug options in all debug kernel flavors.
- commit 0094d8e
* Thu Mar 13 2014 bp@suse.de
- ia64/efi: Implement efi_enabled() (fate#315017).
- commit cc1656b
* Thu Mar 13 2014 trenn@suse.de
- Should be handled in mainline. Differently but should work, remove this one:
  Delete patches.arch/x86_do_not_set_nvs_ram_busy.patch.
- commit 4eba5b6
* Thu Mar 13 2014 mmarek@suse.cz
- supported.conf: Add dependencies of supported drivers
- commit f6ef720
* Thu Mar 13 2014 dchang@suse.com
- Update s390x config files
- Enable CONFIG_MLX5_CORE and CONFIG_MLX5_INFINIBAND on s390x
- commit b97898e
* Thu Mar 13 2014 mmarek@suse.cz
- Disable CONFIG_V4L_PLATFORM_DRIVERS
  Not relevant for SLES/SLED.
- commit 5a18926
* Thu Mar 13 2014 jdelvare@suse.de
- supported.conf: Support the AD7879 touchscreen again
  ad7879 was originally a standalone driver, that could be built to
  support either I2C or SPI access. In kernel 2.6.36, it was split into a
  helper module (ad7879) and two device drivers, one for I2C access
  (ad7879-i2c) and one for SPI access (ad7879-spi, which we do not include
  in SLE12.)
  So in order to fully support the AD7879 touchscreen as we used to, we
  must support both ad7879 and ad7879-i2c.
- commit a00b07b
* Thu Mar 13 2014 jdelvare@suse.de
- supported.conf: Drop unused helper modules
  The following helper modules aren't used by any supported driver so
  we don't have to support them either:
- hwmon-vid
- videobuf-dma-contig
- reed_solomon
- commit ce62343
* Thu Mar 13 2014 mgalbraith@suse.de
- sched: Fix endless sync_sched/rcu() loop inside _cpu_down()
  (Automatic NUMA Balancing (fate#315482)).
- commit 309ff98
* Thu Mar 13 2014 jlee@suse.com
- Refresh patches.suse/firmware-dont-spew-errors-in-normal-boot.
  (bnc#867199)
- commit 4553798
* Thu Mar 13 2014 dchang@suse.com
- Update s390x config files
- Disable CONFIG_MLX5_CORE and CONFIG_MLX5_INFINIBAND on s390x
- commit daf08fd
* Thu Mar 13 2014 dchang@suse.com
- net,IB/mlx: Bump all Mellanox driver versions (bnc#865545
  FATE#316891).
- IB/mlx5: Remove dependency on X86 (bnc#865545 FATE#316891).
- IB/mlx5: Don't set "block multicast loopback" capability
  (bnc#865545 FATE#316891).
- IB/mlx5: Fix binary compatibility with libmlx5 (bnc#865545
  FATE#316891).
- IB/mlx5: Fix RC transport send queue overhead computation
  (bnc#865545 FATE#316891).
- commit 764d20b
* Wed Mar 12 2014 bp@suse.de
- x86/efi: Split efi_enter_virtual_mode (fate#315017).
- commit bdbc811
* Wed Mar 12 2014 bp@suse.de
- x86/efi: Make efi virtual runtime map passing more robust
  (fate#315017).
- x86, pageattr: Export page unmapping interface (fate#315017).
- commit 6dc11b9
* Wed Mar 12 2014 bp@suse.de
- x86/efi: Dump the EFI page table (fate#315017).
- commit 44ca6bd
* Wed Mar 12 2014 bp@suse.de
- x86, ptdump: Add the functionality to dump an arbitrary
  pagetable (fate#315017).
- commit 825d56e
* Wed Mar 12 2014 jkosina@suse.cz
- watchdog: remove DEFINE_PCI_DEVICE_TABLE macro (bnc#867259
  FATE#315358).
- watchdog: hpwdt patch to display informative string (bnc#867259
  FATE#315358).
- commit 926b8c2
* Wed Mar 12 2014 bp@suse.de
- efi: Set feature flags inside feature init functions
  (fate#315017).
- Refresh patches.xen/xen-x86-EFI.
- commit a684dfa
* Wed Mar 12 2014 dsterba@suse.cz
- Btrfs: fix preallocate vs double nocow write.
- Btrfs: fix wrong lock range and write size in check_can_nocow().
- Btrfs: remove unneeded field / smaller extent_map structure.
- Btrfs: wake up @scrub_pause_wait as much as we can.
- Btrfs: cancel scrub on transaction abortion.
- Btrfs: device_replace: fix deadlock for nocow case.
- Btrfs: fix a possible deadlock between scrub and transaction
  committing.
- btrfs: wake up transaction thread upon remount.
- Btrfs: fix the skipped transaction commit during the file sync.
- Btrfs: avoid warning bomb of btrfs_invalidate_inodes.
- Btrfs: fix possible deadlock in btrfs_cleanup_transaction.
- btrfs: always choose work from prio_head first.
- Btrfs: skip submitting barrier for missing device.
- Btrfs: unlock extent and pages on error in cow_file_range.
- Btrfs: balance delayed inode updates.
- Btrfs: fix use-after-free in the finishing procedure of the
  device replace.
- Btrfs: fix unprotected alloc list insertion during the finishing
  procedure of replace.
- btrfs: Return EXDEV for cross file system snapshot.
- commit 2360902
* Wed Mar 12 2014 hare@suse.de
- Refresh patches.suse/dm-mpath-no-partitions-feature.
- Disable patches.suse/dm-emulate-blkrrpart-ioctl
- commit 9e28745
* Wed Mar 12 2014 mgorman@suse.de
- mm/compaction: break out of loop on !PageBuddy in
  isolate_freepages_block (VM Functionality).
- mm: fix GFP_THISNODE callers and clarify (VM Functionality).
- thp: move preallocated PTE page table on move_huge_pmd()
  (VM Functionality).
- mm: numa: Recheck for transhuge pages under lock during
  protection changes (Automatic NUMA Balancing (fate#315482)).
- move mmu notifier call from change_protection to
  change_pmd_range (Automatic NUMA Balancing (fate#315482)).
- mm,numa: reorganize change_pmd_range (Automatic NUMA Balancing
  (fate#315482)).
- sched,numa: add cond_resched to task_numa_work (Automatic NUMA
  Balancing (fate#315482)).
- stop_machine: Fix^2 race between stop_two_cpus() and stop_cpus()
  (Automatic NUMA Balancing (fate#315482)).
- commit 6748d0e
* Wed Mar 12 2014 hare@suse.de
- megaraid_sas: Add Dell PowerEdge VRTX SR-IOV VF support
  (FATE#315929,bnc#854993).
- megaraid_sas: Big endian code related fixes
  (FATE#315929,bnc#854993).
- megaraid_sas: Don't wait forever for non-IOCTL DCMDs
  (FATE#315929,bnc#854993).
- megaraid_sas: Fix megasas_ioc_init_fusion
  (FATE#315929,bnc#854993).
- megaraid_sas: Load correct raid context timeout
  (FATE#315929,bnc#854993).
- megaraid_sas: Performance boost fixes (FATE#315929,bnc#854993).
- megaraid_sas: Return leaked MPT frames to MPT frame pool
  (FATE#315929,bnc#854993).
- megaraid_sas: Set 32-bit DMA mask (FATE#315929,bnc#854993).
- megaraid_sas: Version and Changelog update
  (FATE#315929,bnc#854993).
- SCSI: remove unnecessary pci_set_drvdata() (FATE#315939).
- Delete patches.drivers/scsi-bfa-remove_pci_set_drvdata.
- commit e918716
* Wed Mar 12 2014 hare@suse.de
- Update lpfc version for sles12 driver release 10.2.8040.0
  (bnc#854999,FATE#315959).
- lpfc: use NULL instead of 0 for pointer
  (bnc#854999,FATE#315959).
- Delete
  patches.drivers/lpfc-8.3.45-Update-lpfc-version-to-driver-version-8..patch.
- commit 787c4cb
* Wed Mar 12 2014 dchang@suse.com
- Update ppc64le config files
- Add CONFIG_MLX5_CORE and CONFIG_MLX5_INFINIBAND on ppc64le
  (bnc#865545 FATE#316891)
- commit ccbb76d
* Tue Mar 11 2014 jdelvare@suse.de
- Update ppc64le config files: Drop OLPC-related driver
  OLPC drivers are only useful on i386.
- commit 4284a23
* Tue Mar 11 2014 bp@suse.de
- x86/uv/nmi, kgdb/kdb: Fix UV NMI handler when KDB not configured
  (fate#315262).
- commit 6e747ef
* Tue Mar 11 2014 bp@suse.de
- x86/uv/nmi: Fix Sparse warnings (fate#315262).
- commit c9a1b46
* Tue Mar 11 2014 jdelvare@suse.de
- Update config files: Drop all Geode-related drivers
  The Geode was a 32-bit x86 CPU, so all drivers for its companion
  chips (CS55xx) are useless now. Same for OT200 drivers, as the
  Bachmann OT200 device was based on a Geode CPU.
- commit c72200d
* Tue Mar 11 2014 bp@suse.de
- kgdb/kdb: Fix no KDB config problem (fate#315262).
- commit 0876cb9
* Tue Mar 11 2014 bp@suse.de
- x86/UV: Add call to KGDB/KDB from NMI handler (fate#315262).
- commit 38600b7
* Tue Mar 11 2014 bp@suse.de
- kdb: Add support for external NMI handler to call KGDB/KDB
  (fate#315262).
- commit 6e820c2
* Tue Mar 11 2014 bp@suse.de
- x86/UV: Add kdump to UV NMI handler (fate#315262).
- commit 0cca109
* Tue Mar 11 2014 bp@suse.de
- x86/UV: Add summary of cpu activity to UV NMI handler
  (fate#315262).
- commit 0bee93d
* Tue Mar 11 2014 oneukum@suse.de
- Revert "usb: xhci: Link TRB must not occur within a USB payload
  burst" (FATE#315595).
- Revert "xhci: Avoid infinite loop when sg urb requires too
  many trbs" (FATE#315595).
- Revert "xhci: Set scatter-gather limit to avoid failed block
  writes." (FATE#315595).
- xhci 1.0: Limit arbitrarily-aligned scatter gather
  (FATE#315595).
- commit d0ed6b2
* Tue Mar 11 2014 mszeredi@suse.cz
- SELinux: Increase ebitmap_node size for 64-bit configuration
  (bnc#867333).
- SELinux: Reduce overhead of mls_level_isvalid() function call
  (bnc#867333).
- commit e4ab49b
* Tue Mar 11 2014 bp@suse.de
- x86/UV: Check for alloc_cpumask_var() failures properly in uv_nmi_setup()
  (fate#315262).
- commit f2f08af
* Tue Mar 11 2014 oneukum@suse.de
- storage: accept some UAS devices if streams are unavailable
  (FATE#315595).
- xhci: Kill streams URBs when the host dies (FATE#315595).
- xhci: Refactor command watchdog and fix split string
  (FATE#315595).
- commit c524b04
* Tue Mar 11 2014 oneukum@suse.de
- Refresh
  patches.drivers/0021-uas-Fix-response-iu-struct-definition.patch.
- Refresh
  patches.drivers/0022-uas-Pack-iu-struct-definitions.patch.
- Refresh
  patches.drivers/0023-uas-Use-all-available-stream-ids.patch.
- Refresh
  patches.drivers/0024-uas-Add-a-uas_find_uas_alt_setting-helper-function.patch.
- Refresh
  patches.drivers/0025-uas-Move-uas-detect-code-to-uas-detect.h.patch.
- Refresh
  patches.drivers/0026-xhci-xhci_mem_cleanup-make-sure-cmd_ring_reserved_tr.patch.
- Refresh
  patches.drivers/0027-xhci-The-trb_address_map-radix-tree-expects-1KB-segm.patch.
- Refresh patches.drivers/0028-xhci-Handle-MaxPSASize-0.patch.
- Refresh
  patches.drivers/0029-usb-Clear-host_endpoint-streams-when-implicitly-free.patch.
- Refresh
  patches.drivers/0030-usb-Reset-USB-3-devices-on-USB-3-link-bounce.patch.
- Refresh
  patches.drivers/0031-uas-Add-the-posibilty-to-blacklist-uas-devices-from-.patch.
- Refresh
  patches.drivers/0032-usb-storage-Don-t-bind-to-uas-devices-if-the-uas-dri.patch.
- Refresh
  patches.drivers/0033-usb-storage-Modify-and-export-adjust_quirks-so-that-.patch.
- Refresh
  patches.drivers/0034-uas-Honor-no-uas-quirk-set-in-usb-storage-s-quirks-m.patch.
- Refresh
  patches.drivers/0035-uas-Add-uas_find_endpoints-helper-function.patch.
- Refresh
  patches.drivers/0036-uas-Fix-bounds-check-in-uas_find_endpoints.patch.
- Refresh
  patches.drivers/0037-uas-Move-uas_find_endpoints-to-uas-detect.h.patch.
- Refresh
  patches.drivers/0038-uas-Drop-fixed-endpoint-config-handling.patch.
- Refresh
  patches.drivers/0039-uas-Verify-endpoint-descriptors-from-uas_use_uas_dri.patch.
- Refresh
  patches.drivers/0040-uas-Not-being-able-to-alloc-streams-when-connected-t.patch.
- Refresh
  patches.drivers/0041-uas-task_mgmt-Kill-the-sense-urb-if-we-fail-to-submi.patch.
- Refresh
  patches.drivers/0042-uas-Don-t-allow-more-then-one-task-to-run-at-the-sam.patch.
- Refresh
  patches.drivers/0043-uas-Use-GFP_NOIO-rather-then-GFP_ATOMIC-where-possib.patch.
- Refresh
  patches.drivers/0044-uas-Add-suspend-resume-support.patch.
- Refresh patches.drivers/0045-uas-Reset-device-on-reboot.patch.
- Refresh
  patches.drivers/0046-uas-Fix-task-management-not-working-when-connected-o.patch.
- Refresh
  patches.drivers/0047-uas-uas_alloc_data_urb-Remove-unnecessary-use_stream.patch.
- Refresh
  patches.drivers/0048-uas-Properly-complete-inflight-commands-on-bus-reset.patch.
- Refresh
  patches.drivers/0049-uas-add-uas_mark_cmd_dead-helper-function.patch.
- Refresh
  patches.drivers/0050-uas-cmdinfo-use-only-one-list-head.patch.
- Refresh
  patches.drivers/0051-uas-Fix-command-task-mgmt-submission-racing-with-dis.patch.
- Refresh patches.drivers/0052-uas-Fix-memory-management.patch.
- Refresh
  patches.drivers/0053-uas-Clear-cmdinfo-on-command-queue-ing.patch.
- Refresh
  patches.drivers/0054-uas-Use-the-right-error-codes-for-different-kinds-of.patch.
- Refresh patches.drivers/0055-uas-Improve-error-reporting.patch.
- Refresh
  patches.drivers/0056-uas-Add-some-data-in-out-ready-iu-sanity-checks.patch.
- Refresh
  patches.drivers/0057-uas-Make-sure-sg-elements-are-properly-aligned.patch.
- Refresh patches.drivers/0058-uas-remove-BROKEN.patch.
- Refresh
  patches.drivers/0059-uas-Add-Hans-de-Goede-as-uas-maintainer.patch.
- Refresh
  patches.drivers/0060-uas-Remove-comment-about-registering-a-uas-scsi-cont.patch.
- commit 619ae61
* Tue Mar 11 2014 bp@suse.de
- x86/UV: Update UV support for external NMI signals
  (fate#315262).
- commit 62b6d30
* Mon Mar 10 2014 bp@suse.de
- x86/UV: Move NMI support (fate#315262).
- commit deff9d5
* Mon Mar 10 2014 bp@suse.de
- efi: Move facility flags to struct efi (fate#315017).
- Refresh patches.xen/xen-x86-EFI.
- commit 6369230
* Mon Mar 10 2014 jdelvare@suse.de
- supported.conf: Drop all scx200 drivers
  scx200 drivers are i386-only, so we are no longer building them, so
  we can't support them.
- commit 4bba7b5
* Mon Mar 10 2014 vbabka@suse.cz
- mm: include VM_MIXEDMAP flag in the VM_SPECIAL list to avoid
  m(un)locking (VM Functionality).
- Refresh patches.xen/xen3-auto-common.diff.
- commit af63902
* Mon Mar 10 2014 bp@suse.de
- x86/efi: Fix 32-bit fallout (fate#315017).
- commit 1a118d8
* Mon Mar 10 2014 oneukum@suse.de
- Refresh
  patches.drivers/0001-usb-core-Move-USB_MAXENDPOINTS-definitions-to-usb.h.patch.
- Refresh
  patches.drivers/0002-usb-core-Track-if-an-endpoint-has-streams.patch.
- Refresh
  patches.drivers/0003-usb-core-Free-bulk-streams-on-interface-release.patch.
- Refresh
  patches.drivers/0004-usbfs-Kill-urbs-on-interface-before-doing-a-set_inte.patch.
- Refresh
  patches.drivers/0005-usbfs-proc_do_submiturb-use-a-local-variable-for-num.patch.
- Refresh
  patches.drivers/0006-usbfs-Add-support-for-bulk-stream-ids.patch.
- Refresh
  patches.drivers/0007-usbfs-Add-ep_to_host_endpoint-helper-function.patch.
- Refresh
  patches.drivers/0007-xhci-use-usb_ss_max_streams-in-xhci_check_streams_en.patch.
- Refresh
  patches.drivers/0008-usbfs-Add-support-for-allocating-freeing-streams.patch.
- Refresh
  patches.drivers/0008-xhci-Remove-segments-from-radix-tree-on-failed-inser.patch.
- Refresh
  patches.drivers/0009-uas-properly-reinitialize-in-uas_eh_bus_reset_handle.patch.
- Refresh
  patches.drivers/0009-usb-core-Fix-usb_free_streams-return-value-documenta.patch.
- Refresh
  patches.drivers/0010-uas-make-work-list-per-device.patch.
- Refresh patches.drivers/0011-uas-add-dead-request-list.patch.
- Refresh
  patches.drivers/0012-uas-replace-BUG_ON-WARN_ON-with-WARN_ON_ONCE.patch.
- Refresh
  patches.drivers/0013-uas-Urbs-must-be-anchored-before-submitting-them.patch.
- Refresh
  patches.drivers/0014-uas-Properly-set-interface-to-altsetting-0-on-probe-.patch.
- Refresh
  patches.drivers/0015-uas-Avoid-unnecessary-unlock-lock-calls-around-unlin.patch.
- Refresh
  patches.drivers/0016-uas-uas_alloc_cmd_urb-drop-unused-stream_id-paramete.patch.
- Refresh
  patches.drivers/0017-uas-Fix-uas-not-working-when-plugged-into-an-ehci-po.patch.
- Refresh patches.drivers/0018-uas-Fix-reset-locking.patch.
- Refresh
  patches.drivers/0019-uas-Fix-reset-handling-for-externally-triggered-rese.patch.
- Refresh
  patches.drivers/0020-uas-s-response_ui-response_iu.patch.
- commit 4330254
* Mon Mar 10 2014 oneukum@suse.de
- Refresh patches.drivers/0001-xhci-fix-usb3-streams.patch.
- Refresh
  patches.drivers/0002-xhci-Free-streams-when-they-are-still-allocated-on-a.patch.
- Refresh
  patches.drivers/0003-xhci-Check-size-rather-then-number-of-streams-when-a.patch.
- Refresh
  patches.drivers/0004-xhci-For-streams-the-css-flag-most-be-read-from-the-.patch.
- Refresh
  patches.drivers/0005-xhci-Set-SCT-field-for-Set-TR-dequeue-on-streams.patch.
- Refresh
  patches.drivers/0006-xhci-For-streams-the-dequeue-ptr-must-be-read-from-t.patch.
- commit 8ae4f99
* Mon Mar 10 2014 jslaby@suse.cz
- Linux 3.12.14 (CVE-2014-00691 FATE#315534 FATE#315916
  LTC#104787 bnc#846531 bnc#852488 bnc#852650 bnc#864025
  bnc#865994 bnc#866937 fate#315275).
- Refresh
  patches.drivers/ALSA-hda-load-EQ-params-into-IDT-codec-on-HP-bNB13-s.
- Refresh
  patches.fixes/cgroup-protect-modifications-to-cgroup_idr-with-cgroup_mutex.patch.
- Refresh patches.fixes/nfs-sock-timeout.fix.
- Refresh
  patches.suse/btrfs-0131-incompatible-format-change-to-remove-hole-exte.patch.
- Refresh
  patches.suse/sched-provide-rtkthreads-rtworkqueues-boot-options.patch.
- Delete
  patches.arch/ppc64le-correctly-handle-stop-self-RTAS-token.
- Delete
  patches.arch/ppc64le-fix-page-frame-number-check-in-copy_oldmem_page.
- Delete
  patches.drivers/ALSA-hda-Add-extra-chmap-for-2.1-outputs-on-ASUS-lap.
- Delete patches.drivers/drm-radeon-fix-audio-disable-on-dce6.
- Delete
  patches.drivers/tg3-0028-tg3-Fix-deadlock-in-tg3_change_mtu.patch.
- Delete
  patches.fixes/cifs-ensure-that-uncached-writes-handle-unmapped-are.patch.
- Delete
  patches.fixes/quota-Fix-race-between-dqput-and-dquot_scan_active.patch.
- Delete
  patches.suse/btrfs-0178-return-immediately-if-tree-log-mod-is-not-nece.patch.
- Delete patches.suse/btrfs-0186-fix-tree-mod-logging.patch.
- Delete
  patches.suse/btrfs-0263-fix-data-corruption-when-reading-updating-comp.patch.
- Delete
  patches.suse/intel-tsx-0006-perf-enforce-1-as-lower-limit-for-perf_event_max_sample_rate.patch.
- Delete patches.suse/mm-thp-fix-infinite-loop-on-memcg-oom.patch.
- commit 9cedbe0
* Mon Mar 10 2014 oneukum@suse.de
- xhci: add the meaningful IRQ description if it is empty
  (FATE#315595).
- commit fe9921c
* Mon Mar 10 2014 jdelvare@suse.de
- supported.conf: Delete all +isa drivers
  None of the architectures we support, support ISA, so we can get rid
  of all the ISA drivers in supported.conf.
- commit 5de3640
* Mon Mar 10 2014 mkubecek@suse.cz
- ipv6: router reachability probing (bnc#853162).
- ipv6: remove the unnecessary statement in find_match()
  (bnc#853162).
- commit 6033f71
* Mon Mar 10 2014 ohering@suse.de
- hyperv: Change the receive buffer size for legacy hosts.
- commit 6d8ee23
* Sat Mar  8 2014 jjolly@suse.de
- supported.conf: Added usnic_verbs.ko (bnc#866078)
- commit 6c5510e
* Fri Mar  7 2014 jbohac@suse.cz
- tcp: syncookies: reduce cookie lifetime to 128 seconds
  (bnc#833968).
- tcp: syncookies: reduce mss table to four values (bnc#833968).
- commit 275356b
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Generate a per-architecture per-package _constraints file
- commit 65a07f7
* Fri Mar  7 2014 jjolly@suse.de
- Kernel message catalog (bnc#864937, LTC#104501).
- Update config files.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 86e4253
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Remove dead code
- commit 3fc95f5
* Fri Mar  7 2014 oneukum@suse.de
- xhci: Prevent runtime pm from autosuspending during
  initialization (FATE#315518).
- commit 209c157
* Fri Mar  7 2014 jkosina@suse.cz
- supported.conf: mark vmware drivers as externally supported (FATE#315587)
- commit 9101c72
* Fri Mar  7 2014 tiwai@suse.de
- drm/radeon: enable speaker allocation setup on dce3.2
  (bnc#866937).
- drm/radeon: change audio enable logic (bnc#866937).
- drm/radeon: fix audio disable on dce6+ (bnc#866937).
- commit 8f7018c
* Thu Mar  6 2014 lduncan@suse.de
- qla4xxx: v5.04.00.00.12.0-k2 (FATE#315934 bnc#866849).
- qla4xxx: Initialize hardware queue for ISP40XX (FATE#315934
  bnc#866849).
- qla4xxx: Check for correct return status (FATE#315934
  bnc#866849).
- qla4xxx: qla4xxx: Move qla4_8xxx_ms_mem_write_128b to ql4_nx.c
  (FATE#315934 bnc#866849).
- qla4xxx: Added PEX DMA Support for ISP8022 Adapter (FATE#315934
  bnc#866849).
- qla4xxx: Added new opcodes for 84XX Minidump template
  (FATE#315934 bnc#866849).
- qla4xxx: Add support of 0xFF capture mask for minidump
  (FATE#315934 bnc#866849).
- qla4xxx: Change default capture to firmware defined capture mask
  (FATE#315934 bnc#866849).
- qla4xxx: Do not wait for IO completion, after issuing
  stop_firmware (FATE#315934 bnc#866849).
- commit 684fe5b
* Thu Mar  6 2014 jbohac@suse.cz
- Delete patches.fixes/ntp-avoid-printk-under-xtime_lock.patch.
  fixed by ca4523cda429712fc135c5db50920d90eb776a6c in v3.10
- commit a417182
* Thu Mar  6 2014 jeffm@suse.com
- config: NET_DROP_MONITOR=m (FATE#313768).
- commit 2b1ebba
* Thu Mar  6 2014 hare@suse.de
- Refresh
  patches.drivers/i40evf-0005-i40evf-driver-core-headers.patch: fixup build warnings
- commit c293e85
* Thu Mar  6 2014 jjolly@suse.de
- appldata_os: fix cpu array size calculation (bnc#865896,
  LTC#104859).
- commit 2576c7a
* Thu Mar  6 2014 jjolly@suse.de
- cio: Fix missing subchannels after CHPID configure on
  (bnc#865896, LTC#104808).
- commit 456062c
* Thu Mar  6 2014 jjolly@suse.de
- cio: Fix process hangs during subchannel scan (bnc#865896,
  LTC#104805).
- commit d658d0e
* Thu Mar  6 2014 jjolly@suse.de
- s390/pci/dma: use correct segment boundary size (bnc#865896,
  LTC#104566).
- commit 8173341
* Thu Mar  6 2014 jjolly@suse.de
- cio: fix unusable device (bnc#865896, LTC#104168).
- commit 138293c
* Thu Mar  6 2014 hare@suse.de
- Update patches.suse/no-partition-scan
- commit 0d0489e
* Thu Mar  6 2014 mmarek@suse.cz
- config.conf: Include kernel-trace-devel in kernel-syms
- commit 25b0ddf
* Thu Mar  6 2014 hare@suse.de
- Remove obsolete patches after review
- Delete
  patches.fixes/dm-mpath-do-not-detach-stale-hardware-handler.patch.
- Delete patches.fixes/dm-use-done-bytes-for-io-completion.patch.
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit 3602293
* Thu Mar  6 2014 hare@suse.de
- dm: Initialize flush_rq (bnc#866989).
- commit 28382c6
* Thu Mar  6 2014 jdelvare@suse.de
- Update x86_64 config files: CONFIG_THERMAL=y
  The generic thermal module is used by several ACPI components
  (processor, fan, thermal and video) and a few other drivers. So
  in practice it will end up being loaded on almost all systems
  which support ACPI. It is small so build it into the kernel to
  improve boot speed on x86_64.
- commit 2026dd3
* Thu Mar  6 2014 dchang@suse.com
- supported.conf: mark mlx5_core and mlx5_ib as supported (bnc#858723 FATE
  315949)
- commit d77f792
* Thu Mar  6 2014 neilb@suse.de
- Refresh patches.suse/md-abort-pending-requests.
- Refresh patches.suse/md-raid10-tracepoints.
  Protect against mddev->gendisk being NULL as happens when
  md-raid is used. (bnc#866843)
- commit 15a961f
* Wed Mar  5 2014 bp@suse.de
- Refresh patches.xen/xen3-patch-3.7.
- commit 6b35a46
* Wed Mar  5 2014 tiwai@suse.de
- ALSA: hda - Explicitly keep codec powered up in
  hdmi_present_sense (bnc#866937).
- ALSA: hda - Fix missing ELD info when using jackpoll_ms
  parameter (bnc#866937).
- ALSA: hda - hdmi: Fix wrong baseline length in ATI/AMD generated
  ELD (bnc#866937).
- ALSA: hda - hdmi: Skip out-of-range latency values in AMD ELD
  generator (bnc#866937).
- ALSA: hda - hdmi: Add error-checking to some codec reads
  (bnc#866937).
- ALSA: hda - hdmi: Use TFx channel positions instead of FxH
  (bnc#866937).
- ALSA: hda - Get rid of AMD HDMI exception in
  hdmi_present_sense() (bnc#866937).
- ALSA: hda - block HDMI jack reports while repolling
  (bnc#866937).
- ALSA: hda - Add a block_report flag to jacks (bnc#866937).
- ALSA: hda - Delay HDMI presence reports while waiting for ELD
  information (bnc#866937).
- ALSA: hda - hdmi: Re-setup pin and infoframe on plug-in on
  all codecs (bnc#866937).
- ALSA: hda - hdmi: Disable ramp-up/down for non-PCM on AMD codecs
  (bnc#866937).
- ALSA: hda - hdmi: Add HBR bitstreaming support for ATI/AMD
  HDMI codecs (bnc#866937).
- ALSA: hda - hdmi: Add ELD emulation for ATI/AMD codecs
  (bnc#866937).
- ALSA: hda - hdmi: Add ATI/AMD multi-channel audio support
  (bnc#866937).
- ALSA: hda - hdmi: Allow HDA patches to customize more operations
  (bnc#866937).
- ALSA: hda - Fix typos in patch_hdmi.c (bnc#866937).
- ALSA: hda - Move mutex from hda_eld to per_pin in HDMI codec
  driver (bnc#866937).
- ALSA: hda - Fix possible races in HDMI driver (bnc#866937).
- ALSA: hda - hdmi: Tweak debug messages to be more useful
  (bnc#866937).
- ALSA: hda - hdmi: Fix available channel maps missing from TLV
  (bnc#866937).
- ALSA: hda - hdmi: Fix channel maps with less common speakers
  (bnc#866937).
- ALSA: hda - hdmi: Fix unused slots being enabled in manual
  and non-PCM mappings (bnc#866937).
- ALSA: hda - hdmi: Fix programmed active channel count
  (bnc#866937).
- ALSA: hda - hdmi: Fix incorrect default channel mapping for
  unusual CAs (bnc#866937).
- commit 79ea578
* Wed Mar  5 2014 bp@suse.de
- x86, microcode, AMD: Unify valid container checks (fate#315602).
- x86, microcode: Move to a proper location (fate#315602).
- x86, microcode, AMD: Fix early ucode loading (fate#315602).
- x86, microcode: Share native MSR accessing variants
  (fate#315602).
- commit 616f9b3
* Wed Mar  5 2014 bp@suse.de
- x86, ramdisk: Export relocated ramdisk VA (fate#315602).
- Refresh patches.xen/xen3-patch-2.6.33.
- commit d94ebff
* Wed Mar  5 2014 hare@suse.de
- lpfc: remove self-assignments (FATE#315959).
- lpfc 8.3.45: Update lpfc version to driver version 8.3.45
  (FATE#315959).
- lpfc 8.3.45: Fixed crash during driver unload (FATE#315959).
- lpfc 8.3.45: Fixed driver error messages after firmware download
  (FATE#315959).
- lpfc 8.3.45: Fixed missing initialization for task management
  IOCBs (FATE#315959).
- lpfc 8.3.45: Fix sysfs buffer overrun in read of
  lpfc_fcp_cpu_map for 128 CPUs (FATE#315959).
- lpfc 8.3.45: Incorporate changes to use reason in
  change_queue_depth function (FATE#315959).
- lpfc 8.3.45: Incorporated support of a low-latency io path
  (FATE#315959).
- lpfc 8.3.45: Added dport mailbox pass through support
  (FATE#315959).
- lpfc 8.3.44: Update lpfc version to driver version 8.3.44
  (FATE#315959).
- lpfc 8.3.44: Fixed unassigned variable in ELS timeout message
  (FATE#315959).
- lpfc 8.3.44: Fixed incorrect allocation of iDiags
  directories/files in debugfs (FATE#315959).
- lpfc 8.3.44: Fix kernel panics from corrupted ndlp list
  (FATE#315959).
- lpfc 8.3.44: Fix Crash in lpfc_els_timeout_handler
  (FATE#315959).
- lpfc 8.3.44: Fixed stopped FCF discovery on failed FCF record
  read (FATE#315959).
- lpfc 8.3.44: Fixed IO hang when in msi mode (FATE#315959).
- commit 01ac37d
* Wed Mar  5 2014 duwe@suse.de
- powerpc/relocate fix relocate processing in LE mode (bnc#865994
  fate#315275, LTC#104787).
- powerpc/crashdump : fix page frame number check in
  copy_oldmem_page (bnc#865994 fate#315275, LTC#104787).
- powerpc/le: Ensure that the 'stop-self' RTAS token is handled
  correctly (bnc#865994 fate#315275, LTC#104787).
- powerpc/boot: fix do_div for 64bit wrapper (fate#315275,
  LTC#104787, bnc#865994).
- commit 9882976
* Wed Mar  5 2014 bp@suse.de
- Remove trailing whitespace
  Verified no other changes are erroneously introduced with git diff -w
- commit 9fe7052
* Wed Mar  5 2014 mmarek@suse.cz
- supported.conf: Move old wireless card drivers to -extra
  Also, match the unsupported drivers with a glob for simplicity.
- commit aaff476
* Wed Mar  5 2014 brogers@suse.com
- supported.conf: Add drivers/vfio/vfio_iommu_type1
    (fate#315169).
- commit 47a709c
* Tue Mar  4 2014 jkosina@suse.cz
- supported.conf: HID drivers cleanup
- commit 7c1fc62
* Tue Mar  4 2014 mmarek@suse.cz
- supported.conf: xt_ipvs is unsupported, like the rest of IPVS code
- commit 5e583e6
* Tue Mar  4 2014 jdelvare@suse.de
- Update config files: revert LEDS_CLASS to built-in
  The core leds module is small (14 kB on x86_64) and many drivers
  depend on it or even select it, in particular laptop-specific
  drivers and wireless network drivers. So the core leds module
  will end up being loaded on most laptop systems, where boot time
  matters. On top of that, different architectures have different
  dependencies, some of them requiring that the core leds module is
  built-in. So the easiest way forward is to just keep the core
  leds module built into the kernel on all architectures.
- commit 5f654cf
* Tue Mar  4 2014 mmarek@suse.cz
- supported.conf: Match unsupported drivers/media stuff with a glob
- commit a20e294
* Tue Mar  4 2014 jack@suse.cz
- ext4: Speedup WB_SYNC_ALL pass (bnc#833820).
- commit 3dcf756
* Tue Mar  4 2014 jack@suse.cz
- Delete
  patches.fixes/writeback-do-not-sync-data-dirtied-after-sync-start.patch.
  The patch has been reverted upstream (commit 0dc83bd30b0b). We need to
  fix the problem differently.
- commit af2a365
* Tue Mar  4 2014 jdelvare@suse.de
- Update ppc64le config files: disable STE_MODEM_RPROC
  Disable config option STE_MODEM_RPROC on all ppc64le flavors, because
  it draws dependencies which aren't available on ppc64le:
  warning: (REMOTEPROC && RPMSG) selects VIRTUALIZATION which has unmet direct dependencies (!CPU_LITTLE_ENDIAN)
- commit d53d7ef
* Mon Mar  3 2014 mgorman@suse.de
- mm: numa: bugfix for LAST_CPUPID_NOT_IN_PAGE_FLAGS
  (Automatic NUMA Balancing (fate#315482)).
- commit cd93f1c
* Mon Mar  3 2014 mmarek@suse.cz
- Enable CONFIG_SYSCTL_SYSCALL (bnc#864365)
- commit e413df9
* Mon Mar  3 2014 jlee@suse.com
- X.509: Fix certificate gathering (bnc#805114).
- commit 1dd07d3
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/mkspec: Fix whitespace in NoSource lines
- commit 6320617
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not zero modules.dep before using it
  (bnc#866075)
- commit b67b660
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Drop useless ExclusiveArch statement
- commit 5cdf1da
* Fri Feb 28 2014 mkubecek@suse.cz
- ipvs: fix AF assignment in ip_vs_conn_new() (bnc#856848).
- commit cbec914
* Fri Feb 28 2014 duwe@suse.de
- hwrng: provide in-kernel interface for drivers (fate#316346).
- commit 6f5abe0
* Fri Feb 28 2014 tiwai@suse.de
- ALSA: hda/sigmatel - Allow auto-switching for dock line-in of
  HP laptops (bnc#866100).
- commit d814581
* Fri Feb 28 2014 duwe@suse.de
- hwrng: feed randomness from pure hardware generator into kernel
  pool (fate#316346).
- provide hardware randomness from HWRNG to /dev/random
  (fate#316346).
- commit b2dc3d2
* Fri Feb 28 2014 hare@suse.de
- scsi_dh_alua: fixup RTPG retry delay miscalculation
  (bnc#854025).
- scsi_dh_alua: Simplify state machine (bnc#854025).
- scsi_dh_alua: endless STPG retries for a failed LUN
  (bnc#865342).
- commit 84d6c44
* Fri Feb 28 2014 mgorman@suse.de
- mm: page_alloc: exempt GFP_THISNODE allocations from zone fairness
- commit c6aea13
* Fri Feb 28 2014 jdelvare@suse.de
- supported.conf: Add recently modularized drivers
  Add dns_resolver, inet_lro and cls_cgroup as supported. They used to be built
  into the kernel and we supported them there.
- commit 85b43ca
* Fri Feb 28 2014 oneukum@suse.de
- xhci: Fix resume issues on Renesas chips in Samsung laptops
  (bnc#866247).
- commit 91298c6
* Fri Feb 28 2014 jdelvare@suse.de
- Update x86_64 config files: CONFIG_X86_MSR=m
  The msr driver creates /dev/cpu/*/msr through which you can poke
  at all the MSRs if you have CAP_SYS_RAWIO. We prefer to be able
  to remove that module if it is not needed.
- commit e0163b7
* Fri Feb 28 2014 brogers@suse.com
- supported.conf: Add drivers/vfio/vfio and drivers/vfio/pci/vfio-pci
  (fate#315169).
- commit 1451b61
* Thu Feb 27 2014 jdelvare@suse.de
- Update ppc64le config files.
  Oops, ppc64le still needs LEDS_CLASS built-in for the moment. I think
  we can modularize it later after the configs have been cleaned up to
  drop support for old hardware, but I was too quick.
- commit e3a3704
* Thu Feb 27 2014 jdelvare@suse.de
- Update config files: modularize BLK_DEV_MD, disable MD_AUTODETECT
  Michal Marek says:
  I think that the reason why BLK_DEV_MD is built in is
  config MD_AUTODETECT
    bool "Autodetect RAID arrays during kernel boot"
    depends on BLK_DEV_MD=y
  but since we compile the raid presonalities as modules, this cannot
  work. Also, we use the initrd even in the trivial cases, so why bother
  about root-on-md.
  Neil Brown adds:
  I certainly don't want customers using MD_AUTODETECT so I am quite
  happy for md to become a module and MD_AUTODETECT to be disabled.
  And Lars Marowsky-Bree adds:
  It seems conceivable that the cluster RAID code might possibly be a
  KMP which overrides basic md for a while. So making it a module is a
  good idea.
- commit bdef217
* Thu Feb 27 2014 jdelvare@suse.de
- Update config files: CONFIG_ISO9660_FS=m
  There is no good reason why isofs would be built into the kernel.
  Most systems don't need it after installation, and reportedly
  mkinitrd etc. can deal with it as a module just fine.
- commit 4996668
* Thu Feb 27 2014 jdelvare@suse.de
- Update config files.
  Modularize the following helper drivers:
  LEDS_CLASS, INET_LRO, NET_CLS_CGROUP, DNS_RESOLVER
  They had to be built-in before due to dependencies, but this is no
  longer the case, so we can modularize them again.
- commit fa32a66
* Thu Feb 27 2014 jack@suse.cz
- bdi: Avoid oops on device removal (bnc#862389).
- bdi: Fix hung task on sync (bnc#862389).
- commit 4e6a606
* Thu Feb 27 2014 jslaby@suse.cz
- Refresh
  patches.suse/mm-reintroduce-global_reclaimable_page.patch.
- commit ada8551
* Thu Feb 27 2014 jdelvare@suse.de
- Update config files: CONFIG_CRC16=m
  No built-in driver selects CRC16 any longer, so we can modularize it
  again.
- commit e3c858d
* Thu Feb 27 2014 jack@suse.cz
- llists: move llist_reverse_order from raid5 to llist.c
  (fate#315209).
- commit a3d93c6
* Thu Feb 27 2014 jack@suse.cz
- blk-mq: pair blk_mq_start_request / blk_mq_requeue_request
  (fate#315209).
- blk-mq: dont assume rq->errors is set when returning an error
  from ->queue_rq (fate#315209).
- block: Fix type mismatch in ssize_t_blk_mq_tag_sysfs_show
  (fate#315209).
- blk-mq: rework flush sequencing logic (fate#315209).
- null_blk: use blk_complete_request and blk_mq_complete_request
  (fate#315209).
- blk-mq: rework I/O completions (fate#315209).
- block/null_blk: Fix completion processing from LIFO to FIFO
  (fate#315209).
- blk-mq: Add bio_integrity setup to blk_mq_make_request
  (fate#315209).
- blk-mq: initialize sg_reserved_size (fate#315209).
- blk-mq: handle dma_drain_size (fate#315209).
- blk-mq: support at_head inserations for blk_execute_rq
  (fate#315209).
- blk-mq: Don't reserve a tag for flush request (fate#315209).
- block/blk-mq-cpu.c: use hotcpu_notifier() (fate#315209).
- null_blk: Null pointer deference problem in alloc_page_buffers
  (fate#315209).
- block: null_blk: fix queue leak inside removing device
  (fate#315209).
- blk-mq: uses page->list incorrectly (fate#315209).
- blk-mq: use __smp_call_function_single directly (fate#315209).
- blk-mq: fix initializing request's start time (fate#315209).
- block: blk-mq: don't export blk_mq_free_queue() (fate#315209).
- block: blk-mq: make blk_sync_queue support mq (fate#315209).
- block: blk-mq: support draining mq queue (fate#315209).
- commit fdadf4f
* Thu Feb 27 2014 jbeulich@suse.com
- Update Xen patches to 3.12.12.
- x86/mm/pageattr: Lookup address in an arbitrary PGD
  (fate#315019).
- x86/mm/pageattr: Add a PGD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PUD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PMD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PTE pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PUD error unwinding path (fate#315019).
- x86/mm/pageattr: Add last levels of error path (fate#315019).
- x86/mm/cpa: Map in an arbitrary pgd (fate#315019).
- x86/efi: Runtime services virtual mapping (fate#315019).
- efi: Export EFI runtime memory mapping to sysfs (fate#315019).
- x86/efi: Pass necessary EFI data for kexec via setup_data
  (fate#315019).
- x86: Export x86 boot_params to sysfs (fate#315019).
- x86: Reserve setup_data ranges late after parsing memmap cmdline
  (fate#315019).
- commit fa3d808
* Thu Feb 27 2014 ohering@suse.de
- hyperv: Add latest NetVSP versions to auto negotiation.
- commit 33eb05c
* Thu Feb 27 2014 ohering@suse.de
- hyperv-fb: kick off efifb early.
- commit 27826f7
* Thu Feb 27 2014 ohering@suse.de
- hyperv-fb: add support for generation 2 virtual machines.
- commit 599f3cf
* Thu Feb 27 2014 ohering@suse.de
- vmbus: use resource for hyperv mmio region.
- commit ff314d3
* Thu Feb 27 2014 ohering@suse.de
- vmbus: add missing breaks.
- commit 5bb2fd4
* Thu Feb 27 2014 ohering@suse.de
- Drivers: net: hyperv: Cleanup the netvsc receive callback
  functio.
- commit f663be4
* Thu Feb 27 2014 duwe@suse.de
- drm/radeon: remove generic rptr/wptr functions (v2)
  (bnc#865919).
- of: fix PCI bus match for PCIe slots (bnc#865919).
- commit 6c01a7a
* Thu Feb 27 2014 jbohac@suse.cz
- bonding: disallow enslaving a bond to itself (bnc#599263).
- commit d77e06e
* Thu Feb 27 2014 oneukum@suse.de
- USB: hub: handle -ETIMEDOUT during enumeration (bnc#866012).
- commit 2f78818
* Thu Feb 27 2014 acho@suse.com
- Refresh patches.xen/xen3-patch-2.6.25.
  Refresh for tg3-0016-PCI-tg3-Give-up-chip-reset-and-carrier-loss-handling.patch
- commit 8f833ec
* Thu Feb 27 2014 acho@suse.com
- tg3: Fix deadlock in tg3_change_mtu() (bnc#852650 FATE#315916).
- tg3: cleanup an error path in tg3_phy_reset_5703_4_5()
  (bnc#852650 FATE#315916).
- tg3: Update version to 3.136 (bnc#852650 FATE#315916).
- tg3: Poll cpmu link state on APE + ASF enabled devices
  (bnc#852650 FATE#315916).
- tg3: Set the MAC clock to the fastest speed during boot code
  load (bnc#852650 FATE#315916).
- tg3: Add unicast filtering support (bnc#852650 FATE#315916).
- tg3: Refactor __tg3_set_mac_addr() (bnc#852650 FATE#315916).
- tg3: Update version to 3.135 (bnc#852650 FATE#315916).
- tg3: Expand multicast drop counter miscounting fix to 5762
  (bnc#852650 FATE#315916).
- tg3: Fix bit definition for the nvram Auto Power Down setting
  (bnc#852650 FATE#315916).
- tg3: Add flag to disable 1G Half Duplex advertisement
  (bnc#852650 FATE#315916).
- tg3: Don't add rxbds_empty to rx_over_errors (bnc#852650
  FATE#315916).
- PCI / tg3: Give up chip reset and carrier loss handling if
  PCI device is not present (bnc#852650 FATE#315916).
- tg3: Convert to use hwmon_device_register_with_groups
  (bnc#852650 FATE#315916).
- tg3: Implement the SIOCGHWTSTAMP ioctl (bnc#852650 FATE#315916).
- tg3: Validate hwtstamp_config completely before applying it
  (bnc#852650 FATE#315916).
- net: tg3: remove unnecessary pci_set_drvdata() (bnc#852650
  FATE#315916).
- tg3: use phylib when robo switch is in use (bnc#852650
  FATE#315916).
- ssb: provide phy address for Gigabit Ethernet driver (bnc#852650
  FATE#315916).
- tg3: add support a phy at an address different than 01
  (bnc#852650 FATE#315916).
- tg3: Update version to 3.134 (bnc#852650 FATE#315916).
- tg3: Remove unnecessary spinlock (bnc#852650 FATE#315916).
- tg3: Appropriately classify interrupts during request_irq
  (bnc#852650 FATE#315916).
- tg3: Remove redundant if check (bnc#852650 FATE#315916).
- tg3: Remove if 0'd code (bnc#852650 FATE#315916).
- tg3: LED in shared mode does not blink during traffic
  (bnc#852650 FATE#315916).
- tg3: Add support for new 577xx device ids (bnc#852650
  FATE#315916).
- tg3: Add function tg3_phy_shdw_write() (bnc#852650 FATE#315916).
- commit 1b66abe
* Thu Feb 27 2014 jslaby@suse.cz
- Refresh
  patches.fixes/cifs-ensure-that-uncached-writes-handle-unmapped-are.patch.
  (update patch-mainline)
- commit 712e905
* Thu Feb 27 2014 dchang@suse.com
- cxgb4: make functions static and remove dead code (bnc#863630
  FATE#315956).
- cxgb4vf: added much cleaner implementation of is_t4()
  (bnc#863630 FATE#315956).
- net: cxgb4vf: use DEFINE_PCI_DEVICE_TABLE (bnc#863630
  FATE#315956).
- net: cxgb4vf: remove unnecessary pci_set_drvdata() (bnc#863630
  FATE#315956).
- net: cxgb4vf: Staticize local symbols (bnc#863630 FATE#315956).
- commit ae08254
* Thu Feb 27 2014 dchang@suse.com
- net/cxgb4: use remove handler as shutdown handler (bnc#863619
  FATE#315951).
- net/cxgb4: Fix referencing freed adapter (bnc#863619
  FATE#315951).
- net/cxgb4: Don't retrieve stats during recovery (bnc#863619
  FATE#315951).
- net/cxgb4: Avoid disabling PCI device for towice (bnc#863619
  FATE#315951).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bnc#863619 FATE#315951).
- cxgb4: silence shift wrapping static checker warning (bnc#863619
  FATE#315951).
- cxgb4: Changed FW check version to match FW binary version
  (bnc#863619 FATE#315951).
- cxgb4: allow large buffer size to have page size (bnc#863619
  FATE#315951).
- cxgb4: make functions static and remove dead code (bnc#863619
  FATE#315951).
- cxgb4: Add API to correctly calculate tuple fields (bnc#863619
  FATE#315951).
- cxgb4: Account for stid entries properly in case of IPv6
  (bnc#863619 FATE#315951).
- cxgb4: Assign filter server TIDs properly (bnc#863619
  FATE#315951).
- cxgb4: Include TCP as protocol when creating server filters
  (bnc#863619 FATE#315951).
- cxgb4: Reserve stid 0 for T4/T5 adapters (bnc#863619
  FATE#315951).
- net: cxgb4 calls skb_set_hash (bnc#863619 FATE#315951).
- cxgb4: Add new scheme to update T4/T5 firmware (bnc#863619
  FATE#315951).
- cxgb4vf: added much cleaner implementation of is_t4()
  (bnc#863619 FATE#315951).
- cxgb4: Much cleaner implementation of is_t4()/is_t5()
  (bnc#863619 FATE#315951).
- cgxb4: remove duplicate include in cxgb4.h (bnc#863619
  FATE#315951).
- net: cxgb4: remove unnecessary pci_set_drvdata() (bnc#863619
  FATE#315951).
- commit 73da878
* Wed Feb 26 2014 duwe@suse.de
- GenWQE PCI support, health monitoring and recovery (bnc#865576,
  fate#316890).
- GenWQE Character device and DDCB queue (bnc#865576,
  fate#316890).
- GenWQE Utility functions (bnc#865576, fate#316890).
- GenWQE Debugfs interfaces (bnc#865576, fate#316890).
- GenWQE Sysfs interfaces (bnc#865576, fate#316890).
- GenWQE Enable driver (bnc#865576, fate#316890).
- GenWQE: Fix endian issues detected by sparse (bnc#865576,
  fate#316890).
- GenWQE: Replace dynamic_hex_dump with print_hex_dump_debug
  (bnc#865576, fate#316890).
- GenWQE: Accidently casting to u32 where u64 is required
  (bnc#865576, fate#316890).
- GenWQE: Rework return code for flash-update ioctl (bnc#865576,
  fate#316890).
- GenWQE: Fix compile problems for Alpha (bnc#865576,
  fate#316890).
- GenWQE: Fix warnings for sparc (bnc#865576, fate#316890).
- misc: genwqe: fix return value check in genwqe_device_create()
  (bnc#865576, fate#316890).
- Update config files.
- commit 7bdbb77
* Wed Feb 26 2014 jack@suse.cz
- Fixed up compilation breakage in
  patches.fixes/ocfs2-Avoid-blocking-in-ocfs2_mark_lockres_freeing-i.patch.
- commit 014d16f
* Wed Feb 26 2014 acho@suse.com
- bnx2: Update version to 2.2.5 (bnc#853231 FATE#315917).
- bnx2: Report MDI/MDIX status to ethtool (bnc#853231
  FATE#315917).
- bnx2: Enable auto-mdix when autoneg is disabled (bnc#853231
  FATE#315917).
- bnx2: Advertise nothing when speed is forced (bnc#853231
  FATE#315917).
- net: bnx2 calls skb_set_hash (bnc#853231 FATE#315917).
- net: bnx2: remove unnecessary pci_set_drvdata() (bnc#853231
  FATE#315917).
- commit 4d50dd4
* Wed Feb 26 2014 hare@suse.de
- fnic: Changing the IO Throttle count from 2048 to 256
  (bnc#863365,FATE#315811).
- fnic: Remove Driver Timeout debug messages
  (bnc#863365,FATE#315811).
- fnic: Failing to queue aborts due to Q full cause terminate
  driver timeout (bnc#863365,FATE#315811).
- fnic: Fnic Ctlr Path Trace Utility (bnc#863365,FATE#315811).
- fnic: HDS: VMware host not recovering path after switch reboot
  (san boot) (bnc#863365,FATE#315811).
- fnic: Incremented driver version (bnc#863365,FATE#315811).
- fnic: Incremented driver version (bnc#863365,FATE#315811).
- fnic: Sending single FIP solicitation frame in non-FIP mode
  (bnc#863365,FATE#315811).
- Delete patches.drivers/fnic-Incremented-driver-version.patch.
- commit 4c7c761
* Wed Feb 26 2014 acho@suse.com
- bnx2x: Allow VF rss on higher PFs (bnc#853494 FATE#315918).
- bnx2[x]: Make module parameters readable (bnc#853494
  FATE#315918).
- bnx2x: fix L2-GRE TCP issues (bnc#853494 FATE#315918).
- bnx2x: Fix generic option settings (bnc#853494 FATE#315918).
- bnx2x: More Shutdown revisions (bnc#853494 FATE#315918).
- bnx2x: Fix VF flr flow (bnc#853494 FATE#315918).
- bnx2x: Don't release PCI bars on shutdown (bnc#853494
  FATE#315918).
- bnx2x: fix sparse warning (bnc#853494 FATE#315918).
- bnx2x: Correct default Tx switching behaviour (bnc#853494
  FATE#315918).
- bnx2x: namespace and dead code cleanups (bnc#853494
  FATE#315918).
- bnx2x: prevent WARN during driver unload (bnc#853494
  FATE#315918).
- bnx2x: fix VLAN configuration for VFs (bnc#853494 FATE#315918).
- bnx2x: fix AFEX memory overflow (bnc#853494 FATE#315918).
- bnx2x: Clean before update RSS arrives (bnc#853494 FATE#315918).
- bnx2x: Correct number of MSI-X vectors for VFs (bnc#853494
  FATE#315918).
- bnx2x: limit number of interrupt vectors for 57711 (bnc#853494
  FATE#315918).
- bnx2x: Fix KR2 work-around detection of BCM8073 (bnc#853494
  FATE#315918).
- bnx2x: Fix incorrect link-up report (bnc#853494 FATE#315918).
- bnx2x: Fix Duplex setting for 54618se (bnc#853494 FATE#315918).
- bnx2x: Fix passive DAC cable detection (bnc#853494 FATE#315918).
- bnx2x: Fix 578xx-KR 1G link (bnc#853494 FATE#315918).
- net: bnx2x: slight optimization of addr compare (bnc#853494
  FATE#315918).
- etherdevice: Add ether_addr_equal_unaligned (bnc#853494
  FATE#315918).
- bnx2x: Fix build with SRIOV disabled (bnc#853494 FATE#315918).
- bnx2x: add VF Multicast filters support (bnc#853494
  FATE#315918).
- bnx2x: Add num of VFs to Management statistics (bnc#853494
  FATE#315918).
- bnx2x: no error when RSS configuration fails (bnc#853494
  FATE#315918).
- bnx2x: add Big-Endian ethtool comment (bnc#853494 FATE#315918).
- bnx2x: Add AER support (missing bits) (bnc#853494 FATE#315918).
- bnx2x: Add support for Multi-Function UNDI (bnc#853494
  FATE#315918).
- bnx2x: cleanup skb_set_hash (bnc#853494 FATE#315918).
- bnx2x: downgrade "valid ME register value" message level
  (bnc#853494 FATE#315918).
- net: bnx2x calls skb_set_hash (bnc#853494 FATE#315918).
- bnx2x: avoid null pointer dereference when enabling SR-IOV
  (bnc#853494 FATE#315918).
- bnx2x: Prevent "timeout waiting for state X" (bnc#853494
  FATE#315918).
- bnx2x: prevent CFC attention (bnc#853494 FATE#315918).
- bnx2x: Prevent panic during DMAE timeout (bnc#853494
  FATE#315918).
- bnx2x: Clean the sp rtnl task upon unload (bnc#853494
  FATE#315918).
- list: introduce list_next_entry() and list_prev_entry()
  (bnc#853494 FATE#315918).
- bnx2x: Disable VF access on PF removal (bnc#853494 FATE#315918).
- bnx2x: prevent FW assert on low mem during unload (bnc#853494
  FATE#315918).
- bnx2x: add TSO support for SIT tunnels (bnc#853494 FATE#315918).
- ipv6: sit: add GSO/TSO support (bnc#853494 FATE#315918).
- ipv6: gso: make ipv6_gso_segment() stackable (bnc#853494
  FATE#315918).
- bnx2x: add TSO support for IPIP (bnc#853494 FATE#315918).
- ipip: add GSO/TSO support (bnc#853494 FATE#315918).
- ipv4: gso: make inet_gso_segment() stackable (bnc#853494
  FATE#315918).
- ipv4: gso: send_check() & segment() cleanups (bnc#853494
  FATE#315918).
- ipv4: generalize gre_handle_offloads (bnc#853494 FATE#315918).
- net: generalize skb_segment() (bnc#853494 FATE#315918).
- net: bnx2x: remove unnecessary pci_set_drvdata() (bnc#853494
  FATE#315918).
- bnx2x: Add ndo_get_phys_port_id support (bnc#853494
  FATE#315918).
- net: bnx2x: Change variable type to bool (bnc#853494
  FATE#315918).
- net: skb_is_gso_v6() requires skb_is_gso() (bnc#853494
  FATE#315918).
- bnx2x: use pcie_get_minimum_link() (bnc#853494 FATE#315918).
- bnx2x: Add support for EXTPHY2 LED mode (bnc#853494
  FATE#315918).
- bnx2x: Change function prototype (bnc#853494 FATE#315918).
- bnx2x: Don't disable/enable SR-IOV when loading (bnc#853494
  FATE#315918).
- bnx2x: Correct VF driver info (bnc#853494 FATE#315918).
- bnx2x: Test nvram when interface is down (bnc#853494
  FATE#315918).
- DMA-API: net: broadcom/bnx2x: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#853494 FATE#315918).
- net: bnx2x: Staticize local symbols (bnc#853494 FATE#315918).
- commit a109cbb
* Wed Feb 26 2014 acho@suse.com
- cnic: Add a signature to indicate valid doorbell offset
  (bnc#859297 FATE#315915).
- broadcom: Remove extern from function prototypes (bnc#859297
  FATE#315915).
- commit c543172
* Wed Feb 26 2014 hare@suse.de
- Update config files:
- Modularize SCSI, sd, and ahci
- Drop aic7xxx_old driver (removed upstream)
- Drop advansys driver (deprecated for ages)
- commit 6dd0409
* Wed Feb 26 2014 dchang@suse.com
- Update config files: Set i40evf as a module, disable i40evf in s390x
  supported.conf: Mark i40evf as supported
- commit 511b2f0
* Tue Feb 25 2014 jack@suse.cz
- quota: Fix race between dqput() and dquot_scan_active().
- ocfs2: Revert iput deferring code in ocfs2_drop_dentry_lock
  (fate#315054).
- ocfs2: Avoid blocking in ocfs2_mark_lockres_freeing() in
  downconvert thread (fate#315054).
- ocfs2: Implement delayed dropping of last dquot reference
  (fate#315054).
- quota: Provide function to grab quota structure reference
  (fate#315054).
- ocfs2: Move dquot_initialize() in ocfs2_delete_inode() somewhat
  later (fate#315054).
- ocfs2: Remove OCFS2_INODE_SKIP_DELETE flag (fate#315054).
- ocfs2: Fix quota file corruption.
- commit 30f4c87
* Tue Feb 25 2014 hare@suse.de
- fnic: Incremented driver version (bnc#863365,FATE#315811).
- fnic: Fnic Statistics Collection (bnc#863365,FATE#315811).
- fnic: host reset returns nonzero value(errno) on success
  (bnc#863365,FATE#315811).
- libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception
  (bnc#863365,FATE#315811).
- fcoe: Reduce fcoe_sysfs_fcf_add() stack usage
  (bnc#863365,FATE#315811).
- commit 6262d19
* Tue Feb 25 2014 mgorman@suse.de
- mm: exclude memory less nodes from zone_reclaim (bnc#863526).
- commit d960c13
* Tue Feb 25 2014 dsterba@suse.cz
- Delete patches.suse/btrfs-0006-fix-error-check-of-btrfs_lookup_dentry.patch.
- commit 0c7471c
* Tue Feb 25 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-update-message-levels.patch.
- commit 5a068a4
* Tue Feb 25 2014 jslaby@suse.cz
- Linux 3.12.13 (bnc#859342 bnc#860346 bnc#865919 LTC#103575
  fate#315482 FATE#315595).
- Refresh
  patches.drivers/0016-iwlwifi-mvm-add-no_basic_ssid-option.
- Delete
  patches.arch/s390-sles12-01-05-dump-fix-zvm-memory-detect.patch.
- Delete patches.arch/s390-sles12-01-09-linkage-stack.patch.
- Delete
  patches.drivers/0001-xhci-1.0-Limit-arbitrarily-aligned-scatter-gather.patch.
- Delete
  patches.drivers/0002-Revert-xhci-Set-scatter-gather-limit-to-avoid-failed.patch.
- Delete
  patches.drivers/0003-Revert-xhci-Avoid-infinite-loop-when-sg-urb-requires.patch.
- Delete
  patches.drivers/0004-Revert-usb-xhci-Link-TRB-must-not-occur-within-a-USB.patch.
- Delete patches.drivers/OF-fix-PCI-bus-match-for-PCIe-slots.
- Delete patches.fixes/nfs-lockd.fix.
- Delete patches.suse/mm-fix-page-leak-nfs_symlink.patch.
- Delete
  patches.suse/msft-hv-0579-Drivers-hv-vmbus-Don-t-timeout-during-the-initial-co.patch.
- Delete
  patches.suse/xen-properly-account-for-_PAGE_NUMA-during-xen-pte-translations.patch.
- commit 86c378c
* Mon Feb 24 2014 tiwai@suse.de
- Obsolete compat-wireless, rts5229 and rts_pstor KMPs
  These are found in SLE11-SP3, now replaced with the upstream drivers.
- commit 37738dd
* Mon Feb 24 2014 jdelvare@suse.de
- supported.conf: Remove i386-only edac drivers
  We don't build them, we don't ship them, we can't support them.
- commit a755d28
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not obsolete ocfs2-kmp (bnc#865259)865259
- commit c8661b5
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete the -base package from SLE11 (bnc#865096)
- commit 3f926c3
* Mon Feb 24 2014 dchang@suse.com
- i40e: Fix device ID define names to align to standard
  (bnc#857953 FATE#316843).
- i40evf: fix s390 build failure due to implicit prefetch.h
  (bnc#857953 FATE#316843).
- i40evf: A0 silicon specific (bnc#857953 FATE#316843).
- commit 9538033
* Mon Feb 24 2014 dchang@suse.com
- i40evf: add driver to kernel build system (bnc#857953
  FATE#316843).
  Update config files: Enable CONFIG_I40EVF
- i40evf: init code and hardware support (bnc#857953 FATE#316843).
- i40evf: driver core headers (bnc#857953 FATE#316843).
- i40evf: virtual channel interface (bnc#857953 FATE#316843).
- i40evf: core ethtool functionality (bnc#857953 FATE#316843).
- i40evf: transmit and receive functionality (bnc#857953
  FATE#316843).
- i40evf: main driver core (bnc#857953 FATE#316843).
- commit 4dbe700
* Mon Feb 24 2014 dchang@suse.com
- i40e: Add missing braces to i40e_dcb_need_reconfig() (bnc#857397
  FATE#315659).
- i40e: Fix device ID define names to align to standard
  (bnc#857397 FATE#315659).
- commit d9be109
* Mon Feb 24 2014 dchang@suse.com
- i40e: add DCB option to Kconfig (bnc#857397 FATE#315659).
  Update config files: Enable CONFIG_I40E_DCB
- i40e: add DCB and DCBNL support (bnc#857397 FATE#315659).
- i40e: implement DCB support infastructure (bnc#857397
  FATE#315659).
- i40e: refactor flow director (bnc#857397 FATE#315659).
- i40e: rename defines (bnc#857397 FATE#315659).
- i40e: whitespace fixes (bnc#857397 FATE#315659).
- i40e: Change firmware workaround (bnc#857397 FATE#315659).
- i40e: fix compile warning on checksum_local (bnc#857397
  FATE#315659).
- i40e: updates to AdminQ interface (bnc#857397 FATE#315659).
- i40e: check desc pointer before printing (bnc#857397
  FATE#315659).
- drivers/net: delete non-required instances of include
  <linux/init.h> (bnc#857397 FATE#315659).
- i40e: Retain MAC filters on port VLAN deletion (bnc#857397
  FATE#315659).
- i40e: Warn admin to reload VF driver on port VLAN configuration
  (bnc#857397 FATE#315659).
- i40e: Bump version number (bnc#857397 FATE#315659).
- i40e: trivial cleanup (bnc#857397 FATE#315659).
- i40e: whitespace fixes (bnc#857397 FATE#315659).
- i40e: make message meaningful (bnc#857397 FATE#315659).
- i40e: associate VMDq queue with VM type (bnc#857397
  FATE#315659).
- i40e: remove extra register write (bnc#857397 FATE#315659).
- i40e: fix log message wording (bnc#857397 FATE#315659).
- i40e: enable PTP (bnc#857397 FATE#315659).
- i40e: call clear_pxe after adminq is initialized (bnc#857397
  FATE#315659).
- i40e: clear qtx_head before enabling Tx queue (bnc#857397
  FATE#315659).
- i40e: adjust ITR max and min values (bnc#857397 FATE#315659).
- i40e: check for possible incorrect ipv6 checksum (bnc#857397
  FATE#315659).
- i40e: allow VF to remove any MAC filter (bnc#857397
  FATE#315659).
- i40e: do not bail when disabling if Tx queue disable fails
  (bnc#857397 FATE#315659).
- i40e: Setting queue count to 1 using ethtool is valid
  (bnc#857397 FATE#315659).
- i40e: Cleanup Doxygen warnings (bnc#857397 FATE#315659).
- i40e: fix long lines (bnc#857397 FATE#315659).
- i40e: Update the Current NVM version Low value (bnc#857397
  FATE#315659).
- i40e: drop unused macros (bnc#857397 FATE#315659).
- i40e: use assignment instead of memcpy (bnc#857397 FATE#315659).
- i40e: Turn flow director off in MFP mode (bnc#857397
  FATE#315659).
- i40e: Add a dummy packet template (bnc#857397 FATE#315659).
- i40e: trivial: formatting and checkpatch fixes (bnc#857397
  FATE#315659).
- i40e: shorten wordy fields (bnc#857397 FATE#315659).
- i40e: accept pf to pf adminq messages (bnc#857397 FATE#315659).
- i40e: remove interrupt on AQ error (bnc#857397 FATE#315659).
- i40e: release NVM resource reservation on startup (bnc#857397
  FATE#315659).
- i40e: Cleanup reconfig rss path (bnc#857397 FATE#315659).
- i40e: disable packet split (bnc#857397 FATE#315659).
- i40e: add a comment on barrier and fix panic on reset
  (bnc#857397 FATE#315659).
- i40e: Fix MAC format in Write MAC address AQ cmd (bnc#857397
  FATE#315659).
- i40e: Fix GPL header (bnc#857397 FATE#315659).
- i40e: use kernel specific defines (bnc#857397 FATE#315659).
- i40e: Re-enable interrupt on ICR0 (bnc#857397 FATE#315659).
- i40e: correctly setup ARQ descriptors (bnc#857397 FATE#315659).
- i40e: remove redundant AQ enable (bnc#857397 FATE#315659).
- i40e: Enable/Disable PF switch LB on SR-IOV configure changes
  (bnc#857397 FATE#315659).
- i40e: whitespace paren and comment tweaks (bnc#857397
  FATE#315659).
- i40e: rework shadow ram read functions (bnc#857397 FATE#315659).
- i40e: check MAC type before any REG access (bnc#857397
  FATE#315659).
- i40e: move PF ID init from PF reset to SC init (bnc#857397
  FATE#315659).
- i40e: Reduce range of interrupt reg in reg test (bnc#857397
  FATE#315659).
- i40e: update firmware api to 1.1 (bnc#857397 FATE#315659).
- i40e: Add code to wait for FW to complete in reset path
  (bnc#857397 FATE#315659).
- i40e: Allow VF to set already assigned MAC address (bnc#857397
  FATE#315659).
- i40e: Stop accepting any VLAN tag on VLAN 0 filter set
  (bnc#857397 FATE#315659).
- i40e: Do not enable broadcast promiscuous by default (bnc#857397
  FATE#315659).
- i40e: Expose AQ debugfs hooks (bnc#857397 FATE#315659).
- i40e: Do not allow AQ calls from ndo-ops (bnc#857397
  FATE#315659).
- i40e: check asq alive before notify (bnc#857397 FATE#315659).
- i40e: Admin queue shutdown fixes (bnc#857397 FATE#315659).
- i40e: Hide the Port VLAN VLAN ID (bnc#857397 FATE#315659).
- i40e: use correct struct for get and update vsi params
  (bnc#857397 FATE#315659).
- i40e: Fix VF driver MAC address configuration (bnc#857397
  FATE#315659).
- i40e: support VFs on PFs other than 0 (bnc#857397 FATE#315659).
- i40e: acknowledge VFLR when disabling SR-IOV (bnc#857397
  FATE#315659).
- i40e: don't allocate zero size (bnc#857397 FATE#315659).
- i40e: use struct assign instead of memcpy (bnc#857397
  FATE#315659).
- i40e: Do not enable default port on the VEB (bnc#857397
  FATE#315659).
- i40e: avoid unnecessary register read (bnc#857397 FATE#315659).
- i40e: Fix SR-IOV VF port VLAN (bnc#857397 FATE#315659).
- i40e: Record dma buffer info for dummy packets (bnc#857397
  FATE#315659).
- i40e: remove un-necessary io-write (bnc#857397 FATE#315659).
- i40e: Remove unnecessary prototypes (bnc#857397 FATE#315659).
- i40e: I40E_FLAG_MQ_ENABLED is not used (bnc#857397 FATE#315659).
- i40e: Fix ring allocation (bnc#857397 FATE#315659).
- i40e: catch unset q_vector (bnc#857397 FATE#315659).
- i40e: keep allocated memory in structs (bnc#857397 FATE#315659).
- i40e: fix error handling when alloc of vsi array fails
  (bnc#857397 FATE#315659).
- i40e: reinit buffer size each time (bnc#857397 FATE#315659).
- i40e: use functions to enable and disable icr 0 (bnc#857397
  FATE#315659).
- i40e: add header file flag _I40E_TXRX_H_ (bnc#857397
  FATE#315659).
- i40e: guard against vf message races (bnc#857397 FATE#315659).
- i40e: fix constant cast issues (bnc#857397 FATE#315659).
- i40e: Change the ethtool NVM read method to use AQ (bnc#857397
  FATE#315659).
- i40e: fix mac address checking (bnc#857397 FATE#315659).
- i40e: Dump the whole NVM, not half (bnc#857397 FATE#315659).
- i40e: report VF MAC addresses correctly (bnc#857397
  FATE#315659).
- i40e: update led set args (bnc#857397 FATE#315659).
- i40e: make a define from a large constant (bnc#857397
  FATE#315659).
- i40e: be more informative (bnc#857397 FATE#315659).
- i40e: fix error return (bnc#857397 FATE#315659).
- i40e: remove chatty log messages (bnc#857397 FATE#315659).
- i40e: remove redundant code (bnc#857397 FATE#315659).
- i40e: refactor VF reset flow (bnc#857397 FATE#315659).
- i40e: move i40e_reset_vf (bnc#857397 FATE#315659).
- i40e: Rx checksum offload for VXLAN (bnc#857397 FATE#315659).
- commit f6cf5af
* Mon Feb 24 2014 dchang@suse.com
- i40e: Implementation of VXLAN ndo's (bnc#857397 FATE#315659).
  Update config files: Enable CONFIG_I40E_VXLAN
- i40e: fix curly brace use and return type (bnc#857397
  FATE#315659).
- i40e: add wake-on-lan support (bnc#857397 FATE#315659).
- i40e: Populate and check pci bus speed and width (bnc#857397
  FATE#315659).
- pci_regs.h: Add PCI bus link speed and width defines (bnc#857397
  FATE#315659).
- i40e: Suppress HMC error to Interrupt message level (bnc#857397
  FATE#315659).
- i40e: using for_each_set_bit to simplify the code (bnc#857397
  FATE#315659).
- i40e: make functions static and remove dead code (bnc#857397
  FATE#315659).
- i40e: Fix off by one in i40e_dbg_command_write (bnc#857397
  FATE#315659).
- i40e: Fix wrong mask bits being used in misc interrupt
  (bnc#857397 FATE#315659).
- i40e: more print_hex_dump use (bnc#857397 FATE#315659).
- i40e: fix up scanf decoders (bnc#857397 FATE#315659).
- i40e: simplify error messages for dump descriptor (bnc#857397
  FATE#315659).
- i40e: prevent null pointer exception in dump descriptor
  (bnc#857397 FATE#315659).
- i40e: Fix dump output from debugfs calls (bnc#857397
  FATE#315659).
- i40e: Remove FCoE in i40e_virtchnl_pf.c code (bnc#857397
  FATE#315659).
- i40e: support for suspend and resume (bnc#857397 FATE#315659).
- i40e: rtnl_lock in reset path fixes (bnc#857397 FATE#315659).
- i40e: Add basic support for get/set channels for RSS (bnc#857397
  FATE#315659).
- i40e: function to reconfigure RSS queues and rebuild (bnc#857397
  FATE#315659).
- i40e: reinit flow for the main VSI (bnc#857397 FATE#315659).
- i40e: use same number of queues as CPUs (bnc#857397
  FATE#315659).
- i40e: trivial fixes (bnc#857397 FATE#315659).
- i40e: init flow control settings to disabled (bnc#857397
  FATE#315659).
- i40e: Tell the stack about our actual number of queues
  (bnc#857397 FATE#315659).
- i40e: fix pf reset after offline test (bnc#857397 FATE#315659).
- i40e: fix up some of the ethtool connection reporting
  (bnc#857397 FATE#315659).
- i40e: fix null dereference (bnc#857397 FATE#315659).
- i40e: remove and fix confusing define name (bnc#857397
  FATE#315659).
- i40e: complain about out-of-range descriptor request (bnc#857397
  FATE#315659).
- i40e: loopback info and set loopback fix (bnc#857397
  FATE#315659).
- i40e: restrict diag test messages (bnc#857397 FATE#315659).
- i40e: Add a new variable to track number of pf instances
  (bnc#857397 FATE#315659).
- i40e: add num_VFs message (bnc#857397 FATE#315659).
- i40e: refactor ethtool tests (bnc#857397 FATE#315659).
- i40e: clear test state bit after all ethtool tests (bnc#857397
  FATE#315659).
- i40e: only set up the rings to be used (bnc#857397 FATE#315659).
- i40e: Enable all PCTYPEs except FCOE for RSS (bnc#857397
  FATE#315659).
- i40e: refactor reset code (bnc#857397 FATE#315659).
- i40e: enable early hardware support (bnc#857397 FATE#315659).
- i40e: Add flag for L2 VEB filtering (bnc#857397 FATE#315659).
- i40e: get media type during link info (bnc#857397 FATE#315659).
- i40e: check multi-bit state correctly (bnc#857397 FATE#315659).
- i40e: separate TSYNVALID and TSYNINDX fields in Rx descriptor
  (bnc#857397 FATE#315659).
- i40e: sync header files with hardware (bnc#857397 FATE#315659).
- i40e: restrict diag test length (bnc#857397 FATE#315659).
- i40e: add support for triggering EMPR (bnc#857397 FATE#315659).
- i40e: add interrupt test (bnc#857397 FATE#315659).
- i40e: default debug mask setting (bnc#857397 FATE#315659).
- i40e: fix debugging messages (bnc#857397 FATE#315659).
- i40e: properly add VF MAC addresses (bnc#857397 FATE#315659).
- i40e: retry call on timeout (bnc#857397 FATE#315659).
- i40e: select reset counters correctly (bnc#857397 FATE#315659).
- i40e: allow one more vector for VFs (bnc#857397 FATE#315659).
- i40e: firmware version fields offsets update (bnc#857397
  FATE#315659).
- i40e: simplify aq head-tail-len setups (bnc#857397 FATE#315659).
- i40e: clear AQ head and tail registers (bnc#857397 FATE#315659).
- i40e: register file updates (bnc#857397 FATE#315659).
- i40e: set pf_id based on device and function numbers (bnc#857397
  FATE#315659).
- i40e: fix error return code in i40e_probe() (bnc#857397
  FATE#315659).
- i40e: remove unused including <linux/version.h> (bnc#857397
  FATE#315659).
- i40e: use pf_id for pf function id in qtx_ctl (bnc#857397
  FATE#315659).
- i40e: check vsi ptrs before dumping them (bnc#857397
  FATE#315659).
- i40e: reorder block declarations in debugfs (bnc#857397
  FATE#315659).
- i40e: tweaking icr0 handling for legacy irq (bnc#857397
  FATE#315659).
- i40e: refactor fdir setup function (bnc#857397 FATE#315659).
- i40e: fix sign extension issue (bnc#857397 FATE#315659).
- i40e: fix use of untrusted scalar value warning (bnc#857397
  FATE#315659).
- i40e: clamp debugfs nvm read command (bnc#857397 FATE#315659).
- i40e: debugfs fixups (bnc#857397 FATE#315659).
- i40e: fixup legacy interrupt handling (bnc#857397 FATE#315659).
- i40e: assign correct vector to VF (bnc#857397 FATE#315659).
- i40e: don't free nonexistent rings (bnc#857397 FATE#315659).
- i40e: do not flush after re-enabling interrupts (bnc#857397
  FATE#315659).
- i40e: Add support for 64 bit netstats (bnc#857397 FATE#315659).
- i40e: Move rings from pointer to array to array of pointers
  (bnc#857397 FATE#315659).
- i40e: Replace ring container array with linked list (bnc#857397
  FATE#315659).
- i40e: Move q_vectors from pointer to array to array of pointers
  (bnc#857397 FATE#315659).
- i40e: Split bytes and packets from Rx/Tx stats (bnc#857397
  FATE#315659).
- i40e: Add support for Tx byte queue limits (bnc#857397
  FATE#315659).
- i40e: Drop dead code and flags from Tx hotpath (bnc#857397
  FATE#315659).
- i40e: clean up Tx fast path (bnc#857397 FATE#315659).
- i40e: Do not directly increment Tx next_to_use (bnc#857397
  FATE#315659).
- i40e: Cleanup Tx buffer info layout (bnc#857397 FATE#315659).
- i40e: Drop unused completed stat (bnc#857397 FATE#315659).
- i40e: Link code updates (bnc#857397 FATE#315659).
- commit 1eb5b9b
* Mon Feb 24 2014 trenn@suse.de
- Use CRS is default with new kernels anyway, no whitelisting needed anymore
  Delete patches.fixes/pci_use_acpi_resources_whitelist.patch.
- commit afcaec3
* Mon Feb 24 2014 trenn@suse.de
- After verifying with IBM: x3850M2 platform is by far not supported anymore in
  SLE12 -> remove the ugly SLE11 workarounds:
- Delete patches.fixes/pci_blacklist_usecrs.patch.
- Delete patches.suse/ibm_x3850M2_blacklist_modesetting.patch.
- commit ca2f963
* Sat Feb 22 2014 dsterba@suse.cz
- btrfs: fix null pointer deference at btrfs_sysfs_add_one+0x105.
- Btrfs: unset DCACHE_DISCONNECTED when mounting default subvol.
- Btrfs: fix max_inline mount option.
- Btrfs: fix a lockdep warning when cleaning up aborted
  transaction.
- Revert "btrfs: add ioctl to export size of global metadata
  reservation".
- commit f9ffd33
* Fri Feb 21 2014 tonyj@suse.de
- SP3 porting review
- Delete patches.arch/uv-update-nmi-handler-for-uv2.patch.
- Delete patches.suse/kdb-v4.4-3.1-x86-1-fix-merge-error.patch.
- Delete
  patches.suse/perf-0277-x86-Fix-cmpxchg-usage-in-amd_put_event_constrai.patch.
- Delete patches.suse/perf-userspace-no-werror.patch.
- commit 13db90c
* Fri Feb 21 2014 bpoirier@suse.de
- Refresh
  patches.drivers/ixgbe-0030-net-core-explicitly-select-a-txq-before-doing-l2-for.patch.
  Also adjust drivers/net/virtio_net.c
  This was not needed upstream because of "9bb8ca8 virtio-net: switch
  to use XPS to choose txq (v3.13-rc1)"
- commit ae055cd
* Fri Feb 21 2014 bp@suse.de
- Update config files.
  Disable CONFIG_RTC_HCTOSYS.
- commit 253e6b1
* Fri Feb 21 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 09fd0b1
* Fri Feb 21 2014 ptesarik@suse.cz
- patches.arch/x86-kexec-disable_cpu_apicid: Use return without value.
- commit c17ce5d
* Thu Feb 20 2014 jslaby@suse.cz
- Linux 3.12.12.
- Delete
  patches.suse/btrfs-0256-disable-snapshot-aware-defrag-for-now.patch.
- Delete
  patches.suse/x86-mm-Change-tlb_flushall_shift-for-IvyBridge.patch.
- commit 933b8bf
* Thu Feb 20 2014 jslaby@suse.cz
- Linux 3.12.11 (LTC#103626 LTC#103627 bnc#799216 bnc#860346).
- mm: reintroduce global_reclaimable_page (FATE309111)
- Refresh
  patches.suse/percpu_ida-make-percpu_ida-percpu-size-batch-config.patch.
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-patch-3.12.
- Delete
  patches.arch/s390-sles12-01-07-fs-compat-fix-lookup_dcookie-parameter-handling.patch.
- Delete
  patches.arch/s390-sles12-01-08-fs-compat-fix-parameter-handling-for-compat-readv-wr.patch.
- Delete
  patches.drivers/drm-cirrus-Correct-register-values-for-16bpp.
- Delete
  patches.suse/memcg-fix-css-reference-leak-and-endless-loop-in-mem.patch.
- Delete
  patches.suse/memcg-fix-endless-loop-caused-by-mem_cgroup_iter.patch.
- Delete patches.suse/mm-ignore-VM_SOFTDIRTY-on-VMA-merging.patch.
- Delete
  patches.suse/mm-memcg-iteration-skip-memcgs-not-yet-fully-initial.patch.
- Update config files.
- commit ba37358
* Thu Feb 20 2014 dchang@suse.com
- qlcnic: update version to 5.3.55 (bnc#853685 FATE#315935).
- qlcnic: Enhance logic to calculate msix vectors (bnc#853685
  FATE#315935).
- qlcnic: Refactor interrupt coalescing code for all adapters
  (bnc#853685 FATE#315935).
- qlcnic: Update poll controller code path (bnc#853685
  FATE#315935).
- qlcnic: Interrupt code cleanup (bnc#853685 FATE#315935).
- qlcnic: Enhance Tx timeout debugging (bnc#853685 FATE#315935).
- qlcnic: Use bool for rx_mac_learn (bnc#853685 FATE#315935).
- qlcnic: fix sparse warnings (bnc#853685 FATE#315935).
- qlcnic: remove unused code (bnc#853685 FATE#315935).
- qlcnic: make local functions static (bnc#853685 FATE#315935).
- qlcnic: Update version to 5.3.54 (bnc#853685 FATE#315935).
- qlcnic: Enable IPv6 LRO even if IP address is not programmed
  (bnc#853685 FATE#315935).
- qlcnic: Fix SR-IOV cleanup code path (bnc#853685 FATE#315935).
- qlcnic: Enable beaconing for 83xx/84xx Series adapter
  (bnc#853685 FATE#315935).
- qlcnic: Turn on promiscous mode for SRIOV PF (bnc#853685
  FATE#315935).
- qlcnic: Do MAC learning for SRIOV PF (bnc#853685 FATE#315935).
- qlcnic: Enable VF flood bit on PF (bnc#853685 FATE#315935).
- qlcnic: Restrict VF from configuring any VLAN mode (bnc#853685
  FATE#315935).
- qlcnic: Convert vmalloc/memset to kcalloc (bnc#853685
  FATE#315935).
- qlcnic: Fix ethtool statistics length calculation (bnc#853685
  FATE#315935).
- qlcnic: Fix bug in TX statistics (bnc#853685 FATE#315935).
- qlcnic: Fix bug in Tx completion path (bnc#853685 FATE#315935).
- qlcnic: Fix resource allocation for TX queues (bnc#853685
  FATE#315935).
- qlcnic: Fix loopback diagnostic test (bnc#853685 FATE#315935).
- drivers: net: Mark functions as static in qlcnic_83xx_hw.c
  (bnc#853685 FATE#315935).
- drivers: net: Mark functions as static in qlcnic_io.c
  (bnc#853685 FATE#315935).
- commit 7952ffe
* Thu Feb 20 2014 neilb@suse.de
- FS-Cache: Handle removal of unadded object to the
  fscache_object_list rb tree (bnc#855885).
- commit 9a8dca1
* Wed Feb 19 2014 trenn@suse.de
- Delete patches.arch/acpi_processor_fix_cpuidle_unregister.patch.
- Delete
  patches.arch/intel_iommu_fix_wrong_firmware_warning.patch.
- Delete patches.arch/x86_intel_do_not_modify_perf_bias.patch.
- Delete patches.drivers/pnp_fix_misleading_error_msg.patch.
- Delete patches.fixes/x86_acer_acpi_ec_call_reg_blacklist.patch.
- Delete patches.suse/acpi_osi_sle11_not_winp_key.patch.
- commit 9826b11
* Wed Feb 19 2014 jslaby@suse.cz
- Refresh
  patches.fixes/tty-Set-correct-tty-name-in-active-sysfs-attribute.patch.
- commit e76a98b
* Wed Feb 19 2014 neilb@suse.de
- supported.conf:
  add fs/nfs/blocklayout/blocklayoutdriver for FATE 316310
- commit a228495
* Wed Feb 19 2014 neilb@suse.de
- Remove dm-raid45 module.
  This is superceded by dm-raid which support raid1/4/5/6 and is included
  in mainline.
- commit 6df797c
* Wed Feb 19 2014 neilb@suse.de
- sunrpc: turn warn_gssd() log message into a dprintk()
  (bnc#864413).
- rpc_pipe: fix cleanup of dummy gssd directory when notification
  fails (bnc#864413).
- sunrpc: add an "info" file for the dummy gssd pipe (bnc#864413).
- rpc_pipe: remove the clntXX dir if creating the pipe fails
  (bnc#864413).
- nfs: check if gssd is running before attempting to use krb5i
  auth in SETCLIENTID call (bnc#864413).
- sunrpc: replace sunrpc_net->gssd_running flag with a more
  reliable check (bnc#864413).
- sunrpc: create a new dummy pipe for gssd to hold open
  (bnc#864413).
- commit 59164a8
* Tue Feb 18 2014 jack@suse.cz
- dm log userspace: allow mark requests to piggyback on flush
  requests (fate#315092).
- commit 92fdea9
* Tue Feb 18 2014 mhocko@suse.cz
- memcg: remove unused code from kmem_cache_destroy_work_func
  (memcg changes).
- memcg: reparent charges of children before processing parent
  (memcg changes).
- memcg: fix endless loop in __mem_cgroup_iter_next() (memcg
  changes).
- memcg: fix endless loop caused by mem_cgroup_iter (memcg
  changes).
- memcg: fix css reference leak and endless loop in
  mem_cgroup_iter (memcg changes).
- mm/memcg: iteration skip memcgs not yet fully initialized
  (memcg changes).
- mm/memcg: fix last_dead_count memory wastage (memcg changes).
- memcg: rework memcg_update_kmem_limit synchronization (memcg
  changes).
- memcg: remove KMEM_ACCOUNTED_ACTIVATED flag (memcg changes).
- memcg: do not use vmalloc for mem_cgroup allocations (memcg
  changes).
- memcg: change oom_info_lock to mutex (memcg changes).
- memcg, oom: lock mem_cgroup_print_oom_info (memcg changes).
- memcg: make memcg_update_cache_sizes() static (memcg changes).
- memcg: fix kmem_account_flags check in memcg_can_account_kmem()
  (memcg changes).
- memcg, kmem: use cache_from_memcg_idx instead of hard code
  (memcg changes).
- memcg, kmem: use is_root_cache instead of hard code (memcg
  changes).
- memcg: support hierarchical memory.numa_stats (memcg changes).
- memcg: refactor mem_control_numa_stat_show() (memcg changes).
- memcg: stop using css id (memcg changes).
- memcg: fail to create cgroup if the cgroup id is too big
  (memcg changes).
- memcg: convert to use cgroup id (memcg changes).
- memcg: convert to use cgroup_is_descendant() (memcg changes).
- mm, thp: fix infinite loop on memcg OOM (mm fixes).
- mm, oom: prefer thread group leaders for display purposes
  (oom fixes).
- oom_kill: add rcu_read_lock() into find_lock_task_mm()
  (oom fixes).
- oom_kill: has_intersects_mems_allowed() needs rcu_read_lock()
  (oom fixes).
- oom_kill: change oom_kill.c to use for_each_thread()
  (oom fixes).
- introduce for_each_thread() to replace the buggy
  while_each_thread() (oom fixes).
- commit e9027ec
* Tue Feb 18 2014 mhocko@suse.cz
- move patch for later dependencies
- commit e83bf04
* Tue Feb 18 2014 mszeredi@suse.cz
- epoll: do not take the nested ep->mtx on EPOLL_CTL_DEL
  (bnc#849463).
- epoll: do not take global 'epmutex' for simple topologies
  (bnc#849463).
- epoll: optimize EPOLL_CTL_DEL using rcu (bnc#849463).
- commit cd5ef96
* Tue Feb 18 2014 oneukum@suse.de
- Revert "xhci: replace xhci_read_64() with readq()" (bnc#864252).
- commit 7a2c0a8
* Tue Feb 18 2014 duwe@suse.de
- Refresh
  patches.arch/ppc-put-FP_VSX-and-VR-state-into-structures.
  (more from merge 3ad26e5c4459d3)
- commit 146c4b4
* Tue Feb 18 2014 duwe@suse.de
- powerpc: Reclaim two unused thread_info flag bits (bnc#863212).
- powerpc: Don't corrupt transactional state when using FP/VMX
  in kernel (bnc#863212).
- powerpc: Fix transactional FP/VMX/VSX unavailable handlers
  (bnc#863212).
- powerpc: Provide for giveup_fpu/altivec to save state in
  alternate location (bnc#863212).
- powerpc: Put FP/VSX and VR state into structures (bnc#863212).
- Update patches.arch/ppc64le-0009-Reset-MSR_LE-on-signal-entry
  (bnc#856774 fate#315275, LTC#92305, bnc#863212).
- Refresh
  patches.arch/pseries-no-relocation-on-exception-during-crash-kdump.
- commit 43b15aa
* Tue Feb 18 2014 mszeredi@suse.cz
- cifs: ensure that uncached writes handle unmapped areas
  correctly (bnc#864025 CVE-2014-00691).
- commit 85bd6cd
* Mon Feb 17 2014 ptesarik@suse.cz
- x86, apic: Make disabled_cpu_apicid static read_mostly, fix
  typos (FATE#315239).
- x86, apic, kexec: Add disable_cpu_apicid kernel parameter
  (FATE#315239).
- commit e36899a
* Mon Feb 17 2014 oneukum@suse.de
- Revert "xhci: replace xhci_write_64() with writeq()"
  (bnc#864252).
- commit 4c611cf
* Mon Feb 17 2014 neilb@suse.de
- Refresh patches.fixes/nfs-sock-timeout.fix.
  Improve patch based on upstream recommendations.
- commit bcacb1c
* Sat Feb 15 2014 ohering@suse.de
- Add Git-commit tags to two hv patches
- commit f4c5d4d
* Fri Feb 14 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Do not mount /sys, the build script does it
- commit f11b02a
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CEPH_LIB and RBD, will be provided as KMPs for HA
- commit 2144507
* Fri Feb 14 2014 mmarek@suse.cz
- Disable LZ4 options, as we do not have the necessary tools
- commit c0f6001
* Fri Feb 14 2014 mmarek@suse.cz
- Drop following filesystems: hfs, minix, omfs, sysv and romfs
  (fate#316999)
- commit 6515fc3
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_VIA_WDT (32bit hardware)
- commit 89f4380
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_TOUCHSCREEN_* options that were not requested for
  SLED/SLEPOS.
- commit 36299d0
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_SOC_CAMERA_OV5642
  Not relevant for SLES/SLED hardware.
- commit 1d7d018
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_SH_ETH
- commit 146ba33
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_POWER_RESET on no-arm
- commit c9f25c6
* Fri Feb 14 2014 mmarek@suse.cz
- Disable empty CONFIG_POWER_AVS menu
- commit dcc3c47
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_MMC_SDHCI_PXAV2 / V3 on non-arm
- commit 93be481
* Fri Feb 14 2014 mmarek@suse.cz
- Disable drivers for unsupported MFD devices
- commit 31ca808
* Fri Feb 14 2014 mmarek@suse.cz
- Disable the CONFIG_MEMORY menu
  None of the actual drivers was enabled.
- commit 8d8fa87
* Fri Feb 14 2014 mmarek@suse.cz
- Disable CONFIG_INTERVAL_TREE_TEST
- commit 5f05582
* Fri Feb 14 2014 oneukum@suse.de
- Update config files.
  Disable build of SSB HC driver for HCs in embedded systems
- commit f98a999
* Fri Feb 14 2014 mmarek@suse.cz
- Disable crypto/async_tx/raid6test
- commit f8130e9
* Fri Feb 14 2014 mmarek@suse.cz
- Mark new crypto modules as supported
- commit 4fe5352
* Fri Feb 14 2014 mmarek@suse.cz
- Disable FB drivers for epaper devices and other unsupported hardware
- commit e572084
* Fri Feb 14 2014 mmarek@suse.cz
- Mark dm-raid and dm-bio-prison as supported, disable dm-flakey, dm-switch
  and md/multipath.
- commit 6c6fd83
* Fri Feb 14 2014 bp@suse.de
- Update config files: Reenable COREDUMP
- commit 4f50a37
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable external I2C adapters on ppc64le
  These are drivers for hardware and software development, they aren't
  needed in SLES.
- commit e67414d
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable TS5500 drivers
  These drivers are useless except on the TS5500 board itself, which we
  do not support. So:
  CONFIG_GPIO_TS5500 is not set
  CONFIG_MTD_TS5500 is not set
- commit fd87e75
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable many hwmon drivers
  Disable hwmon drivers we do not expect our customers will ever use:
  * Humidity sensors: hih6130, htu21, sht15 and sht21
  * Current sensors: ina209, ina2xx, lineage-pem, ltc4151, ltc4215,
  ltc4245, ltc4261 and max16065
  * Platform-specific drivers: gpio-fan, max197 and ntc_thermistor
  * Old drivers: atxp1, gl518sm, gl520sm
  * ADC drivers: mcp3021, pcf8591, smm665
  All these drivers could be re-enabled and even supported of a customer
  ever asks.
- commit 14adc2a
* Fri Feb 14 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.12.9-10 (FATE#315019
  FATE#315482 FATE#315648 FATE#315669 LTC#103622 bnc#802445
  bnc#857399 bnc#860346 bnc#860993).
- commit bdd826f
* Fri Feb 14 2014 ohering@suse.de
- Drivers: hv: Ballon: Make pressure posting thread sleep
  interruptibly.
- commit b1d95d2
* Fri Feb 14 2014 bp@suse.de
- Update config files: Disable RBTREE_TEST
- commit 41a804a
* Thu Feb 13 2014 bp@suse.de
- Update config files: Disable NFS_V4_2
- commit a4410ef
* Thu Feb 13 2014 bp@suse.de
- Update config files: Disable wakelocks
- commit 972254a
* Thu Feb 13 2014 bp@suse.de
- Update config files: disable COREDUMP and F2FS
- commit 0a46bb1
* Thu Feb 13 2014 bp@suse.de
- Update config files: Disable BLK_DEV_RSXX.
- commit 11bc58e
* Thu Feb 13 2014 bp@suse.de
- supported.conf: Add nlmon
- commit 1012732
* Thu Feb 13 2014 duwe@suse.de
- powerpc/pseries: Disable relocation on exception while going
  down during crash (bnc#863534).
- powerpc: Fix kdump hang issue on p8 with relocation on exception
  enabled (bnc#863534).
- commit 7f5ec55
* Thu Feb 13 2014 duwe@suse.de
- KVM: PPC: Book3S: MMIO emulation support for little endian
  (bnc#863310, fate#315275, LTC#92305).
- powerpc/pseries: fix regression on PCI link speed (bnc#863310,
  fate#315275, LTC#92305).
- powerpc/pseries: add Gen3 definitions for PCIE link speed
  (bnc#863310, fate#315275, LTC#104113).
- powerpc: Make 64-bit non-VMX __copy_tofrom_user bi-endian
  (bnc#863310, fate#315275, LTC#92305).
- powerpc: Make unaligned accesses endian-safe for powerpc
  (bnc#863310, fate#315275, LTC#92305).
- KVM: PPC: Unify kvmppc_get_last_inst and sc (bnc#863310,
  fate#315275, LTC#92305).
- powerpc: Fix endian issues in kexec and crash dump code
  (bnc#863310, fate#315275, LTC#92305).
- powerpc: Fix alignment of secondary cpu spin vars (bnc#863310,
  fate#315275, LTC#92305).
- powerpc: Check return value of instance-to-package OF call
  (bnc#863310, fate#315275, LTC#92305).
- commit 804c5d8
* Thu Feb 13 2014 bp@suse.de
- Update config files.
  Disable a bunch of backlight and battery embedded devices.
- commit 78d0d4a
* Thu Feb 13 2014 mmarek@suse.cz
- Mark bcache as supported (fate#315210)
- commit 4567a08
* Thu Feb 13 2014 bp@suse.de
- Update config files.
- commit 9a38e01
* Thu Feb 13 2014 mmarek@suse.cz
- Run oldconfig on all config files
- commit e9001d9
* Thu Feb 13 2014 jdelvare@suse.de
- Update config files: disable I2C_MPC
  No known users.
- commit cb8165e
* Thu Feb 13 2014 hare@suse.de
- Delete patches.arch/s390-con3270-use-correct-driver-name.patch.
- commit ef61e4a
* Thu Feb 13 2014 mkubecek@suse.cz
- bonding: fix locking in bond_loadbalance_arp_mon()
  (fate#316924).
- rtnetlink: remove IFLA_BOND_SLAVE definition (fate#316924).
- rtnetlink: add missing IFLA_BOND_AD_INFO_UNSPEC (fate#316924).
- rtnetlink: remove ndo_get_slave (fate#316924).
- bonding: convert netlink to use slave data info api
  (fate#316924).
- rtnetlink: provide api for getting and setting slave info
  (fate#316924).
- rtnetlink: put "BOND" into nl attribute names which are related
  to bonding (fate#316924).
- bonding: change name of sysfs dir for bonding slaves
  (fate#316924).
- bonding: add netlink attributes to slave link dev (fate#316924).
- bonding: add sysfs /slave dir for bond slave devices
  (fate#316924).
- bonding: fix kstrtou8() return value verification in
  num_peer_notif (fate#316924).
- bonding: fix netlink msg size (fate#316924).
- bonding: add ad_info attribute netlink support (fate#316924).
- bonding: add ad_select attribute netlink support (fate#316924).
- bonding: add lacp_rate attribute netlink support (fate#316924).
- bonding: add packets_per_slave attribute netlink support
  (fate#316924).
- bonding: add lp_interval attribute netlink support
  (fate#316924).
- bonding: add min_links attribute netlink support (fate#316924).
- bonding: add all_slaves_active attribute netlink support
  (fate#316924).
- bonding: add num_grat_arp attribute netlink support
  (fate#316924).
- bonding: add resend_igmp attribute netlink support
  (fate#316924).
- bonding: add xmit_hash_policy attribute netlink support
  (fate#316924).
- bonding: add fail_over_mac attribute netlink support
  (fate#316924).
- bonding: add primary_select attribute netlink support
  (fate#316924).
- bonding: add primary attribute netlink support (fate#316924).
- bonding: add arp_all_targets netlink support (fate#316924).
- bonding: add arp_validate netlink support (fate#316924).
- bonding: add arp_ip_target netlink support (fate#316924).
- bonding: add arp_interval netlink support (fate#316924).
- bonding: add use_carrier netlink support (fate#316924).
- bonding: add downdelay netlink support (fate#316924).
- bonding: add updelay netlink support (fate#316924).
- bonding: add miimon netlink support (fate#316924).
- bonding: fix packets_per_slave showing (fate#316924).
- bonding: disable arp and enable mii monitoring when bond change
  to no uses arp mode (fate#316924).
- bonding: add ip checks when store ip target (fate#316924).
- bonding: extend round-robin mode with packets_per_slave
  (fate#316924).
- bonding: bond_get_size() returns wrong size (fate#316924).
- net: fix rtnl notification in atomic context (fate#316924).
- bonding: Remove __exit tag from bond_netlink_fini()
  (fate#316924).
- bonding: add Netlink support active_slave option (fate#316924).
- bonding: add Netlink support mode option (fate#316924).
- bonding: move active_slave getting into separate function
  (fate#316924).
- bonding: remove bond_ioctl_change_active() (fate#316924).
- bonding: move active_slave setting into separate function
  (fate#316924).
- bonding: move mode setting into separate function (fate#316924).
- bonding: push Netlink bits into separate file (fate#316924).
- bonding: verify if we still have slaves in
  bond_3ad_unbind_slave() (fate#316924).
- bonding: correctly verify for the first slave in bond_enslave
  (fate#316924).
- bonding: add bond_has_slaves() and use it (fate#316924).
- bonding: populate neighbour's private on enslave (fate#316924).
- net: add netdev_adjacent->private and allow to use it
  (fate#316924).
- commit a563c9a
* Thu Feb 13 2014 mkubecek@suse.cz
- series.conf: move two patches to more suitable place
  Patches
  patches.fixes/net-use-lists-as-arguments-instead-of-bool-upper.patch
  patches.fixes/net-add-adj_list-to-save-only-neighbours.patch
  are not ixgbe specific so move them up so that changes
  introduced by them can be used in other backports.
- commit a61e1a0
* Thu Feb 13 2014 mgalbraith@suse.de
- Re-enable nohz throttle, pick up two fixes for silent RCU regression.
  High frequency idle enter/exit can save considerable number of cycles
  with the throttle enabled, the two fixes below allow turning it back on.
  cross core pipe-test measured on Q6600 box
  5.059112 usecs/loop -- avg 5.041456 396.7 KHz     1.000  -nohz-throttle
  4.240344 usecs/loop -- avg 4.243427 471.3 KHz     1.188  +nohz-throttle
- rcu: Throttle invoke_rcu_core() invocations due to non-lazy callbacks.
- rcu: Throttle rcu_try_advance_all_cbs() execution.
- Refresh patches.fixes/nohz-check-for-nohz-active-instead-of-nohz-enabled.patch.
- commit 9b28a2e
* Thu Feb 13 2014 bp@suse.de
- Update config files: disable SATA_HIGHBANK
  32-bit only hw.
- commit 1e5c279
* Thu Feb 13 2014 bp@suse.de
- Update config files: disable pounders
  We can always enable them later in the -debug kernel if needed.
- commit 9dfcfa0
* Thu Feb 13 2014 dvaleev@suse.de
- rpm/kernel-obs-build.spec: Fix for ppc64le
- commit 50c4205
* Thu Feb 13 2014 bp@suse.de
- Update config files: disable NET_CALXEDA_XGMAC
- commit 4477cad
* Thu Feb 13 2014 mmarek@suse.cz
- supported.conf: ibmvscsic has been renamed to ibmvscsi
- commit aa70cda
* Thu Feb 13 2014 jlee@suse.com
- Xen: ACPI / driver core: Store an ACPI device pointer in struct
  acpi_dev_node (fate#316836).
- commit 24e0f89
* Thu Feb 13 2014 mgorman@suse.de
- mm: swap: Use swapfiles in priority order (VM Functionality).
- commit 09d65b2
* Thu Feb 13 2014 bp@suse.de
- Update config files.
  Disable a bunch of embedded stuff.
- commit 294a6de
* Thu Feb 13 2014 jack@suse.cz
- Update config files.
- supported.conf: Mark ext4 as supported, remove ext2 & ext3 since ext4
  driver is used for them now
- commit d7b63e2
* Thu Feb 13 2014 neilb@suse.de
- NFS: Allow NFSv4 mounts to not share transports (FATE#315593).
- commit 92504bd
* Thu Feb 13 2014 mgalbraith@suse.de
- Disable patches.suse/sched-throttle-nohz.patch
  Combined with CONFIG_RCU_FAST_NO_HZ, now induces screaming RCU softirq.
- commit ba6f780
* Wed Feb 12 2014 mgorman@suse.de
- mm: close PageTail race (VM Functionality).
- commit 6e1c836
* Wed Feb 12 2014 mgorman@suse.de
- mm/swap.c: reorganize put_compound_page() (VM Functionality).
- mm/hugetlb.c: simplify PageHeadHuge() and PageHuge() (VM
  Functionality).
- mm: hugetlbfs: use __compound_tail_refcounted in __get_page_tail
  too (VM Functionality).
- mm: tail page refcounting optimization for slab and hugetlbfs
  (VM Functionality).
- mm: thp: optimize compound_trans_huge (VM Functionality).
- mm: hugetlbfs: move the put/get_page slab and hugetlbfs
  optimization in a faster path (VM Functionality).
- mm: hugetlb: use get_page_foll() in follow_hugetlb_page()
  (VM Functionality).
- fs/proc/page.c: add PageAnon check to surely detect thp
  (VM Functionality).
- commit e686b22
* Wed Feb 12 2014 jdelvare@suse.de
- Update config files: Disable embedded I2C bus drivers
  Specifically, the following drivers are disabled as it is believed customers
  don't need them:
  gi2c-cbus-gpio
  gi2c-designware-core
  gi2c-designware-pci
  gi2c-eg20t
  gi2c-gpio
  gi2c-kempld
  gi2c-ocores
  gi2c-pca-platform
- commit 54945c3
* Wed Feb 12 2014 mmarek@suse.cz
- MODSIGN: Support for signing_key.{x509,priv} in the M= directory
- commit 473cba6
* Wed Feb 12 2014 mmarek@suse.cz
- series.conf: Move time/date removal patches to the kbuild section
- commit 8b7d085
* Wed Feb 12 2014 mq@suse.cz
- Scripts: .nosrc.rpm should contain only the specfile (bnc #639379)
- commit afe62e0
* Wed Feb 12 2014 jdelvare@suse.de
- Drop outdated comment
- commit a242897
* Wed Feb 12 2014 jdelvare@suse.de
- i2c: attach/detach I2C client device to the ACPI power domain
  (FATE#315621).
- ACPI / PM: allow child devices to ignore parent power state
  (FATE#315621).
- commit 89cc550
* Wed Feb 12 2014 jlee@suse.com
- Refresh patches.xen/pci-guestdev.
  Refresh patches.xen/pci-guestdev after backported ACPI hotplug patches.
  (fate#316836).
- commit e0deb3e
* Wed Feb 12 2014 jlee@suse.com
- ACPI / hotplug / driver core: Handle containers in a special
  way (fate#316836).
- ACPI / hotplug: Add demand_offline hotplug profile flag
  (fate#316836).
- ACPI / hotplug: Move container-specific code out of the core
  (fate#316836).
- ACPI / hotplug: Make ACPI PCI root hotplug use common hotplug
  code (fate#316836).
- ACPI / hotplug: Introduce common hotplug function
  acpi_device_hotplug() (fate#316836).
- ACPI / hotplug: Do not fail bus and device checks for disabled
  hotplug (fate#316836).
- ACPI / scan: Add acpi_device objects for all device nodes in
  the namespace (fate#316836).
- ACPI / scan: Define non-empty device removal handler
  (fate#316836).
- ACPI / hotplug: Fix PCI host bridge hot removal (fate#316836).
- ACPI / hotplug: Fix acpi_bus_get_device() return value check
  (fate#316836).
- ACPI / driver core: Store an ACPI device pointer in struct
  acpi_dev_node (fate#316836).
- ACPI / hotplug: Consolidate deferred execution of ACPI hotplug
  routines (fate#316836).
- ACPI / hotplug: Carry out PCI root eject directly (fate#316836).
- ACPI / hotplug: Merge device hot-removal routines (fate#316836).
- ACPI / hotplug: Make acpi_bus_hot_remove_device() internal
  (fate#316836).
- ACPI / hotplug: Refuse to hot-remove all objects with disabled
  hotplug (fate#316836).
- ACPI / hotplug: Simplify device ejection routines (fate#316836).
- ACPI / scan: Start matching drivers after trying scan handlers
  (fate#316836).
- ACPI: Write OSC_PCI_CONTROL_MASKS like OSC_PCI_SUPPORT_MASKS
  (fate#316836).
- ACPI: Remove unused OSC_PCI_NATIVE_HOTPLUG (fate#316836).
- PCI/ACPI: Name _OSC #defines more consistently (fate#316836).
- ACPI: Write _OSC bit field definitions in hex (fate#316836).
- commit 0280942
* Wed Feb 12 2014 oneukum@suse.de
- Update config files.
- commit 3128d38
* Wed Feb 12 2014 oneukum@suse.de
- Update config files.
  no compilation of HC drivers for embedded systems
- commit 516d122
* Wed Feb 12 2014 oneukum@suse.de
- let PortPowerOff compile without CONFIG_PM (FATE#315518).
- commit 5bc9f57
* Wed Feb 12 2014 ohering@suse.de
- Drivers: hv: vmbus: Cleanup the packet send path.
- commit e446d22
* Wed Feb 12 2014 ohering@suse.de
- Drivers: net: hyperv: Cleanup the receive path.
- commit b95edca
* Wed Feb 12 2014 ohering@suse.de
- Drivers: net: hyperv: Get rid of the rndis_filter_packet
  structure.
- commit 7e6ee2f
* Wed Feb 12 2014 ohering@suse.de
- hyperv_fb: Add support for Gen2 VM.
- commit 6f461c2
* Wed Feb 12 2014 ohering@suse.de
- Drivers: hv: vmbus: Extract the mmio information from DSDT.
- commit 277218e
* Wed Feb 12 2014 ohering@suse.de
- x86, hyperv: bypass the timer_irq_works() check.
- commit e96ec8d
* Wed Feb 12 2014 lpechacek@suse.cz
- doc/README.PATCH-POLICY.SUSE: updated links
- commit ac58062
* Tue Feb 11 2014 mmarek@suse.cz
- Disable EXOFS and CODA (fate#316706)
- commit 75782d7
* Tue Feb 11 2014 mmarek@suse.cz
- Disable unsupported disk filesystems (fate#316706)
- commit b81882f
* Tue Feb 11 2014 dsterba@suse.cz
- btrfs: commit transaction after setting label and features.
- btrfs: reserve no transaction units in btrfs_ioctl_set_features.
- Btrfs: don't loop forever if we can't run because of the tree
  mod log.
- Btrfs: fix data corruption when reading/updating compressed
  extents.
- Delete patches.suse/btrfs-use-end-trans-in-label-ioctl.
- commit 1b3247a
* Tue Feb 11 2014 bp@suse.de
- Update config files: disable BLK_DEV_RSXX
- commit e491b65
* Tue Feb 11 2014 bp@suse.de
- Update config files.
  Disable CHECKPOINT_RESTORE.
- commit bc4d203
* Tue Feb 11 2014 mmarek@suse.cz
- Disable unsupported ocfs2 and gfs2
  Will be shipped in separate KMPs.
- commit 4000388
* Tue Feb 11 2014 bp@suse.de
- supported.conf: A bunch of EDAC drivers for intel chipsets
- commit 2ec0950
* Tue Feb 11 2014 mmarek@suse.cz
- Disable unsupported CONFIG_CEPH_FS
- commit 16520db
* Tue Feb 11 2014 mmarek@suse.cz
- Disable unsupported 1-Wire drivers (fate#316706)
- commit 39e550b
* Tue Feb 11 2014 bp@suse.de
- Update config files.
  Disable CEPH_FSCACHE.
- commit a13eab4
* Tue Feb 11 2014 ohering@suse.de
- Refresh patches.suse/suse-hv-Drivers-hv-Implement-the-file-copy-service.patch.
  use misc device, its now /dev/vmbus/hv_fcopy
- commit b2db7eb
* Tue Feb 11 2014 mmarek@suse.cz
- Disable unsupported WAN drivers
- commit 7ddc356
* Tue Feb 11 2014 mszeredi@suse.cz
- supported.conf: add fs/squashfs3/squashfs3
- commit 140d1db
* Tue Feb 11 2014 mmarek@suse.cz
- Disable CONFIG_BUILD_DOCSRC
- commit 1b619a8
* Tue Feb 11 2014 spargaonkar@suse.com
- ipr: Handle early EEH (bnc#862959 FATE#315742).
- ipr: Add new CCIN definition for new hardware support
  (bnc#862959 FATE#315742).
- ipr: Remove extended delay bit on GSCSI reads/writes ops
  (bnc#862959 FATE#315742).
- ipr: increase dump size in ipr driver (bnc#862959 FATE#315742).
- commit 8cb11be
* Tue Feb 11 2014 mmarek@suse.cz
- Drop UV patches from SP3 that are upstream already
- commit 39228d6
* Tue Feb 11 2014 mmarek@suse.cz
- Delete SP3 ia64 patches
- commit 9c9efc4
* Tue Feb 11 2014 oneukum@suse.de
- storage: accept some UAS devices if streams are unavailable
  (bnc#862400).
- commit 1f353f2
* Tue Feb 11 2014 tiwai@suse.de
- drm/cirrus: Fix cirrus drm driver for fbdev + qemu (bnc#856760).
- commit 060c1e4
* Tue Feb 11 2014 mq@suse.cz
- Spec: zeroing modules.dep to get identical builds among different machines
- commit a1c5879
* Tue Feb 11 2014 mhocko@suse.cz
- arch/x86/mm/srat: Skip NUMA_NO_NODE while parsing SLIT
  (bnc#863178).
- commit 41fd581
* Tue Feb 11 2014 mhocko@suse.cz
- cgroup: protect modifications to cgroup_idr with cgroup_mutex
  (bnc#863031).
- commit 6252fb6
* Tue Feb 11 2014 mmarek@suse.cz
- rpm/guards: Report which config file has problem in --check mode
- commit b39543d
* Tue Feb 11 2014 mmarek@suse.cz
- Delete patches that have been removed from series.conf
- commit f96a3a6
* Tue Feb 11 2014 jlee@suse.com
- MODSIGN: load hash blacklist of modules from MOKx (fate#316531,
  bnc#854875).
- MODSIGN: check hash of kernel module in blacklist (fate#316531,
  bnc#854875).
- commit 72805d2
* Tue Feb 11 2014 bp@suse.de
- Refresh
  patches.rpmify/nouveau-make-vga_switcheroo-code-depend-on-vga_switcheroo.
  For some reason the original backport was missing
  nouveau_switcheroo_optimus_dsm() which caused a boom during build after
  I disabled VGA_SWITCHEROO.
  Replace with the upstream version of the patch.
- commit 1ca934a
* Mon Feb 10 2014 bp@suse.de
- Update config files.
  Disable RING_BUFFER_BENCHMARK, SBP_TARGET and VGA_SWITCHEROO
- commit f3a7c1b
* Mon Feb 10 2014 oneukum@suse.de
- Update config files.
  fix typo
- commit edd69a8
* Mon Feb 10 2014 mgorman@suse.de
- mm, compaction: avoid isolating pinned pages (VM functionality).
- mm, page_alloc: make first_page visible before PageTail
  (VM functionality).
- commit 4c61b86
* Mon Feb 10 2014 mmarek@suse.cz
- doc/README.SUSE: Update to match the current package layout
- commit f357abb
* Mon Feb 10 2014 mmarek@suse.cz
- Add the README.SUSE file to the packaging branch
- commit 11905ea
* Mon Feb 10 2014 mq@suse.cz
- inet: defines IPPROTO_* needed for module alias generation.
- commit cfb28d0
* Mon Feb 10 2014 bpoirier@suse.de
- drivers/net: delete non-required instances of include
  <linux/init.h> (FATE#315952).
- net: cxgb3: slight optimization of addr compare (FATE#315952).
- chelsio: remove duplicate defines (FATE#315952).
- net: cxgb3: remove unnecessary pci_set_drvdata() (FATE#315952).
- commit 25c0c9f
* Mon Feb 10 2014 tiwai@suse.de
- Bluetooth: Add support for Intel Bluetooth device [8087:0a2a]
  (bnc#862996,FATE#316958).
- commit 66c3ae7
* Mon Feb 10 2014 tonyj@suse.de
- perf/x86: Fix constraint table end marker bug (FATE# 315534).
- perf: Disable all pmus on unthrottling and rescheduling
  (FATE# 315534).
- perf/x86/intel: Add Ivy Bridge-EP uncore IRP box support
  (FATE# 315534).
- perf/x86/intel/uncore: Add filter support for IvyBridge-EP
  QPI boxes (FATE# 315534).
- perf/x86: Optimize intel_pmu_pebs_fixup_ip() (FATE# 315534).
- perf/x86: Suppress duplicated abort LBR records (FATE# 315534).
- tools/perf: Add support for record transaction flags (FATE#
  315534).
- tools/perf/record: Add abort_tx, no_tx, in_tx branch filter
  options to perf record -j (FATE# 315534).
- tools/perf: Support sorting by in_tx or abort branch flags
  (FATE# 315534).
- perf: Add generic transaction flags (FATE# 315534).
- perf/x86: Add Haswell specific transaction flag reporting
  (FATE# 315534).
- tools/perf/stat: Add perf stat --transaction (FATE# 315534).
- perf: Enforce 1 as lower limit for perf_event_max_sample_rate
  (FATE# 315534).
- tools/perf: Fix sorting for 64bit entries (FATE# 315534).
- perf/x86/intel: Clean-up/reduce PEBS code (FATE# 315534).
- perf/x86/intel: Add Haswell TSX event aliases (FATE# 315534).
- perf/x86: Report TSX transaction abort cost as weight (FATE#
  315534).
- perf/x86/intel: Avoid checkpointed counters causing excessive
  TSX aborts (FATE# 315534).
- commit f0af750
* Sun Feb  9 2014 jslaby@suse.cz
- Linux 3.12.10 (FATE#315482 FATE#315648 FATE#315669 LTC#103622
  bnc#802445 bnc#857399 bnc#860346).
- Refresh
  patches.suse/btrfs-0187-convert-printk-to-btrfs_-and-fix-btrfs-prefix.patch.
- Refresh
  patches.suse/mm-mempolicy-make-mpol_to_str-robust-and-always-succeed.patch.
- Refresh patches.xen/xen3-patch-3.10.
- Delete
  patches.arch/0014-x86-efi-Fix-off-by-one-bug-in-EFI-Boot-Services-rese.patch.
- Delete patches.arch/s390-sles12-01-06-uapi-statfs64.patch.
- Delete
  patches.drivers/e1000e-0004-e1000e-fix-compiler-warnings.patch.
- Delete
  patches.drivers/hp_accel-Add-a-new-PnP-ID-HPQ6007-for-new-HP-laptops.
- Delete
  patches.suse/btrfs-0212-handle-EAGAIN-case-properly-in-btrfs_drop_snap.patch.
- Delete
  patches.suse/btrfs-0239-restrict-snapshotting-to-own-subvolumes.patch.
- Delete patches.suse/md-raid5-write_failure_bitmap_handling.
- Delete
  patches.suse/mm-hugetlbfs-fix-hugetlbfs-optimization.patch.
- Delete
  patches.suse/mm-numa-fix-mempolicy-printing-numa_maps.patch.
- commit 65584f5
* Sat Feb  8 2014 oneukum@suse.de
- Update config files.
  fix typo
- commit f0e3a3c
* Sat Feb  8 2014 oneukum@suse.de
- Update config files.
  Do not compile the USB HC drivers for embedded systems
- commit c7f3de9
* Fri Feb  7 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-0186-fix-tree-mod-logging.patch.
- commit 7be758a
* Fri Feb  7 2014 mgorman@suse.de
- mm: fix page leak at nfs_symlink() (VM functionality).
- commit 5ecd849
* Fri Feb  7 2014 bp@suse.de
- Update config files.
  New ÜFI functionality.
- commit 2cc122c
* Fri Feb  7 2014 jjolly@suse.de
- kernel: oops due to linkage stack instructions
  (bnc#860346,LTC#103860).
- commit 7d26986
* Fri Feb  7 2014 jjolly@suse.de
- kernel: fix parameter handling for compat readv/writev syscalls
  (bnc#860346,LTC#103627).
- commit cabf6c6
* Fri Feb  7 2014 jjolly@suse.de
- kernel: fix compat lookup_dcookie system call
  (bnc#860346,LTC#103626).
- commit 86dd47a
* Fri Feb  7 2014 jjolly@suse.de
- Refresh patches.arch/s390-sles12-01-06-uapi-statfs64.patch.
- commit 8fb8d33
* Fri Feb  7 2014 jjolly@suse.de
- kernel: fix struct statfs64 definition (bnc#860346,LTC#103622).
- commit badb0f3
* Fri Feb  7 2014 jjolly@suse.de
- dump: Fix dump memory detection (bnc#860346,LTC#103575).
- commit 02f33ea
* Fri Feb  7 2014 jjolly@suse.de
- appldata: restore missing init_virt_timer()
  (bnc#860346,LTC#103493).
- commit 0e543b2
* Fri Feb  7 2014 jjolly@suse.de
- kernel: incorrect clockevent timeouts (bnc#860346,LTC#100340).
- commit 7312e1b
* Fri Feb  7 2014 jjolly@suse.de
- kernel: wall clock drift (bnc#860346,LTC#100323).
- Update config files.
- commit 0405971
* Fri Feb  7 2014 jjolly@suse.de
- fs3270: unloading module does not remove device
  (bnc#860346,LTC#100284).
- commit fcbebee
* Fri Feb  7 2014 dsterba@suse.cz
- Btrfs: introduce lock_ref/unlock_ref (FATE#312751).
- Btrfs: rework qgroup accounting (FATE#312751).
- Btrfs: add sanity tests for new qgroup accounting code
  (FATE#312751).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit c878090
* Fri Feb  7 2014 tiwai@suse.de
- Move patches.drm/* back to patches.drivers again
  Now all huge amount of patches are gone, so we don't need any dedicated
  patches directory.  Removed from the spec file, too.
- commit e33ec00
* Fri Feb  7 2014 tiwai@suse.de
- Delete patches.drm/3220-i915-lvds-add-standard-modes.diff.
- Delete patches.drm/3288-drm-i915-edp-add-standard-modes.
- commit 1848cf9
* Fri Feb  7 2014 tiwai@suse.de
- ALSA: hda - Fix inconsistent Mic mute LED (bnc#862612).
- commit fc6c4dd
* Fri Feb  7 2014 dsterba@suse.cz
- btrfs update II
- btrfs: replace path->slots[0] with otherwise unused variable
  'slot'.
- btrfs: fix unused variables in qgroup.c.
- btrfs: bootstrap generic btrfs_find_item interface.
- btrfs: expand btrfs_find_item() to include find_root_ref
  functionality.
- btrfs: expand btrfs_find_item() to include find_orphan_item
  functionality.
- btrfs: cleanup: removed unused 'btrfs_get_inode_ref_index'.
- Btrfs: make btrfs_debug match pr_debug handling related
  to DEBUG.
- btrfs: reserve no transaction units in btrfs_feature_attr_store.
- btrfs: replace BUG in can_modify_feature.
- Btrfs: cleanup unnecessary parameter and variant of
  prepare_pages().
- Btrfs: fix the reserved space leak caused by the race between
  nonlock dio and buffered io.
- Btrfs: fix ordered extent check in btrfs_punch_hole.
- Btrfs: improve forever loop when doing balance relocation.
- Btrfs: fix very slow inode eviction and fs unmount.
- btrfs: fix static checker warnings.
- btrfs: fix leaks during sysfs teardown.
- Btrfs: avoid unnecessary ordered extent cache resets.
- Btrfs: try harder to avoid btree node splits.
- Btrfs: fix extent boundary check in bio_readpage_error.
- Btrfs: faster and more efficient extent map insertion.
- Btrfs: add missing extent state caching calls.
- Btrfs: more efficient extent state insertions.
- Btrfs: fix max dir item size calculation.
- btrfs: remove dead code.
- Btrfs: fix extent_map block_len after merging.
- Btrfs: fix pass of transid with wrong endianness in send.c.
- Btrfs: fix wrong super generation mismatch when scrubbing
  supers.
- Btrfs: wrap repeated code into scrub_blocked_if_needed().
- Btrfs: more efficient push_leaf_right.
- Btrfs: deal with io_tree->mapping being NULL.
- Btrfs: use a bit to track if we're in the radix tree.
- Btrfs: move the extent buffer radix tree into the fs_info.
- Btrfs: return immediately if tree log mod is not necessary.
- Btrfs: fix error check of btrfs_lookup_dentry().
- Btrfs: remove unnecessary filemap writting and waiting after
  block group relocation.
- Btrfs: fix use of uninitialized err variable.
- Btrfs: remove field tree_mod_seq_elem from btrfs_fs_info struct.
- Btrfs: fix deadlock when iterating inode refs and running
  delayed inodes.
- Btrfs: fix a warning when iput a file.
- Btrfs: fix double initialization of the raid kobject.
- Btrfs: fix tree mod logging.
- Btrfs: convert printk to btrfs_ and fix BTRFS prefix.
- Btrfs: remove residual code in delayed inode async helper.
- Btrfs: don't run delayed nodes again after all nodes flush.
- Btrfs: cleanup code of btrfs_balance_delayed_items().
- Btrfs: remove btrfs_end_transaction_dmeta().
- Btrfs: use flags instead of the bool variants in delayed node.
- Btrfs: introduce the delayed inode ref deletion for the single
  link inode.
- Btrfs: stop caching thread if extent_commit_sem is contended.
- fs/btrfs: Integer overflow in btrfs_ioctl_resize().
- Btrfs: reduce btree node locking duration on item update.
- Btrfs: remove unused argument from select_reloc_root().
- Btrfs: fix an oops when we fail to merge reloc roots.
- Btrfs: fix the wrong nocow range check.
- Btrfs: fix an oops when we fail to relocate tree blocks.
- Btrfs: return free space to global_rsv as much as possible.
- Btrfs: only fua the first superblock when writting supers.
- btrfs: Add "barrier" option to support "-o remount,barrier".
- btrfs: Add noautodefrag mount option.
- btrfs: Add nodiscard mount option.
- btrfs: Add noenospc_debug mount option.
- btrfs: Add noflushoncommit mount option.
- btrfs: Add acl mount option.
- btrfs: Add datacow mount option.
- btrfs: Add datasum mount option.
- btrfs: Add treelog mount option.
- Btrfs: handle EAGAIN case properly in btrfs_drop_snapshot().
- Btrfs: faster file extent item replace operations.
- Btrfs: add support for inode properties.
- Btrfs: make fsync latency less sucky.
- Btrfs: attach delayed ref updates to delayed ref heads.
- Btrfs: throttle delayed refs better.
- Btrfs: fix extent_from_logical to deal with skinny metadata.
- Btrfs: fix qgroup rescan to work with skinny metadata.
- Btrfs: only process as many file extents as there are refs.
- Btrfs: fix the race between write back and nocow buffered write.
- Btrfs: release subvolume's block_rsv before transaction commit.
- Btrfs: optimize to remove unnecessary removal with ulist
  reallocation.
- Btrfs: unlock inodes in correct order in clone ioctl.
- Btrfs: fix btrfs boot when compiled as built-in.
- Btrfs: fix missing skinny metadata check in scrub_stripe().
- Btrfs: fix to search previous metadata extent item since
  skinny metadata.
- btrfs: Add noinode_cache mount option.
- btrfs: Cleanup the btrfs_parse_options for remount.
- Btrfs: fix extent state leak on transaction abortion.
- Btrfs: faster file extent item search in clone ioctl.
- Btrfs: fix transaction abortion when remounting btrfs from RW
  to RO.
- Btrfs: flush the dirty pages of the ordered extent aggressively
  during logging csum.
- Btrfs: fix wrong search path initialization before searching
  tree root.
- Btrfs: change the members' order of btrfs_space_info structure
  to reduce the cache miss.
- Btrfs: cleanup the redundant code for the block group allocation
  and init.
- Btrfs: cleanup the code of used_block_group in
  find_free_extent().
- Btrfs: fix wrong block group in trace during the free space
  allocation.
- btrfs: restrict snapshotting to own subvolumes.
- btrfs: call permission checks earlier in ioctls and return
  EPERM.
- btrfs: sysfs: don't show reserved incompat feature.
- btrfs: sysfs: list the NO_HOLES feature.
- btrfs: fix defrag 32-bit integer overflow.
- btrfs: undo sysfs when open_ctree() fails.
- btrfs: fix warning while merging two adjacent extents.
- Btrfs: fix protection between walking backrefs and root
  deletion.
- Btrfs: fix to catch all errors when resolving indirect ref.
- Btrfs: add a reschedule point in btrfs_find_all_roots().
- Btrfs: fix memory leaks on walking backrefs failure.
- Btrfs: rework ulist with list+rb_tree.
- Btrfs: do not export ulist functions.
- Btrfs: fix btrfs_search_slot_for_read backwards iteration.
- Btrfs: don't use ram_bytes for uncompressed inline items.
- Btrfs: setup inode location during btrfs_init_inode_locked.
- Btrfs: fix spin_unlock in check_ref_cleanup.
- Btrfs: disable snapshot aware defrag for now.
- Btrfs: use btrfs_crc32c everywhere instead of libcrc32c.
- Btrfs: use late_initcall instead of module_init.
- rwsem: add rwsem_is_contended.
- Refresh
  patches.suse/btrfs-0130-sanitize-btrfs_IOC_FILE_EXTENT_SAME.patch.
- Refresh
  patches.suse/btrfs-0131-incompatible-format-change-to-remove-hole-exte.patch.
- Refresh
  patches.suse/btrfs-0132-fix-check-integrity-to-look-at-the-referenced-.patch.
- Refresh
  patches.suse/btrfs-0133-introduce-a-head-ref-rbtree.patch.
- Refresh
  patches.suse/btrfs-0134-skip-merge-part-for-delayed-data-refs.patch.
- Refresh
  patches.suse/btrfs-0135-add-ioctls-to-query-change-feature-bits-online.patch.
- Refresh
  patches.suse/btrfs-0136-publish-supported-featured-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-0137-publish-per-super-attributes-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-0138-publish-per-super-features-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-0139-publish-unknown-feature-bits-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-0140-add-ability-to-change-features-via-sysfs.patch.
- Refresh
  patches.suse/btrfs-0141-use-feature-attribute-names-to-print-better-er.patch.
- Refresh
  patches.suse/btrfs-0142-add-ioctl-to-export-size-of-global-metadata-re.patch.
- Refresh
  patches.suse/btrfs-0143-publish-allocation-data-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-0144-publish-device-membership-in-sysfs.patch.
- Refresh patches.suse/btrfs-0145-publish-fs-label-in-sysfs.patch.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh patches.suse/export-kobj_sysfs_ops.
- commit ffef3ed
* Fri Feb  7 2014 dsterba@suse.cz
- btrfs: sanitize BTRFS_IOC_FILE_EXTENT_SAME.
- Btrfs: incompatible format change to remove hole extents.
- Btrfs: fix check-integrity to look at the referenced data
  properly.
- Btrfs: introduce a head ref rbtree.
- Btrfs: skip merge part for delayed data refs.
- btrfs: add ioctls to query/change feature bits online.
- btrfs: publish supported featured in sysfs.
- btrfs: publish per-super attributes in sysfs.
- btrfs: publish per-super features in sysfs.
- btrfs: publish unknown feature bits in sysfs.
- btrfs: add ability to change features via sysfs.
- btrfs: use feature attribute names to print better error
  messages.
- btrfs: add ioctl to export size of global metadata reservation.
- btrfs: publish allocation data in sysfs.
- btrfs: publish device membership in sysfs.
- btrfs: publish fs label in sysfs.
- Delete
  patches.suse/btrfs-add-ability-to-change-features-via-sysfs.
- Delete
  patches.suse/btrfs-add-ability-to-query-change-feature-bits-online-ioctl.
- Delete
  patches.suse/btrfs-add-ioctl-to-export-size-of-global-metadata-reservation.
- Delete patches.suse/btrfs-publish-allocation-data-in-sysfs.
- Delete patches.suse/btrfs-publish-device-membership-in-sysfs.
- Delete patches.suse/btrfs-publish-fs-label-in-sysfs.
- Delete patches.suse/btrfs-publish-per-super-attributes-in-sysfs.
- Delete patches.suse/btrfs-publish-per-super-features-in-sysfs.
- Delete patches.suse/btrfs-publish-supported-featured-in-sysfs.
- Delete patches.suse/btrfs-publish-unknown-feature-bits-in-sysfs.
- Delete
  patches.suse/btrfs-use-feature-attributes-to-print-names-in-errors.
- commit 365b3dd
* Fri Feb  7 2014 oneukum@suse.de
- usb: force warm reset to break resume livelock (FATE#315518).
- usb: guarantee child device resume on port poweron
  (FATE#315518).
- usb: introduce port status lock (FATE#315518).
- xhci: cancel in-flight resume requests when the port is powered
  off (FATE#315518).
- usb: synchronize port poweroff and khubd (FATE#315518).
- usb: refactor port handling in hub_events() (FATE#315518).
- usb: usb3 ports do not support FEAT_C_ENABLE (FATE#315518).
- usb: don't clear FEAT_C_ENABLE on usb_port_runtime_resume
  failure (FATE#315518).
- usb: defer suspension of superspeed port while peer is powered
  (FATE#315518).
- usb: sysfs link peer ports (FATE#315518).
- usb: find internal hub tier mismatch via acpi (FATE#315518).
- usb: assign usb3 external hub port peers (FATE#315518).
- usb: assign default peer ports for root hubs (FATE#315518).
- commit a24ffac
* Fri Feb  7 2014 bp@suse.de
- x86/efi: Fix earlyprintk off-by-one bug (fate#315019).
- x86/efi: Delete superfluous global variables (fate#315019).
- x86: Reserve setup_data ranges late after parsing memmap cmdline
  (fate#315019).
- x86: Export x86 boot_params to sysfs (fate#315019).
- x86: Add xloadflags bit for EFI runtime support on kexec
  (fate#315019).
- x86/efi: Pass necessary EFI data for kexec via setup_data
  (fate#315019).
- efi: Export EFI runtime memory mapping to sysfs (fate#315019).
- commit bdc7737
* Fri Feb  7 2014 bp@suse.de
- efi: Export more EFI table variables to sysfs (fate#315019).
- commit 9b2d60e
* Fri Feb  7 2014 bp@suse.de
- x86/efi: Cleanup efi_enter_virtual_mode() function
  (fate#315019).
- x86/efi: Fix off-by-one bug in EFI Boot Services reservation
  (fate#315019).
- x86/efi: Add a wrapper function efi_map_region_fixed()
  (fate#315019).
- x86/efi: Remove unused variables in __map_region()
  (fate#315019).
- x86/efi: Check krealloc return value (fate#315019).
- x86/efi: Runtime services virtual mapping (fate#315019).
- x86/mm/cpa: Map in an arbitrary pgd (fate#315019).
- x86/mm/pageattr: Add last levels of error path (fate#315019).
- x86/mm/pageattr: Add a PUD error unwinding path (fate#315019).
- x86/mm/pageattr: Add a PTE pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PMD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PUD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Add a PGD pagetable populating function
  (fate#315019).
- x86/mm/pageattr: Lookup address in an arbitrary PGD
  (fate#315019).
- x86/efi: Simplify EFI_DEBUG (fate#315019).
- commit 3d9c9e6
* Fri Feb  7 2014 hare@suse.de
- tty: Set correct tty name in 'active' sysfs attribute
  (bnc#861528).
- commit 8db11da
* Fri Feb  7 2014 mgorman@suse.de
- mm: create a separate slab for page->ptl allocation (Automatic
  NUMA Balancing (fate#315482)).
- mm: fix build of split ptlock code (Automatic NUMA Balancing
  (fate#315482)).
- commit 6ecfbc1
* Fri Feb  7 2014 mgorman@suse.de
- mm: do not allocate page->ptl dynamically, if spinlock_t fits to long
  (Automatic NUMA Balancing (fate#315482)).
- commit 2b665c5
* Fri Feb  7 2014 mgorman@suse.de
- mm: place page->pmd_huge_pte to right union (Automatic NUMA
  Balancing (fate#315482)).
- commit 1308e91
* Fri Feb  7 2014 mgorman@suse.de
- Delete patches.suse/mm-create-a-separate-slab-for-page-ptl-allocation.patch.
- commit 344f81d
* Fri Feb  7 2014 mq@suse.cz
- Makefile: Build with -Werror=date-time if the compiler
  supports it.
- x86: math-emu: Drop already-disabled print of build date.
- staging: wlags49_h2: Drop debug macro recording build date/time.
- staging: rts5139: Drop print of build time.
- staging: rtl8188eu: Drop print of build date/time.
- net: wireless: brcm80211: Drop debug version with build
  date/time.
- mtd: denali: Drop print of build date/time.
- commit 3a2bd83
* Fri Feb  7 2014 jbeulich@suse.com
- Add lost hunk to patches.xen/xen3-fixup-xen.
- commit 0a3ee0d
* Fri Feb  7 2014 neilb@suse.de
- Refresh patches.fixes/nfs-lockd.fix.
  bug fix
- commit 94eba25
* Fri Feb  7 2014 jjolly@suse.de
- Update config files. Added MLX4_EN_DCB and MLX4_DEBUG to s390x
- commit 1611de2
* Fri Feb  7 2014 spargaonkar@suse.com
- ipr: Increase msi-x interrupt vectors to 16 (bnc#858630
  FATE#315742).
- commit 2800001
* Thu Feb  6 2014 jbeulich@suse.com
- privcmd: allow preempting long running user-mode originating
  hypercalls (bnc#861093).
- /dev/mem: handle out-of-bounds read/write (FATE#310031).
- memblock: make memblock_set_node() support
  differentmemblock_type (Memory node hot-remove (fate#316483)).
- xen: properly account for _PAGE_NUMA during xen ptetranslations
  (Automatic NUMA Balancing (fate#315482)).
- Update Xen patches to 3.12.9 and c/s 1252.
- Update Xen config files.
- commit 9bf7dc5
* Thu Feb  6 2014 spargaonkar@suse.com
- config: Disable CONFIG_SCSI_IPR for x86_64 (FATE#315562).
  Withdrawn FATE request.
- commit 4c9488e
* Thu Feb  6 2014 mmarek@suse.cz
- Disable CONFIG_DRM_GMA600/GMA3600 for now
- commit c12b6dc
* Thu Feb  6 2014 jjolly@suse.de
- IB/core: Add support for RDMA_NODE_USNIC_UDP
  (bnc#860248,FATE#315827).
- commit 4a5a8c9
* Thu Feb  6 2014 jjolly@suse.de
- IB/core: Add RDMA_TRANSPORT_USNIC_UDP (bnc#860248,FATE#315827).
- commit 821aa46
* Thu Feb  6 2014 jjolly@suse.de
- IB/core: Add Cisco usNIC rdma node and transport types
  (bnc#860248,FATE #315827).
- commit 24d6dd1
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Set userspace/kernel ABI ver to 4
  (bnc#860248,FATE#315827).
- commit fb83124
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Remove unused variable in usnic_debugfs_exit()
  (bnc#860248,FATE#315827).
- commit 5947369
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Remove superflous parentheses
  (bnc#860248,FATE#315827).
- commit 5529b9b
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Fix typo "Ignorning" -> "Ignoring"
  (bnc#860248,FATE#315827).
- commit 6a43698
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Fix endianness-related warnings
  (bnc#860248,FATE#315827).
- commit d822376
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Expose flows via debugfs (bnc#860248,FATE#315827).
- commit 8bb1260
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add UDP support to usnic_fwd (bnc#860248,FATE#315827).
- commit 018a681
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add UDP support in u*verbs.c, u*main.c and u*util.h
  (bnc#860248,FATE#315827).
- commit 82f5a77
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add UDP support in usnic_ib_qp_grp
  (bnc#860248,FATE#315827).
- commit 329c84a
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Use GFP_ATOMIC under spinlock
  (bnc#860428,FATE#315827).
- commit 8ce32b0
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Use for_each_sg instead of a for-loop
  (bnc#860248,FATE#315827).
- commit 2197648
* Thu Feb  6 2014 trenn@suse.de
- intel_idle: Support Intel Atom Processor C2000 Product Family.
- commit e141359
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Update ABI and Version file for UDP support
  (bnc#860248,FATE#315827).
- commit b4f70d2
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Remove unused includes of <linux/version.h>
  (bnc#860248,FATE#315827).
- commit 17285f3
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Push all forwarding state to usnic_fwd
  (bnc#860248,FATE#315827).
- commit ea672e1
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Port over usnic_ib_qp_grp. to new usnic_fwd.h
  (bnc#860248,FATE#315827).
- commit d083da3
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Port over sysfs to new usnic_fwd.h
  (bnc#860248,FATE#315827).
- commit 129836d
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Port over main.c and verbs.c to the usnic_fwd.h
  (bnc#860248,FATE#315827).
- commit ec67334
* Thu Feb  6 2014 mgorman@suse.de
- xen: properly account for _PAGE_NUMA during xen pte translations
  (Automatic NUMA Balancing (fate#315482)).
- mm: Warn users of node memory hot-remove if the memory ratio
  is a high risk (Memory node hot-remove (fate#316483)).
- commit d410f10
* Thu Feb  6 2014 mgorman@suse.de
- ACPI / tables: Check if id is NULL in acpi_table_parse()
  (Memory node hot-remove (fate#316483)).
- ACPI / tables: Return proper error codes from acpi_table_parse()
  and fix comment (Memory node hot-remove (fate#316483)).
- x86/mm/numa: Fix 32-bit kernel NUMA boot (Memory node hot-remove
  (fate#316483)).
- x86, numa, acpi, memory-hotplug: make movable_node have higher
  priority (Memory node hot-remove (fate#316483)).
- memblock, mem_hotplug: make memblock skip hotpluggable regions
  if needed (Memory node hot-remove (fate#316483)).
- acpi, numa, mem_hotplug: mark all nodes the kernel resides
  un-hotpluggable (Memory node hot-remove (fate#316483)).
- acpi, numa, mem_hotplug: mark hotpluggable memory in memblock
  (Memory node hot-remove (fate#316483)).
- memblock: make memblock_set_node() support different
  memblock_type (Memory node hot-remove (fate#316483)).
- memblock, mem_hotplug: introduce MEMBLOCK_HOTPLUG flag to mark
  hotpluggable regions (Memory node hot-remove (fate#316483)).
- memblock, numa: introduce flags field into memblock (Memory
  node hot-remove (fate#316483)).
- mm/memblock: debug: correct displaying of upper memory boundary
  (Memory node hot-remove (fate#316483)).
- commit ceebf83
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Change WARN_ON to lockdep_assert_held
  (bnc#860248,FATE#315827).
- commit 09261b1
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Append documentation to usnic_transport.h and cleanup
  (bnc#860248,FATE#315827).
- commit 37e8858
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Advertise usNIC devices as RDMA_NODE_USNIC_UDP
  (bnc#860248,FATE#315827).
- commit b64bc46
* Thu Feb  6 2014 jjolly@suse.de
- IB:usnic: Add UDP support to usnic_transport (FATE #315827).
- commit e2189b9
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add struct usnic_transport_spec
  (bnc#860248,FATE#315827).
- commit d5442f7
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add dependency on CONFIG_INET (FATE #315827).
- commit ad30bde
* Thu Feb  6 2014 jjolly@suse.de
- Update config files.
- commit c5c3210
* Thu Feb  6 2014 jjolly@suse.de
- IB/usnic: Add Cisco VIC low-level hardware driver
  (bnc#860248,FATE #315827).
- commit a22faf4
* Thu Feb  6 2014 neilb@suse.de
- Avoid occasional hang with NFS (bnc#852488).
- commit 111a644
* Thu Feb  6 2014 jlee@suse.com
- Refresh patches of firmware signature check and enable CONFIG_MODULE_SIG
- Update config files.
- Refresh
  patches.suse/0001-firmware_Add_the_firmware_signing_support_to_scripts_sign-file.patch.
- Refresh
  patches.suse/0003-firmware_Add_support_for_signature_checks.patch.
- Refresh
  patches.suse/0004-firmware_Install_firmware_signature_files_automatically.patch.
- commit 6764aff
* Thu Feb  6 2014 jjolly@suse.de
- s390/smp: improve setup of possible cpu mask (bnc#859260,
  LTC#102688).
- Update config files.
- commit 873da72
* Thu Feb  6 2014 jjolly@suse.de
- s390/smp,sclp: fix size of sclp_cpu_info structure (bnc#859260,
  LTC#102688).
- commit 26078fb
* Thu Feb  6 2014 jjolly@suse.de
- Update config files.
- commit 79ff2ad
* Thu Feb  6 2014 jjolly@suse.de
- s390: increase CONFIG_NR_CPUS limit (bnc#859260,LTC#103006).
- Update config files.
- commit d280219
* Thu Feb  6 2014 neilb@suse.de
- lockd: send correct lock when granting a delayed lock
  (bnc#859342).
- commit 4ba667c
* Thu Feb  6 2014 jjolly@suse.de
- Refresh
  patches.arch/s390-sles12-00-05-qeth-Accurate-ethtool-output.patch.
  - Refreshed because of the removal of...
- Delete
  patches.arch/s390-sles12-00-04-ethtool-display_switch_port_mode-1.patch.
- Delete
  patches.arch/s390-sles12-00-04-ethtool-display_switch_port_mode-2.patch.
  - Both patches delayed and not accepted upstream. Possibly to be brought
    back in SLE12 SP1 (bnc#855818)
- commit a4fa4cc
* Thu Feb  6 2014 mgalbraith@suse.de
- Disable CONFIG_RCU_NOCB_CPU in all configs
- commit 94173c6
* Thu Feb  6 2014 jlee@suse.com
- Refresh patches.xen/xen-x86-EFI.
  After applied 20658586ce1605a517d94aee2a3db26cb3ed46e1, need refresh
  patches.xen/xen-x86-EFI.
- commit b470b4f
* Wed Feb  5 2014 jjolly@suse.de
- ib_uverbs: Allow explicit mmio trigger (fate#315287, LTC#94186).
- Delete
  patches.arch/s390-sles12-00-03-pci-ofed-uverbs_add_kwrite-mmio.patch.
- commit f332d62
* Wed Feb  5 2014 bp@suse.de
- x86/efi: Fix config_table_type array termination (fate#315017).
- efi: x86: make efi_lookup_mapped_addr() a common function
  (fate#315017).
- commit 4d55c48
* Wed Feb  5 2014 bp@suse.de
- efi: x86: ia64: provide a generic efi_config_init() (fate#315017).
- commit 33af896
* Wed Feb  5 2014 tiwai@suse.de
- iwlwifi: add new devices for 7265 series (FATE#316958).
- iwlwifi: mvm: use a cast to calculate the last seqno from the
  next one (FATE#316958).
- iwlwifi: mvm: set seqno also when no keys are set (FATE#316958).
- iwlwifi: pcie: stop sending commands to dead firmware
  (FATE#316958).
- iwlwifi: bump required firmware API version for 3160/7260
  (FATE#316958).
- iwlwifi: mvm: don't WARN about unsuccessful time event
  (FATE#316958).
- iwlwifi: mvm: BT Coex fix another NULL pointer dereference
  (FATE#316958).
- iwlwifi: mvm: BT Coex - don't enable MULTI_PRIO_LUT
  (FATE#316958).
- iwlwifi: add new HW - 7265 series (FATE#316958).
- iwlwifi: mvm: BT Coex - fix copy paste issue (FATE#316958).
- iwlwifi: remove duplicate includes (FATE#316958).
- iwlwifi: warn if firmware image doesn't exist (FATE#316958).
- iwlwifi: mvm: add missing break in debugfs (FATE#316958).
- iwlwifi: mvm: capture the FCS in monitor mode (FATE#316958).
- iwlwifi: pcie: move warning message into warning (FATE#316958).
- iwlwifi: mvm: BT Coex fix NULL pointer dereference
  (FATE#316958).
- iwlwifi: transport config n_no_reclaim_cmds should be unsigned
  (FATE#316958).
- iwlwifi: mvm: update UAPSD support TLV bits (FATE#316958).
- iwlwifi: mvm: fix scan request's suspend time parameter
  (FATE#316958).
- iwlwifi: don't WARN on bad firmware state (FATE#316958).
- iwlwifi: pcie: poke device when commands don't complete quickly
  (FATE#316958).
- iwlwifi: mvm: fix operator precedence (FATE#316958).
- iwlwifi: mvm: fix fw_rx_stats debugfs entry (FATE#316958).
- iwlwifi: mvm: BT Coex - enable Tx power based on BT status
  (FATE#316958).
- iwlwifi: mvm: BT Coex - always set mandatory fields
  (FATE#316958).
- iwlwifi: mvm: NVM - increase max section size (FATE#316958).
- iwlwifi: support Signed firmware image and Dual CPUs
  (FATE#316958).
- iwlwifi: Support 7265 devices (FATE#316958).
- iwlwifi: mvm: BT Coex - update integration with rate control
  (FATE#316958).
- iwlwifi: mvm: BT Coex - remove duplicate code in rate control
  (FATE#316958).
- iwlwifi: mvm: BT Coex - start AMPDU even when BT is active
  (FATE#316958).
- iwlwifi: mvm: BT Coex - tune SMPS parameters (FATE#316958).
- iwlwifi: mvm: BT Coex - track bandwidth changes in HT
  (FATE#316958).
- iwlwifi: mvm: keep connection to AP after WoWLAN (FATE#316958).
- iwlwifi: mvm: add support for NICs which have only 16 Tx queues
  (FATE#316958).
- iwlwifi: mvm: prevent the NIC to be powered at driver load time
  (FATE#316958).
- iwlwifi: mvm: Add device wide power command (FATE#316958).
- iwlwifi: pcie: restart the driver when a command times out
  (FATE#316958).
- iwlwifi: mvm: BT Coex - set the proper LUT for single ant
  devices (FATE#316958).
- iwlwifi: mvm: BT Coex - don't limit agg size in loose scheme
  (FATE#316958).
- wireless: iwlwifi: remove unnecessary pci_set_drvdata()
  (FATE#316958).
- iwlwifi: pcie: dump_stack upon timeout of SYNC cmd
  (FATE#316958).
- iwlwifi: mvm: change the name of init_ucode_run flag
  (FATE#316958).
- iwlwifi: mvm: implement new IPv6 offload API (FATE#316958).
- iwlwifi: mvm: BT Coex - Correctly enable and treat rssi events
  (FATE#316958).
- iwlwifi: mvm: BT Coex - adapt debugfs to new API (FATE#316958).
- iwlwifi: mvm: don't use reduced Tx power when not applicable
  (FATE#316958).
- iwlwifi: mvm: make debugfs write() operations write up to
  count bytes (FATE#316958).
- iwlwifi: mvm: remove GF support in rs (FATE#316958).
- iwlwifi: mvm: support VHT in rs (FATE#316958).
- iwlwifi: mvm: BT Coex - use data from firmware (FATE#316958).
- iwlwifi: mvm: BT Coex - no need to send envelopes (FATE#316958).
- iwlwifi: mvm: new BT Coex API (FATE#316958).
- iwlwifi: mvm: support sched scan if supported by the fw
  (FATE#316958).
- iwlwifi: mvm: add no_basic_ssid option (FATE#316958).
- iwlwifi: mvm: don't sleep while allocating in atomic context
  (FATE#316958).
- iwlwifi: mvm: update expected tpt tables for VHT (FATE#316958).
- iwlwifi: mvm: fix switch from shared antenna in case of BT load
  (FATE#316958).
- iwlwifi: pcie: clean RFKILL interrupt in AMPG (FATE#316958).
- iwlwifi: mvm: split ADD_STA and ADD_STA_KEY in firmware API
  (FATE#316958).
- iwlwifi: mvm: Adjust some power management constants
  (FATE#316958).
- iwlwifi: mvm: fix locking in iwl_mvm_bt_rssi_event()
  (FATE#316958).
- iwlwifi: mvm: Implement BT coex notifications (FATE#316958).
- iwlwifi: mvm: give client MACs time to synchronise during
  restart (FATE#316958).
- iwlwifi: mvm: remove rs FSM actions relevant only for 3 antennas
  (FATE#316958).
- iwlwifi: mvm: use CTS to Self if firmware allows it
  (FATE#316958).
- iwlwifi: mvm: debugfs: add an option to set antennas for scan
  command (FATE#316958).
- iwlwifi: mvm: query firmware for non-QoS seqno (FATE#316958).
- iwlwifi: mvm: implement beacon filtering testmode command
  (FATE#316958).
- iwlwifi: mvm: implement NoA testing using testmode cmd
  (FATE#316958).
- mac80211: add ieee80211_iterate_active_interfaces_rtnl()
  (FATE#316958).
- commit 944a30b
* Wed Feb  5 2014 mmarek@suse.cz
- Change also BuildRequires from module-init-tools to modutils
- commit f650166
* Wed Feb  5 2014 spargaonkar@suse.com
- Revert "config: Remove CONFIG_SCSI_IPR for x86_64 (FATE#315562)."
  Build errors.
  This reverts commit 091061beaa32347b4ff5d483caea0dba2915327b.
- commit 5c29981
* Wed Feb  5 2014 jdelvare@suse.de
- rapidio: Build core as a module on PPC64 too
  Now all the supported architectures do it the same way.
- commit 740f181
* Wed Feb  5 2014 jdelvare@suse.de
- supported.conf: Add acpi_power_meter, fam15h_power and jc42
  All 3 hwmon drivers were supported in SLE11 SP3.
- commit 290215f
* Wed Feb  5 2014 spargaonkar@suse.com
- config: Remove CONFIG_SCSI_IPR for x86_64 (FATE#315562).
  Withdrawn FATE request.
- commit 091061b
* Wed Feb  5 2014 bp@suse.de
- i2c: piix4: Use different message for AMD Auxiliary SMBus Controller (bnc#860416).
- commit ba6c32b
* Wed Feb  5 2014 jlee@suse.com
- Removed old patches that were respined for secure boot lock functions
  and kernel module blacklist
- Delete patches.suse/0002-Add-EFI-signature-data-types.patch.
- Delete
  patches.suse/0003-Add-an-EFI-signature-blob-parser-and-key-loader.patch.
- Delete
  patches.suse/0004-EFI-Add-in-kernel-variable-to-determine-if-Secure-Boot-is-enabled.patch.
- Delete
  patches.suse/0005-MODSIGN-Add-module-certificate-blacklist-keyring.patch.
- Delete
  patches.suse/0006-MODSIGN-Import-certificates-from-UEFI-Secure-Boot-v3.patch.
- Delete
  patches.suse/0007-Dont-soft-lockup-on-bad-EFI-signature-lists.patch.
- Delete
  patches.suse/0007_Secure_boot_Add_a_dummy_kernel_parameter_that_will_switch_on_Secure_Boot_mode_v2.patch.
- Delete
  patches.suse/0010_SELinux_define_mapping_for_new_Secure_Boot_capability_v2.patch.
- commit 124aecf
* Wed Feb  5 2014 lduncan@suse.com
- qla4xxx: v5.04.00.00.12.0-k1 (FATE#315934 bnc#862073).
- qla4xxx: Fix sparse warnings (FATE#315934 bnc#862073).
- qla4xxx: Handle IPv6 AEN notifications (FATE#315934 bnc#862073).
- qla4xxx: Update print statements in func qla4xxx_do_dpc()
  (FATE#315934 bnc#862073).
- qla4xxx: Update print statements in func qla4xxx_eh_abort()
  (FATE#315934 bnc#862073).
- qla4xxx: Update print statements in qla4xxx_mailbox_command()
  (FATE#315934 bnc#862073).
- qla4xxx: Updated print for device login, logout path
  (FATE#315934 bnc#862073).
- qla4xxx: Remove unused code from qla4xxx_set_ifcb() (FATE#315934
  bnc#862073).
- qla4xxx: Fix failure of mbox 0x31 (FATE#315934 bnc#862073).
- qla4xxx: Reduce rom-lock contention during reset recovery
  (FATE#315934 bnc#862073).
- qla4xxx: Clear DDB index map upon connection close failure
  (FATE#315934 bnc#862073).
- qla4xxx: Fix pending IO completion in reset path before
  initiating chip reset (FATE#315934 bnc#862073).
- qla4xxx: Fix processing response queue during probe (FATE#315934
  bnc#862073).
- qla4xxx: Fix failure of IDC Time Extend mailbox command
  (FATE#315934 bnc#862073).
- qla4xxx: Return correct error status from func
  qla4xxx_request_irqs() (FATE#315934 bnc#862073).
- qla4xxx: Fixed AER reset sequence for ISP83xx/ISP84xx
  (FATE#315934 bnc#862073).
- qla4xxx: Correctly handle msleep_interruptible (FATE#315934
  bnc#862073).
- qla4xxx: Rename ACB_STATE macros with IP_ADDRSTATE macros
  (FATE#315934 bnc#862073).
- qla4xxx: Improve loopback failure messages (FATE#315934
  bnc#862073).
- qla4xxx: Use IDC_CTRL bit1 directly instead of AF_83XX_NO_FWDUMP
  flag (FATE#315934 bnc#862073).
- qla4xxx: Fix comments in code (FATE#315934 bnc#862073).
- qla4xxx: Print WARN_ONCE() if iSCSI function presence bit
  removed (FATE#315934 bnc#862073).
- qla4xxx: ISP8xxx: Correct retry of adapter initialization
  (FATE#31        5934 bnc#862073).
- commit f4a5cd7
* Tue Feb  4 2014 ohering@suse.de
- Tools: hv: remove inclusion of linux/types.h.
- drivers: hv: Mark the function hv_synic_free_cpu() as static
  in hv.c.
- hyperv: Add support for physically discontinuous receive buffer.
- commit 3948a58
* Tue Feb  4 2014 jeffm@suse.com
- Updated patch headers for 3.14-rc1.
- commit 589929a
* Tue Feb  4 2014 mmarek@suse.cz
- Disable CONFIG_X86_X32 (not requested for SLE)
- commit c9def69
* Tue Feb  4 2014 mmarek@suse.cz
- Disable CONFIG_NET_CADENCE on non-ARM
- commit c2bb26e
* Tue Feb  4 2014 mmarek@suse.cz
- Drop Big-endian ppc64 configs
- commit 1660fc5
* Tue Feb  4 2014 mmarek@suse.cz
- Disable CONFIG_SECURITY_TOMOYO
- commit b251efd
* Tue Feb  4 2014 mmarek@suse.cz
- Disable CONFIG_IP_PNP (bnc#822825)
- commit 440151b
* Tue Feb  4 2014 jkosina@suse.cz
- Update config files: enable SECURITY_DMESG_RESTRICT (FATE#315175)
- commit d76eff2
* Tue Feb  4 2014 jkosina@suse.cz
- Update config files: re-enable CONFIG_PROC_KCORE, it's needed for kdump.
- commit 8a14703
* Tue Feb  4 2014 spargaonkar@suse.com
- md/raid5: fix long-standing problem with bitmap handling on
  write failure (FATE#315669).
- md/raid5.c: add proper locking to error path of
  raid5_start_reshape (FATE#315669).
- commit f39d7b1
* Fri Jan 31 2014 mgorman@suse.de
- Update config files to disable THP on ppc64le by default
- commit 798b4c2
* Fri Jan 31 2014 mmarek@suse.cz
- Disable unsupported AFS and RXRPC (fate#315021)
- commit 50e87af
* Fri Jan 31 2014 hare@suse.de
- con3270: Use correct name for console driver (bnc#861528).
- commit 9f8e683
* Fri Jan 31 2014 mgorman@suse.de
- sched/numa: Turn some magic numbers into #defines (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Rename variables in task_numa_fault() (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Do statistics calculation using local variables only
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Normalize faults_cpu stats and weigh by CPU use
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa, mm: Use active_nodes nodemask to limit numa
  migrations (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Build per numa_group active node mask from
  numa_faults_cpu statistics (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Track from which nodes NUMA faults are triggered
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Rename p->numa_faults to numa_faults_memory
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa, mm: Remove p->numa_migrate_deferred (Automatic
  NUMA Balancing (fate#315482)).
- commit fd89121
* Fri Jan 31 2014 ptesarik@suse.cz
- Delete patches.arch/x86-physnode_map-init.patch.
  This patch is only useful on 32-bit x86 => not needed for SLE12.
- commit 7c54f56
* Fri Jan 31 2014 adrian@suse.de
- avoid double /sys mounts for kernel-obs-build, OBS is doing this meanwhile
- commit 3ea39a4
* Thu Jan 30 2014 jkosina@suse.cz
- floppy: bail out in open() if drive is not responding to block0
  read (bnc#773058).
- commit 9e6aafb
* Thu Jan 30 2014 ptesarik@suse.cz
- Refresh
  patches.suse/0006_V3_Restrict__dev_mem_and__dev_kmem_when_module_loading_is_restricted.patch.
- commit a886859
* Thu Jan 30 2014 ptesarik@suse.cz
- /dev/mem: handle out-of-bounds read/write (FATE#310031).
- Delete patches.suse/dev_mem-read-write-phys_addr_t.patch.
- Delete patches.suse/valid_phys_addr_range-use-phys_addr_t.patch.
- Delete patches.suse/xlate_dev_mem_ptr-use-phys_addr_t.patch.
- commit dd36d6a
* Thu Jan 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require 'modutils' also in the subpackages
- commit 91f0a2e
* Thu Jan 30 2014 mmarek@suse.cz
- Reformat the spec files to what the buildservice expects
- commit 0b9e9a1
* Thu Jan 30 2014 jbohac@suse.cz
- Delete
  patches.fixes/keep-tick_do_timer_cpu-on-CPU0-with-nohz-off.patch.
  Upstream commit f5d00c1f9adb350c24c5301600f7bf2da99b66de.
- commit ee44133
* Thu Jan 30 2014 jbohac@suse.cz
- Delete
  patches.fixes/ipv6-xfrm-use-conntrack-reassembled-packet-for-policy-lookup.patch.
  Original problem solved by upstream patch 6aafeef03b9d9ecf255f3a80ed85ee070260e1ae,
  backported to stable 3.12.4
- commit 98c1d8d
* Thu Jan 30 2014 ptesarik@suse.cz
- Delete patches.trace/utrace-core.patch.
  utrace was technology preview in SLE11, but since it never made it into
  mainline, it is no longer needed.
- commit a121d91
* Wed Jan 29 2014 jbohac@suse.cz
- temporarily disable
  patches.fixes/ipv6-xfrm-use-conntrack-reassembled-packet-for-policy-lookup.patch
  to fix build
- commit 0ce64ff
* Wed Jan 29 2014 spargaonkar@suse.com
- md/raid1: fix request counting bug in new 'barrier' code
  (FATE#315669).
- raid1: Rewrite the implementation of iobarrier (FATE#315669).
- raid1: Add some macros to make code clearly (FATE#315669).
- raid1: Replace raise_barrier/lower_barrier with
  freeze_array/unfreeze_array when reconfiguring the array
  (FATE#315669).
- raid1: Add a field array_frozen to indicate whether raid in
  freeze state (FATE#315669).
- commit 6398e24
* Wed Jan 29 2014 spargaonkar@suse.com
- md/raid5: avoid deadlock when raid5 array has unack badblocks
  during md_stop_writes (FATE#315669).
- md: use MD_RECOVERY_INTR instead of kthread_should_stop in
  resync thread (FATE#315669).
- md: fix some places where mddev_lock return value is not checked
  (FATE#315669).
- commit 927b3d1
* Wed Jan 29 2014 bpoirier@suse.de
- netxen_nic: Update version to 4.0.82 (bnc#853679 FATE#315937).
- netxen_nic: Print ULA information (bnc#853679 FATE#315937).
- commit 985d27e
* Wed Jan 29 2014 lduncan@suse.com
- Moved be2iscsi and qla4xxx patches to iscsi area
- commit 92e1f37
* Wed Jan 29 2014 mmarek@suse.cz
- Disable CONFIG_ATALK and unsupported network modules (fate#315021)
- commit 66ad060
* Wed Jan 29 2014 bpoirier@suse.de
- net/mlx4_core: Remove unnecessary validation for port number
  (bnc#858727 FATE#315946).
- IB/mlx5: Verify reserved fields are cleared (bnc#858727
  FATE#315946).
- IB/mlx5: Remove old field for create mkey mailbox (bnc#858727
  FATE#315946).
- IB/mlx5: Abort driver cleanup if teardown hca fails (bnc#858727
  FATE#315946).
- IB/mlx5: Allow creation of QPs with zero-length work queues
  (bnc#858727 FATE#315946).
- mlx5_core: Fix PowerPC support (bnc#858727 FATE#315946).
- mlx5_core: Improve debugfs readability (bnc#858727 FATE#315946).
- IB/mlx5: Add support for resize CQ (bnc#858727 FATE#315946).
- IB/mlx5: Implement modify CQ (bnc#858727 FATE#315946).
- IB/mlx5: Make sure doorbell record is visible before doorbell
  (bnc#858727 FATE#315946).
- mlx5_core: Use mlx5 core style warning (bnc#858727 FATE#315946).
- IB/mlx5: Clear out struct before create QP command (bnc#858727
  FATE#315946).
- IB/mlx5: Fix micro UAR allocator (bnc#858727 FATE#315946).
- IB/mlx5: Remove unused code in mr.c (bnc#858727 FATE#315946).
- net/mlx4_core: Warn if device doesn't have enough PCI bandwidth
  (bnc#858727 FATE#315946).
- mlx4_en: Only cycle port if HW timestamp config changes
  (bnc#858727 FATE#315946).
- mlx4_en: Add PTP hardware clock (bnc#858727 FATE#315946).
- net: mlx4: slight optimization of addr compare (bnc#858727
  FATE#315946).
- IB/uverbs: Check access to userspace response buffer in extended
  command (bnc#858727 FATE#315946).
- IB/uverbs: Check input length in flow steering uverbs
  (bnc#858727 FATE#315946).
- IB/uverbs: Set error code when fail to consume all flow_spec
  items (bnc#858727 FATE#315946).
- IB/uverbs: Check reserved fields in create_flow (bnc#858727
  FATE#315946).
- IB/uverbs: Check comp_mask in destroy_flow (bnc#858727
  FATE#315946).
- IB/uverbs: Check reserved field in extended command header
  (bnc#858727 FATE#315946).
- net/mlx4_en: Add netdev support for TCP/IP offloads of vxlan
  tunneling (bnc#858727 FATE#315946).
- net/mlx4_core: Add basic support for TCP/IP offloads under
  tunneling (bnc#858727 FATE#315946).
- net/mlx4_core: Check port number for validity before accessing
  data (bnc#858727 FATE#315946).
- net/mlx4_en: Add NAPI support for transmit side (bnc#858727
  FATE#315946).
- net/mlx4_en: Ignore irrelevant hypervisor events (bnc#858727
  FATE#315946).
- net/mlx4_core: Set CQE/EQE size to 64B by default (bnc#858727
  FATE#315946).
- net/mlx4_en: Configure the XPS queue mapping on driver load
  (bnc#858727 FATE#315946).
- net/mlx4_en: Implement ndo_get_phys_port_id (bnc#858727
  FATE#315946).
- net/mlx4_core: Expose physical port id as PF/VF capability
  (bnc#858727 FATE#315946).
- net/mlx4_core: Introduce nic_info new flag in QUERY_FUNC_CAP
  (bnc#858727 FATE#315946).
- net/mlx4_core: Rename QUERY_FUNC_CAP fields (bnc#858727
  FATE#315946).
- net/mlx4_core: Remove zeroed out of explicit QUERY_FUNC_CAP
  fields (bnc#858727 FATE#315946).
- mlx4_core: Roll back round robin bitmap allocation commit for
  CQs, SRQs, and MPTs (bnc#858727 FATE#315946).
- net/mlx4_core: destroy workqueue when driver fails to register
  (bnc#858727 FATE#315946).
- net/mlx4_en: Remove selftest TX queues empty condition
  (bnc#858727 FATE#315946).
- IB/core: Re-enable create_flow/destroy_flow uverbs (bnc#858727
  FATE#315946).
- IB/core: extended command: an improved infrastructure for
  uverbs commands (bnc#858727 FATE#315946).
- IB/core: Remove ib_uverbs_flow_spec structure from userspace
  (bnc#858727 FATE#315946).
- IB/core: Use a common header for uverbs flow_specs (bnc#858727
  FATE#315946).
- IB/core: Make uverbs flow structure use names like verbs ones
  (bnc#858727 FATE#315946).
- IB/core: Rename 'flow' structs to match other uverbs structs
  (bnc#858727 FATE#315946).
- IB/core: clarify overflow/underflow checks on
  ib_create/destroy_flow (bnc#858727 FATE#315946).
- IB/mlx5: Fix page shift in create CQ for userspace (bnc#858727
  FATE#315946).
- IB/mlx4: Fix device max capabilities check (bnc#858727
  FATE#315946).
- IB/mlx5: Fix list_del of empty list (bnc#858727 FATE#315946).
- IB/mlx5: Remove dead code (bnc#858727 FATE#315946).
- IB/mlx4: Fix endless loop in resize CQ (bnc#858727 FATE#315946).
- mlx5: Use enum to indicate adapter page size (bnc#858727
  FATE#315946).
- IB/mlx5: Update opt param mask for RTS2RTS (bnc#858727
  FATE#315946).
- IB/mlx5: Remove "Always false" comparison (bnc#858727
  FATE#315946).
- IB/mlx5: Remove dead code in mr.c (bnc#858727 FATE#315946).
- mlx5_core: Change optimal_reclaimed_pages for better performance
  (bnc#858727 FATE#315946).
- mlx5: Clear reserved area in set_hca_cap() (bnc#858727
  FATE#315946).
- mlx5: Support communicating arbitrary host page size to firmware
  (bnc#858727 FATE#315946).
- mlx5: Fix cleanup flow when DMA mapping fails (bnc#858727
  FATE#315946).
- IB/mlx5: Fix srq free in destroy qp (bnc#858727 FATE#315946).
- IB/mlx5: Simplify mlx5_ib_destroy_srq (bnc#858727 FATE#315946).
- IB/mlx5: Fix overflow check in IB_WR_FAST_REG_MR (bnc#858727
  FATE#315946).
- IB/mlx5: Multithreaded create MR (bnc#858727 FATE#315946).
- IB/mlx5: Fix check of number of entries in create CQ (bnc#858727
  FATE#315946).
- IPoIB: lower NAPI weight (bnc#858727 FATE#315946).
- IPoIB: Start multicast join process only on active ports
  (bnc#858727 FATE#315946).
- IPoIB: Add path query flushing in ipoib_ib_dev_cleanup
  (bnc#858727 FATE#315946).
- IPoIB: Fix usage of uninitialized multicast objects (bnc#858727
  FATE#315946).
- IPoIB: Avoid flushing the driver workqueue on dev_down
  (bnc#858727 FATE#315946).
- IPoIB: Fix deadlock between dev_change_flags() and
  __ipoib_dev_flush() (bnc#858727 FATE#315946).
- IPoIB: Change CM skb memory allocation to be non-atomic during
  init (bnc#858727 FATE#315946).
- IPoIB: Fix crash in dev_open error flow (bnc#858727
  FATE#315946).
- net/mlx4_en: Datapath structures are allocated per NUMA node
  (bnc#858727 FATE#315946).
- net/mlx4_core: ICM pages are allocated on device NUMA node
  (bnc#858727 FATE#315946).
- net/mlx4_en: Datapath resources allocated dynamically
  (bnc#858727 FATE#315946).
- net/mlx4_core: Add immediate activate for VGT->VST->VGT
  (bnc#858727 FATE#315946).
- net/mlx4_core: Initialize all mailbox buffers to zero before
  use (bnc#858727 FATE#315946).
- net/mlx4_en: Add RFS support in UDP (bnc#858727 FATE#315946).
- net/mlx4_core: Implement resource quota enforcement (bnc#858727
  FATE#315946).
- net/mlx4_core: Fix quota handling in the QUERY_FUNC_CAP wrapper
  (bnc#858727 FATE#315946).
- mlx4: Structures and init/teardown for VF resource quotas
  (bnc#858727 FATE#315946).
- net/mlx4_core: Fix checking order in MR table init (bnc#858727
  FATE#315946).
- net/mlx4_core: Don't fail reg/unreg vlan for older guests
  (bnc#858727 FATE#315946).
- net/mlx4_core: Resource tracker for reg/unreg vlans (bnc#858727
  FATE#315946).
- net/mlx4_en: Use vlan id instead of vlan index for
  unregistration (bnc#858727 FATE#315946).
- net/mlx4_core: Fix reg/unreg vlan/mac to conform to the firmware
  spec (bnc#858727 FATE#315946).
- net/mlx4_core: Fix register/unreg vlan flow (bnc#858727
  FATE#315946).
- net/mlx4_core: Load higher level modules according to ports type
  (bnc#858727 FATE#315946).
- net/mlx4: Unused local variable in mlx4_opreq_action (bnc#858727
  FATE#315946).
- net/mlx4: Fix typo, move similar defs to same location
  (bnc#858727 FATE#315946).
- net/mlx4: Clean the code to eliminate trivial build warnings
  (bnc#858727 FATE#315946).
- treewide: Fix typo in printk (bnc#858727 FATE#315946).
- commit b3fade1
* Wed Jan 29 2014 bpoirier@suse.de
- Disable patches.arch/s390-sles12-00-03-pci-ofed-uverbs_add_kwrite-mmio.patch
  This patch conflicts with the forthcoming mlx updates. It is also not
  upstream. Therefore I think it should be moved later in the series and
  refreshed. Also, that patch has been lumped with "arch" patches despite the
  fact that it touches infiniband code only.
- commit 6080089
* Wed Jan 29 2014 jbohac@suse.cz
- Delete patches.fixes/ipv6-fix-dst-expires-race-condition.patch.
  Fixed by upstream patch ecd9883724b78cc72ed92c98bcb1a46c764fff21
- commit c2ed495
* Wed Jan 29 2014 jbohac@suse.cz
- Refresh
  patches.fixes/ipv6-xfrm-use-conntrack-reassembled-packet-for-policy-lookup.patch.
- commit 4e4754a
* Wed Jan 29 2014 mgorman@suse.de
- Refresh
  patches.fixes/cpuset-mm-optimise-put_mems_allowed-usage.patch.
- commit e78bc38
* Wed Jan 29 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 07385d9
* Wed Jan 29 2014 vbabka@suse.cz
- mm: compaction: reset scanner positions immediately when they
  meet (VM Functionality).
- mm: compaction: do not mark unmovable pageblocks as skipped
  in async compaction (VM Functionality).
- mm: compaction: detect when scanners meet in isolate_freepages
  (VM Functionality).
- mm: compaction: reset cached scanner pfn's before reading them
  (VM Functionality).
- mm: compaction: encapsulate defer reset logic (VM
  Functionality).
- mm: compaction: trace compaction begin and end (VM
  Functionality).
- commit 1d243ed
* Wed Jan 29 2014 mgorman@suse.de
- mm, mempolicy: make mpol_to_str robust and always succeed
  (Automatic NUMA Balancing (fate#315482)).
- commit 9ec9fcd
* Wed Jan 29 2014 mgorman@suse.de
- mm: Handle possibility of preemption in spin_trylock_page() and cancel
- mm: filemap: Avoid unnecessary barries and waitqueue lookup
- mm: filemap: Optimise __lock_page_or_retry() by emulating an adaptive sleeping spinlock
- mm: filemap: Optimise __lock_pages() by emulating an adaptive sleeping spinlock
- mm: use cpu_chill() in spin_trylock_page() and cancel (RT-Only)
  (VM performance, lock page scalability (bnc#436953, bnc#629170)).
- commit 1ca2d86
* Wed Jan 29 2014 mgorman@suse.de
- Delete patches.fixes/mm-call-sleep_on_page_killable-in-__wait_on_page_locked_killable.patch.
- Delete patches.suse/lock_page-priority-inversion-fix.patch.
- Delete patches.suse/lock_page-speedup.patch.
- Delete patches.suse/lock_page_or_retry-speedup.patch.
- Delete patches.suse/mm-Fix-add_page_wait_queue-to-work-for-locked.patch.
- Delete patches.suse/mm-use-cpu_chill-in-spin_trylock_page.patch.
- Delete patches.suse/unlock_page-speedup.patch.
- commit 487ef2c
* Wed Jan 29 2014 mgorman@suse.de
- mm: ignore VM_SOFTDIRTY on VMA merging
  (VM functionality).
- commit ec9da8f
* Wed Jan 29 2014 mgorman@suse.de
- mm/mempolicy.c: fix mempolicy printing in numa_maps
  (Automatic NUMA Balancing (fate#315482)).
- commit 79791bd
* Tue Jan 28 2014 jack@suse.cz
- Delete patches.suse/cfq-turn-lowlatency-off-by-default.patch
  - CFQ scheduling logic has changed significantly since 3.0 and it
    shouldn't be needed.
- commit 62f083e
* Tue Jan 28 2014 jkosina@suse.cz
- Delete patches.arch/Disable-ERST-pstore-by-default.patch: the issue turned
  out to be caused by buggy BIOS.
- commit cf75990
* Tue Jan 28 2014 jkosina@suse.cz
- Delete patches.fixes/ia64-select-mmu-notifier-for-sgi-xp.patch: drop
  ia64-specific patch
- commit 69088cb
* Tue Jan 28 2014 jkosina@suse.cz
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/fix-TAINT_NO_SUPPORT-handling-on-module-load.patch.
  Fold fixup patch into the main one.
- commit 7e4561d
* Tue Jan 28 2014 spargaonkar@suse.com
- mm/zswap.c: change params from hidden to ro (FATE#315454).
- mm/zswap: refactor the get/put routines (FATE#315454).
- mm/zswap: avoid unnecessary page scanning  (FATE#315454).
- commit 8a43001
* Tue Jan 28 2014 spargaonkar@suse.com
- Revert "mm/zswap: avoid unnecessary page scanning  (FATE#315454)."
  This reverts commit e9788a3806361c0c4cca2a75bb34a02d1ba8092b.
  build errors
- commit 31edf17
* Tue Jan 28 2014 spargaonkar@suse.com
- Revert "mm/zswap: bugfix: memory leak when invalidate and reclaim"
  This reverts commit cbf81920fefaf3aabd20e1288a96fb4f86875058.
  build errors
- commit b449783
* Tue Jan 28 2014 spargaonkar@suse.com
- Revert "mm/zswap: refactor the get/put routines (FATE#315454)."
  This reverts commit b3a38e786d9f735a2550f2c112a8b23e0e5bfc2e.
  build errors
- commit b8c865a
* Tue Jan 28 2014 spargaonkar@suse.com
- Revert "mm/zswap.c: change params from hidden to ro (FATE#315454)."
  This reverts commit 9db7747cb4631f2ceacdfb8de64baf9cb495297c.
  build errors
- commit cdd69a7
* Tue Jan 28 2014 jbohac@suse.cz
- Delete
  patches.suse/enable_nf_conntrack_accounting_by_default.patch.
  Obsolete - only for compatibility between SLE11 service packs.
- commit 686e030
* Tue Jan 28 2014 spargaonkar@suse.com
- mm/zswap.c: change params from hidden to ro (FATE#315454).
- mm/zswap: refactor the get/put routines (FATE#315454).
- mm/zswap: bugfix: memory leak when invalidate and reclaim
  occur concurrently (FATE#315454).
- mm/zswap: avoid unnecessary page scanning  (FATE#315454).
- commit 9db7747
* Tue Jan 28 2014 spargaonkar@suse.com
- config: Enable CONFIG_FRONTSWAP/CONFIG_ZSWAP for ppc64 and ppc64le (FATE#315454).
  It's built-in but a no-op without zswap.enabled=1 on the kernel command line.
- commit a442ab3
* Tue Jan 28 2014 eich@suse.de
- * Ported not-yet upstream MGAG200 patches:
- drm/mgag200: Add additional limits for certain G200 variants.
- drm/mgag200: Add doublescan and interlace support.
- drm/mgag200: Copy fb name string before using it in
  mgag200_fb_create() (bnc #806990).
- drm/mgag200: Fix memleak in error path in mgag200_bo_create()
  (bnc #806990).
- drm/mgag200: Fix memleaks in error path in mgag200_fb_create()
  (bnc #806990).
- drm/mgag200: Free container instead of member in
  mga_user_framebuffer_destroy() (bnc #806990).
- drm/mgag200: Initialized data needed to map fbdev memory
  (bnc #806990).
- drm/mgag200: Make local function mgag200_gem_init_object()
  static (bnc #806990).
- drm/mgag200: Reject modes when hdisplay is no multiple of 8
  (bnc #806990).
- drm/mgag200: Simplify function mgag200_bo_unpin() (bnc #806990).
- drm/mgag200: Simplify function mgag200_ttm_placement()
  (bnc #806990).
- Delete patches.drm/drm-mgag200-Add-missing-limits.patch.
  * Reviewed:
- patches.suse/drm-radeon-limit-bpp-for-low-vram.patch.
- commit f30e12a
* Tue Jan 28 2014 jdelvare@suse.de
- nohz: Fix another inconsistency between CONFIG_NO_HZ=n and
  nohz=off (bnc#846790).
- NOHZ: Check for nohz active instead of nohz enabled
  (bnc#846790).
- commit cb98086
* Tue Jan 28 2014 jbohac@suse.cz
- Delete patches.suse/l2tp_ppp-alias.patch.
  Obsolete - only needed for SLE11-SPx compatibility with SP1.
- commit 70a8d7c
* Tue Jan 28 2014 jbohac@suse.cz
- Delete patches.suse/ebt_vlan-dummy-debug-option.patch.
  Obsolete - only needed for SLE11-SPx compatibility with SP1.
- commit 3b962e2
* Tue Jan 28 2014 jbohac@suse.cz
- Delete
  patches.suse/ipv6-dont-block-modules-that-depend-on-ipv6-when-blacklisted.patch.
  IPv6 is now built in, this temporary workaround is not needed.
- commit b1d9709
* Tue Jan 28 2014 lduncan@suse.com
- removing unused be2iscsi version patch
- commit adb79d5
* Mon Jan 27 2014 mgorman@suse.de
- Delete
  patches.suse/s390-fix-compact-wrappers-for-process_vm-fix.patch.
- commit bcd15ec
* Mon Jan 27 2014 mgorman@suse.de
- mm: numa: Initialse numa balancing after jump label initialisation
  (Automatic NUMA Balancing (fate#315482)).
- commit 7cff5ce
* Mon Jan 27 2014 duwe@suse.de
- patches.suse/zcrypt-feed-hwrandom*
  no longer apply. Mainline solves the
  slow startup problem differently now,
  And the remaining runtime issues ought
  to be solved arch-independently.
- commit 8f60911
* Mon Jan 27 2014 jslaby@suse.cz
- Linux 3.12.9.
- Refresh
  patches.fixes/md-Change-handling-of-save_raid_disk-and-metadata-up.patch.
- Refresh
  patches.suse/0004-md-raid10-add-failfast-handling-for-reads.patch.
- Refresh patches.suse/md-display-timeout-error.patch.
- commit 54eed58
* Mon Jan 27 2014 mmarek@suse.cz
- Delete SP3 patches that have been removed from series.conf
- commit a06e8f7
* Mon Jan 27 2014 mmarek@suse.cz
- Update vanilla configs.
- commit 20c5db9
* Mon Jan 27 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add README.PATCH-POLICY.SUSE as source file
- commit 9c9ce61
* Mon Jan 27 2014 mmarek@suse.cz
- Drop the _constraints file, we are using the prjconf setting for now
- commit a0aa890
* Mon Jan 27 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add patches.drm.tar.bz2
- commit 11c7fed
* Mon Jan 27 2014 hare@suse.de
- Delete obsolete S/390 patches after review
- Delete patches.arch/ccwgroup-fix-uevent-vs-dev-attrs-race.patch.
- Delete
  patches.arch/qeth-l3-add-large_send-and-checksumming-sysfs-attributes-again.patch.
- Delete patches.arch/s390-3270-asynchronous-size-sensing.patch.
- Delete patches.arch/s390-3270-introduce-device-notifier.patch.
- Delete patches.arch/s390-kmsg-dev-printk.patch.
- Delete patches.fixes/virtio-console-early-console.patch.
- commit e2e6520
* Mon Jan 27 2014 hare@suse.de
- Delete obsolete S/390 patches after review
- Delete patches.arch/s390-43-01-qeth_hd_recover.patch.
- Delete patches.arch/s390-43-02-console-panic.patch.
- Delete patches.arch/s390-43-03-dasd-fix-erp-expiration.patch.
- Delete
  patches.arch/s390-56-04-zfcp-optional-port-rescan-on-rscn.patch.
- Delete patches.arch/s390-56-05-dasd_fix_path_group_race.patch.
- Delete patches.arch/s390-57-02-dasd_check_count_address.patch.
- Delete
  patches.arch/s390-58-01-qeth-recovery-bonding_deadlock.patch.
- Delete
  patches.arch/s390-59-01-qeth_Fix_IPA_CMD_QIPASSIST_rc_handling.patch.
- Delete patches.arch/s390-60-01-smsgiucv-resume.patch.
- Delete patches.arch/s390-61-04-crypto-perffix-msgtype50.patch.
- Delete
  patches.arch/s390-62-01-qeth_fix_retries_on_hardsetup.patch.
- Delete patches.arch/s390-vmcp-module.patch.
- Delete patches.arch/s390-vmlinux-note-header.patch.
- commit e7750bd
* Mon Jan 27 2014 hare@suse.de
- Delete patches.suse/mkinitrd-scsi_host_template-proc_name.patch.
- commit 7be733c
* Mon Jan 27 2014 jlee@suse.com
- Update config files.
  Set CONFIG_EFIVAR_FS=y on x86_64 as SLE-11 SP3. (fate#314499)
- commit 18dd0c7
* Mon Jan 27 2014 hare@suse.de
- Enable patches after review
  * patches.fixes/scsi-Retry-failfast-commands-after-EH.patch.
  * patches.fixes/scsi-Warn-on-invalid-command-completion.patch.
  * patches.suse/scsi-always-retry-internal-target-error.patch
  * patches.suse/scsi-do-not-retry-invalid-function-error.patch
- commit 0a32d7c
* Mon Jan 27 2014 hare@suse.de
- Port SCSI scanning fixes from upstream
- scsi: dual scan thread bug fix.
- scsi: fix our current target reap infrastructure.
- Delete
  patches.fixes/scsi-check-for-invalid-sdev-in-scsi_prep_fn.
- Delete patches.fixes/scsi-return-BLKPREP_KILL-in-prep_fn.patch.
- Delete patches.fixes/scsi-short-circuit-scsi_abort_eh_cmnds.
- Delete
  patches.suse/block-add-WARN_ON-in-blk_complete_requests.patch.
- commit dd5d8f9
* Mon Jan 27 2014 hare@suse.de
- Delete patches.suse/scsi-netlink-ml.
  Patch is not upstream, and has been superseded by udev interface.
- commit 5eb3995
* Fri Jan 24 2014 lduncan@suse.de
- be2iscsi: fix memory leak in error path (FATE#315960
  bnc#855063).
- be2iscsi: Bump driver version (FATE#315960 bnc#855063).
- be2iscsi: Fix SGL posting for unaligned ICD values (FATE#315960
  bnc#855063).
- be2iscsi: Fix AER handling in driver (FATE#315960 bnc#855063).
- be2iscsi: Invalidate WRB in Abort/Reset Path (FATE#315960
  bnc#855063).
- be2iscsi: Fix Insufficient Buffer Error returned in MBX
  Completion (FATE#315960 bnc#855063).
- be2iscsi: Fix log level for protocol specific logs (FATE#315960
  bnc#855063).
- be2iscsi: Fix MSIx creation for SKH-R adapter (FATE#315960
  bnc#855063).
- be2iscsi: Display Port Identifier for each iSCSI function
  (FATE#315960 bnc#855063).
- be2iscsi: Dispaly CID available for connection offload
  (FATE#315960 bnc#855063).
- be2iscsi: Fix chute cleanup during drivers unload (FATE#315960
  bnc#855063).
- be2iscsi: Fix connection offload to support Dual Chute
  (FATE#315960 bnc#855063).
- be2iscsi: Fix CID allocation/freeing to support Dual chute mode
  (FATE#315960 bnc#855063).
- be2iscsi: Fix WRB_Q posting to support Dual Chute mode
  (FATE#315960 bnc#855063).
- be2iscsi: Fix SGL Initilization and posting Pages for Dual Chute
  (FATE#315960 bnc#855063).
- be2iscsi: Fix Template HDR support for Dual Chute mode
  (FATE#315960 bnc#855063).
- be2iscsi: Fix changes in ASYNC Path for SKH-R adapter
  (FATE#315960 bnc#855063).
- be2iscsi: Config parameters update for Dual Chute Support
  (FATE#315960 bnc#855063).
- be2iscsi: Fix soft lock up issue during UE or if FW taking
  time to respond (FATE#315960 bnc#855063).
- be2iscsi: Fix locking mechanism in Unsol Path (FATE#315960
  bnc#855063).
- be2iscsi: Fix negotiated parameters upload to FW (FATE#315960
  bnc#855063).
- be2iscsi: Fix repeated issue of MAC ADDR get IOCTL (FATE#315960
  bnc#855063).
- be2iscsi: Fix the MCCQ count leakage (FATE#315960 bnc#855063).
- be2iscsi: Fix Template HDR IOCTL (FATE#315960 bnc#855063).
- commit 1b45374
* Fri Jan 24 2014 trenn@suse.de
- PowerCap: Introduce Intel RAPL power capping driver
  (fate#315628).
- powercap / RAPL: add support for ValleyView Soc (fate#315628).
- x86 / msr: add 64bit _on_cpu access functions (fate#315628).
- bitops: Introduce BIT_ULL (fate#315628).
- PowerCap: Add class driver (fate#315628).
- PowerCap: Add to drivers Kconfig and Makefile (fate#315628).
- PowerCap: Fix mode for energy counter (fate#315628).
- PowerCap: Fix build error with option -Werror=format-security
  (fate#315628).
- PowerCap: Convert class code to use dev_groups (fate#315628).
- Update config files:
  +CONFIG_POWERCAP=y
  +CONFIG_INTEL_RAPL=m
  for all x86_64 flavors (without ec2), all other archs:
  +# CONFIG_POWERCAP is not set
  as no powercap drivers exist for these yet
- commit 4523423
* Fri Jan 24 2014 jbeulich@suse.com
- Refresh Xen patches (fixing PV driver build).
- commit 606a735
* Fri Jan 24 2014 mgorman@suse.de
- Update config files.
  Disable CONFIG_JUMP_LABEL on configurations requiring automatic NUMA
  balancing support as right now they are incompatible.
- commit 61a87d2
* Fri Jan 24 2014 duwe@suse.de
- Update config files:
  config IMA (bool) selects TCG_IBMVTPM if TCG_TPM && PPC64
  => TCG_IBMVTPM m -> y to get it built
- commit 56a6ea3
* Fri Jan 24 2014 hare@suse.de
- megaraid: Use resource_size_t for PCI resources, not long
  (bnc#854993,FATE#315929).
- megaraid_sas: Fix synchronization problem between sysPD IO
  path and AEN path (bnc#854993,FATE#315929).
- megaraid_sas: fixes for few endianess issues
  (bnc#854993,FATE#315929).
- commit 21ec59b
* Fri Jan 24 2014 duwe@suse.de
- PPC: Build only vmlinux target.
- commit 6cb4e7e
* Fri Jan 24 2014 hare@suse.de
- scsi_dh_rdac: Add new IBM 1813 product id to rdac devlist
  (bnc#852365,FATE#316338).
- commit 2279aa7
* Fri Jan 24 2014 hare@suse.de
- Update config files
  Some configuration options weren't set on all architectures.
- commit c155d29
* Fri Jan 24 2014 hare@suse.de
- mtip32xx: dynamically allocate buffer in debugfs functions
  (FATE#315962).
- mtip32xx: Add SRSI support (FATE#315962).
- commit 592b6b1
* Fri Jan 24 2014 jlee@suse.com
- Update config files.
  Set CONFIG_PERSISTENT_KEYRINGS, CONFIG_BIG_KEYS,
  CONFIG_SYSTEM_TRUSTED_KEYRING and CONFIG_SYSTEM_BLACKLIST_KEYRING
  to not set on ppc64 and ppc64le. (FATE#314508)
- commit fc83f42
* Fri Jan 24 2014 jlee@suse.com
- Update config files to enable CONFIG_IMA_APPRAISE for IMA
  Update config files to enable CONFIG_IMA_APPRAISE for IMA.
  Need make sure we should with a zero-policy loaded to avoid the
  performance impact. (FATE#316148)
- commit a1f19aa
* Fri Jan 24 2014 jlee@suse.com
- Update config files.
  Set CONFIG_PERSISTENT_KEYRINGS and CONFIG_BIG_KEYS
  to not set on ARM64 and s390x. (FATE#314508)
- commit 33e85e9
* Fri Jan 24 2014 jlee@suse.com
- Update config files.
  Set CONFIG_SYSTEM_TRUSTED_KEYRING and CONFIG_SYSTEM_BLACKLIST_KEYRING
  to not set on ARM64 and s390x. (FATE#314508)
- commit 9140ef8
* Thu Jan 23 2014 ohering@suse.de
- Drivers: hv: Implement the file copy service.
- commit 7b6408d
* Thu Jan 23 2014 oneukum@suse.de
- Update config files.
  Enable UAS (FATE#315595)
- commit 936904a
* Thu Jan 23 2014 oneukum@suse.de
- uas: Remove comment about registering a uas scsi controller
  for each usb bus (FATE#315595).
- uas: Add Hans de Goede as uas maintainer (FATE#315595).
- uas: remove BROKEN (FATE#315595).
- uas: Make sure sg elements are properly aligned (FATE#315595).
- uas: Add some data in/out ready iu sanity checks (FATE#315595).
- uas: Improve error reporting (FATE#315595).
- uas: Use the right error codes for different kinds of errors
  (FATE#315595).
- uas: Clear cmdinfo on command queue-ing (FATE#315595).
- uas: Fix memory management (FATE#315595).
- uas: Fix command / task mgmt submission racing with disconnect
  (FATE#315595).
- uas: cmdinfo: use only one list head (FATE#315595).
- uas: add uas_mark_cmd_dead helper function (FATE#315595).
- uas: Properly complete inflight commands on bus-reset or
  disconnect (FATE#315595).
- uas: uas_alloc_data_urb: Remove unnecessary use_streams check
  (FATE#315595).
- uas: Fix task-management not working when connected over USB-2
  (FATE#315595).
- uas: Reset device on reboot (FATE#315595).
- uas: Add suspend/resume support (FATE#315595).
- uas: Use GFP_NOIO rather then GFP_ATOMIC where possible
  (FATE#315595).
- uas: Don't allow more then one task to run at the same time
  (FATE#315595).
- uas: task_mgmt: Kill the sense-urb if we fail to submit the
  cmd urb (FATE#315595).
- uas: Not being able to alloc streams when connected through
  usb-3 is an error (FATE#315595).
- uas: Verify endpoint descriptors from uas_use_uas_driver()
  (FATE#315595).
- uas: Drop fixed endpoint config handling (FATE#315595).
- uas: Move uas_find_endpoints to uas-detect.h (FATE#315595).
- uas: Fix bounds check in uas_find_endpoints (FATE#315595).
- uas: Add uas_find_endpoints() helper function (FATE#315595).
- uas: Honor no-uas quirk set in usb-storage's quirks module
  parameter (FATE#315595).
- usb-storage: Modify and export adjust_quirks so that it can
  be used by uas (FATE#315595).
- usb-storage: Don't bind to uas devices if the uas driver is
  enabled (FATE#315595).
- uas: Add the posibilty to blacklist uas devices from using
  the uas driver (FATE#315595).
- usb: Reset USB-3 devices on USB-3 link bounce (FATE#315595).
- usb: Clear host_endpoint->streams when implicitly freeing
  streams (FATE#315595).
- xhci: Handle MaxPSASize == 0 (FATE#315595).
- xhci: The trb_address_map radix tree expects 1KB segment memory
  aligment (FATE#315595).
- xhci: xhci_mem_cleanup: make sure cmd_ring_reserved_trbs really
  is 0 (FATE#315595).
- uas: Move uas detect code to uas-detect.h (FATE#315595).
- uas: Add a uas_find_uas_alt_setting helper function
  (FATE#315595).
- uas: Use all available stream ids (FATE#315595).
- uas: Pack iu struct definitions (FATE#315595).
- uas: Fix response iu struct definition (FATE#315595).
- uas: s/response_ui/response_iu/ (FATE#315595).
- uas: Fix reset handling for externally triggered reset
  (FATE#315595).
- uas: Fix reset locking (FATE#315595).
- uas: Fix uas not working when plugged into an ehci port
  (FATE#315595).
- uas: uas_alloc_cmd_urb: drop unused stream_id parameter
  (FATE#315595).
- uas: Avoid unnecessary unlock / lock calls around
  unlink_data_urbs (FATE#315595).
- uas: Properly set interface to altsetting 0 on probe failure
  (FATE#315595).
- uas: Urbs must be anchored before submitting them (FATE#315595).
- uas: replace BUG_ON() + WARN_ON() with WARN_ON_ONCE()
  (FATE#315595).
- uas: add dead request list (FATE#315595).
- uas: make work list per-device (FATE#315595).
- uas: properly reinitialize in uas_eh_bus_reset_handler
  (FATE#315595).
- usbfs: Add support for allocating / freeing streams
  (FATE#315595).
- usbfs: Add ep_to_host_endpoint helper function (FATE#315595).
- usbfs: Add support for bulk stream ids (FATE#315595).
- usbfs: proc_do_submiturb use a local variable for
  number_of_packets (FATE#315595).
- usbfs: Kill urbs on interface before doing a set_interface
  (FATE#315595).
- usb-core: Free bulk streams on interface release (FATE#315595).
- usb-core: Track if an endpoint has streams (FATE#315595).
- usb-core: Move USB_MAXENDPOINTS definitions to usb.h
  (FATE#315595).
- commit cf3496f
* Thu Jan 23 2014 oneukum@suse.de
- usb-core: Fix usb_free_streams return value documentation
  (FATE#315595).
- xhci: Remove segments from radix tree on failed insert
  (FATE#315595).
- xhci: use usb_ss_max_streams in xhci_check_streams_endpoint
  (FATE#315595).
- xhci: For streams the dequeue ptr must be read from the stream
  ctx (FATE#315595).
- xhci: Set SCT field for Set TR dequeue on streams (FATE#315595).
- xhci: For streams the css flag most be read from the stream-ctx
  on ep stop (FATE#315595).
- xhci: Check size rather then number of streams when allocating
  stream ctxs (FATE#315595).
- xhci: Free streams when they are still allocated on a
  set_interface call (FATE#315595).
- xhci: fix usb3 streams (FATE#315595).
- commit 8c035e0
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "NFC: netlink: SE API implementation (FATE#315944)."
  Unrelated and unnecessary change brought in due to faulty dependency analysis
  This reverts commit e3be57599536894604d4feba92649400dd0470b5.
- commit fc58a66
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "genetlink.h: Remove extern from function prototypes"
  Unrelated and unnecessary change brought in due to faulty dependency analysis
  This reverts commit 892526f9f0dc7fd8afebfaeee1a0f87a5c0176e0.
- commit ea024b7
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "NFC: Fix SE API related sparse warning (FATE#315944)."
  Unrelated and unnecessary change brought in due to faulty dependency analysis
  This reverts commit 2c4cb3568e80fecf43db6fc7ae7bf8bb817c481b.
- commit cb95fce
* Thu Jan 23 2014 bpoirier@suse.de
- net: e100: remove unnecessary pci_set_drvdata() (bnc#857398
  FATE#315650).
- net: igbvf: slight optimization of addr compare (bnc#857395
  FATE#315660).
- igbvf: add missing iounmap() on error in igbvf_probe()
  (bnc#857395 FATE#315660).
- igbvf: integer wrapping bug setting the mtu (bnc#857395
  FATE#315660).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bnc#857395 FATE#315660).
- intel: Remove extern from function prototypes (bnc#857395
  FATE#315660).
- DMA-API: net: intel/igbvf: fix 32-bit DMA mask handling
  (bnc#857395 FATE#315660).
- commit 8b5de9a
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "openvswitch: fix vport-netdev unregister (FATE#315944)."
  Unrelated and unnecessary change brought in due to faulty dependency analysis:wq
  This reverts commit ec3f9ecd9b82e77efffef59dbf926e08ed10a919.
- commit e786ff1
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "net/hsr: Add support for the High-availability Seamless"
  Unrelated and unnecessary change brought in due to faulty dependency analysis
  This reverts commit 457ca7dceba33bfc1d69c4e59e739df6b436d138.
- commit bd8713e
* Thu Jan 23 2014 spargaonkar@suse.com
- Revert "kernel/taskstats.c: add nla_nest_cancel() for failure processing"
  Unrelated and unnecessary change brought in due to faulty dependency analysis
  This reverts commit 88dfdae493ccf348fb9318b27dc4e0a5865eb272.
- commit 3812e37
* Thu Jan 23 2014 bpoirier@suse.de
- igb: Change to use statically allocated array for MSIx entries
  (bnc#857394 FATE#315661).
- igb: Fix queue allocation method to accommodate changing during
  runtime (bnc#857394 FATE#315661).
- igb: Start temperature sensor attribute index with 1 (bnc#857394
  FATE#315661).
- igb: Convert to use devm_hwmon_device_register_with_groups
  (bnc#857394 FATE#315661).
- igb: Add new feature Media Auto Sense for 82580 devices only
  (bnc#857394 FATE#315661).
- igb: Support ports mapped in 64-bit PCI space (bnc#857394
  FATE#315661).
- igb: Add media switching feature for i354 PHY's (bnc#857394
  FATE#315661).
- igb: Fixed Wake On LAN support (bnc#857394 FATE#315661).
- igb: Update link modes display in ethtool (bnc#857394
  FATE#315661).
- igb: Don't let ethtool try to write to iNVM in i210/i211
  (bnc#857394 FATE#315661).
- igb: fix driver reload with VF assigned to guest (bnc#857394
  FATE#315661).
- igb: Fix master/slave mode for all m88 i354 PHY's (bnc#857394
  FATE#315661).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bnc#857394 FATE#315661).
- igb: Add ethtool support to configure number of channels
  (bnc#857394 FATE#315661).
- igb: Add ethtool offline tests for i354 (bnc#857394
  FATE#315661).
- intel: Remove extern from function prototypes (bnc#857394
  FATE#315661).
- DMA-API: net: intel/igb: fix 32-bit DMA mask handling
  (bnc#857394 FATE#315661).
- commit ffa83e1
* Thu Jan 23 2014 brogers@suse.com
- Delete patches.suse/acpiphp-match-to-Bochs-dmi-data.patch.
- commit 8da34a6
* Thu Jan 23 2014 oneukum@suse.de
- xhci: replace 'event' with 'cmd_comp_code' in set_deq and
  reset_ep handlers (FATE#315595).
- xhci: add argument 'slot_id' in stop_ep, set_deq and reset_ep
  cmd handlers (FATE#315595).
- xhci: replace 'xhci->cmd_ring->dequeue' with 'trb' in stop_ep
  cmd handler (FATE#315595).
- xhci: add variable 'cmd_type' in handle_cmd_completion()
  (FATE#315595).
- xhci: add variable 'cmd_trb' in handle_cmd_completion()
  (FATE#315595).
- xhci: add variable 'cmd_comp_code' in handle_cmd_completion()
  (FATE#315595).
- xhci: refactor TRB_CONFIG_EP case into function (FATE#315595).
- xhci: remove unused 'ep_ring' variable in
  handle_cmd_completion() (FATE#315595).
- xhci: refactor TRB_EVAL_CONTEXT case into function
  (FATE#315595).
- xhci: refactor TRB_NEC_GET_FW case into function (FATE#315595).
- xhci: refactor TRB_RESET_DEV case into function (FATE#315595).
- xhci: use completion event's slot id rather than dig it out
  of command (FATE#315595).
- xhci: refactor TRB_ADDR_DEV case into function (FATE#315595).
- xhci: refactor TRB_DISABLE_SLOT case into function
  (FATE#315595).
- xhci: refactor TRB_ENABLE_SLOT case into function (FATE#315595).
- xhci: rename existing Command Completion Event handlers
  (FATE#315595).
- xhci: remove unused argument from xhci_giveback_urb_in_irq()
  (FATE#315595).
- commit 0995673
* Thu Jan 23 2014 jdelvare@suse.de
- i2c: i801: Add Device IDs for Intel Wildcat Point-LP PCH
  (bnc#854594 FATE#315629).
- commit 21393ea
* Thu Jan 23 2014 jbeulich@suse.com
- x86: Lock down IO port access when module security is enabled
  (fate#314486).
- Restrict /dev/mem and /dev/kmem when module loading is
  restricted (fate#314486).
- Add option to automatically enforce module signatures when in
  Secure Boot mode (fate#314486).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (bnc#855062 FATE#315961).
- x86, acpi, crash, kdump: do reserve_crashkernel() after SRATis
  parsed (Node memory hot remove (fate#316483)).
- x86/mem-hotplug: support initialize page tables in bottom-up
  (Node memory hot remove (fate#316483)).
- x86/mm: Add 'step_size' comments to init_mem_mapping() (Node
  memory hot remove (fate#316483)).
- x86/mm: factor out of top-down direct mapping setup (Node
  memory hot remove (fate#316483)).
- Update Xen patches to 3.12.8 and c/s 1248.
- commit 3f0fab5
* Thu Jan 23 2014 spargaonkar@suse.com
- kernel/taskstats.c: add nla_nest_cancel() for failure processing
  between nla_nest_start() and nla_nest_end() (FATE#315944).
- net/hsr: Add support for the High-availability Seamless
  Redundancy protocol (HSRv0) (FATE#315944).
- openvswitch: fix vport-netdev unregister (FATE#315944).
- NFC: Fix SE API related sparse warning (FATE#315944).
- genetlink.h: Remove extern from function prototypes
  (FATE#315944).
- NFC: netlink: SE API implementation (FATE#315944).
- commit 88dfdae
* Thu Jan 23 2014 tiwai@suse.de
- ALSA: hda/hdmi - apply all Haswell fix-ups to Broadwell display
  codec (bnc#854594).
- ALSA: hda - rename function not_share_unassigned_cvt()
  (bnc#854594).
- ALSA: hda - not choose assigned converters for unused pins of
  Valleyview (bnc#854594).
- ALSA: hda - add codec ID for Valleyview2 display codec
  (bnc#854594).
- ALSA: hda - add codec ID for Broadwell display audio codec
  (bnc#854594).
- ALSA: hda - add device ID for Broadwell display audio controller
  (bnc#854594).
- ALSA: hda - Name Haswell HDMI controllers better (bnc#854594).
- ALSA: hda: add device IDs for AMD Evergreen/Northern Islands
  HDMI (bnc#854594).
- ALSA: hda - Add Device IDs for Intel Wildcat Point-LP PCH
  (bnc#854594).
- commit 2110243
* Thu Jan 23 2014 hare@suse.de
- Update supported.conf
- Drop support for I2O modules (FATE#316786)
- Mark esas2r as supported (FATE#316786)
- commit 7a36567
* Thu Jan 23 2014 hare@suse.de
- esas2r: Cleanup snprinf formatting of firmware version
  (FATE#316532).
- esas2r: Directly call kernel functions for atomic bit operations
  (FATE#316532).
- esas2r: Fixes for big-endian platforms (FATE#316532).
- esas2r: Remove superfluous mask of pcie_cap_reg (FATE#316532).
- commit a9d0a97
* Thu Jan 23 2014 hare@suse.de
- Compile-in 3270 drivers (bnc#856615)
- commit dd0144c
* Thu Jan 23 2014 jlee@suse.com
- Update config files, rollback config change in ec2 for TPM, EVM and IMA
  Rollback config change in ec2 for TPM, EVM and IMA.
- commit 68901b8
* Thu Jan 23 2014 jlee@suse.com
- Update config files to enable TPM, EVM and IMA
  Update config files to enable TPM, EVM and IMA. (FATE#315749,
  FATE#315782, FATE#315783, FATE#316148)
- commit 4cf4f82
* Thu Jan 23 2014 jlee@suse.com
- Update config files.
  Grab certificate from MokList (MODSIGN) FATE#314508
- commit 3cb7924
* Thu Jan 23 2014 jlee@suse.com
- MODSIGN: Support not importing certs from db (fate#314574).
- MODSIGN: Import certificates from UEFI Secure Boot
  (fate#314574).
- KEYS: Add a system blacklist keyring (fate#314574).
- Add an EFI signature blob parser and key loader (fate#314574).
- Add EFI signature data types (fate#314574).
- KEYS: Add a 'trusted' flag and a 'trusted only' flag
  (fate#314574).
- KEYS: Separate the kernel signature checking keyring from
  module signing (fate#314574).
- KEYS: Have make canonicalise the paths of the X.509 certs
  better to deduplicate (fate#314574).
- X.509: Handle certificates that lack an authorityKeyIdentifier
  field (fate#314574).
- X.509: Check the algorithm IDs obtained from parsing an X.509
  certificate (fate#314574).
- X.509: Embed public_key_signature struct and create filler
  function (fate#314574).
- KEYS: Store public key algo ID in public_key_signature struct
  (fate#314574).
- KEYS: Split public_key_verify_signature() and make available
  (fate#314574).
- KEYS: Store public key algo ID in public_key struct
  (fate#314574).
- KEYS: Move the algorithm pointer array from x509 to public_key.c
  (fate#314574).
- KEYS: Rename public key parameter name arrays (fate#314574).
- KEYS: Add per-user_namespace registers for persistent per-UID
  kerberos caches (fate#314574).
- KEYS: Implement a big key type that can save to tmpfs
  (fate#314574).
- KEYS: Expand the capacity of a keyring (fate#314574).
- Add a generic associative array implementation (fate#314574).
- KEYS: Drop the permissions argument from __keyring_search_one()
  (fate#314574).
- KEYS: Define a __key_get() wrapper to use rather than
  atomic_inc() (fate#314574).
- KEYS: Search for auth-key by name rather than target key ID
  (fate#314574).
- KEYS: Introduce a search context structure (fate#314574).
- KEYS: Consolidate the concept of an 'index key' for key access
  (fate#314574).
- KEYS: key_is_dead() should take a const key pointer argument
  (fate#314574).
- KEYS: Use bool in make_key_ref() and is_key_possessed()
  (fate#314574).
- KEYS: Skip key state checks when checking for possession
  (fate#314574).
- commit d3f00e8
* Thu Jan 23 2014 spargaonkar@suse.com
- pm80xx: Fixed return value issue (FATE#315941).
- pm80xx: Removing redundant code snippets (FATE#315941).
- pm80xx: Tasklets synchronization fix (FATE#315941).
- pm80xx: Resetting the phy state (FATE#315941).
- pm80xx: Fix for direct attached device (FATE#315941).
- pm80xx: Module author addition (FATE#315941).
- pm80xx: Firmware logging support (FATE#315941).
- pm80xx: Phy settings support for motherboard controller
  (FATE#315941).
- pm80xx: IButton security feature support for motherboard
  controllers (FATE#315941).
- pm80xx: Device id changes to support series 8 controllers
  (FATE#315941).
- pm80xx: 4G boundary fix (FATE#315941).
- pm80xx: Queue rotation logic for inbound and outbound queues
  (FATE#315941).
- pm80xx: Set device state response logic fix (FATE#315941).
- pm80xx: Display controller BIOS version (FATE#315941).
- pm80xx: Indirect SMP request fix (FATE#315941).
- pm80xx: Device id changes to support series 8 controllers
  (FATE#315941).
- commit 25dd11e
* Thu Jan 23 2014 spargaonkar@suse.com
- BNX2FC: Updated version to 2.4.2 (FATE#316095).
- BNX2FC: Fixed the handling for the SCSI retry delay
  (FATE#316095).
- BNX2FC: Fixed scsi_remove_target soft lockup when rmmod bnx2x
  (FATE#316095).
- commit 8395bb5
* Thu Jan 23 2014 neilb@suse.de
- md: Change handling of save_raid_disk and metadata update
  during recovery (bnc#849364).
- commit 72572b8
* Thu Jan 23 2014 lduncan@suse.com
- removing unused bnx2i driver version patch
- commit e158fe2
* Thu Jan 23 2014 lduncan@suse.com
- remove old unneeded qla4xxx patches
- commit 4efdfab
* Wed Jan 22 2014 jack@suse.cz
- Update config files.
- commit 4420ae4
* Wed Jan 22 2014 jack@suse.cz
- DMAPI support for xfs (bnc#859795 fate#315263).
- Make NFSD DMAPI aware (bnc#859795 fate#315263).
- DMAPI Source (bnc#859795 fate#315263).
- commit c5cd2f2
* Wed Jan 22 2014 bpoirier@suse.de
- bnad: code cleanup (bnc#855232 FATE#315938).
- bna: Fix build due to missing use of dma_unmap_len_set()
  (bnc#855232 FATE#315938).
- bna: Update the Driver Version to 3.2.23.0 (bnc#855232
  FATE#315938).
- bna: Firmware Patch Simplification (bnc#855232 FATE#315938).
- bna: Embed SKB Length in TX Vector (bnc#855232 FATE#315938).
- bna: Handle the TX Setup Failures (bnc#855232 FATE#315938).
- bna: Add NULL Check Before Dereferencing TCB (bnc#855232
  FATE#315938).
- bna: CQ Read Fix (bnc#855232 FATE#315938).
- bna: RX Processing and Config Changes (bnc#855232 FATE#315938).
- bna: Enable Multi Buffer RX (bnc#855232 FATE#315938).
- bna: RX Filter Enhancements (bnc#855232 FATE#315938).
- bna: Fix Filter Add Del (bnc#855232 FATE#315938).
- bna: Set Get IOC fw State (bnc#855232 FATE#315938).
- bna: Add software timestamping support (bnc#855232 FATE#315938).
- bnad: make local variable static (bnc#855232 FATE#315938).
- net: bna: remove unnecessary pci_set_drvdata() (bnc#855232
  FATE#315938).
- brocade: Remove extern from function prototypes (bnc#855232
  FATE#315938).
- DMA-API: net: brocade/bna/bnad.c: fix 32-bit DMA mask handling
  (bnc#855232 FATE#315938).
- commit f4a4154
* Wed Jan 22 2014 bpoirier@suse.de
- qlge: Fix vlan netdev features (bnc#853684 FATE#315936).
- qlge: Update version to 1.00.00.34 (bnc#853684 FATE#315936).
- qlge: Allow enable/disable rx/tx vlan acceleration independently
  (bnc#853684 FATE#315936).
- qlge: Fix ethtool statistics (bnc#853684 FATE#315936).
- net: qlge: remove unnecessary pci_set_drvdata() (bnc#853684
  FATE#315936).
- qlge: Enhance nested VLAN (Q-in-Q) handling (bnc#853684
  FATE#315936).
- qlogic: Remove extern from function prototypes (bnc#853684
  FATE#315936).
- commit 457f925
* Wed Jan 22 2014 hare@suse.de
- Delete obsolete patch after review
  Delete patches.suse/scsi-error-test-unit-ready-timeout.
- commit f21a25f
* Wed Jan 22 2014 hare@suse.de
- bfa: Driver version upgrade to 3.2.23.0
  (bnc#855226,FATE#315939).
- bfa: change FC_ELS_TOV to 20sec (bnc#855226,FATE#315939).
- bfa: Observed auto D-port mode instead of manual
  (bnc#855226,FATE#315939).
- bfa: Fix for bcu or hcm faa query hang (bnc#855226,FATE#315939).
- bfa: LUN discovery issue in direct attach mode
  (bnc#855226,FATE#315939).
- bfa: Register port with SCSI even on port init failure
  (bnc#855226,FATE#315939).
- bfa: Firmware patch simplification (bnc#855226,FATE#315939).
- commit 4eca78a
* Wed Jan 22 2014 hare@suse.de
- Refresh incomplete iscsi patches
- Refresh
  patches.drivers/libiscsi-add-local_ipaddr-parameter-in-iscsi_conn-struct.
- Refresh
  patches.drivers/scsi_transport_iscsi-add-host-statistics-support.
- Refresh
  patches.drivers/scsi_transport_iscsi-export-iscsi_param_local_ipaddr-attr-for-iscsi_connection.
- commit c065d5b
* Wed Jan 22 2014 spargaonkar@suse.com
- Revert "genetlink/pmcraid: use proper genetlink multicast API"
  This reverts commit 5d7cb5bba9ed5509fd0824d69f3f16acadd0d115.
- commit 025d644
* Wed Jan 22 2014 spargaonkar@suse.com
- Revert " pm80xx: Device id changes to support series 8 controllers"
  This reverts commit 62a6f9c23a8fd7162dbfef35e07869e2827bece2.
- commit bb519ec
* Wed Jan 22 2014 spargaonkar@suse.com
-  pm80xx: Device id changes to support series 8 controllers
  (FATE#315941).
- commit 62a6f9c
* Wed Jan 22 2014 spargaonkar@suse.com
- genetlink/pmcraid: use proper genetlink multicast API
  (FATE#315944).
- commit 5d7cb5b
* Tue Jan 21 2014 lduncan@suse.de
- qla4xxx: v5.04.00.00.12.0-k0 (FATE#315934 bnc#853687).
- qla4xxx: Recreate chap data list during get chap operation
  (FATE#315934 bnc#853687).
- qla4xxx: Add support for ISCSI_PARAM_LOCAL_IPADDR sysfs attr
  (FATE#315934 bnc#853687).
- libiscsi: Add local_ipaddr parameter in iscsi_conn struct
  (FATE#315934 bnc#853687).
- scsi_transport_iscsi: Export ISCSI_PARAM_LOCAL_IPADDR attr
  for iscsi_connection (FATE#315934 bnc#853687).
- qla4xxx: Add host statistics support (FATE#315934 bnc#853687).
- scsi_transport_iscsi: Add host statistics support (FATE#315934
  bnc#853687).
- qla4xxx: Added support for Diagnostics MBOX command (FATE#315934
  bnc#853687).
- qla4xxx: Fix memory leak in func qla4_84xx_config_acb()
  (FATE#315934 bnc#853687).
- qla4xxx: Driver not able to collect minidump for ISP84xx
  (FATE#315934 bnc#853687).
- qla4xxx: overflow in qla4xxx_set_chap_entry() (FATE#315934
  bnc#853687).
- qla4xxx: Add support for additional network parameters settings
  (FATE#315934 bnc#853687).
- iscsi_transport: Additional parameters for network settings
  (FATE#315934 bnc#853687).
- iscsi_transport: Remove net param enum values (FATE#315934
  bnc#853687).
- qla4xxx: Add support to get CHAP details for flash target
  session (FATE#315934 bnc#853687).
- qla4xxx: Add support to set CHAP entries (FATE#315934
  bnc#853687).
- scsi_transport_iscsi: Add support to set CHAP entries
  (FATE#315934 bnc#853687).
- qla4xxx: Use offset based on adapter type to set CHAP entry
  in flash (FATE#315934 bnc#853687).
- qla4xxx: Populate local CHAP credentials for flash target
  sessions (FATE#315934 bnc#853687).
- qla4xxx: Support setting of local CHAP index for flash target
  entry (FATE#315934 bnc#853687).
- qla4xxx: Correct the check for local CHAP entry type
  (FATE#315934 bnc#853687).
- qla4xxx: correctly update session discovery_parent_idx
  (FATE#315934 bnc#853687).
- commit 6f0ee31
* Tue Jan 21 2014 dsterba@suse.cz
- Btrfs update
- Btrfs: eliminate the exceptional root_tree refs=0.
- Btrfs: don't store NULL byte in symlink extents.
- btrfs: drop unused parameter from btrfs_item_nr.
- Btrfs: add a sanity test for btrfs_split_item.
- Btrfs: remove duplicated ino cache's inode lookup.
- Btrfs: remove path arg from btrfs_truncate_free_space_cache.
- Btrfs: export btrfs space shared info to userspace.
- Btrfs: fix tracking of orphan inode count.
- Btrfs: fix sync fs to actually wait for all data to be
  persisted.
- Btrfs: don't leak block group on error.
- Btrfs: do not release metadata for space cache inodes.
- Btrfs: cleanup transaction on abort.
- Btrfs: don't delete ordered roots from list during cleanup.
- Btrfs: remove all BUG_ON()'s from commit_cowonly_roots.
- Btrfs: fix two use-after-free bugs with transaction cleanup.
- btrfs: remove unused parameter from btrfs_header_fsid.
- Btrfs: fix BUG_ON() casued by the reserved space migration.
- Btrfs: improve jitter performance of the sequential buffered
  write.
- Btrfs: remove unused max_key arg from btrfs_search_forward.
- Btrfs: remove unnecessary tree search when logging inode.
- Btrfs: improve inode hash function/inode lookup.
- Btrfs: fix the dev-replace suspend sequence.
- Btrfs: fix memory leaks on transaction commit failure.
- Btrfs: do not free the dirty bytes from the trans block rsv
  on cleanup.
- Btrfs: cleanup reserved space when freeing tree log on error.
- Btrfs: free up block groups after everything.
- Btrfs: fixup reserved trace points.
- Btrfs: free reserved space on error in a few places.
- Btrfs: add tests for find_lock_delalloc_range.
- Btrfs: add tests for btrfs_get_extent.
- Btrfs: stop all workers after we free block groups.
- Btrfs: handle a missing extent for the first file extent.
- Btrfs: add a sanity test for a vacant extent at the front of
  a file.
- Btrfs: add an assert to btrfs_lookup_csums_range for alignment.
- Btrfs: fix up seek_hole/seek_data handling.
- Btrfs: Simplify the logic in alloc_extent_buffer() for existing
  extent buffer case.
- Btrfs: remove unnecessary key copy when logging inode.
- Btrfs: cleanup dead code of defragment.
- Btrfs: kill unused code in btrfs_search_forward.
- btrfs: Fix memory leakage in the tree-log.c.
- Btrfs: nuke a bogus rw_devices decrement in
  __btrfs_close_devices.
- Btrfs: don't leak ioctl args in btrfs_ioctl_dev_replace.
- Btrfs: disallow 'btrfs {balance,replace} cancel' on ro mounts.
- Btrfs: fixup error path in __btrfs_inc_extent_ref.
- Btrfs: init device stats for new devices.
- Btrfs: Wait for uuid-tree rebuild task on remount read-only.
- Btrfs: don't leak delayed node on path allocation failure.
- Btrfs: btrfs_add_ordered_operation: Fix last modified
  transaction comparison.
- btrfs: simplify kmalloc+copy_from_user to memdup_user.
- Btrfs: optimize tree-log.c:count_inode_refs().
- Btrfs: fix btrfs_prev_leaf() previous key computation.
- Btrfs: Don't allocate inode that is already in use.
- btrfs: use get_seconds() instead of btrfs wrapper.
- btrfs: remove move_pages().
- btrfs: remove fs/btrfs/compat.h.
- btrfs: add tracing for failed reservations.
- Btrfs: optimize extent item search in run_delayed_extent_op.
- Btrfs: fix check_int 'leaf item out of bounce' regression.
- Btrfs: check_int, remove warning for mixed-mode.
- Btrfs: return an error from btrfs_wait_ordered_range.
- Btrfs: do not bug_on if we try to cow a free space cache inode.
- Btrfs: don't abort transaction in run_delalloc_nocow.
- Btrfs: make sure the delalloc workers actually flush compressed
  writes.
- Btrfs: stop committing the transaction so much during relocate.
- Btrfs: fix the free space write out failure when there is no
  data space.
- Btrfs: use 'u64' rather than 'int' to get extent's generation.
- Btrfs: remove scrub_super_lock holding in btrfs_sync_log().
- Btrfs: fix verification of dir_item.
- Btrfs: fix csum search offset/length calculation in log tree.
- Btrfs: log recovery, don't unlink inode always on error.
- btrfs: Add helper function for free_root_pointers().
- btrfs: Replace multiple atomic_inc() with atomic_add().
- btrfs: Pack struct btrfs_device.
- btrfs: Remove redundant local zero structure.
- btrfs: Use WARN_ON()'s return value in place of WARN_ON(1).
- btrfs: Enclose macros with complex values within parenthesis.
- btrfs: Replace kmalloc with kmalloc_array.
- btrfs: Fix checkpatch.pl warning of spacing issues.
- btrfs: Remove useless variable in write_ctree_super().
- Btrfs: check file extent type before anything else.
- Btrfs: avoid unnecessary scrub workers allocation.
- Btrfs: remove unnecessary initialization and memory barrior
  in shrink_delalloc().
- Btrfs: wait for the ordered extent only when we want.
- Btrfs: pick up the code for the item number calculation in
  flush_space().
- Btrfs: fix the confusion between delalloc bytes and metadata
  bytes.
- Btrfs: don't wait for all the async delalloc when shrinking
  delalloc.
- Btrfs: don't wait for the completion of all the ordered extents.
- Btrfs: rename btrfs_start_all_delalloc_inodes.
- btrfs: fix empty_zero_page misusage.
- btrfs: get rid of fdentry().
- Btrfs: don't BUG_ON() if we get an error walking backrefs.
- Btrfs: make sure to copy everything if we rename.
- Btrfs: only drop modified extents if we logged the whole inode.
- Btrfs: do not inc uncorrectable_errors counter on ro scrubs.
- Btrfs: disable online raid-repair on ro mounts.
- Btrfs: fix __btrfs_start_workers retval.
- Btrfs: avoid heavy operations in btrfs_commit_super.
- Btrfs: don't wait for ordered data outside desired range.
- Btrfs: remove dead codes from ctree.h.
- Btrfs: print bytenr instead of page pointer in check-int.
- Btrfs: fix list delete warning when removing ordered root from
  the list.
- btrfs: fix typo in the log message.
- btrfs: Use trace condition for get_extent tracepoint.
- btrfs: fix bio_size_ok() for max_sectors > 0xffff.
- btrfs: update kconfig help text.
- Btrfs: don't clear the default compression type.
- Btrfs: don't miss skinny extent items on delayed ref head
  contention.
- Btrfs: fix an oops when doing balance relocation.
- Btrfs: skip building backref tree for uuid and quota tree when
  doing balance relocation.
- Btrfs: make sure we cleanup all reloc roots if error happens.
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh
  patches.suse/btrfs-add-ability-to-query-change-feature-bits-online-ioctl.
- Refresh
  patches.suse/btrfs-add-ioctl-to-export-size-of-global-metadata-reservation.
- Refresh patches.suse/btrfs-check-index-in-extent_buffer_page.
- Refresh patches.suse/btrfs-publish-allocation-data-in-sysfs.
- Refresh
  patches.suse/btrfs-publish-per-super-attributes-in-sysfs.
- Refresh patches.suse/btrfs-publish-supported-featured-in-sysfs.
- Refresh patches.suse/btrfs-use-correct-device-for-maps.patch.
- Refresh patches.suse/btrfs-use-end-trans-in-label-ioctl.
- Refresh patches.suse/export-kobj_sysfs_ops.
- Delete patches.suse/btrfs-add-tracing-for-failed-reservations.
- commit 20c7a31
* Tue Jan 21 2014 jlee@suse.com
- Update config files enable EFI_SECURE_BOOT_SIG_ENFORCE on x86_64
  Enable EFI_SECURE_BOOT_SIG_ENFORCE on x86_64.(fate#314486)
- commit 242396b
* Tue Jan 21 2014 spargaonkar@suse.com
- MAINTAINER: Updated maintainer info for bnx2fc (FATE#316095).
- commit f2ee045
* Tue Jan 21 2014 bp@suse.de
- Delete rtc-add-an-alarm-disable-quirk.patch (bnc#805740)
  This was an initial bug fix from bnc#805740 which we decided not
  to bring upstream because it was a brown paper bag. However,
  upstream wanted the fix too as someone found the fix in our repo so
  John Stultz produced an upstream version which went in into 3.14
  (d5a1c7e3fc38d9c7d629e1e47f32f863acbdec3d).
  As the upstream version is tagged for stable, I'm dropping our version
  here as SLE12 will pick up the stable version.
- commit ed8a854
* Tue Jan 21 2014 mhocko@suse.cz
- patches.fixes/drop_caches-add-some-documentation-and-info-message.patch:
  enabled
- commit b112530
* Tue Jan 21 2014 mhocko@suse.cz
- NMI safe printk will be handled by Petr
- commit 5bf9097
* Tue Jan 21 2014 jlee@suse.com
- Removed old lock down patches that were respined
- Delete
  patches.suse/0001-modsign-Always-enforce-module-signing-in-a-Secure-Boot.patch.
- Delete
  patches.suse/0001_Secure_boot_Add_new_capability_v2.patch.
- Delete
  patches.suse/0002_PCI_Lock_down_BAR_access_in_secure_boot_environments_v2.patch.
- Delete
  patches.suse/0003_x86_Lock_down_IO_port_access_in_secure_boot_environments_v2.patch.
- Delete
  patches.suse/0004_ACPI_Limit_access_to_custom_method_v2.patch.
- Delete
  patches.suse/0005_asus-wmi_Restrict_debugfs_interface_v2.patch.
- Delete
  patches.suse/0006_Restrict__dev_mem_and__dev_kmem_in_secure_boot_setups_v2.patch.
- Delete
  patches.suse/0008_efi_Enable_secure_boot_lockdown_automatically_when_enabled_in_firmware_v2.patch.
- Delete
  patches.suse/0009_acpi_Ignore_acpi_rsdp_kernel_parameter_in_a_secure_boot_environment_v2.patch.
- Delete
  patches.suse/0011-hibernate-Disable-in-a-Secure-Boot-environment.patch.
- Delete
  patches.suse/kexec-Disable-in-a-secure-boot-environment.patch.
- Delete
  patches.suse/x86-Require-CAP_COMPROMISE_KERNEL-for-MSR-writing.patch.
- commit 021b8db
* Tue Jan 21 2014 jlee@suse.com
- Add secure_modules() call (fate#314486).
- PCI: Lock down BAR access when module security is enabled
  (fate#314486).
- x86: Lock down IO port access when module security is enabled
  (fate#314486).
- ACPI: Limit access to custom_method (fate#314486).
- asus-wmi: Restrict debugfs interface when module loading is
  restricted (fate#314486).
- Restrict /dev/mem and /dev/kmem when module loading is
  restricted (fate#314486).
- acpi: Ignore acpi_rsdp kernel parameter when module loading
  is restricted (fate#314486).
- kexec: Disable at runtime if the kernel enforces module loading
  restrictions (fate#314486).
- uswsusp: Disable when module loading is restricted
  (fate#314486).
- x86: Restrict MSR access when module loading is restricted
  (fate#314486).
- Add option to automatically enforce module signatures when in
  Secure Boot mode (fate#314486).
- efi: Make EFI_SECURE_BOOT_SIG_ENFORCE depend on EFI
  (fate#314486).
- efi: Add EFI_SECURE_BOOT bit (fate#314486).
- hibernate: Disable in a signed modules environment
  (fate#314486).
- commit fecf50c
* Tue Jan 21 2014 mgalbraith@suse.de
- Add fix for futex scalability series, and update headers
  now that they're in mainline.
- futexes: Fix futex_hashsize initialization (bnc#851603).
- Refresh patches.fixes/futex-Avoid-taking-the-hb-lock-if-there-is-nothing-to-wake-up.patch.
- Refresh patches.fixes/futex-Clean-up-various-details.patch.
- Refresh patches.fixes/futex-Document-multiprocessor-ordering-guarantees.patch.
- Refresh patches.fixes/futex-Increase-hash-table-size-for-better-performance.patch.
- commit 5d301d7
* Mon Jan 20 2014 bpoirier@suse.de
- qlcnic: update version to 5.3.53 (bnc#853685 FATE#315935).
- qlcnic: Support for 16 virtual NIC functions (bnc#853685
  FATE#315935).
- qlcnic: VLAN enhancement for 84XX adapters (bnc#853685
  FATE#315935).
- qlcnic: Allow single Tx/Rx queue for all adapters (bnc#853685
  FATE#315935).
- qlcnic: Refactor initialize nic code path (bnc#853685
  FATE#315935).
- qlcnic: Issue INIT_NIC command only once (bnc#853685
  FATE#315935).
- qlcnic: Disable DCB operations from SR-IOV VFs (bnc#853685
  FATE#315935).
- qlcnic: Dump mailbox registers when mailbox command times out
  (bnc#853685 FATE#315935).
- qlcnic: Fix mailbox processing during diagnostic test
  (bnc#853685 FATE#315935).
- qlcnic: Allow firmware dump collection when auto firmware
  recovery is disabled (bnc#853685 FATE#315935).
- qlcnic: Fix memory allocation (bnc#853685 FATE#315935).
- qlcnic: Fix TSS/RSS validation for 83xx/84xx series adapter
  (bnc#853685 FATE#315935).
- qlcnic: Fix TSS/RSS ring validation logic (bnc#853685
  FATE#315935).
- qlcnic: Fix diagnostic test for all adapters (bnc#853685
  FATE#315935).
- qlcnic: Fix usage of netif_tx_{wake, stop} api during link
  change (bnc#853685 FATE#315935).
- qlcnic: update version to 5.3.52 (bnc#853685 FATE#315935).
- qlcnic: Enable multiple Tx queue support for 83xx/84xx Series
  adapters (bnc#853685 FATE#315935).
- qlcnic: refactor Tx/SDS ring calculation and validation in
  driver (bnc#853685 FATE#315935).
- qlcnic: Enhance ethtool Statistics for Multiple Tx queue
  (bnc#853685 FATE#315935).
- qlcnic: Register netdev in FAILED state for 83xx/84xx
  (bnc#853685 FATE#315935).
- qlcnic: Do not read QLCNIC_FW_CAPABILITY_MORE_CAPS bit for
  83xx adapter (bnc#853685 FATE#315935).
- qlcnic: Do not force adapter to perform LRO without destination
  IP check (bnc#853685 FATE#315935).
- net: qlcnic: remove unnecessary pci_set_drvdata() (bnc#853685
  FATE#315935).
- qlcnic: update version to 5.3.51 (bnc#853685 FATE#315935).
- qlcnic: Skip unknown entry type while collecting firmware dump
  (bnc#853685 FATE#315935).
- qlcnic: dcb code cleanup and refactoring (bnc#853685
  FATE#315935).
- qlcnic: Remove redundant eSwitch enable commands (bnc#853685
  FATE#315935).
- qlcnic: Update ethtool standard pause settings (bnc#853685
  FATE#315935).
- qlcnic: Firmware dump collection when auto recovery is disabled
  (bnc#853685 FATE#315935).
- qlcnic: Enhance ethtool to display ring indices and interrupt
  mask (bnc#853685 FATE#315935).
- qlcnic: Print informational messages only once during driver
  load (bnc#853685 FATE#315935).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bnc#853685 FATE#315935).
- commit 7c8c5c0
* Mon Jan 20 2014 bpoirier@suse.de
- ixgbevf: merge ixgbevf_tx_map and ixgbevf_tx_queue into a
  single function (bnc#857402 FATE#315667).
- ixgbevf: redo dma mapping using the tx buffer info (bnc#857402
  FATE#315667).
- ixgbevf: make the first tx_buffer a repository for most of
  the skb info (bnc#857402 FATE#315667).
- ixgbevf: add tx counters (bnc#857402 FATE#315667).
- ixgbevf: remove counters for Tx/Rx checksum offload (bnc#857402
  FATE#315667).
- ixgbevf: move ring specific stats into ring specific structure
  (bnc#857402 FATE#315667).
- ixgbevf: make use of the dev pointer in the ixgbevf_ring struct
  (bnc#857402 FATE#315667).
- ixgbevf: bump version (bnc#857402 FATE#315667).
- ixgbevf: create function for all of ring init (bnc#857402
  FATE#315667).
- ixgbevf: Convert ring storage form pointer to an array to
  array of pointers (bnc#857402 FATE#315667).
- ixgbevf: use pci drvdata correctly in ixgbevf_suspend()
  (bnc#857402 FATE#315667).
- ixgbevf: set the disable state when ixgbevf_qv_disable is called
  (bnc#857402 FATE#315667).
- ixgbevf: add DCB configuration into queue setup (bnc#857402
  FATE#315667).
- ixgbe: Focus config of head, tail ntc, and ntu all into a
  single function (bnc#857402 FATE#315667).
- ixgbe: cleanup IXGBE_DESC_UNUSED (bnc#857402 FATE#315667).
- ixgbevf: remove redundant workaround (bnc#857402 FATE#315667).
- ixgbevf: Add zero_base handler to network statistics (bnc#857402
  FATE#315667).
- ixgbevf: add BP_EXTENDED_STATS for CONFIG_NET_RX_BUSY_POLL
  (bnc#857402 FATE#315667).
- ixgbevf: implement CONFIG_NET_RX_BUSY_POLL (bnc#857402
  FATE#315667).
- ixgbevf: have clean_rx_irq return total_rx_packets cleaned
  (bnc#857402 FATE#315667).
- ixgbevf: add ixgbevf_rx_skb (bnc#857402 FATE#315667).
- ixgbevf: bump driver version (bnc#857402 FATE#315667).
- ixgbevf: implement ethtool get/set coalesce (bnc#857402
  FATE#315667).
- ixgbevf: Adds function to set PSRTYPE register (bnc#857402
  FATE#315667).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bnc#857402 FATE#315667).
- ixgbevf: move API neg to reset path (bnc#857402 FATE#315667).
- ixgbevf: add wait for Rx queue disable (bnc#857402 FATE#315667).
- ixgbevf: cleanup redundant mailbox read failure check
  (bnc#857402 FATE#315667).
- ixgbevf: do not print registers to dmesg in ixgbevf_get_regs
  (bnc#857402 FATE#315667).
- intel: Remove extern from function prototypes (bnc#857402
  FATE#315667).
- DMA-API: net: intel/ixgbevf: fix 32-bit DMA mask handling
  (bnc#857402 FATE#315667).
- commit ffd52c2
* Mon Jan 20 2014 bpoirier@suse.de
- ixgbe: bump version number (bnc#857401 FATE#315668).
- ixgbe: add braces around else condition in ixgbe_qv_lock_*
  calls (bnc#857401 FATE#315668).
- ixgbe: set driver_max_VFs should be done before enabling SRIOV
  (bnc#857401 FATE#315668).
- ixgbe: define IXGBE_MAX_VFS_DRV_LIMIT macro and cleanup const 63
  (bnc#857401 FATE#315668).
- ixgbe: Fix incorrect logic for fixed fiber eeprom write
  (bnc#857401 FATE#315668).
- ixgbe: reinit_locked() should be called with rtnl_lock
  (bnc#857401 FATE#315668).
- ixgbe: Clear head write-back registers on VF reset (bnc#857401
  FATE#315668).
- ixgbe: Force QDE via PFQDE for VFs during reset (bnc#857401
  FATE#315668).
- ixgbe: Additional adapter removal checks (bnc#857401
  FATE#315668).
- ixgbe: Check for adapter removal on register writes (bnc#857401
  FATE#315668).
- ixgbe: Check register reads for adapter removal (bnc#857401
  FATE#315668).
- ixgbe: Make ethtool register test use accessors (bnc#857401
  FATE#315668).
- ixgbe: Use static inlines instead of macros (bnc#857401
  FATE#315668).
- ixbge: Protect ixgbe_down with __IXGBE_DOWN bit (bnc#857401
  FATE#315668).
- ixgbe: Indicate removal state explicitly (bnc#857401
  FATE#315668).
- net: core: explicitly select a txq before doing l2 forwarding
  (bnc#857401 FATE#315668).
- net: ixgbe: slight optimization of addr compare (bnc#857401
  FATE#315668).
- ixgbe: fix for unused variable warning with certain config
  (bnc#857401 FATE#315668).
- ixgbe: Start temperature sensor attribute index with 1
  (bnc#857401 FATE#315668).
- ixgbe: Convert to use devm_hwmon_device_register_with_groups
  (bnc#857401 FATE#315668).
- hwmon: Provide managed hwmon registration (bnc#857401
  FATE#315668).
- ixgbe: Make ixgbe_identify_qsfp_module_generic static
  (bnc#857401 FATE#315668).
- ixgbe: turn NETIF_F_HW_L2FW_DOFFLOAD off by default (bnc#857401
  FATE#315668).
- ixgbe: ixgbe_fwd_ring_down needs to be static (bnc#857401
  FATE#315668).
- ixgbe: add warning when max_vfs is out of range (bnc#857401
  FATE#315668).
- ixgbe: deleting dfwd stations out of order can cause null ptr
  deref (bnc#857401 FATE#315668).
- ixgbe: fix build err, num_rx_queues is only available with
  CONFIG_RPS (bnc#857401 FATE#315668).
- ixgbe: enable l2 forwarding acceleration for macvlans
  (bnc#857401 FATE#315668).
- net: Add layer 2 hardware acceleration operations for macvlan
  devices (bnc#857401 FATE#315668).
- net: add adj_list to save only neighbours (bnc#857401
  FATE#315668).
- net: use lists as arguments instead of bool upper (bnc#857401
  FATE#315668).
- ixgbe: fix inconsistent clearing of the multicast table
  (bnc#857401 FATE#315668).
- ixgbe: Reduce memory consumption with larger page sizes
  (bnc#857401 FATE#315668).
- ixgbe: remove unnecessary duplication of PCIe bandwidth display
  (bnc#857401 FATE#315668).
- ixgbe: show <2%% for encoding loss on PCIe Gen3 (bnc#857401
  FATE#315668).
- ixgbe: fix qv_lock_napi call in ixgbe_napi_disable_all
  (bnc#857401 FATE#315668).
- ixgbe: fix rx-usecs range checks for BQL (bnc#857401
  FATE#315668).
- ixgbe: use pcie_capability_read_word() to simplify code
  (bnc#857401 FATE#315668).
- ixgbe: cleanup ixgbe_enumerate_functions (bnc#857401
  FATE#315668).
- net:drivers/net: Miscellaneous conversions to ETH_ALEN
  (bnc#857401 FATE#315668).
- ixgbe: remove marketing names from busy poll code (bnc#857401
  FATE#315668).
- ixgbe: Cleanup the use of tabs and spaces (bnc#857401
  FATE#315668).
- ixgbe: ethtool DCB registers dump for 82599 and x540 (bnc#857401
  FATE#315668).
- intel: Remove extern from function prototypes (bnc#857401
  FATE#315668).
- DMA-API: net: intel/ixgbe: fix 32-bit DMA mask handling
  (bnc#857401 FATE#315668).
- commit 6bf87e9
* Mon Jan 20 2014 jslaby@suse.cz
- Linux 3.12.8 (FATE#315942 bnc#848336 bnc#856380).
- Refresh
  patches.drivers/cpufreq_pstate_intel_refactor_driver.patch.
- Refresh
  patches.drivers/sfc-0012-sfc-Remove-extern-from-function-prototypes.patch.
- Refresh
  patches.fixes/macvlan-introduce-IFF_MACVLAN-flag-and-helper-functi.patch.
- Delete
  patches.drivers/sfc-0015-sfc-Add-length-checks-to-efx_xmit_with_hwtstamp-and-.patch.
- Delete
  patches.drivers/sfc-0016-sfc-PTP-Moderate-log-message-on-event-queue-overflow.patch.
- Delete
  patches.drivers/sfc-0017-sfc-Rate-limit-log-message-for-PTP-packets-without-a.patch.
- Delete
  patches.drivers/sfc-0018-sfc-Stop-re-start-PTP-when-stopping-starting-the-dat.patch.
- Delete
  patches.drivers/sfc-0019-sfc-Maintain-current-frequency-adjustment-when-apply.patch.
- Delete
  patches.drivers/sfc-0020-sfc-RX-buffer-allocation-takes-prefix-size-into-acco.patch.
- Delete
  patches.drivers/sfc-0021-sfc-Refactor-efx_mcdi_poll-by-introducing-efx_mcdi_p.patch.
- Delete
  patches.drivers/sfc-0022-sfc-Poll-for-MCDI-completion-once-before-timeout-occ.patch.
- Delete
  patches.fixes/sched-Fix-cfs_bandwidth-misuse-of-hrtimer_expires_remaining.patch.
- Delete
  patches.fixes/sched-Fix-hrtimer_cancel-vs-rq-lock-deadlock.patch.
- Delete
  patches.fixes/sched-Fix-race-on-toggling-cfs_bandwidth_used.patch.
- Delete
  patches.fixes/sched-Guarantee-new-group-entities-always-have-weight.patch.
- commit 0bdc567
* Fri Jan 17 2014 lduncan@suse.com
- No longer supporting old way of setting this flag, as planned.
- commit 4e25365
* Fri Jan 17 2014 ohering@suse.de
- xen: pv-on-hvm: skip initialization of emulated devices
  (fate#311487).
- commit 18b2e08
* Fri Jan 17 2014 jeffm@suse.com
- scripts/log, scripts/log2: Filter out leading colon in subjects.
  A recent commit with a subject of the format:
  "Subject: [SUBSYS]: driver: blahblah" caused a commit message of:
  ": driver: blablah" to be generated. Let's clear out the colon.
- commit 734fe9b
* Fri Jan 17 2014 jeffm@suse.com
- scripts/log: uses bashisms so should explicitly call bash
  On non-SUSE systems, other shells may be used as /bin/sh. This has
  been observed to cause runtime failures.
- commit 15dff55
* Fri Jan 17 2014 spargaonkar@suse.com
- : ipr: Increase msi-x interrupt vectors to 16 (bnc#858630
  FATE#315742).
- commit 8293791
* Fri Jan 17 2014 mmarek@suse.cz
- rpm/config.sh: Do not build the KOTD against Factory
- commit 49ef1e1
* Fri Jan 17 2014 hare@suse.de
- scsi_error: disable eh_deadline if no host_reset_handler is set
  (FATE#316307).
- Update documentation (FATE#316307).
- Set the minimum valid value of 'eh_deadline' as 0 (FATE#316307).
- Unlock accesses to eh_deadline (FATE#316307).
- improved eh timeout handler (FATE#316307).
- Fix erratic device offline during EH (FATE#316307).
- commit b1f88fe
* Fri Jan 17 2014 oneukum@suse.de
- Delete patches.suse/xhci-Add-xhci_disable_ports-boot-option. SP3->SLE12
  not usable in this form. Sorry for the mistake.
- commit 3f74207
* Fri Jan 17 2014 oneukum@suse.de
- Delete patches.fixes/elousb-firmware-m-quirk.patch. SP3->SLE12 unneeded patch.
- commit fad6ef3
* Fri Jan 17 2014 hare@suse.de
- Backport eh_deadline patches from mainline (bnc#798050)
- Add 'eh_deadline' to limit SCSI EH runtime (bnc#798050).
- scsi_error: Escalate to LUN reset if abort fails (bnc#798050).
- advansys: Remove 'last_reset' references (bnc#798050).
- dc395: Move 'last_reset' into internal host structure
  (bnc#798050).
- dpt_i2o: Remove DPTI_STATE_IOCTL (bnc#798050).
- dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset
  (bnc#798050).
- remove check for 'resetting' (bnc#798050).
- tmscsim: Move 'last_reset' into host structure (bnc#798050).
- commit 8ad7d1f
* Fri Jan 17 2014 hare@suse.de
- Review some more SP3 patches
- Delete patches.fixes/fixup-section-annotations.
- Delete patches.fixes/scsi-Fixup-compilation-warning.patch.
- commit 945e3e9
* Fri Jan 17 2014 oneukum@suse.de
- Delete patches.drivers/elousb-update-apis. SP3->SLE12 unneeded patch.
- commit 6073af7
* Fri Jan 17 2014 tiwai@suse.de
- ACPI: add missing win8 OSI comment to blacklist (bnc#856294).
- ACPI: update win8 OSI blacklist (bnc#856294).
- Refresh
  patches.arch/ACPI-Blacklist-Win8-OSI-for-some-HP-laptop-2013-mode.
- commit 56992ec
* Fri Jan 17 2014 tiwai@suse.de
- ACPI: Blacklist Win8 OSI for some HP laptop 2013 models
  (bnc#856294).
- commit a5b3f01
* Fri Jan 17 2014 tiwai@suse.de
- Remove obsoleted workarounds for LVDS modeset bugs on HP laptops
  patches.drivers/drm-i915-lvds-disable-at-modeset-for-hp-elitebook
  patches.drivers/drm-i915-lvds-disable-at-modeset-for-hp-probook
- commit 8ebcb9b
* Fri Jan 17 2014 tiwai@suse.de
- Apply patches.drivers/hp_accel-Add-a-new-PnP-ID-HPQ6007-for-new-HP-laptops
- commit 978a4c5
* Fri Jan 17 2014 tiwai@suse.de
- Removed a few obsoleted sle11-sp3 patches
- commit 701f598
* Fri Jan 17 2014 oneukum@suse.de
- Remove patches from SP3 under review. They are no longer needed.
- Delete
  patches.drivers/0001-uvc-increase-number-of-buffers.patch.
- Delete
  patches.drivers/0005-modify-hub-to-detect-unplugs-in-all-states.patch.
- Delete patches.drivers/xhci_register_fixup.diff.
- Delete
  patches.suse/0001-USB-pwc-add-dummy-module-parameter.patch.
- Delete patches.suse/0001-USB-resurrect-the-vstusb-driver.patch.
- Delete
  patches.suse/0001-USB-usbvision-add-compatibility-module-parameters.patch.
- Delete
  patches.suse/0001-USB-usbvision-more-compatibility-parameters.patch.
- Delete
  patches.suse/0001-elousb-really-long-delays-for-broken-devices.patch.
- Delete
  patches.suse/0001-storage-SMI-Corporation-usb-key-added-to-READ_CAPACI.patch.
- commit a1cdd4b
* Fri Jan 17 2014 hare@suse.de
- Drop I2O support (FATE#316786)
- commit 669458a
* Fri Jan 17 2014 hare@suse.de
- supported.conf: drop dm-leastpending (FATE#316861)
- commit 9077dd6
* Fri Jan 17 2014 hare@suse.de
- patches.fixes/dm-multipath-Improve-logging.patch: Fix compilation.
- commit cce6d73
* Fri Jan 17 2014 hare@suse.de
- Remove obsolete dm-thin backport patches
  * patches.suse/dm-thin-0003-dm-table-share-target-argument-parsing-functions.patch.fix.
  * patches.suse/dm-thin-0011-dm-add-bufio.patch.fix.
  * patches.suse/dm-thin-0012-dm-add-persistent-data-library.patch.fix.
  * patches.suse/dm-thin-0090-dm-thin-commit-before-gathering-status.patch.fix.
- commit e20f582
* Fri Jan 17 2014 hare@suse.de
- Review dm-multipath patches
- Refresh patches:
  * dm-multipath: Improve logging
  * multipath devices are not getting created for readonly devices
    (bnc#382705).
  * dm-multipath: Accept failed paths for multipath maps
    (bnc#458037,bnc#458393).
  * dm-multipath: Do not activate offlined paths (bnc#484529).
- Delete obsolete patches:
  * patches.fixes/dm-mpath-Fixup-race-condition-in-activate_path.patch.
  * patches.fixes/dm-mpath-reattach-dh.
  * patches.fixes/dm-release-map_lock-before-set_disk_ro.
  * patches.suse/dm-mpath-leastpending-path-update.
  * patches.suse/dm-mpath-leastpending-select-path-fix.
  * patches.suse/dm-mpath-leastpending-status-display-fix.
  * patches.suse/dm-mpath-skip-disabled-devices-when-iterating.
  * patches.suse/mpath-fix.
- commit 61ea8be
* Fri Jan 17 2014 hare@suse.de
- Review SP3 patches
- Delete obsolete patches:
  * patches.drivers/0033-be2net-Changed-version-to-4.1.227.patch.
  * patches.drivers/ibmvfc-fix-for-offlining-devices.patch.
  * patches.fixes/iscsi_target-race-condition-on-shutdown.patch.
- Enable
  patches.drivers/aacraid-export-fixed-module-param
- commit 7ef6a53
* Fri Jan 17 2014 spargaonkar@suse.com
- SCSI: remove unnecessary pci_set_drvdata() (FATE#315939).
- bfa: Use pcie_set()/get_readrq() to simplify code (FATE#315939).
- bnx2fc: Bump version from 1.0.14 to 2.4.1 (FATE#316095).
- BNX2FC: hung task timeout warning observed when rmmod bnx2x
  with active FCoE targets (FATE#316095).
- bnx2fc: Fixed a SCSI CMD cmpl race condition between ABTS and
  CLEANUP (FATE#316095).
- commit 210ed8a
* Fri Jan 17 2014 jeffm@suse.de
- scripts/log2: uses bashisms so should explicitly call bash
  On non-SUSE systems, other shells may be used as /bin/sh. This has
  been observed to cause runtime failures.
- commit 238691e
* Thu Jan 16 2014 jeffm@suse.com
- Revert "Changes for FATE#315939 and FATE#316095"
  This reverts commit b8f25f3fc9d7eeba98e79726859763180c46e25a.
  Needs a real commit message.
- commit 920e753
* Thu Jan 16 2014 spargaonkar@suse.com
- Changes for FATE#315939 and FATE#316095
- commit b8f25f3
* Thu Jan 16 2014 ohering@suse.de
- Drivers: hv: vmbus: Don't timeout during the initial connection
  with host.
- commit a3b6ad2
* Thu Jan 16 2014 mmarek@suse.cz
- Delete patches.fixes/keyspan-firmware-install.patch
  Upstream did not take it and the files are in the kernel-firmware
  package.
- commit 944c90a
* Thu Jan 16 2014 mmarek@suse.cz
- patches.fixes/X.509-time-h-include: Replace with upstream version
- commit bf627f5
* Thu Jan 16 2014 mmarek@suse.cz
- Delete patches.drivers/bnx2x-advance-version.patch.
  SLE11-specific patch.
- commit 2a1dfd9
* Thu Jan 16 2014 mmarek@suse.cz
- Delete patches.drivers/sfc-dummy-option.
  This was only needed for compatibility among SLE11 service packs.
- commit 2788c52
* Thu Jan 16 2014 ohering@suse.de
- Drivers: hv: vmbus: Specify the target CPU that should receive
  notification.
- commit 0f0ca1d
* Thu Jan 16 2014 mgorman@suse.de
- mm/sparsemem: fix a bug in free_map_bootmem when
  CONFIG_SPARSEMEM_VMEMMAP (Node memory hot remove (fate#316483)).
- mm/sparsemem: use PAGES_PER_SECTION to remove redundant nr_pages
  parameter (Node memory hot remove (fate#316483)).
- mem-hotplug: introduce movable_node boot option (Node memory
  hot remove (fate#316483)).
- x86, acpi, crash, kdump: do reserve_crashkernel() after SRAT
  is parsed (Node memory hot remove (fate#316483)).
- x86/mem-hotplug: support initialize page tables in bottom-up
  (Node memory hot remove (fate#316483)).
- x86/mm: factor out of top-down direct mapping setup (Node
  memory hot remove (fate#316483)).
- mm/memblock.c: introduce bottom-up allocation mode (Node memory
  hot remove (fate#316483)).
- mm/memblock.c: factor out of top-down allocation (Node memory
  hot remove (fate#316483)).
- x86/mm: Add 'step_size' comments to init_mem_mapping() (Node
  memory hot remove (fate#316483)).
- commit 36a6fe8
* Thu Jan 16 2014 mmarek@suse.cz
- Delete SP3 patches that turned out to be backports
- commit 0a83f58
* Thu Jan 16 2014 mmarek@suse.cz
- Delete patches that have been removed from series.conf
- commit e2811f6
* Thu Jan 16 2014 bpoirier@suse.de
- be2net: update driver version to 10.0.x (bnc#855062
  FATE#315961).
- be2net: cleanup wake-on-lan code (bnc#855062 FATE#315961).
- be2net: use GET_MAC_LIST cmd to query mac-address from a pmac-id
  (bnc#855062 FATE#315961).
- be2net: do not use frag index in the RX-compl entry (bnc#855062
  FATE#315961).
- be2net: Remove "10Gbps" from driver description string
  (bnc#855062 FATE#315961).
- be2net: fix incorrect setting of cmd_privileges for VFs
  (bnc#855062 FATE#315961).
- be2net: ignore mac-addr set call for an already programmed
  mac-addr (bnc#855062 FATE#315961).
- be2net: do not call be_set/get_fw_log_level() on Skyhawk-R
  (bnc#855062 FATE#315961).
- be2net: Log the profile-id used by FW during driver
  initialization (bnc#855062 FATE#315961).
- be2net: don't set "pport" field when querying "pvid" (bnc#855062
  FATE#315961).
- be2net: Use MCC_CREATE_EXT_V1 cmd for Skyhawk-R (bnc#855062
  FATE#315961).
- commit 9e90e34
* Thu Jan 16 2014 oneukum@suse.de
- [SCSI] sd: Add error handling during flushing caches
  (bnc#639803).
- commit f2ef2cf
* Thu Jan 16 2014 duwe@suse.de
- Delete patches.arch/ppc-fate-312285-1.
  [#]defines PCIE_DEVICE_ID_NEO_2_OX_IBM in linux/pci_ids.h,
  but since kernel 3.0 this cpp constant is already in
  drivers/tty/serial/8250_pci.c
- Delete patches.arch/s390-35-02-page-referenced,
- Delete patches.suse/ppc-dlpar_call_notifier_first.
  Functionality is upstream, in a rewritten code base.
- Delete patches.arch/s390-35-04-zfcp-disable-auto-lun-scan.
  This change of a default was so that SLE11SP3 wouldn't
  differ in behaviour from SP2. SLE12 now sticks to the
  current upstream.
- Delete patches.arch/s390-35-06-zfcp-kmsg-lun-limit-reached.
  IBM will provide a fresh version of kmsg for SLE12.
- commit bdd4af8
* Thu Jan 16 2014 ohering@suse.de
- Drivers: input: serio:hyperv-keyoard: Handle 0xE1 prefix.
- commit 61237de
* Thu Jan 16 2014 ohering@suse.de
- hyperv_fb: Add screen refresh after pause/resume operation.
- commit 1ee61b2
* Thu Jan 16 2014 ohering@suse.de
- hyperv: Fix race between probe and open calls.
- commit c741272
* Thu Jan 16 2014 ohering@suse.de
- patch review: remove obsolete sles11 only patches
- Delete patches.suse/suse-hv-HV_DRV_VERSION.patch.
- Delete patches.suse/suse-hv-bind-hv_blkkvsc-to-hv_storvsc.patch.
- Delete patches.suse/suse-hv-bind-hv_mouse-to-hid-hyperv.patch.
- Delete patches.suse/suse-hv-hv_kvp-sles11sp2-negotiate-serveral-versions.patch.
- Delete patches.suse/suse-hv-storvsc-scsi-proc_name.patch.
- commit 85de97f
* Thu Jan 16 2014 hare@suse.de
- Fixup
  patches.drivers/megaraid-sas-boot-hangs-while-LD-is-offline.patch.
- commit 14cbcea
* Thu Jan 16 2014 mgorman@suse.de
- x86: mm: Change tlb_flushall_shift for IvyBridge
  (VM Performance).
- commit 6484340
* Thu Jan 16 2014 hare@suse.de
- Review megaraid_sas patches
- Refresh patches.drivers/megaraids-sas-boot-hangs-while-LD-is-offline.patch
- Enable patches.drivers/megaraid_Disable-controller-reset-for-ppc.patch
- Delete patches.drivers/megaraid_sas_fix_kdump.patch.
- commit 0ad23a1
* Thu Jan 16 2014 mgorman@suse.de
- mm: vmstat: Do not display stats for TLB flushes unless debugging
  (VM Performance).
- commit c6492ce
* Thu Jan 16 2014 mgorman@suse.de
- mm: numa: serialise parallel get_user_page against THP migration pmd-locking
  (Automatic NUMA Balancing (fate#315482)).
- commit 42b6a37
* Thu Jan 16 2014 mgorman@suse.de
- mm: numa: avoid unnecessary disruption of NUMA hinting during migration pmd-locking
  (Automatic NUMA Balancing (fate#315482)).
- commit 0625200
* Thu Jan 16 2014 hare@suse.de
- lpfc: Fix typo on NULL assignment (bnc#854999,FATE#315959).
- lpfc 8.3.43: Update lpfc version to driver version 8.3.43
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed not processing task management IOCB
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed spinlock hang (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed invalid Total_Data_Placed value received
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed invalid fcp_rsp length fir FCP_ICMND
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed invalid mailbox timeouts
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fixed spinlock inversion problem
  (bnc#854999,FATE#315959).
- lpfc 8.3.43: Fix crash after xri limit is reached
  (bnc#854999,FATE#315959).
- lpfc: remove unnecessary read of PCI_CAP_ID_EXP
  (bnc#854999,FATE#315959).
- commit 1026ec4
* Thu Jan 16 2014 jlee@suse.com
- This patch merged to mainline in v3.10, commit 04b00bdb. So removed this
  patch from SLE-12:
  Delete
  patches.fixes/0002-X.509-Support-parse-long-form-of-length-octets-in-Au.patch.
- commit adfd8c9
* Thu Jan 16 2014 jlee@suse.com
- Removed Avoton SoC backported patch for upstream moved to mfd driver
  Removed the following patch because Avoton SoC watchdog driver used mfd
  in 3.12 kernel.
  Delete
  patches.drivers/iTCO_wdt-Watchdog-GPIO-patch-for-intel-Avoton-SoC.patch.
- commit 8ba2d4a
* Thu Jan 16 2014 jlee@suse.com
- Remove dummy option patches of r8169 and via-velocity
  Base on bnc#720459, the folllowing 3 patches add dummy option of
  kernel module for backwards compatibility. So, removed them from
  SLE12:
- Delete patches.drivers/r8169-dummy-option.
- Delete patches.drivers/via-velocity-dummy-option.
- Delete patches.drivers/via-velocity-revive-txcsum_offload.
- commit 42268f8
* Thu Jan 16 2014 neilb@suse.de
- NFS: make nfs_flush_incompatible more generous (bnc#816099).
- commit 46e6736
* Thu Jan 16 2014 neilb@suse.de
- Delete
  patches.fixes/bug-795354_Allow-sec-none-mounts-in-certain-cases.patch.
  This is made redundant by:
  commit d497ab975141666e674e7bd8729e00095ec23c9d
  Author: Weston Andros Adamson <dros@netapp.com>
  Date:   Mon May 6 17:12:13 2013 -0400
    NFSv3: match sec= flavor against server list
  in v3.10
- commit b052a54
* Thu Jan 16 2014 neilb@suse.de
- Delete patches.fixes/nfs-umount-fix.
  This has been made redundant by:
  commit 8033426e6bdb2690d302872ac1e1fadaec1a5581
  Author: Jeff Layton <jlayton@redhat.com>
  Date:   Fri Jul 26 06:23:25 2013 -0400
    vfs: allow umount to handle mountpoints without revalidating them
  in v3.12
- commit 3819538
* Thu Jan 16 2014 neilb@suse.de
- Delete patches.fixes/nfs-reval-dot.fix.
  Made redundant by
  commit ecf3d1f1aa74da0d632b651a2e05a911f60e92c0
  Author: Jeff Layton <jlayton@redhat.com>
  Date:   Wed Feb 20 11:19:05 2013 -0500
    vfs: kill FS_REVAL_DOT by adding a d_weak_revalidate dentry op
  in v3.9
- commit dec6332
* Thu Jan 16 2014 neilb@suse.de
- Refresh patches.suse/nfs-no-share-transport.
  Added a missing stanza
- commit f9e96d3
* Thu Jan 16 2014 neilb@suse.de
- md/failfast:  add failfast flag for md to be used by some personalities (Fate#311379).
- md/raid1 add failfast handling for reads (Fate#311379).
- md/raid1 - add failfast handling for writes (Fate#311379).
- md/raid10 add failfast handling for reads (Fate#311379).
- md/raid10 - add failfast handling for writes (Fate#311379).
- Use FAILFAST on metadata writes where appropriate (FATE#311379).
- Cause IO to O_DIRECT|O_NONBLOCK devices to use REQ_FAILFAST_DEV (bnc#750141).
- Abort pending request for RAID10 (bnc#773251).
- md/bitmap: Don't write bitmap while earlier writes might be in-flight (bnc#771398).
- md: display timeout errors in /etc/mdstat etc (bnc#763402).
- md/raid10: expedite the removal of lots of devices (bnc#768084).
- md/raid10: Don't print RAID10 conf messages for large arrays (bnc#768084).
- md: add raid10 tracepoints (bnc#768084).
- md: unblock 'SET_DISK_FAULTY' ioctl (bnc#768084).
- Don't take mddev lock when reading rdev attributes from sysfs (bnc#772420).
- md: perform async updates for metadata where possible (bnc#768084).
- md: wakeup thread upon rdev_dec_pending() (bnc#771398)
- commit 3f703a5
* Wed Jan 15 2014 bpoirier@suse.de
- e1000: fix possible reset_task running after adapter down
  (bnc#857400 FATE#315649).
- e1000: fix lockdep warning in e1000_reset_task (bnc#857400
  FATE#315649).
- e1000: prevent oops when adapter is being closed and reset
  simultaneously (bnc#857400 FATE#315649).
- e1000: fix wrong queue idx calculation (bnc#857400 FATE#315649).
- intel: Remove extern from function prototypes (bnc#857400
  FATE#315649).
- DMA-API: net: intel/e1000: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#857400 FATE#315649).
- commit 9cfda37
* Wed Jan 15 2014 bpoirier@suse.de
- e1000e: Implement the SIOCGHWTSTAMP ioctl (bnc#857399
  FATE#315648).
- e1000e: Fix a compile flag mis-match for suspend/resume
  (bnc#857399 FATE#315648).
- e1000e: fix compiler warning (maybe-unitialized variable)
  (bnc#857399 FATE#315648).
- e1000e: fix compiler warnings (bnc#857399 FATE#315648).
- e1000e: Validate hwtstamp_config completely before applying it
  (bnc#857399 FATE#315648).
- intel: Remove extern from function prototypes (bnc#857399
  FATE#315648).
- DMA-API: net: intel/e1000e: fix 32-bit DMA mask handling
  (bnc#857399 FATE#315648).
- commit 7bc98e3
* Wed Jan 15 2014 bpoirier@suse.de
- net: benet: slight optimization of addr compare (bnc#855062
  FATE#315961).
- net: emulex-benet calls skb_set_hash (bnc#855062 FATE#315961).
- commit 7d89b00
* Wed Jan 15 2014 jeffm@suse.com
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
  CONFIG_ENTERPRISE_SUPPORT -> CONFIG_SUSE_KERNEL_SUPPORTED
- commit 25b7a4e
* Wed Jan 15 2014 hare@suse.de
- NVMe: Disable admin queue on init failure
  (bnc#858774,FATE#315511).
- NVMe: Dynamically allocate partition numbers
  (bnc#858774,FATE#315511).
- NVMe: Async IO queue deletion (bnc#858774,FATE#315511).
- NVMe: Surprise removal handling (bnc#858774,FATE#315511).
- NVMe: Abort timed out commands (bnc#858774,FATE#315511).
- NVMe: Schedule reset for failed controllers
  (bnc#858774,FATE#315511).
- NVMe: Device resume error handling (bnc#858774,FATE#315511).
- NVMe: Cache dev->pci_dev in a local pointer
  (bnc#858774,FATE#315511).
- NVMe: Fix lockdep warnings (bnc#858774,FATE#315511).
- NVMe: compat SG_IO ioctl (bnc#858774,FATE#315511).
- NVMe: remove deprecated IRQF_DISABLED (bnc#858774,FATE#315511).
- NVMe: Avoid shift operation when writing cq head doorbell
  (bnc#858774,FATE#315511).
- commit 215bf71
* Wed Jan 15 2014 hare@suse.de
- Delete
  patches.drivers/sd_dif-problem-with-verify-of-type-1-protection-information.
- commit e861d6b
* Wed Jan 15 2014 hare@suse.de
- Remove obsolete cciss patches (FATE#315362)
  * patches.drivers/cciss-kdump-fails-on-p410i.patch.
  * patches.drivers/cciss-stable-controller-enumeration.patch.
  * patches.drivers/cciss-update-to-4.6.28.patch.
  * patches.drivers/cciss_fix_const.patch.
  * patches.fixes/cciss-unmap-xfer-buffer-correctly.
- commit 520ad3f
* Wed Jan 15 2014 hare@suse.de
- cciss: Set 'cciss_allow_hpsa' per default (FATE#316683).
- supported.conf: mark cciss as unsupported
- commit 3f3a588
* Wed Jan 15 2014 hare@suse.de
- hpsa: Enable 'hpsa_allow_any' per default (FATE#316683).
- commit 9e53801
* Wed Jan 15 2014 hare@suse.de
- hpsa: marking older boards as unsupported (FATE#316683).
- hpsa: fixup MSI-X registration (bnc#858854, FATE#316683).
- commit d437b36
* Wed Jan 15 2014 neilb@suse.de
- Delete patches.fixes/md-get-bitmap-file.fix.
- Delete patches.suse/md-Do-not-block-when-displaying-info.patch.
  This are already upstream, though in a different-looking patch,
  in commit 1ca69c4bc4b1ef889861db39f325901eadbf9497
- commit 05a542f
* Tue Jan 14 2014 neilb@suse.de
- Delete
  patches.fixes/net-sunrpc-xpt_auth_cache-should-be-ignored-when-exp.patch.
- Delete
  patches.fixes/sunrpc-cache-ensure-items-removed-from-cache-do-not-.patch.
- Delete
  patches.fixes/sunrpc-cache-remove-races-with-queuing-an-upcall.patch.
- Delete
  patches.fixes/sunrpc-cache-use-cache_fresh_unlocked-consistently-a.patch.
  All these are in 3.11
- commit ce0e66e
* Tue Jan 14 2014 neilb@suse.de
- Delete patches.fixes/nfs-execute-only-files.
  This is superceded by commit f8d9a897d4384b77f13781ea813156568f68b83e in v3.8
- commit a8fc3db
* Tue Jan 14 2014 neilb@suse.de
- Avoid softlockup in shrink_dcache_for_umount_subtree. (bnc#834473)
- commit 461accc
* Tue Jan 14 2014 neilb@suse.de
- NFS: support "nosharetransport" option (bnc#807502, bnc#828192, FATE#315593)
  Forward-port from 11-SP3.  Upstream aren't interested in this.
- commit 4998be4
* Tue Jan 14 2014 neilb@suse.de
- SUNRPC: close a rare race in xs_tcp_setup_socket (bnc#794824).
- commit e3fb5af
* Tue Jan 14 2014 bpoirier@suse.de
- sfc: fix sparse non static symbol warning (bnc#856380
  FATE#315942).
- net: sfc calls skb_set_hash (bnc#856380 FATE#315942).
- sfc: Fix RX drop filters for EF10 (bnc#856380 FATE#315942).
- sfc: Add PTP counters to ethtool stats (bnc#856380 FATE#315942).
- sfc: Changed the statistic name emerg_{fetch,wait} to
  hlb_{fetch,wait} (bnc#856380 FATE#315942).
- sfc: remove unused 'enum efx_rx_alloc_method' (bnc#856380
  FATE#315942).
- sfc: remove unused 'refcnt' from efx_rx_page_state (bnc#856380
  FATE#315942).
- sfc: Implement efx_nic_type::filter_clear_rx operation for EF10
  (bnc#856380 FATE#315942).
- sfc: Allow filter removal only with exactly matching priority
  (bnc#856380 FATE#315942).
- sfc: Don't refer to 'stack' in filter implementation (bnc#856380
  FATE#315942).
- sfc: Change priority and flags for automatic MAC filters
  (bnc#856380 FATE#315942).
- sfc: Change efx_nic_type::rx_push_indir_table to push hash
  key as well (bnc#856380 FATE#315942).
- sfc: Add more information to many warnings using WARN() and
  netdev_WARN() (bnc#856380 FATE#315942).
- sfc: Remove unnecessary condition for processing the TX
  timestamp queue (bnc#856380 FATE#315942).
- sfc: Don't clear timestamps in efx_ptp_rx() (bnc#856380
  FATE#315942).
- sfc: Enable PTP clock and timestamping for all functions on EF10
  (bnc#856380 FATE#315942).
- sfc: Associate primary and secondary functions of controller
  (bnc#856380 FATE#315942).
- sfc: Store VPD serial number at probe time (bnc#856380
  FATE#315942).
- sfc: Add RX packet timestamping for EF10 (bnc#856380
  FATE#315942).
- sfc: Copy RX prefix into skb head area in efx_rx_mk_skb()
  (bnc#856380 FATE#315942).
- sfc: split setup of hardware timestamping into NIC-type
  operation (bnc#856380 FATE#315942).
- sfc: Add support for SFC9100 timestamp format (bnc#856380
  FATE#315942).
- sfc: Tidy up PTP synchronization code (bnc#856380 FATE#315942).
- sfc: PTP - tidy up unused/useless variables (bnc#856380
  FATE#315942).
- sfc: Remove kernel-doc for efx_ptp_data fields not present in
  this version (bnc#856380 FATE#315942).
- sfc: Initialise efx_ptp_data::phc_clock_info from a static
  template (bnc#856380 FATE#315942).
- sfc: Do not use MAC address as clock name (bnc#856380
  FATE#315942).
- sfc: Store flags from MC_CMD_DRV_ATTACH for later use
  (bnc#856380 FATE#315942).
- sfc: Remove dependency of PTP on having a dedicated channel
  (bnc#856380 FATE#315942).
- sfc: Split PTP multicast filter insertion/removal out of
  efx_ptp_{start,stop}() (bnc#856380 FATE#315942).
- sfc: Return EBUSY for filter insertion on EF10, matching
  Falcon/Siena (bnc#856380 FATE#315942).
- sfc: Expose NVRAM_PARTITION_TYPE_LICENSE on EF10 (bnc#856380
  FATE#315942).
- sfc: Fold efx_flush_all() into efx_stop_port() and update
  comments (bnc#856380 FATE#315942).
- sfc: Map MCDI error MC_CMD_ERR_ENOTSUP to Linux EOPNOTSUPP
  (bnc#856380 FATE#315942).
- sfc: Log all unexpected MCDI errors (bnc#856380 FATE#315942).
- sfc: Add new sensor names (bnc#856380 FATE#315942).
- sfc: Revise sensor names to be more understandable and
  consistent (bnc#856380 FATE#315942).
- sfc: Report units in sensor warnings (bnc#856380 FATE#315942).
- sfc: Correct RX dropped count for drops while interface is down
  (bnc#856380 FATE#315942).
- sfc: Make initial fill of RX descriptors synchronous (bnc#856380
  FATE#315942).
- sfc: Tighten the check for RX merged completion events
  (bnc#856380 FATE#315942).
- sfc: Add MC BISTs to ethtool offline self test on EF10
  (bnc#856380 FATE#315942).
- net: sfc: remove unnecessary pci_set_drvdata() (bnc#856380
  FATE#315942).
- sfc: Update MCDI protocol definitions (bnc#856380 FATE#315942).
- sfc: Demote "MC Scheduler error" messages (bnc#856380
  FATE#315942).
- sfc: Implement the SIOCGHWTSTAMP ioctl (bnc#856380 FATE#315942).
- sfc: Poll for MCDI completion once before timeout occurs
  (bnc#856380 FATE#315942).
- sfc: Refactor efx_mcdi_poll() by introducing
  efx_mcdi_poll_once() (bnc#856380 FATE#315942).
- sfc: RX buffer allocation takes prefix size into account in
  IP header alignment (bnc#856380 FATE#315942).
- sfc: Maintain current frequency adjustment when applying a
  time offset (bnc#856380 FATE#315942).
- sfc: Stop/re-start PTP when stopping/starting the datapath
  (bnc#856380 FATE#315942).
- sfc: Rate-limit log message for PTP packets without a matching
  timestamp event (bnc#856380 FATE#315942).
- sfc: PTP: Moderate log message on event queue overflow
  (bnc#856380 FATE#315942).
- sfc: Add length checks to efx_xmit_with_hwtstamp() and
  efx_ptp_is_ptp_tx() (bnc#856380 FATE#315942).
- sfc: Convert to use hwmon_device_register_with_groups
  (bnc#856380 FATE#315942).
- sfc: Fix DMA unmapping issue with firmware assisted TSO
  (bnc#856380 FATE#315942).
- sfc: Remove extern from function prototypes (bnc#856380
  FATE#315942).
- DMA-API: net: sfc/efx.c: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#856380 FATE#315942).
- sfc: Support ARFS for IPv6 flows (bnc#856380 FATE#315942).
- sfc: Use TX PIO for sufficiently small packets (bnc#856380
  FATE#315942).
- sfc: Introduce inline functions to simplify TX insertion
  (bnc#856380 FATE#315942).
- sfc: Separate out queue-empty check from
  efx_nic_may_push_tx_desc() (bnc#856380 FATE#315942).
- sfc: Allocate and link PIO buffers; map them with
  write-combining (bnc#856380 FATE#315942).
- sfc: Implement firmware-assisted TSO for EF10 (bnc#856380
  FATE#315942).
- sfc: Fold tso_get_head_fragment() into tso_start() (bnc#856380
  FATE#315942).
- sfc: Add EF10 registers to register dump (bnc#856380
  FATE#315942).
- sfc: efx_ef10_filter_update_rx_scatter() can be static
  (bnc#856380 FATE#315942).
- sfc: efx_ethtool_get_ts_info() can be static (bnc#856380
  FATE#315942).
- net: Add function to set the rxhash (bnc#856380 FATE#315942).
- net_tstamp: Add SIOCGHWTSTAMP ioctl to match SIOCSHWTSTAMP
  (bnc#856380 FATE#315942).
- net/compat: Merge multiple implementations of ifreq::ifr_data
  conversion (bnc#856380 FATE#315942).
- net/compat: Fix minor information leak in siocdevprivate_ioctl()
  (bnc#856380 FATE#315942).
- net_tstamp: Improve kernel-doc for struct hwtstamp_config
  (bnc#856380 FATE#315942).
- hwmon: Introduce hwmon_device_register_with_groups (bnc#856380
  FATE#315942).
- commit f0bda06
* Tue Jan 14 2014 jdelvare@suse.de
- Delete patches.arch/x86-mce-xeon75xx-fix-typo-causing-a-kernel-crash.patch
  A fixup for a driver we no longer ship, so it can be dropped.
- commit 7f67627
* Tue Jan 14 2014 msrb@suse.com
- Delete patches.drm/2215-radeon-fix-kmalloc_array.diff.
  * It was drm compability patch. kmalloc_array exists now.
- Delete patches.drm/2805-define-kuid_t.diff.
  * It was drm compability patch. kuid_t exists now.
- Delete patches.drm/2807-kbuild-fix-drm-include.diff.
  * It was drm compability patch. Not needed anymore.
- Delete patches.drm/3221-mgag200-kms-only-for-secure-boot.diff.
  * Use KMS everywhere now.
- Delete patches.drm/3222-cirrus-kms-only-for-secure-boot.diff.
  * Use KMS everywhere now.
- Delete patches.drm/3223-ast-kms-only-for-secure-boot.diff.
  * Use KMS everywhere now.
- Delete patches.drm/3241-revert-use-of-memchr_inv.diff.
  * It was drm compability patch. memchr_inv exists now.
- Delete patches.drm/3243-use-pm_qos_params_h.diff.
  * It was drm compability patch. pm_qos_params.h moved to pm_qos.h.
- commit bdf85b9
* Tue Jan 14 2014 hare@suse.de
- patches.fixes/scsi_dh_alua-Use-workqueue-for-RTPG.patch:
  fixup to avoid stall during boot.
- commit 7061e94
* Tue Jan 14 2014 hare@suse.de
- Disable Paralle IDE driver (FATE#316857).
- commit 3aa0131
* Tue Jan 14 2014 jdelvare@suse.de
- Delete patches.fixes/natsemi-long-cable-fix and patches.suse/trace-open.patch
  natsemi-long-cable-fix is only needed on old 32-bit machines, and
  trace-open.patch is the kernel side of a suse-specific utility which is
  superseded by systemd.
- commit 76cc96a
* Tue Jan 14 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Require kernel-devel%%variant
- commit 810ea41
* Tue Jan 14 2014 duwe@suse.de
- Make ppc64/vanilla build again after endianness confusion.
- commit cbb0c9a
* Tue Jan 14 2014 mgalbraith@suse.de
- Scheduler audit additions
- sched: Assign correct scheduling domain to 'sd_llc'.
- sched: Avoid NULL dereference on sd_busy.
- sched: Check sched_domain before computing group power.
- sched: Initialize power_orig for overlapping groups.
- sched: Remove unnecessary iteration over sched domains to update nr_busy_cpus.
- sched/rt: Add missing rmb().
- sched/rt: Remove redundant nr_cpus_allowed test.
- commit 93378ed
* Tue Jan 14 2014 hare@suse.de
- Delete patches.drivers/pci-skip-IOV-BARs after review
- commit b88aee5
* Tue Jan 14 2014 hare@suse.de
- Review some more SP3 patches
- Refresh patches.drivers/bfa-set-correct-scsi-returncode.
- Delete obsolete patches:
  * patches.drivers/bfa-fix-faulty-handling-of-states-in-lps-state-machine.patch.
  * patches.drivers/bfa-fix-for-Brocade-FC-Direct-Attach-LUN-discovery-failure.patch.
  * patches.drivers/bfa-xen-port-init-fix.patch.
  * patches.fixes/scsi-fix-race-between-starved-list-processing.patch.
- commit e0b33ce
* Tue Jan 14 2014 jdelvare@suse.de
- supported.conf: Add the coretemp and k10temp hwmon drivers
  Intel and AMD have asked us to backport support for newer hardware
  to these drivers in the past, so they certainly want us to support
  them.
- commit 4cafb5e
* Tue Jan 14 2014 mgalbraith@suse.de
- futexes: Avoid taking the hb->lock if there's nothing to wake up
  (bnc#851603).
- futexes: Document multiprocessor ordering guarantees
  (bnc#851603).
- futexes: Increase hash table size for better performance
  (bnc#851603).
- futexes: Clean up various details (bnc#851603).
- futex: move user address verification up to common code
  (bnc#851603).
- commit cf7e931
* Tue Jan 14 2014 hare@suse.de
- Review scsi_dh_alua patches and update to upstream version
  * scsi_dh_alua: ALUA check sense should retry device internal
    reset unit attention (bnc#846092).
  * scsi_dh_alua: ALUA handler attach should succeed while TPG is
    transitioning (bnc#846092).
  * scsi_dh_alua: Clarify logging message (bnc#708296).
  * scsi_dh_alua: Do not attach to management devices (bnc#708296).
  * scsi_dh_alua: Use workqueue for RTPG (bnc#708296).
  * scsi_dh_alua: revert commit
    a8e5a2d593cbfccf530c3382c2c328d2edaa7b66 (bnc#708296).
  * scsi_dh_alua: simplify sense code handling (bnc#708296).
  * patches.fixes/scsi_dh-invoke-callback-if-activate-is-not-present.patch:
    Update to upstream version
  * patches.fixes/scsi_dh-return-individual-errors-in-scsi_dh_activate.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-Improve-error-handling.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-Make-stpg-synchronous.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-Pass-buffer-as-function-argument.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-Use-separate-alua_port_group-structure.patch:
    Update to upstream version
  * Update patches.fixes/scsi_dh_alua-multipath-failover-fails.patch
    (bnc#708296).
  * patches.fixes/scsi_dh_alua-parse-target-device-id.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-put-sense-buffer-on-stack.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-use-flag-for-RTPG-extended-header.patch:
    Update to upstream version
  * patches.fixes/scsi_dh_alua-use-local-buffer-for-VPD-inquiry.patch:
    Update to upstream version
- Delete old patches:
  * patches.fixes/scsi_dh_alua-Decode-EMC-Clariion-extended-inquiry.patch.
  * patches.fixes/scsi_dh_alua-Decode-HP-EVA-array-identifier.patch.
  * patches.fixes/scsi_dh_alua-Evaluate-state-for-all-port-groups.patch.
  * patches.fixes/scsi_dh_alua-Fix-missing-close-brace-in-alua_check_s.patch.
  * patches.fixes/scsi_dh_alua-Re-evaluate-port-group-states-after-STP.patch.
  * patches.fixes/scsi_dh_alua-Recheck-state-on-transitioning.patch.
  * patches.fixes/scsi_dh_alua-Rework-rtpg-workqueue.patch.
  * patches.fixes/scsi_dh_alua-allow-get_alua_data-to-return-NULL.patch.
  * patches.fixes/scsi_dh_alua-asynchronous-RTPG.patch.
  * patches.fixes/scsi_dh_alua-correctly-terminate-target-port-strings.patch.
  * patches.fixes/scsi_dh_alua-defer-I-O-while-workqueue-item-is-pendi.patch.
  * patches.fixes/scsi_dh_alua-fine-grained-locking-in-alua_rtpg_work.patch.
  * patches.fixes/scsi_dh_alua-invalid-state-information-for-optimized.patch.
  * patches.fixes/scsi_dh_alua-move-RTPG-to-workqueue.patch.
  * patches.fixes/scsi_dh_alua-move-expiry-into-PG-structure.patch.
  * patches.fixes/scsi_dh_alua-move-some-sense-codes.patch.
  * patches.fixes/scsi_dh_alua-protect-accesses-to-struct-alua_port_gr.patch.
  * patches.fixes/scsi_dh_alua-reattach-device-handler-failure.patch.
  * patches.fixes/scsi_dh_alua-remove-locking-when-checking-state.patch.
  * patches.fixes/scsi_dh_alua-remove-stale-variable.patch.
  * patches.fixes/scsi_dh_alua-retry-RTPG-on-UNIT-ATTENTION.patch.
  * patches.fixes/scsi_dh_alua-retry-command-on-mode-parameter-changed.patch.
  * patches.fixes/scsi_dh_alua-simplify-alua_check_sense.patch.
  * patches.fixes/scsi_dh_alua-simplify-state-update.patch.
  * patches.fixes/scsi_dh_alua-use-delayed_work.patch.
  * patches.fixes/scsi_dh_alua-use-spin_lock_irqsave-for-port-group.patch.
- commit 9cce834
* Mon Jan 13 2014 brogers@suse.com
- Refresh patches.suse/acpiphp-match-to-Bochs-dmi-data.patch.
- commit 7439048
* Mon Jan 13 2014 bpoirier@suse.de
- SLE12 patch review:
  ==> bphilips@suse.de <==
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch
  "an upstream fix will come later once IBM can review [...]",
  until then, re-enabled.
  patches.drivers/bnx2-entropy-source.patch
  patches.drivers/e1000-entropy-source.patch
  patches.drivers/e1000e-entropy-source.patch
  patches.drivers/igb-entropy-source.patch
  patches.drivers/ixgbe-entropy-source.patch
  patches.drivers/tg3-entropy-source.patch
  All of these have been removed. IRQF_SAMPLE_RANDOM is gone
  (775f4b2 random: make 'add_interrupt_randomness()' do
  something sane (v3.6-rc1))
- commit 060d5be
* Mon Jan 13 2014 mhocko@suse.cz
- Update config files.
  disable CONFIG_MEMCG_SWAP_ENABLED because we do not want to have
  memcg swap accounting enabled by default because of the runtime
  and memory overhead. We are doing same in SLE11-SP*
- commit 3c57e52
* Mon Jan 13 2014 mhocko@suse.cz
- NEEDS review - DO NOT PUSH
  it compiles but no further tests have been done
- commit f0aa572
* Mon Jan 13 2014 duwe@suse.de
- Update config files:
  unset big endian on ppc64le
  disable KVM (unsupported on LE)
- rpm/arch-symbols:
  add ppc64le to the list
- commit 9284e95
* Mon Jan 13 2014 duwe@suse.de
- Update config files.
- config.conf:
- rpm/kernel-binary.spec.in:
- rpm/post.sh:
- scripts/osc_wrapper:
- scripts/run_oldconfig.sh:
  Establish ppc64le as independent architecture.
- commit 69aa9d2
* Mon Jan 13 2014 jslaby@suse.cz
- Delete patches.suse/cgroup-disable-memcg-when-low-lowmem.patch.
  Only x86_32 specific.
- Delete patches.suse/remove-syslog-WARN_ON.patch.
  We now have the sysctl in userspace. The warn_on is appropriate.
- Delete
  patches.suse/revert-U6715-16550A-serial-driver-support.patch.
  This one I'm biased. The HW is broken. So let's try to drop it for
  now.
- Delete
  patches.suse/revert-pcmcia-remove-irq_list-parameter-from-pd6729.patch.
  We don't need to support the parameter over releases, only over SPs.
- commit 5b811f9
* Mon Jan 13 2014 bpoirier@suse.de
- SLE12 patch review:
  patches.drivers/bnx2x-remove-WARN_ON.patch
  Made it upstream as "185d4c8 bnx2x: remove false warning
  regarding interrupt number (v3.6-rc7)"
  I've replaced it in sp2.
  patches.drivers/bnx2x-update-driver-version.patch
  This patch only changes DRV_MODULE_VERSION. It is not
  applicable to upstream or SLE12, version numbers have
  diverged.
  patches.suse/drivers-net-Add-README-about-driver-re-organization.patch
  Used to document that the network driver subdirectory
  reorganisation done in 3.2 was backported to SP3. It was
  there to help partners do the backports I think. I've removed
  it now, as it's not really needed anymore.
  patches.drivers/bnx2x-0077-bnx2x-Cosmetic-changes-to-align-to-upstream-kernel.patch
  This is a fixup for whitespace errors accumulated over many
  backports that make the end result slightly different from
  upstream. This patch removes the differences. Since the
  backports are only in SP3, the patch is only needed there.
  patches.drivers/ixgbe-0001-Revert-ixgbe-add-support-for-new-82599-device-id.patch
  patches.drivers/ixgbe-0002-Revert-ixgbe-add-support-for-new-82599-device.patch
  patches.drivers/ixgbe-0003-Revert-ixgbe-add-support-for-X540-AT1.patch
  patches.drivers/ixgbe-0004-Revert-ixgbe-fix-possible-null-buffer-error.patch
  These four patches revert commits that were in 3.0.x -stable.
  They bring back the ixgbe driver to what it was in 3.0 so that
  patches could be applied unmodified from 3.0.. during the
  driver backports for SP3. Since the backports are only in SP3,
  these patches are only needed there.
  patches.drivers/mlx4-0001-IB-mlx4-remove-__devinit-from-mlx4_init_xrcd_table.patch
  This was a fixup of an out-of-tree IB patch
  (patches.drivers/mlx4_0450_xrc_base_implementation.patch)
  taken during SP2 (kernel-source.git f6f2813). The fixup was
  bunched up in the mlx4 SP3 driver update. These out-of-tree IB
  patches are not present in SLE12.
- commit 29020c2
* Mon Jan 13 2014 duwe@suse.de
- little endian ppc64 will be called 'ppc64le', not 'ppc64'.
  Revert config files.
- commit 0fd00b6
* Mon Jan 13 2014 dsterba@suse.cz
- Refresh patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit 0e50d24
* Mon Jan 13 2014 mmarek@suse.cz
- KEYS: Load *.x509 files into kernel keyring.
- commit 3d1d94f
* Mon Jan 13 2014 dsterba@suse.cz
- Enable patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit 0d1d571
* Mon Jan 13 2014 hare@suse.de
- qla2xxx: Update the driver version to 8.06.00.14.12.0-k
  (bnc#853689,FATE#315933).
- qla2xxx: Check for peg alive counter and clear any outstanding
  (bnc#853689,FATE#315933).
- qla2xxx: Allow the next firmware dump if the previous dump
  capture (bnc#853689,FATE#315933).
- qla2xxx: Issue abort command for outstanding commands during
  cleanup (bnc#853689,FATE#315933).
- qla2xxx: Log when device state is moved to failed state
  (bnc#853689,FATE#315933).
- qla2xxx: Add module parameter for interrupt mode
  (bnc#853689,FATE#315933).
- qla2xxx: Fix multiqueue MSI-X registration
  (bnc#853689,FATE#315933).
- qla2xxx: Correctly set the read_optrom pointer for ISP8044
  (bnc#853689,FATE#315933).
- qla2xxx: Read capture firmware dump on mailbox timeout for
  ISP8044 (bnc#853689,FATE#315933).
- qla2xxx: Simplify the ISPFX00 interrupt handler code for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Avoid poisoning in the response queue for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Add changes in the IOCB structures to adjust driver
  source (bnc#853689,FATE#315933).
- qla2xxx: Remove ISP_ABORT_NEEDED and ISP_ABORT_RETRY checks from
  (bnc#853689,FATE#315933).
- qla2xxx: Remove Marker type IOCB logic for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Set host can_queue value based on available resources
  (bnc#853689,FATE#315933).
- qla2xxx: Properly handle 32 bit mailbox register for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Enable the Flash Access Control (FAC) mailbox command
  (bnc#853689,FATE#315933).
- qla2xxx: Select correct request queue for error type IOCB for
  (bnc#853689,FATE#315933).
- qla2xxx: Remove init control block related dead code for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Use proper message for Non owner reset ACK Timeout
  (bnc#853689,FATE#315933).
- qla2xxx: Replace constant value for IOCTL IOCB abort execution
  (bnc#853689,FATE#315933).
- qla2xxx: Add handling for boot indication progress AENs for
  ISPFX00 (bnc#853689,FATE#315933).
- qla2xxx: Add mutex around optrom calls to serialize accesses
  (bnc#853689,FATE#315933).
- qla2xxx: Update the driver version to 8.06.00.12-k
  (bnc#853689,FATE#315933).
- qla2xxx: Adding MAINTAINERS for qla2xxx FC-SCSI driver
  (bnc#853689,FATE#315933).
- qla2xxx: Replace a constant with a macro definition for
  host->canqueue assigmnment (bnc#853689,FATE#315933).
- qla2xxx: Reset nic_core_reset_owner on moving from COLD to
  READY for ISP8044 (bnc#853689,FATE#315933).
- qla2xxx: Only complete dcbx_comp and lb_portup_comp for virtual
  port index 0 (bnc#853689,FATE#315933).
- qla2xxx: Use scnprintf() instead of snprintf() in the sysfs
  handlers (bnc#853689,FATE#315933).
- qla2xxx: Use the correct mailbox registers when acknowledging
  an IDC request on ISP8044 (bnc#853689,FATE#315933).
- qla2xxx: Add changes to obtain ISPFX00 adapters
  product information in accordance with firmware update
  (bnc#853689,FATE#315933).
- qla2xxx: Add logic to abort BSG commands for ISPFX00
  (bnc#853689,FATE#315933).
- qla2xxx: Clear RISC INT reg only for an event and not always
  while polling (bnc#853689,FATE#315933).
- qla2xxx: Fix undefined behavior in call to snprintf()
  (bnc#853689,FATE#315933).
- qla2xxx: Add BSG interface for read/write serdes register
  (bnc#853689,FATE#315933).
- qla2xxx: Fix issue with not displaying node name after system
  reboot (bnc#853689,FATE#315933).
- qla2xxx: Disable adapter when we encounter a PCI disconnect
  (bnc#853689,FATE#315933).
- qla2xxx: Refactor shutdown code so some functionality can be
  reused (bnc#853689,FATE#315933).
- Revert "qla2xxx: Ramp down queue depth for attached SCSI devices
  when driver resources are low." (bnc#853689,FATE#315933).
- qla2xxx: Don't consider the drivers knocked out of
  IDC participation for future reset recovery process
  (bnc#853689,FATE#315933).
- qla2xxx: Add BPM support for ISP25xx (bnc#853689,FATE#315933).
- qla2xxx: Correctly set mailboxes for extended init control block
  (bnc#853689,FATE#315933).
- qla2xxx: Disable INTx interrupt for ISP82XX
  (bnc#853689,FATE#315933).
- qla2xxx: Honor execute firmware failures
  (bnc#853689,FATE#315933).
- qla2xxx: Print proper QLAFX00 product name at probe
  (bnc#853689,FATE#315933).
- commit 96b515e
* Mon Jan 13 2014 jslaby@suse.cz
- efifb: prevent null-deref when iterating dmi_list (bnc#858404).
- commit a0b52d5
* Mon Jan 13 2014 dsterba@suse.cz
- Remove old workaround for get_maps_dev
  Replaced by patch patches.suse/btrfs-use-correct-device-for-maps.patch
- commit 595cd57
* Mon Jan 13 2014 dsterba@suse.cz
- Remove local btrfs patches
  Old patches that were implemented in another way upstream or unimportant
  ones that will be yet upstreamed.
- commit e02245e
* Mon Jan 13 2014 mszeredi@suse.cz
- squashfs v3.4 (bnc#666893, FATE#311173).
- Update config files.
- commit 8faf660
* Mon Jan 13 2014 bpoirier@suse.de
- dlm: set zero linger time on sctp socket (bnc#787843).
- commit a026a89
* Mon Jan 13 2014 dsterba@suse.cz
- Remove upstreamed patches
  Btrfs patches that were missing mainline git-commit.
- commit 61dd816
* Mon Jan 13 2014 hare@suse.de
- hpsa: Bump driver version (bnc#857800,FATE#315359).
- hpsa: Remove unused PCI IDs (bnc#857800,FATE#315359).
- hpsa: Add new Gen9 IDs (bnc#857800,FATE#315359).
- hpsa: remove P822se PCI ID (bnc#857800,FATE#315359).
- hpsa: prevent stalled i/o (bnc#857800,FATE#315359).
- hpsa: cap CCISS_PASSTHRU at 20 concurrent commands
  (bnc#857800,FATE#315359).
- hpsa: bring logical drives online when format completes
  (bnc#857800,FATE#315359).
- hpsa: hide logical drives with format in progress from linux
  (bnc#857800,FATE#315359).
- hpsa: add MSA 2040 to list of external target devices
  (bnc#857800,FATE#315359).
- hpsa: fix memory leak in CCISS_BIG_PASSTHRU ioctl
  (bnc#857800,FATE#315359).
- hpsa: remove unneeded include of seq_file.h
  (bnc#857800,FATE#315359).
- hpsa: add 5 second delay after doorbell reset
  (bnc#857800,FATE#315359).
- hpsa: do not attempt to flush the cache on locked up controllers
  (bnc#857800,FATE#315359).
- hpsa: remove unused Smart Array ID (bnc#857800,FATE#315359).
- commit 58c6da5
* Mon Jan 13 2014 dsterba@suse.cz
- Remove writeback_indes_sb* helpers for btrfs
  Dropped upstream and implemented in another way
- patches.suse/0002-vfs-re-implement-writeback_inodes_sb-_nr-_if_idle-an.patch
- patches.suse/btrfs-1009-fixup-writeback_inodes_sb-wrappers-use.patch
- commit 48db2c9
* Mon Jan 13 2014 hare@suse.de
- Disable cpqarray driver (bnc#857800)
- commit 8989d37
* Mon Jan 13 2014 hare@suse.de
- Remove obsolete hpsa update patches
  * patches.drivers/hpsa-Add-new-PCI-IDs.patch.
  * patches.drivers/hpsa-Fixup-marketing-names.patch.
  * patches.drivers/hpsa-Move-hpsa_wait_for_board_state-function-to-more-clos.patch.
  * patches.drivers/hpsa-Remove-gratuitous-cosmetic-diffs-vs.-kernel.org.patch.
  * patches.drivers/hpsa-add-__devinit-annotation-to-hpsa_wait_for_board.patch.
  * patches.drivers/hpsa-add-new-controller-names.
  * patches.drivers/hpsa-fix-wrong-return-value-from-hpsa_find_cfgtables.patch.
  * patches.drivers/hpsa-remove-closed-source-hpvsa-hooks.patch.
  * patches.drivers/hpsa-remove-pre-gen-8-controller-PCI-IDs.patch.
  * patches.drivers/hpsa-remove-unintentional-exporting-of-hpsa_init_one.patch.
  * patches.drivers/hpsa-remove-unnecessary-pci-id-skipping-code.patch.
  * patches.drivers/hpsa-sanitize-version-number.patch.
  * patches.drivers/hpsa-section-annotations.
  * patches.drivers/hpsa-update-to-hp-version.patch.
  * patches.drivers/hpsa-update-version-number-to-3.2.0.patch.
  * patches.drivers/hpsa-use-WARN-ON-return-value-directly.patch.
- commit ab703d0
* Mon Jan 13 2014 hare@suse.de
- Remove upstream patches
  * patches.drivers/0032-fcoe-libfcoe-Move-common-code-for-fcoe_get_lesb-to-f.patch.
  * patches.drivers/0035-bnx2fc-Unable-to-send-lun-tgt-reset-on-SLES-11-kerne.patch.
  * patches.drivers/0040-be2iscsi-Fix-MSI-X-Interrupt-Names.patch.
  * patches.drivers/be2net-0147-Use-new-F-W-mailbox-cmd-to-manipulate-interru.patch.
  * patches.drivers/bna-fix-for-RX-data_processing.patch.
  * patches.drivers/bnx2fc-Bumped-version-to-1.0.13.patch.
  * patches.drivers/bnx2fc-Bumped-version-to-1.0.14.patch.
  * patches.drivers/bnx2fc-Enable-cached-tasks-to-improve-performance.patch.
  * patches.drivers/bnx2fc-Fix-race-condition-between-IO-completion-and-.patch.
  * patches.drivers/bnx2fc-Include-chip-number-in-the-symbolic-name.patch.
  * patches.drivers/bnx2fc-Map-the-doorbell-register-between-offload-and.patch.
  * patches.drivers/bnx2fc-Move-offload-upload-wait-logic-into-a-functio.patch.
  * patches.drivers/bnx2fc-Remove-potential-NULL-dereference.patch.
  * patches.drivers/bnx2fc-Support-max-IO-size-to-512KB.patch.
  * patches.drivers/bnx2fc-Tx-Rx-byte-counts-reset-to-0-when-exceeding-3.patch.
  * patches.drivers/bnx2fc-Update-copyright-information.patch.
  * patches.drivers/bnx2fc-remove-useless-calls-to-memset.patch.
  * patches.drivers/bnx2fc-support-software-fcoe-target.patch.
  * patches.drivers/bnx2fc-v2-Support-software-fcoe-target.patch.
  * patches.drivers/fcoe-0063-libfcoe-check-for-unuseable-fcfs.patch.
  * patches.drivers/fcoe-0064-libfcoe-handle-cvl-while-waiting.patch.
  * patches.drivers/fnic-FIP-VLAN-Discovery-Feature-Support.patch.
  * patches.drivers/fnic-Fnic-Trace-Utility.patch.
  * patches.drivers/fnic-Incremented-driver-version.patch.
  * patches.drivers/fnic-Kernel-panic-due-to-FIP-mode-misconfiguration.patch.
  * patches.drivers/fnic-New-debug-flags-and-debug-log-messages.patch.
  * patches.drivers/fnic-fnic-driver-may-hit-BUG_ON-on-device-reset.patch.
  * patches.drivers/fnic-updated-MAINTAINERS-list.patch.
  * patches.drivers/ibmvfc-Driver-version-1.0.11.patch.
  * patches.drivers/ibmvfc-Properly-set-cancel-flags-when-cancelling-abo.patch.
  * patches.drivers/ibmvfc-Send-cancel-when-link-is-down.patch.
  * patches.drivers/ibmvfc-Support-FAST_IO_FAIL-in-EH-handlers.patch.
  * patches.drivers/ibmvfc-Suppress-ABTS-if-target-gone.patch.
  * patches.drivers/isci-add-isci_compat.h.patch.
  * patches.drivers/mpt2sas-EEH_recovery-for-sles11-sp3.patch.
  * patches.drivers/xhci_bad_pci_irq.patch.
  * patches.fixes/block-fix-discard-merging-limits.patch.
  * patches.fixes/libfc-check-fc_block_scsi_eh-return-success.
  * patches.fixes/scsi-error-netlink-GFP_ATOMIC.patch.
  * patches.fixes/scsi-ses-crash-on-lun0.
  * patches.suse/scsi-netlink-ml-module-param.
- commit c028865
* Mon Jan 13 2014 hare@suse.de
- Remove upstream patches
  * patches.suse/dasd-Abort-all-requests-from-ioctl.patch.
  * patches.suse/dasd-Clarify-comment.patch.
  * patches.suse/dasd-Disable-block-timeouts-per-default.patch.
  * patches.suse/dasd-Implement-failfast_retries.patch.
  * patches.suse/dasd-Reduce-amount-of-messages-for-specific-errors.patch.
  * patches.suse/dasd-Rename-ioctls.patch.
  * patches.suse/dasd-blk-timeout.patch.
  * patches.suse/dasd-check-blk_noretry_request-in-dasd_times_out.patch.
  * patches.suse/dasd-continue-device-tasklet.patch.
  * patches.suse/dasd-detailed-io-errors.patch.
  * patches.suse/dasd-fail-all-requests-after-timeout.patch.
  * patches.suse/dasd-failfast-expires.
  * patches.suse/dasd-lock-ccw-queue-in-dasd_times_out.patch.
  * patches.suse/dasd-make-DASD_FLAG_TIMEOUT-setting-more-robust.patch.
  * patches.suse/dasd-make-number-of-retries-configurable.patch.
  * patches.suse/dasd-rename-flag-to-abortall.patch.
  * patches.suse/dasd-timeout-attribute.patch.
- commit 5865b6d
* Mon Jan 13 2014 hare@suse.de
- Delete obsolete patches
  patches.drivers/Update-lpfc-version-for-8.3.7.7.1p-driver-release.patch.
  patches.drivers/lpfc-8.3.26-Change-driver-version-to-8.3.26.patch.
  patches.drivers/lpfc-8.3.26-Fix-HBA-initialization-issues.patch.
  patches.drivers/lpfc-8.3.26-Fix-SYSFS-interface-issues.patch.
  patches.drivers/lpfc-8.3.26-Fix-issues-pertaining-to-SCSI-FC-protoc.patch.
  patches.drivers/lpfc-8.3.37-Fix-potential-memory-corruption-bug.patch.
  patches.drivers/lpfc-8.3.37-Fixed-exhausted-retry-for-plogi-to-names.patch.
  patches.drivers/lpfc-8.3.37-Fixed-infinite-loop-in-lpfc_sli4_fcf_rr_.patch.
  patches.drivers/lpfc-8.3.37-Fixed-no-context-ABTS-received-on-unsoli.patch.
  patches.drivers/lpfc-8.3.37-Fixed-not-properly-handle-ELS_REC-receiv.patch.
  patches.drivers/lpfc-8.3.37-Fixed-processing-stale-ndlp-state-when-t.patch.
  patches.drivers/lpfc-8.3.37-Fixed-system-crash-due-to-SLI-Port-provi.patch.
  patches.drivers/lpfc-8.3.37-Provide-support-for-FCoE-protocol-dual-c.patch.
  patches.drivers/lpfc-8.3.37-Provide-support-for-change_queue_type-me.patch.
  patches.drivers/lpfc-8.3.37-Removed-use-of-NOP-mailboxes-for-interrupt-verificat.patch.
  patches.drivers/lpfc-8.3.5.48.2p-update.
  patches.drivers/lpfc-8.3.7.10.1p-driver-panic-during-eeh.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Fix-driver-issues-with-SCSI-Host-reset.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-bad-book-keeping-in-posting-els-sgls-to-port.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-crash-when-processing-bsg-s-sg-list-with-high-.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-deadlock-between-hbalock-and-nlp_lock-use.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Fixed-not-returning-FAILED-status-when-SCSI-invoking.patch.
  patches.drivers/lpfc-8.3.7.10.2p-Update-lpfc-version-for-8.3.7.10.3p-driver-release.patch.
  patches.drivers/lpfc-8.3.7.10.3p-Update-lpfc-version-for-8.3.7.10.5p-driver-release.patch.
  patches.drivers/lpfc-8.3.7.10.3p-fix-unsafe-walking-and-delete-linked-list.patch.
  patches.drivers/lpfc-8.3.7.10.5p-Update-lpfc-version-for-8.3.7.10.6p-driver-release.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fix-default-value-for-lpfc_enable_rrq.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-NMI-watch-dog-panic-s-when-resetting-the-hba.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-OXID-reuse-issue.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-PT2PT-bring-up-problem-for-FC-SLI4.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-async-FCF-modified-event-to-in-use-FCF-failure.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-bsg-timeout-handling-issues-that-would-result-.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-circular-locking-dependency-and-inconsistent-l.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-deadlock-condition-in-FCF-round-robin-handling.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-degraded-performance-after-cable-pulls.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Fixed-potential-mis-interpretation-of-READ_TOPOLOGY-.patch.
  patches.drivers/lpfc-8.3.7.7.1p-Update-lpfc-version-for-8.3.7.10.1p-driver-release.patch.
  patches.drivers/lpfc-8.3.7.7.1p-fix-potential-NULL-pointer-dereference-in-lpfc_sli4_.patch.
  patches.drivers/lpfc-correct-an-issue-with-rrq-processing.patch.
  patches.drivers/lpfc-correct-some-issues-with-txcomplq-processing.patch.
  patches.drivers/lpfc-revert-Fixed-async-FCF-modified-event.patch.
  patches.drivers/qla2xxx-0225-Obtain-loopback-iteration-count-from-bsg-req.patch.
  patches.drivers/qla2xxx-0226-Correct-race-in-loop_state-assignment-during.patch.
  patches.drivers/qla2xxx-0227-Get-VPD-information-from-common-location-for.patch.
  patches.drivers/qla2xxx-0228-Avoid-null-pointer-dereference-in-shutdown-r.patch.
  patches.drivers/qla2xxx-0229-Print-thermal-unsupported-message.patch.
  patches.drivers/qla2xxx-0230-Reject-loopback-request-if-one-is-already-in.patch.
  patches.drivers/qla2xxx-0231-Update-the-FTP-site-references-in-the-driver.patch.
  patches.drivers/qla2xxx-0232-Do-link-initialization-on-get-loop-id-failur.patch.
  patches.drivers/qla2xxx-0233-Do-MPI-reset-only-for-81xx.patch.
  patches.drivers/qla2xxx-0234-Unload-hangs-after-issuing-BSG-commands-to-v.patch.
  patches.drivers/qla2xxx-0235-Extra-loopback-error-handling-for-ISP83xx.patch.
  patches.drivers/qla2xxx-0236-Move-loopback-mode-reset-after-chip-reset-ch.patch.
  patches.drivers/qla2xxx-0237-Display-the-lock-owner-on-lock-acquire-failu.patch.
  patches.drivers/qla2xxx-0238-Update-the-copyright-information.patch.
  patches.drivers/qla2xxx-0239-Revert-Avoid-losing-any-fc-ports-when-loop-i.patch.
  patches.drivers/qla2xxx-0240-Revert-Optimize-existing-port-name-server-qu.patch.
  patches.drivers/qla2xxx-0241-Correct-list-iteration-bug-in-Report-ID-Acqu.patch.
  patches.drivers/qla2xxx-0242-Correction-of-comment-in-MBC-opcode-defines.patch.
  patches.drivers/qla2xxx-0243-Don-t-process-RSCNs-for-a-vport-on-the-same-.patch.
  patches.drivers/qla2xxx-0244-Don-t-process-state-change-aen-for-reset-own.patch.
  patches.drivers/qla2xxx-0245-Wait-for-IDC-complete-event-to-finish-loopba.patch.
  patches.drivers/qla2xxx-0246-Update-version-number-to-8.04.00.13.11.3-k.patch.
  patches.drivers/qla2xxx-0247-Fix-crash-during-firmware-dump-procedure.patch.
  patches.drivers/qla2xxx-Determine-the-number-of-outstanding-commands.patch.
  patches.drivers/qla2xxx-Module-parameter-ql2xasynclogin.patch.
  patches.drivers/qla2xxx-Ramp-down-queue-depth-for-attached-SCSI-devi.patch.
  patches.drivers/qla2xxx-add-module-paremeter-to-override.patch.
- commit d7a1c47
* Mon Jan 13 2014 mgalbraith@suse.de
- Add sched: tags to these two
- sched: Provide boot option to disable sched_rt_runtime (bnc#610783).
- sched: Provide realtime priority kthread and workqueue boot options (bnc#836718).
- commit 30c995f
* Mon Jan 13 2014 mhocko@suse.cz
- kernel: provide a __smp_call_function_single stub for
  !CONFIG_SMP.
- Delete
  patches.fixes/include-linux-smp.h-define-__smp_call_function_singl.patch.
  include-linux-smp.h-define-__smp_call_function_singl.patch replaced by
  the upstream alternative
- commit df5cca2
* Mon Jan 13 2014 mgalbraith@suse.de
- sched: disable FAIR_SLEEPERS for S390 (bnc#724577).
- sched: add SD_SHARE_PKG_RESOURCES domain flags proc handler (bnc#754690).
- sched: optimize latency defaults (bnc#754690).
- Provide boot option to disable sched_rt_runtime (bnc#610783).
- Provide realtime priority kthread and workqueue boot options (bnc#836718).
- sched: reinstate FAIR_SLEEPERS feature (bnc#724577).
- sched: reinstate sched_compat_yield (bnc#722449).
- sched: Add rtsched_debug boot option (bnc#708730).
- sched: ratelimit nohz (bnc#754690).
- Refresh patches.fixes/reiserfs-unlock-superblock-before-calling-reiserfs_quota_on_mount.patch.
- Delete patches.fixes/clockevents-Reinstate-the-per-cpu-tick-skew.patch.
- Delete patches.fixes/rcu-Revert-limit-rcu_node-leaf-level-fanout.patch.
- Delete patches.fixes/sched-Fix-buglet-in-return_cfs_rq_runtime.
- Delete patches.fixes/sched-Only-queue-remote-wakeups-when-crossing-cache-boundaries-part2.patch.
- Delete patches.fixes/sched-cgroups-Disallow-attaching-kthreadd.
- Delete patches.fixes/sched-disable-FAIR_SLEEPERS-for-S390.patch.
- Delete patches.fixes/sched-domain-flags-proc-handler.patch.
- Delete patches.fixes/sched-fix-divide-by-zero-in-thread_group-and-task_times.patch.
- Delete patches.fixes/sched-fix-select_idle_sibling-induced-bouncing.patch.
- Delete patches.fixes/sched-optimize-latency-defaults.patch.
- Delete patches.fixes/sched-provide-nortsched-boot-option.patch.
- Delete patches.fixes/sched-provide-rtkthreads-rtworkqueues-boot-options.patch.
- Delete patches.fixes/sched-really-revert-latency-defaults.patch.
- Delete patches.fixes/sched-reinstate-FAIR_SLEEPERS-feature.
- Delete patches.fixes/sched-reinstate-sched_compat_yield.patch.
- Delete patches.fixes/sched-rt-Fix-isolated-CPUs-leaving-root_task_group-indefinitely-throttled.patch.
- Delete patches.fixes/sched-rtsched_debug-boot-option.patch.
- Delete patches.fixes/sched-throttle-nohz.patch.
- Delete patches.fixes/smp-generic_smp_call_function_interrupt-additional-memory-order-tightening.
- Delete patches.fixes/timer_list-Correct-the-iterator-for-timer_list.patch.
- Delete patches.suse/sched-accumulate-per-cfs_rq-cpu-usage-and-charge-against-bandwidth.
- commit 3e11a3e
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.fixes/kexec-add-the-values-related-to-buddy-system-for-filtering-free-pages.patch.
  upstream since 3.9
- commit ab3518d
* Mon Jan 13 2014 mhocko@suse.cz
- Refresh
  patches.fixes/kexec-add-the-values-related-to-buddy-system-for-filtering-free-pages.patch.
- commit 2e43bc3
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.fixes/nohz-fix-idle-ticks-in-cpu-summary-line-for-proc-stat.patch.
  upstream since 3.7
- commit c08a447
* Mon Jan 13 2014 mhocko@suse.cz
- Refresh
  patches.fixes/nohz-fix-idle-ticks-in-cpu-summary-line-for-proc-stat.patch.
- commit 74cce10
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.fixes/watchdog-make-disable-enable-hotplug-and-preempt-save.patch.
  dropped because upstream has fixed the issue by 359e6fab6600 watchdog:
  update watchdog attributes atomically
- commit a530604
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.fixes/watchdog-update-watchdog_tresh-properly.patch.
  dropped because the upstream has fixed the issue by 9809b18fcf6b
  watchdog: update watchdog_thresh properly
- commit fbb13aa
* Mon Jan 13 2014 mhocko@suse.cz
- Delete patches.fixes/ipc-ipc_rcu_putref-race.patch.
  Dropped because upstream has fixed the issue by 6062a8dc0517 ipc,sem:
  fine grained locking for semtimedop
- commit 078411e
* Mon Jan 13 2014 mhocko@suse.cz
- Delete patches.fixes/memory_dev_init-do-not-soft-lockup.patch.
- Delete
  patches.fixes/mm-link_mem_sections-touch-nmi-watchdog.patch.
  already dropped by 3660837c11e7381a626eb31d7d7339f576f554e0
- commit 14deb17
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.suse/shmem-do-not-export-shmem_inode_info-struct.patch.
  already dropped by 61b92ebd8fb4fd152baa07a37079537942a37aa7
- commit 701a817
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.suse/memcg-warn-on-deeper-hierarchies-with-use_hierarchy-.patch.
  already dropped by 19d1e6f7b36e38c32cdb57111e21121488ac738a
- commit 9623df1
* Mon Jan 13 2014 mhocko@suse.cz
- Delete patches.fixes/mm-cond_resced-in-putback_lru_pages.patch.
  already dropped by 58b3cb308628194abae7ee3503a2201764c9b945
- commit b7ba4e1
* Mon Jan 13 2014 mhocko@suse.cz
- Delete
  patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch.
  already dropped by 741e7d8b9a078deb5dc1c82aec111d87387d4afe
- commit a47c868
* Mon Jan 13 2014 mhocko@suse.cz
- Delete patches.fixes/Fix-unmap_vma-bug-related-to-mmu_notifiers.patch.
  Already removed by 0e25922c843fdfaa399f4c69ee385778bc572c35
- commit dd94e77
* Mon Jan 13 2014 mhocko@suse.cz
- Delete patches.fixes/rcu-reduce-false-positive-on-racing-rcu.patch.
  Upstream has fixed this by 26cdfedf6a90 rcu: Reject memory-order-induced
  stall-warning false positives
- commit 9737c4f
* Mon Jan 13 2014 mmarek@suse.cz
- Delete patches.suse/kbuild-record-built-in-o
  Not needed, becase we do not generate the Module.builtin file anymore.
- commit 82d2475
* Mon Jan 13 2014 mmarek@suse.cz
- Delete patches removed from series.conf by commit 3c72934
- commit 6579d2f
* Mon Jan 13 2014 mmarek@suse.cz
- Drop SP3 kabi patches that were not in patches.kabi
- commit 48bc02e
* Mon Jan 13 2014 mgalbraith@suse.de
- sched: Guarantee new group-entities always have weight
  (bnc#848336).
- sched: Fix hrtimer_cancel()/rq->lock deadlock (bnc#848336).
- sched: Fix cfs_bandwidth misuse of hrtimer_expires_remaining
  (bnc#848336).
- sched: Fix race on toggling cfs_bandwidth_used (bnc#848336).
- commit 3f6ceb8
* Sat Jan 11 2014 ohering@suse.de
- hv: set guest os id (bnc#814005).
- commit 78d3b27
* Fri Jan 10 2014 jack@suse.cz
- Updated patches from SLE11-SP3.
- commit 3c72934
* Fri Jan 10 2014 jack@suse.cz
- blktrace: Send BLK_TN_PROCESS events to all running traces
  (bnc#838623).
- writeback: do not sync data dirtied after sync start
  (bnc#833820).
- commit 0a0cf03
* Fri Jan 10 2014 jdelvare@suse.de
- Delete patches.arch/iommu-vt-d-only-warn-on-broken-irq-remapping.patch
  As the patch header says:
  "For SLE12 this patch should be dropped to return to upstream's
  behavior."
- commit 0874396
* Fri Jan 10 2014 jdelvare@suse.de
- watchdog: Get rid of MODULE_ALIAS_MISCDEV statements (bnc#827767)
- commit 33f153b
* Fri Jan 10 2014 jeffm@suse.com
- Refresh patches.suse/ext4-rw-unsupported.patch: remove all functionality,
  it is for compatibility with SLE11.
- commit d8c663a
* Fri Jan 10 2014 jeffm@suse.com
- Refresh
  patches.drivers/revert-libata-implement-on-demand-hpa-unlocking.
- commit 51031f5
* Fri Jan 10 2014 jeffm@suse.com
- Remove obsolete patches:
  - patches.arch/uv-use-nmi-backend
  - patches.arch/uv-use-show_regs-in-nmi-handling
  - patches.drivers/0002-qlge-Changing-cpu_to_be16-to-htons-for-udp-checksum.patch
  - patches.drivers/bnx2x-fix-inappropriate-msg-lvl
  - patches.drivers/bnx2x-fixes-for-848x3-phys
  - patches.drivers/hpsa-exported-hpsa_init_one-cant-be-static-__devinit
  - patches.fixes/jbd-mark-super-uptodate
  - patches.fixes/nat-ftp-fix-broken-conntrack
  - patches.fixes/reiserfs-fix-race-with-flush_used_journal_lists-and-flush_journal_list
  - patches.fixes/reiserfs-remove-useless-flush_old_journal_lists
  - patches.fixes/xfs-always-use-iget-in-bulkstat-dmapi
  - patches.fixes/xfs-dmapi-fix-crash-due-to-null-pointer-dereference
  - patches.fixes/xfs-dmapi-fix-crash-on-mount
  - patches.fixes/xfs-dmapi-remove-cached-vfsmount
  - patches.fixes/xfs-fix-re-use-of-ewouldblock-during-read-on-dm-mirror
  - patches.fixes/xfs-remove-block-number-from-inode-lookup-code-dmapi
  - patches.fixes/xfs-rename-xfs_iget_bulkstat-to-xfs_iget_untrusted-dmapi
  - patches.suse/block-add-dev_check_rdonly-and-friends-for-lustre-testing
  - patches.suse/dcache-add-dcache_lustre_invalid-flag-for-lustre-to-handle-its-own-invalidation
  - patches.suse/dmapi-xfs_free_eof_haslock-flag-is-not-always-checked
  - patches.suse/kdb-fix-conflict-in-function-prototypes-between-kdb-h-and-lkdb-h
  - patches.suse/lsm-export-security_inode_unlink
  - patches.suse/lustre-add-lustre-kernel-version
  - patches.suse/supported-flag-module-taint
  - patches.suse/supported-flag-nonfatal-taint
  - patches.suse/update-phidget-driver-apis
  - patches.suse/xfs-3.0-dmapi-fixes
  - patches.suse/xfs-dmapi-add-missing-unlocks-after-transaction-commit
  - patches.suse/xfs-dmapi-initialize-the-function-pointer-vector-statically
  - patches.suse/xfs-dmapi-obtain-vfsmount-for-use-in-xfs_dm_rdwr
  - patches.suse/xfs-dmapi-send-rw-events.patch
  - patches.suse/xfs-dmapi-send_correct_flags_for_preunmount_event.patch
  - patches.suse/xfs-exports-dmapi
  - patches.suse/xfs-restore-dmapi-infrastructure
- commit 0e9dffe
* Fri Jan 10 2014 mkubecek@suse.cz
- Delete
  patches.drivers/bna-do-not-register-ndo_set_rx_mode-callback.patch.
- Delete
  patches.fixes/bonding-check-bond-vlgrp-in-bond_vlan_rx_kill_vid.patch.
- Delete
  patches.fixes/inetpeer-make-unused_peers-list-per-netns.patch.
- Delete
  patches.fixes/netfilter-fix-sending-ICMPv6-on-netfilter-reassembly.patch.
- Delete
  patches.fixes/netfilter-prevent-race-condition-breaking-net-refere.patch.
- Delete
  patches.fixes/netfilter-send-ICMPv6-message-on-fragment-reassembly.patch.
  (all resolved in upstream in a different way)
- commit 3976e0e
* Fri Jan 10 2014 mmarek@suse.cz
- Add SP3 out-of-tree patches for review
- commit ff3dbb1
* Fri Jan 10 2014 mkubecek@suse.cz
- block: modify __bio_add_page check to accept pages that don't
  start a new segment (bnc#769644).
- block: factor out vector mergeable decision to a helper function
  (bnc#769644).
- commit 501264e
* Fri Jan 10 2014 mmarek@suse.cz
- Remove commented-out references to bootsplash patches
- commit cc2e075
* Fri Jan 10 2014 mszeredi@suse.cz
- Refresh
  patches.fixes/autofs4-allow-autofs-to-work-outside-the-initial-pid-namespace.patch.
- Refresh
  patches.fixes/autofs4-translate-pids-to-the-right-namespace-for-the-daemon.patch.
- commit b53bc1a
* Fri Jan 10 2014 mhocko@suse.cz
- Refresh patches.suse/readahead-request-tunables.patch.
  CONFIG_KERNEL_DESKTOP is not set for any kernel flavor/arch so get
  rid of ifdef-ery
- commit b475bd9
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Fix for older Perl
- commit ecf021e
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/oom-warning.
  The additional warning message is not worth carrying. Highorder or
  atomic allocations which are expected to fail should use __GFP_NOWARN
  to not pollute logs with allocation failures which are acceptable.
- commit a0f196c
* Fri Jan 10 2014 mhocko@suse.cz
- autofs4: allow autofs to work outside the initial PID namespace
  (bnc#779294).
- autofs4: translate pids to the right namespace for the daemon
  (bnc#779294).
- mm: Optimize put_mems_allowed() usage (VM performance).
- drop_caches: add some documentation and info message
  (fate#313766).
- mm: call sleep_on_page_killable from
  __wait_on_page_locked_killable (bnc#799909).
- writeback: Do not sync data dirtied after sync start
  (bnc#833820).
- mm: filemap: Avoid priority inversion between high priority
  thread and IO completion (bnc#699916).
- mm: filemap: Optimise __lock_pages() by emulating an adaptive
  sleeping spinlock (bnc#629170).
- mm: filemap: Optimise __lock_page_or_retry() by emulating an
  adaptive sleeping spinlock (bnc#629170, bnc#762414).
- Fix add_page_wait_queue() to work for PG_Locked bit waiters
  (bnc#792584).
- mm: use cpu_chill() in spin_trylock_page() and cancel
  (bnc#768470).
- Make pagecache limit behavior w.r.t. dirty pages configurable
  (FATE309111).
- pagecache limit: Fix the shmem deadlock (bnc#755537).
- Fix calculation of unmapped page cache size (FATE309111).
- Warn on pagecache limit usage (FATE309111).
- Introduce (optional) pagecache limit (FATE309111).
- mm: filemap: Avoid unnecessary barries and waitqueue lookup in
  unlock_page fastpath (Performance regression fixes (bnc#436953,
  bnc#629170)).
  Patches without an upstream alternative to forwardport from SLE11-SP3
- commit e99c6e5
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI-fix.patch.
- Delete patches.fixes/mm-vmscan-take-page-buffers-dirty-and-locked-state-into-account-v3-KABI.patch.
- Delete patches.kabi/memcg-consolidate-memory-cgroup-lru-stat-functions-kabi.patch.
- Delete patches.suse/fsfreeze-reserve-sb-space-to-preserve-kabi.patch.
- Delete patches.suse/mm-uninline-add-to-page-cache.patch.
- Delete patches.suse/shmem-do-not-export-shmem_inode_info-struct.patch.
  kABI workarounds are no longer needed
- commit 61b92eb
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.suse/mm-compaction-migrate-pages-ia64.patch.
- Delete patches.arch/ia64-page-migration
  IA64 is no longer supported in SLE12
- commit 4d4bc8d
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/mm-page-allocator-do-not-drain-per-cpu-lists-via-IPI-from-page-allocator-context.patch.
- Delete patches.fixes/mm-page-allocator-drain-local-per-cpu-lists.patch.
  hotplug implementation has changed a lot since 3.0 and if we need to
  address these issues then we should address them in upstream as well
  and use the same fix
- commit 72624e7
* Fri Jan 10 2014 jslaby@suse.cz
- Linux 3.12.7 (bnc#833097).
- Refresh
  patches.drivers/cpufreq_pstate_intel_refactor_driver.patch.
- Refresh
  patches.suse/Revert-mm-sched-numa-Delay-PTE-scanning-until-a-task-is-scheduled-on-a-new-node.patch.
- Refresh
  patches.suse/mm-Do-not-flush-TLB-during-protection-change-if-pte_present-migration_entry.patch.
- Refresh
  patches.suse/mm-Only-flush-TLBs-if-a-transhuge-PMD-is-modified-for-NUMA-pte-scanning.patch.
- Refresh
  patches.suse/mm-convert-the-rest-to-new-page-table-lock-api.patch.
- Refresh
  patches.suse/mm-hugetlb-convert-hugetlbfs-to-use-split-pmd-lock.patch.
- Refresh
  patches.suse/mm-numa-Change-page-last-nid-pid-into-cpu-pid.patch.
- Refresh
  patches.suse/mm-numa-Do-not-batch-handle-PMD-pages.patch.
- Refresh
  patches.suse/mm-numa-Do-not-migrate-or-account-for-hinting-faults-on-the-zero-page.patch.
- Refresh
  patches.suse/mm-numa-Limit-NUMA-scanning-to-migrate-on-fault-VMAs.patch.
- Refresh
  patches.suse/mm-numa-Scan-pages-with-elevated-page_mapcount.patch.
- Refresh
  patches.suse/mm-thp-change-pmd_trans_huge_lock-to-return-taken-lock.patch.
- Refresh
  patches.suse/sched-numa-Do-not-trap-hinting-faults-for-shared-libraries.patch.
- Refresh patches.suse/sched-numa-Fix-comments.patch.
- Refresh
  patches.suse/sched-numa-Remove-check-that-skips-small-VMAs.patch.
- Refresh
  patches.suse/sched-numa-Set-preferred-NUMA-node-based-on-number-of-private-faults.patch.
- Delete
  patches.drivers/xhci-Limit-the-spurious-wakeup-fix-only-to-HP-machin.
- Delete
  patches.fixes/mm-munlock-fix-a-bug-where-thp-tail-page-is-encountered.patch.
- Delete
  patches.fixes/mm-munlock-fix-deadlock-in-_munlock_pagevec.patch.
- Delete patches.suse/mm-clear-pmd_numa-before-invalidating.patch.
- Delete
  patches.suse/mm-fix-TLB-flush-race-between-migration-and-change_protection_range.patch.
- Delete
  patches.suse/mm-numa-avoid-unnecessary-disruption-of-NUMA-hinting-during-migration.patch.
- Delete
  patches.suse/mm-numa-avoid-unnecessary-work-on-the-failure-path.patch.
- Delete
  patches.suse/mm-numa-call-MMU-notifiers-on-THP-migration.patch.
- Delete
  patches.suse/mm-numa-clear-numa-hinting-information-on-mprotect.patch.
- Delete
  patches.suse/mm-numa-defer-TLB-flush-for-THP-migration-as-long-as-possible.patch.
- Delete
  patches.suse/mm-numa-do-not-clear-PMD-during-PTE-update-scan.patch.
- Delete
  patches.suse/mm-numa-do-not-clear-PTE-for-pte_numa-update.patch.
- Delete
  patches.suse/mm-numa-ensure-anon_vma-is-locked-to-prevent-parallel-THP-splits.patch.
- Delete
  patches.suse/mm-numa-guarantee-that-tlb_flush_pending-updates-are-visible-before-page-table-updates.patch.
- Delete
  patches.suse/mm-numa-serialise-parallel-get_user_page-against-THP-migration.patch.
- Delete
  patches.suse/mm-page_alloc-revert-NUMA-aspect-of-fair-allocation-policy.patch.
- Delete patches.suse/sched-numa-skip-inaccessible-VMAs.patch.
- commit a973910
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/Fix-unmap_vma-bug-related-to-mmu_notifiers.patch.
  SRCU was merged 3 years ago. If this is really a problem then the
  upstream needs a fix as well and we should get it via stable.
- commit 0e25922
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/cpuset-mm-reduce-memory-barrier-related-damage-fix.patch.
  fixed by cc9a6c877661 cpuset: mm: reduce large amounts of memory barrier
  related damage v3
- commit dabbcce
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/writeback-queue_io-avoid-list-traversal.patch.
  As per Jan drop this one and deal with it in a different way if this
  shows up ever again.
- commit 0c3cd20
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix-2.patch.
- Delete patches.fixes/mm-vmscan-Block-kswapd-if-it-is-encountering-pages-under-writeback-fix.patch.
  Use the upstream code. No need to be different in this area. Agreed with
  Mel.
- commit 6804093
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.suse/memcg-warn-on-deeper-hierarchies-with-use_hierarchy-.patch.
  superseded by 8c7f6edbda01 cgroup: mark subsystems with broken hierarchy
  support and whine if cgroups are nested for them
- commit 19d1e6f
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/proc-enable-writing-to-proc-pid-mem-revert.patch.
  Superseded by e268337dfe26 proc: clean up and fix /proc/<pid>/mem
  handling
- commit 741e7d8
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/fs-sysfs-do-dcache-related-updates-to-sysfs-under-sysfs_mutex.patch.
  Superseded by eaf5f9073533 fix shrink_dcache_parent() livelock
- commit 86687a2
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Add .changes file for kernel-obs-*.spec as well
- commit bd3c299
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/memory_dev_init-do-not-soft-lockup.patch.
- Delete patches.fixes/mm-link_mem_sections-touch-nmi-watchdog.patch.
  sysfs file addition is no longer O(N^2) since a406f75840e1 (sysfs: use
  rb-tree for inode number lookup) so we do not need to silent these
  codepaths to prevent Softlockups anymore. We couldn't do this in
  SLE11-SP[23] because the backport would be too invasive and break kABI.
- commit 3660837
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/mm-cond_resced-in-putback_lru_pages.patch.
  not upstreamable and only papers over issue that should be fixed for
  real.
- commit 58b3cb3
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/mm-hugetlbfs-Correctly-detect-if-page-tables-have-just-been-shared.patch.
  Fixed in upstream by d833352a4338 mm: hugetlbfs: close race during
  teardown of hugetlbfs shared page tables
- commit 4053f43
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.suse/mm-vmalloc-fail-dump-stack.patch.
  The patch was aimed only for debugging the particular issue and
  shouldn't be merged in the first place. Drop it finally.
- commit 063bbf1
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.suse/file-capabilities-disable-by-default.diff.
  Let's go with the upstream kernel parameters finally. We have been
  carrying this for long enough.
- commit f8d1c50
* Fri Jan 10 2014 mhocko@suse.cz
- Delete patches.fixes/remount-no-shrink-dcache
  the optimization is no longer needed because dcache_lock is long gone
  and replaced by RCU (see b5c84bf6f6 fs: dcache remove dcache_lock and
  others).
- commit 762fdc6
* Fri Jan 10 2014 ro@suse.de
- rpm/kernel-obs-build.spec: Fix building in chroot instead of Xen
- commit 57e89b6
* Fri Jan 10 2014 mhocko@suse.cz
- patches from SLE11-SP3 which will be dropped
- commit e3b859a
* Fri Jan 10 2014 mkubecek@suse.cz
- macvlan: disable LRO on lower device instead of macvlan
  (bnc#846984).
- macvlan: introduce macvlan_dev_real_dev() helper function
  (bnc#846984).
- macvlan: introduce IFF_MACVLAN flag and helper function
  (bnc#846984).
- commit e34a421
* Fri Jan 10 2014 tiwai@suse.de
- ALSA: hda - load EQ params into IDT codec on HP bNB13 systems
  (bnc#850493).
- commit 071b94c
* Fri Jan 10 2014 mgorman@suse.de
- mm: do not walk all of system memory during show_mem
  (Reduce tasklist_lock hold times (bnc#821259)).
- commit 4a78574
* Thu Jan  9 2014 bpoirier@suse.de
- net: Do not enable tx-nocache-copy by default (bnc#845378).
- commit e92a7d7
* Thu Jan  9 2014 jbeulich@suse.com
- supported.conf: Re-add msr.ko (for the sake of Xen).
- commit 8b04f36
* Thu Jan  9 2014 jbeulich@suse.com
- Update Xen patches to 3.12.6 and c/s 1245.
- netback: bump tx queue length (bnc#849404).
- xen/acpi: Export host physical CPU information to dom0
  (bnc#651066).
- x86/efi: Add EFI framebuffer earlyprintk support (bnc#845706).
- ACPI, x86: Extended error log driver for x86 platform
  (fate#315508).
- DMI: Parse memory device (type 17) in SMBIOS (fate#315508).
- mm: fix TLB flush race between migration,
  andchange_protection_range (Automatic NUMA Balancing
  (fate#315482)).
- mm: rename USE_SPLIT_PTLOCKS to USE_SPLIT_PTE_PTLOCKS (Automatic
  NUMA Balancing (fate#315482)).
- Linux 3.12.2 (bnc#852581).
- x86: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- x86: mm: Account for TLB flushes only when debugging (VM
  Performance).
- x86: mm: Clean up inconsistencies when flushing TLB ranges
  (VM Performance).
- x86: mm: Eliminate redundant page table walk during TLB
  rangeflushing (VM Performance).
- x86, mm: enable split page table lock for PMD level (Automatic
  NUMA Balancing (fate#315482)).
- Update EC2 config file.
- commit b164f85
* Thu Jan  9 2014 bpoirier@suse.de
- be2net: fix max_evt_qs calculation for BE3 in SR-IOV config
  (bnc#855062 FATE#315961).
- be2net: increase the timeout value for loopback-test FW cmd
  (bnc#855062 FATE#315961).
- be2net: disable RSS when number of RXQs is reduced to 1 via
  set-channels (bnc#855062 FATE#315961).
- be2net: Free/delete pmacs (in be_clear()) only if they exist
  (bnc#855062 FATE#315961).
- be2net: Fix Lancer error recovery to distinguish FW download
  (bnc#855062 FATE#315961).
- be2net: call napi_disable() for all event queues (bnc#855062
  FATE#315961).
- Revert "be2net: call napi_disable() for all event queues"
  (bnc#855062 FATE#315961).
- be2net: call napi_disable() for all event queues (bnc#855062
  FATE#315961).
- be2net: Avoid programming permenant MAC by BE3-R VFs (bnc#855062
  FATE#315961).
- be2net: set coalesce-wm in CQ_CREATE_V2 cmd (bnc#855062
  FATE#315961).
- be2net: Disabling and enabling interrupts in suspend and resume
  (bnc#855062 FATE#315961).
- be2net: Delete secondary unicast MAC addresses during be_close
  (bnc#855062 FATE#315961).
- be2net: Fix unconditional enabling of Rx interface options
  (bnc#855062 FATE#315961).
- net/benet: Make lancer_wait_ready() static (bnc#855062
  FATE#315961).
- net/benet: Remove interface type (bnc#855062 FATE#315961).
- be2net: add support for ndo_busy_poll (bnc#855062 FATE#315961).
- be2net: Warn users of possible broken functionality on BE2
  cards with very old FW versions with latest driver (bnc#855062
  FATE#315961).
- net: be2net: remove unnecessary pci_set_drvdata() (bnc#855062
  FATE#315961).
- be2net: Rework PCIe error report log messaging (bnc#855062
  FATE#315961).
- be2net: change the driver version number to 4.9.224.0
  (bnc#855062 FATE#315961).
- be2net: Display RoCE specific counters in ethtool -S (bnc#855062
  FATE#315961).
- be2net: Call version 2 of GET_STATS ioctl for Skyhawk-R
  (bnc#855062 FATE#315961).
- be2net: add a counter for pkts dropped in xmit path (bnc#855062
  FATE#315961).
- be2net: fix adaptive interrupt coalescing (bnc#855062
  FATE#315961).
- be2net: call ENABLE_VF cmd for Skyhawk-R too (bnc#855062
  FATE#315961).
- be2net: Create single TXQ on BE3-R 1G ports (bnc#855062
  FATE#315961).
- be2net: Call be_vf_setup() even when VFs are enbaled from
  previous load (bnc#855062 FATE#315961).
- emulex: Remove extern from function prototypes (bnc#855062
  FATE#315961).
- DMA-API: net: emulex/benet: replace
  dma_set_mask()+dma_set_coherent_mask() with new helper
  (bnc#855062 FATE#315961).
- net: Explicitly initialize u64_stats_sync structures for lockdep
  (bnc#855062 FATE#315961).
- DMA-API: provide a helper to set both DMA and coherent DMA masks
  (bnc#855062 FATE#315961).
- commit 773d6f6
* Thu Jan  9 2014 jdelvare@suse.de
- Disable CONFIG_MODULE_FORCE_UNLOAD (bnc#854171, bnc#857673)
  Forcing module unloading can't lead to anything good. If reference
  counting is wrong then it should be fixed. If the reference count is
  right and a regular (unforced) unloading doesn't work, then a forced
  unloading can only lead to chaos and ultimately a kernel crash.
- commit 5b49610
* Thu Jan  9 2014 jjolly@suse.de
- zcrypt: Add EP11 support to zcrypt device driver (fate#315299,
  LTC#92996).
- commit fe9b2e5
* Thu Jan  9 2014 jjolly@suse.de
- qeth: Accurate ethtool output (fate#315319, LTC#92772).
- commit 1cc5c4f
* Thu Jan  9 2014 jjolly@suse.de
- qeth: Display adjacent switch port attributes in ethtool
  (fate#315320, LTC#92773).
- commit 81c5b05
* Thu Jan  9 2014 jjolly@suse.de
- ethtool: Add callback to indicate adjacent switch port
  attributes (fate#315320, LTC#92773).
- commit 659f499
* Thu Jan  9 2014 jjolly@suse.de
- ib_uverbs: Allow explicit mmio trigger (fate#315287, LTC#94186).
- commit 84f2dc6
* Wed Jan  8 2014 duwe@suse.de
- Update config files.
  SLE12 ppc64 will be little-endian.
- commit 7266850
* Wed Jan  8 2014 duwe@suse.de
- powerpc: Fix endian issues in crash dump code (bnc#856774
  fate#315275, LTC#92305).
- powerpc/pseries: Fix endian issues in MSI code (bnc#856774
  fate#315275, LTC#92305).
- powerpc/pseries: Fix PCIE link speed endian issue (bnc#856774
  fate#315275, LTC#92305).
- powerpc/pseries: Fix endian issues in nvram code (bnc#856774
  fate#315275, LTC#92305).
- powerpc/pseries: Fix endian issues in /proc/ppc64/lparcfg
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix topology core_id endian issue on LE builds
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix endian issue in setup-common.c (bnc#856774
  fate#315275, LTC#92305).
- powerpc: allyesconfig should not select CONFIG_CPU_LITTLE_ENDIAN
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix error when cross building TAGS & cscope (bnc#856774
  fate#315275, LTC#92305).
- kvm: powerpc: allow guest control "E" attribute in mas2
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Wrong DWARF CFI in the kernel vdso for little-endian /
  ELFv2 (bnc#856774 fate#315275, LTC#92305).
- powerpc: Add pseries_le_defconfig (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Add CONFIG_CPU_LITTLE_ENDIAN kernel config option
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Don't use ELFv2 ABI to build the kernel (bnc#856774
  fate#315275, LTC#92305).
- powerpc: ELF2 binaries signal handling (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: ELF2 binaries launched directly (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Set eflags correctly for ELF ABIv2 core dumps
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Add TIF_ELF2ABI flag (bnc#856774 fate#315275,
  LTC#92305).
- pseries: Add H_SET_MODE to change exception endianness
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/pseries: Fix endian issues in pseries EEH code
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Remove big endianness assumption in
  of_find_next_cache_node (bnc#856774 fate#315275, LTC#92305).
- powerpc: word-at-a-time optimization for 64-bit Little Endian
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/bpf: BPF JIT compiler for 64-bit Little Endian
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/nvram: Fix endian issue when using the partition length
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/nvram: Fix endian issue when reading the NVRAM size
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Use -mcpu=power7 on ppc64 little endian builds
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix Unaligned LE Floating Point Loads and Stores
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix Unaligned Loads and Stores (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Enable Little Endian Alignment Handler for Float Pair
  Instructions (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix Handler of Unaligned Load/Store Strings (bnc#856774
  fate#315275, LTC#92305).
- powerpc/pseries: Fix endian issues in pseries iommu code
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix little endian issue in OF PCI scan (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Make kernel module helper endian-safe (bnc#856774
  fate#315275, LTC#92305).
- powerpc: prom_init exception when updating core value
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/kernel: Fix endian issue in rtas_pci (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Work around little endian gcc bug (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Don't set HAVE_EFFICIENT_UNALIGNED_ACCESS on little
  endian builds (bnc#856774 fate#315275, LTC#92305).
- powerpc: Add ability to build little endian kernels (bnc#856774
  fate#315275, LTC#92305).
- KVM: PPC: Disable KVM on little endian builds (bnc#856774
  fate#315275, LTC#92305).
- powerpc/hvsi: Fix endian issues in HVSI driver (bnc#856774
  fate#315275, LTC#92305).
- powerpc/powernv: Fix some PCI sparse errors and one LE bug
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: More little endian issues in OPAL RTC driver
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Don't register exception handlers in little
  endian mode (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix OPAL entry and exit in little endian mode
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix endian issues in OPAL console and udbg
  backend (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix endian issues in powernv PCI code
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Make OPAL NVRAM device tree accesses endian
  safe (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix endian issues in OPAL ICS backend
  (bnc#856774 fate#315275, LTC#92305).
- powerpc/powernv: Fix endian issues in OPAL RTC driver
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Little endian sparse clean up for
  arch/powerpc/platforms/powernv/pci-ioda.c (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Little endian fix for
  arch/powerpc/platforms/powernv/pci-p5ioc2.c (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Little endian fix for (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Little endian fixes for platforms/powernv/opal.c
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: uname should return ppc64le/ppcle on little (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Use generic memcpy code in little endian (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Use generic checksum code in little endian (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Handle VSX alignment faults in little endian mode
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Add little endian support to alignment handler
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Alignment handler shouldn't access VSX registers with
  TS_FPR (bnc#856774 fate#315275, LTC#92305).
- powerpc: Remove hard coded FP offsets in alignment handler
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Remove open coded byte swap macro in alignment handler
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Endian safe trampoline (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Include the appropriate endianness header (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Reset MSR_LE on signal entry (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Set MSR_LE bit on little endian builds (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Add little endian support for word-at-a-time functions
  (bnc#856774 fate#315275, LTC#92305).
- powerpc: Support endian agnostic MMIO (bnc#856774 fate#315275,
  LTC#92305).
- powerpc: Little endian builds double word swap VSX state during
  context save/restore (bnc#856774 fate#315275, LTC#92305).
- powerpc: PTRACE_PEEKUSR/PTRACE_POKEUSER of FPR registers in
  little endian builds (bnc#856774 fate#315275, LTC#92305).
- powerpc: Fix offset of FPRs in VSX registers in little endian
  builds (bnc#856774 fate#315275, LTC#92305).
- powerpc: Book 3S MMU little endian support (bnc#856774
  fate#315275, LTC#92305).
- powerpc: Fix endian issues in VMX copy loops (bnc#856774
  fate#315275, LTC#92305).
- commit d832683
* Tue Jan  7 2014 mgorman@suse.de
- mm: numa: Add a sysctl for numa_balancing
  (Automatic NUMA Balancing (fate#315482)).
- commit 2f667fa
* Tue Jan  7 2014 mgorman@suse.de
- sched: Calculate effective load even if local weight is 0
  (Automatic NUMA Balancing (fate#315482)).
- commit 372b949
* Tue Jan  7 2014 jjolly@suse.de
- Update s390x default and trace config files with.
  - CONFIG_PCI=y
  - CONFIG_HOTPLUG_PCI=y
  - CONFIG_HOTPLUG_PCI_S390=y
  - CONFIG_PCI_IOV=y
  - CONFIG_INFINIBAND=m
  - CONFIG_INFINIBAND_USER_ACCESS=m
  - CONFIG_MLX4_INFINIBAND=m
  - CONFIG_MLX4_EN=m
  - CONFIG_RDS_RDMA=m
  - All others defaulted to No
- commit e28d9b2
* Tue Jan  7 2014 jjolly@suse.de
- s390: add pci support (fate#315311, LTC#92765).
- commit 8d5e8a3
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: reenable per default (fate#315311, LTC#92765).
- commit d0cfb2f
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci/dma: fix accounting of allocated_pages (fate#315311,
  LTC#92765).
- commit fea7d6f
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: set error state for unavailable functions
  (fate#315311, LTC#92765).
- commit cb00965
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: fix removal of nonexistent pci bus (fate#315311,
  LTC#92765).
- commit 7acd4c6
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: prevent inadvertently triggered bus scans
  (fate#315311, LTC#92765).
- commit 11ab4ae
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: implement hotplug notifications (fate#315311,
  LTC#92765).
- commit 58375d2
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: implement pcibios_remove_bus (fate#315311, LTC#92765).
- commit ce44883
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: improve handling of bus resources (fate#315311,
  LTC#92765).
- commit 0c85f5a
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: cleanup function information block (fate#315311,
  LTC#92765).
- commit 9669da8
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: remove CONFIG_PCI_DEBUG dependancy (fate#315311,
  LTC#92765).
- commit 19f4741
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: message cleanup (fate#315311, LTC#92765).
- commit 3dfcbc2
* Tue Jan  7 2014 jjolly@suse.de
- s390/pci: implement hibernation hooks (fate#315311, LTC#92765).
- commit fb1de4d
* Tue Jan  7 2014 jjolly@suse.de
- s390: allow to set gcc -mtune flag (fate#315297, LTC#100558).
- Update config files.
- commit 270706e
* Mon Jan  6 2014 vbabka@suse.cz
- mm: munlock: fix deadlock in __munlock_pagevec()
  (VM Functionality).
- mm: munlock: fix a bug where THP tail page is encountered
  (VM Functionality).
- commit 6373c4e
* Mon Jan  6 2014 jslaby@suse.cz
- Refresh
  patches.fixes/x86-dumpstack-Fix-printk_address-for-direct-addresse.patch.
  Fix upstream commit SHA.
- commit b467c22
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA, no 64-bit system would need it
- commit fdde423
* Mon Jan  6 2014 jdelvare@suse.de
- supported.conf: Update the list of i2c drivers
- commit fde7e06
* Mon Jan  6 2014 jdelvare@suse.de
- supported.conf: Update i2c and hwmon driver paths
- commit b1f594f
* Fri Jan  3 2014 jack@suse.cz
- Update config files.
- commit fecc34b
* Fri Jan  3 2014 jack@suse.cz
- null_blk: support submit_queues on use_per_node_hctx
  (fate#315209).
- null_blk: set use_per_node_hctx param to false (fate#315209).
- null_blk: corrections to documentation (fate#315209).
- null_blk: warning on ignored submit_queues param (fate#315209).
- null_blk: refactor init and init errors code paths
  (fate#315209).
- null_blk: documentation (fate#315209).
- null_blk: mem garbage on NUMA systems during init (fate#315209).
- block: fix memory leaks on unplugging block device
  (fate#315209).
- blk-mq: fix use-after-free of request (fate#315209).
- blk-mq: fix dereference of rq->mq_ctx if allocation fails
  (fate#315209).
- blk-mq: add blktrace insert event trace (fate#315209).
- blk-mq: ensure that we set REQ_IO_STAT so diskstats work
  (fate#315209).
- blk-mq: remove newly added instances of __cpuinit (fate#315209).
- blk-mq: don't disallow request merges for req->special being
  set (fate#315209).
- blk-mq: mq plug list breakage (fate#315209).
- blk-mq: fix for flush deadlock (fate#315209).
- blk-mq: add blk_mq_stop_hw_queues (fate#315209).
- null_blk: multi queue aware block test driver (fate#315209).
- blk-mq: new multi-queue block IO queueing mechanism
  (fate#315209).
- percpu_ida: add an API to return free tags (fate#315209).
- percpu_ida: add percpu_ida_for_each_free (fate#315209).
- percpu_ida: make percpu_ida percpu size/batch configurable
  (fate#315209).
- percpu_counter: make APIs irq safe (fate#315209).
- block: remove request ref_count (fate#315209).
- block: make rq->cmd_flags be 64-bit (fate#315209).
- smp: don't warn about csd->flags having CSD_FLAG_LOCK cleared
  for !wait (fate#315209).
- smp: export __smp_call_function_single() (fate#315209).
- commit 6300d09
* Fri Jan  3 2014 mmarek@suse.cz
- Switch to linux-*.tar.xz
- commit 27d9f61
* Fri Jan  3 2014 mmarek@suse.cz
- Add support for linux-*.tar.xz to the spec files
- commit d12c880
* Fri Dec 27 2013 jslaby@suse.cz
- Linux 3.12.6 (CVE-2013-4587 CVE-2013-6367 bnc#853050
  bnc#853051).
- Delete
  patches.fixes/kvm-improve-create-vcpu-parameter-cve-2013-4587.patch.
- Delete
  patches.fixes/kvm-x86-convert-vapic-synchronization-to-cached-functions-cve-2013-6368.patch.
- Delete
  patches.fixes/kvm-x86-fix-guest-initiated-crash-with-x2apic-cve-2013-6376.patch.
- Delete
  patches.fixes/kvm-x86-fix-potential-divide-by-0-in-lapic-cve-2013-6367.patch.
- commit 22dbca3
* Tue Dec 24 2013 mgorman@suse.de
- mm: Fix NULL pointer dereference in madvise(MADV_WILLNEED)
  support (Automatic NUMA Balancing (fate#315482)).
- commit d71cf52
* Sun Dec 22 2013 bp@suse.de
- KVM: x86: fix guest-initiated crash with x2apic (CVE-2013-6376)
  (bnc#853053 CVE-2013-6376).
- commit fc9748d
* Sun Dec 22 2013 bp@suse.de
- KVM: x86: Convert vapic synchronization to _cached functions
  (CVE-2013-6368) (bnc#853052 CVE-2013-6368).
- commit 28d45f8
* Fri Dec 20 2013 mgorman@suse.de
- Refresh patches.xen/xen3-patch-3.12.
- commit 360b735
* Fri Dec 20 2013 mgorman@suse.de
- x86: mm: Eliminate redundant page table walk during TLB range
  flushing (VM Performance).
- x86: mm: Clean up inconsistencies when flushing TLB ranges
  (VM Performance).
- x86: mm: Account for TLB flushes only when debugging (VM
  Performance).
- commit 0347c48
* Fri Dec 20 2013 mgorman@suse.de
- mm: Remove bogus warning in copy_huge_pmd (Automatic NUMA
  Balancing (fate#315482)).
- commit da30075
* Fri Dec 20 2013 mgorman@suse.de
- mm: page_alloc: revert NUMA aspect of fair allocation policy
  (Misc VM performance).
- commit 8c29bc0
* Fri Dec 20 2013 mgorman@suse.de
- mm/migrate.c: fix setting of cpupid on page migration twice
  against normal page (Automatic NUMA Balancing (fate#315482)).
- mm/migrate.c: fix set cpupid on page migration twice against
  thp (Automatic NUMA Balancing (fate#315482)).
- sched: add tracepoints related to NUMA task migration (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: do not automatically migrate KSM pages (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: trace tasks that fail migration due to rate limiting
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: limit scope of lock for NUMA migrate rate limiting
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: make NUMA-migrate related functions static (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: defer TLB flush for THP migration as long as possible
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: guarantee that tlb_flush_pending updates are
  visible before page table updates (Automatic NUMA Balancing
  (fate#315482)).
- mm: fix TLB flush race between migration, and
  change_protection_range (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: avoid unnecessary disruption of NUMA hinting during
  migration (Automatic NUMA Balancing (fate#315482)).
- mm: numa: clear numa hinting information on mprotect (Automatic
  NUMA Balancing (fate#315482)).
- sched: numa: skip inaccessible VMAs (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: avoid unnecessary work on the failure path (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: ensure anon_vma is locked to prevent parallel THP
  splits (Automatic NUMA Balancing (fate#315482)).
- mm: numa: do not clear PTE for pte_numa update (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: do not clear PMD during PTE update scan (Automatic
  NUMA Balancing (fate#315482)).
- mm: clear pmd_numa before invalidating (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: call MMU notifiers on THP migration (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: serialise parallel get_user_page against THP migration
  (Automatic NUMA Balancing (fate#315482)).
- commit 2567e34
* Fri Dec 20 2013 mgorman@suse.de
- patches.suse/mm-Clear-pmd_numa-before-invalidating.patch.
- patches.suse/mm-numa-Avoid-unnecessary-disruption-of-NUMA-hinting-during-migration.patch.
- patches.suse/mm-numa-Avoid-unnecessary-work-on-the-failure-path.patch.
- patches.suse/mm-numa-Call-MMU-notifiers-on-THP-migration.patch.
- patches.suse/mm-numa-Clear-numa-hinting-information-on-mprotect.patch.
- patches.suse/mm-numa-Do-not-automatically-migrate-KSM-pages.patch.
- patches.suse/mm-numa-Do-not-clear-PMD-during-PTE-update-scan.patch.
- patches.suse/mm-numa-Do-not-clear-PTE-for-pte_numa-update.patch.
- patches.suse/mm-numa-Ensure-anon_vma-is-locked-to-prevent-parallel-THP-splits.patch.
- patches.suse/mm-numa-Limit-scope-of-lock-for-NUMA-migrate-rate-limiting.patch.
- patches.suse/mm-numa-Make-numamigrate_update_ratelimit-static.patch.
- patches.suse/mm-numa-Serialise-parallel-get_user_page-against-THP-migration.patch.
- patches.suse/mm-numa-Trace-tasks-that-fail-migration-due-to-rate-limiting.patch.
- patches.suse/mm-numa-defer-tlb-flush-until-thp-migrate.patch.
- patches.suse/mm-numa-fix-memory-corrupter-race-between-NUMA-unmap-and-migrate.patch.
- patches.suse/sched-Add-tracepoints-related-to-NUMA-task-migration.patch.
- patches.suse/sched-Tracepoint-task-movement.patch.
- patches.suse/sched-numa-Skip-inaccessible-VMAs.patch.
  Delete, will be replaced by final upstream versions
- commit cb8d368
* Thu Dec 19 2013 mmarek@suse.cz
- Disable OSS support (fate#316706)
- commit 9537283
* Thu Dec 19 2013 mmarek@suse.cz
- Disable CONFIG_IDE on POWER, to sync with other archs (fate#316706)
- commit 6b032c9
* Thu Dec 19 2013 mmarek@suse.cz
- Disable staging drivers (fate#316706)
- commit d8cc0bf
* Thu Dec 19 2013 bp@suse.de
- KVM: x86: Fix potential divide by 0 in lapic (CVE-2013-6367)
  (bnc#853051 CVE-2013-6367).
- commit fbea09d
* Thu Dec 19 2013 bp@suse.de
- KVM: Improve create VCPU parameter (CVE-2013-4587) (bnc#853050
  CVE-2013-4587).
- commit b3423a8
* Thu Dec 19 2013 mmarek@suse.cz
- config.conf: Remove reference to non-existent ia64 configs
- commit 61e3e49
* Thu Dec 19 2013 bp@suse.de
- config: Disable CONFIG_USB_WPAN_HCD
  "Take it behind the barn and shoot it." says Michal. :)
- commit 2c1c77c
* Wed Dec 18 2013 mmarek@suse.cz
- Remove ia64 configs
- commit 37a9fda
* Wed Dec 18 2013 tiwai@suse.de
- Disable simplefb and x86 sysfb due to breakage (bnc#855821)
- commit a6fd02d
* Wed Dec 18 2013 mmarek@suse.cz
- Update x86_64/vanilla config
- commit b0e40ab
* Wed Dec 18 2013 adrian@suse.de
- Add kernel-obs-build to use the distribution kernel within OBS VM builds.
  Add kernel-obs-qa to test that the kernel is booting within OBS VMs. It may run also further tests later on.
- commit e9cfd5c
* Tue Dec 17 2013 mmarek@suse.cz
- Port module signing changes from SLE11-SP3 (fate#314508)
- commit 8a264a3
* Mon Dec 16 2013 bpoirier@suse.de
- supported.conf: Remove stray .ko extensions
- commit 8efdb24
* Mon Dec 16 2013 bpoirier@suse.de
- supported.conf: Add some usb network adapters
  > From: Oliver Neukum <oneukum@suse.de>
  > These drivers are necessary for MobileBroadband. So they must be supported.
- commit 155762b
* Mon Dec 16 2013 ohering@suse.de
- fbmem: really support wildcard video=options for all fbdev
  drivers.
- commit 76f697b
* Mon Dec 16 2013 jkosina@suse.cz
- doc/README.PATCH-POLICY.SUSE: add patch policy / best practices document
- commit 60893d6
* Mon Dec 16 2013 ohering@suse.de
- supported.conf: add hid-generic, ehci-pci, ohci-pci (bnc#855248)
- commit 035ee7b
* Mon Dec 16 2013 ohering@suse.de
- Include hyperv related changes from 3.13-rc4:
- hv: Change variable type to bool.
- hv: use dev_groups for device attributes.
- hv: move "state" bus attribute to dev_groups.
- hv: move "monitor_id" bus attribute to dev_groups.
- hv: move "modalias" bus attribute to dev_groups.
- hv: move "class_id" bus attribute to dev_groups.
- hv: move "device_id" bus attribute to dev_groups.
- hv: make "monitor_pages" a "real" pointer array.
- hv: move "client/server_monitor_pending" bus attributes to
  dev_groups.
- hv: move "client/server_monitor_latency" bus attributes to
  dev_groups.
- hv: move "client/server_monitor_conn_id" bus attributes to
  dev_groups.
- hv: delete vmbus_get_debug_info().
- hv: delete struct hv_dev_port_info.
- hv: move ringbuffer bus attributes to dev_groups.
- Tools: hv: cache FQDN in kvp_daemon to avoid timeouts.
- Tools: hv: use single send+recv buffer.
- hv: vmbus: fix vmbus_recvpacket_raw() return code.
- hyperv-fb: add blanking support.
- x86, hyperv: Correctly guard the local APIC calibration code.
- drivers: hv: Fix wrong check for synic_event_page.
- x86, hyperv: Fix build error due to missing <asm/apic.h>
  include.
- x86, hyperv: Move a variable to avoid an unused variable
  warning.
- commit 67d24df
* Mon Dec 16 2013 trenn@suse.de
- supported.conf:
  Clean up cpufreq driver support:
- Remove msr support -> built in
- Remove support of old or special HW
- Add support for new intel_pstate driver
- Add support for powerclamp driver
- commit 07b8435
* Thu Dec 12 2013 bpoirier@suse.de
- supported.conf: add some network drivers
  Drivers for embedded platforms as well as obsolete devices (<1Gb) have been
  left out. I did not consider usb and wireless devices.
- commit 234ade0
* Thu Dec 12 2013 jdelvare@suse.de
- supported.conf: Fix a typo.
- commit 4eeb705
* Thu Dec 12 2013 jdelvare@suse.de
- Delete patches.suse/ida-remove-warning-dump-stack.patch.
  Already included in kernel 3.12 (WARN calls dump_stack.)
- commit e05b43b
* Thu Dec 12 2013 jslaby@suse.cz
- Linux 3.12.5.
- commit 9177f6b
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Spelling fix
- commit 2e074cb
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Delete dead code
- commit 98077a9
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Typo fix from upstream
- commit ce654f8
* Wed Dec 11 2013 tiwai@suse.de
- xhci: Limit the spurious wakeup fix only to HP machines
  (bnc#833097).
- commit b20fa17
* Tue Dec 10 2013 jslaby@suse.cz
- Linux 3.12.4 (bnc#844513).
- Refresh
  patches.drivers/0015-usb-wusbcore-add-support-for-isoc-out-transfers.patch.
- Refresh
  patches.drivers/0016-usb-wusbcore-fix-string-formatting-warnings-on-64-bi.patch.
- Refresh
  patches.drivers/0021-usb-wusbcore-combine-multiple-isoc-frames-in-a-singl.patch.
- Refresh patches.suse/connector-read-mostly.
- Refresh
  patches.suse/mm-Only-flush-TLBs-if-a-transhuge-PMD-is-modified-for-NUMA-pte-scanning.patch.
- Refresh
  patches.suse/mm-numa-Change-page-last-nid-pid-into-cpu-pid.patch.
- Refresh
  patches.suse/mm-numa-Do-not-batch-handle-PMD-pages.patch.
- Refresh
  patches.suse/sched-numa-Set-preferred-NUMA-node-based-on-number-of-private-faults.patch.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete
  patches.arch/iommu-vt-d-remove-stack-trace-from-broken-irq-remapping-warning.patch.
- Delete
  patches.drivers/0023-usb-wusbcore-change-WA_SEGS_MAX-to-a-legal-value.patch.
- Delete
  patches.suse/mm-numa-return-the-number-of-base-pages-altered-by-protection-changes.patch.
- commit a479b6d
* Tue Dec 10 2013 jbohac@suse.cz
- supported.conf: enable openvswitch and vxlan (fate#315731, fate#315433)
- commit 52b35c7
* Tue Dec 10 2013 mmarek@suse.cz
- Disable CONFIG_WIMAX (fate#315021)
- commit b035053
* Tue Dec 10 2013 mmarek@suse.cz
- supported.conf: Update for iwlwifi/iwlegacy
- commit 49f8098
* Tue Dec 10 2013 hare@suse.de
- supported.conf: Mark NVMe as supported (fate#315511)
- commit 9e5c55e
* Tue Dec 10 2013 bpoirier@suse.de
- supported.conf: Add some unlisted network modules
- commit 47bfe97
* Mon Dec  9 2013 bp@suse.de
- supported.conf: amd64_edac: Use real module name
  ... as mmarek says.
- commit d165311
* Mon Dec  9 2013 oneukum@suse.de
- USB: storage: use sg_miter_* APIs to access scsi buffer
  (FATE#315595).
- commit 05f32d2
* Mon Dec  9 2013 mmarek@suse.cz
- supported.conf: Add some missing dependencies
- commit 16de373
* Mon Dec  9 2013 oneukum@suse.de
- lib/scatterlist: export sg_miter_skip() (FATE#315595).
- commit 1ab5e09
* Mon Dec  9 2013 ohering@suse.de
- supported.conf: add hyperv-keyboard and hyperv_fb
- commit 33b52f7
* Mon Dec  9 2013 bp@suse.de
- supported.conf: Some more cleanup
  * drop drivers/ide/
  * ablk_helper for aesni_intel
  * eMCA one
  * add more comments
- commit c37fb13
* Mon Dec  9 2013 mgorman@suse.de
- Refresh patches.suse/mm-numa-Avoid-unnecessary-disruption-of-NUMA-hinting-during-migration.patch.
- commit d655c69
* Mon Dec  9 2013 mgorman@suse.de
- Refresh patches.suse/mm-Clear-pmd_numa-before-invalidating.patch.
- Refresh patches.suse/mm-numa-Avoid-unnecessary-disruption-of-NUMA-hinting-during-migration.patch.
- Refresh patches.suse/mm-numa-Avoid-unnecessary-work-on-the-failure-path.patch.
- Refresh patches.suse/mm-numa-Call-MMU-notifiers-on-THP-migration.patch.
- Refresh patches.suse/mm-numa-Clear-numa-hinting-information-on-mprotect.patch.
- Refresh patches.suse/mm-numa-Do-not-automatically-migrate-KSM-pages.patch.
- Refresh patches.suse/mm-numa-Do-not-clear-PMD-during-PTE-update-scan.patch.
- Refresh patches.suse/mm-numa-Do-not-clear-PTE-for-pte_numa-update.patch.
- Refresh patches.suse/mm-numa-Ensure-anon_vma-is-locked-to-prevent-parallel-THP-splits.patch.
- Refresh patches.suse/mm-numa-Limit-scope-of-lock-for-NUMA-migrate-rate-limiting.patch.
- Refresh patches.suse/mm-numa-Make-numamigrate_update_ratelimit-static.patch.
- Refresh patches.suse/mm-numa-Serialise-parallel-get_user_page-against-THP-migration.patch.
- Refresh patches.suse/mm-numa-Trace-tasks-that-fail-migration-due-to-rate-limiting.patch.
- Refresh patches.suse/sched-Add-tracepoints-related-to-NUMA-task-migration.patch.
- Refresh patches.suse/sched-Tracepoint-task-movement.patch.
- Refresh patches.suse/sched-numa-Skip-inaccessible-VMAs.patch.
- mm: fix TLB flush race between migration, and change_protection_range
- mm: numa: Defer TLB flush for THP migration as long as possible
  (Automatic NUMA Balancing (fate#315482)).
- commit 2a15d8f
* Sun Dec  8 2013 jdelvare@suse.de
- PCI: Drop warning about drivers that don't use pci_set_master()
- commit e4cd782
* Fri Dec  6 2013 jbohac@suse.cz
- supported.conf: mark xt_TEE as supported (fate#314876)
- commit a99c078
* Fri Dec  6 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add the OBS _constraints file as source
- commit 17282e4
* Fri Dec  6 2013 duwe@suse.de
- sched: Fix asymmetric scheduling for POWER7 (bnc#852591).
- powerpc: Fix fatal SLB miss when restoring PPR (bnc#852852).
- commit fb8834f
* Fri Dec  6 2013 mmarek@suse.cz
- rpm/config.sh: Remove the ARM and PPC repositories
  The standard IBS repository supports all the needed architectures.
- commit 5dd6d8b
* Fri Dec  6 2013 mmarek@suse.cz
- supported.conf: Add back nfs.ko
- commit 5e284fa
* Fri Dec  6 2013 mmarek@suse.cz
- Disable the af_802154, ax25, caif, netrom and rose modules (fate#315021)
- commit 5a3fd02
* Fri Dec  6 2013 mgorman@suse.de
- sched: Add tracepoints related to NUMA task migration (Automatic
  NUMA Balancing (fate#315482)).
- sched: Tracepoint task movement (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: Do not automatically migrate KSM pages (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: Trace tasks that fail migration due to rate limiting
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Limit scope of lock for NUMA migrate rate limiting
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Make numamigrate_update_ratelimit static (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: fix memory corrupter race between NUMA unmap and
  migrate (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Avoid unnecessary disruption of NUMA hinting during
  migration (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Clear numa hinting information on mprotect (Automatic
  NUMA Balancing (fate#315482)).
- sched: numa: Skip inaccessible VMAs (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: Avoid unnecessary work on the failure path (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: Ensure anon_vma is locked to prevent parallel THP
  splits (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Do not clear PTE for pte_numa update (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Do not clear PMD during PTE update scan (Automatic
  NUMA Balancing (fate#315482)).
- mm: Clear pmd_numa before invalidating (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: Call MMU notifiers on THP migration (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Serialise parallel get_user_page against THP migration
  (Automatic NUMA Balancing (fate#315482)).
- commit a7b0b54
* Fri Dec  6 2013 mgorman@suse.de
- Delete patches.suse/mm-numa-Serialise-parallel-get_user_page-against-THP-migration.patch.
- Refresh patches.suse/sched-numa-Fix-comments.patch.
- Refresh patches.suse/mm-convert-the-rest-to-new-page-table-lock-api.patch.
- commit 2aa557c
* Thu Dec  5 2013 oneukum@suse.de
- fixup of stupid copy'n'paste issue in series.conf
- commit 84a3edb
* Thu Dec  5 2013 oneukum@suse.de
- usb: ohci: use amd_chipset_type to filter for SB800 prefetch
  (bnc#853497).
-  patches.drivers/0001-usb-ehci-use-amd_chipset_type-to-filter-for-usb-subs.patch.
  (bnc#853496)
- commit ae6457a
* Thu Dec  5 2013 oneukum@suse.de
- usb: ehci: use amd_chipset_type to filter for usb subsystem
  hang bug (bnc#853496).
- commit c9879c5
* Thu Dec  5 2013 oneukum@suse.de
- usb: core: implement AMD remote wakeup quirk (bnc#853495).
- commit ae62ef2
* Thu Dec  5 2013 oneukum@suse.de
- usb: pci-quirks: refactor AMD quirk to abstract AMD chipset
  types (bnc#853493).
- commit 2401ff4
* Wed Dec  4 2013 jslaby@suse.cz
- Linux 3.12.3.
- Refresh
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- commit fd18ffa
* Wed Dec  4 2013 jeffm@suse.com
- config: enable CONFIG_EXPERT
  3.10 introduced Kconfig rules that automatically builds in
  uncommon HID drivers if EXPERT is not set.
  This commit does not introduce any other config changes.
- commit 30a871c
* Wed Dec  4 2013 jeffm@suse.com
- README: Update to document typical patch naming
- commit 427dd7a
* Wed Dec  4 2013 oneukum@suse.de
- USB: kill #undef VERBOSE_DEBUG (FATE#316422).
- usb: kill DEBUG compile option (FATE#316422).
- fusbh200: kill fusbh200_vdbg (FATE#316422).
- fusb200h: always compile in debugfs support (FATE#316422).
- fusbh200: always compile debugfs support (FATE#316422).
- fusb200h: don't log on every interrupt (FATE#316422).
- fusbh200: unconditionally compile debugging helpers
  (FATE#316422).
- uhci: compile debugfs conditional on CONFIG_DYNAMIC_DEBUG ||
  DEBUG (FATE#316422).
- uhci: change dependency for debug parameter (FATE#316422).
- fusbh200: always build debugfs support (FATE#316422).
- fotg210: kill fotg210_vdbg() (FATE#316422).
- fotg210: remove conditional compilation (FATE#316422).
- fotg210: change dbg_port() to evaluate parameters only if needed
  (FATE#316422).
- fotg210: always compile the support for debugfs (FATE#316422).
- fotg210: remove conditional compilation (FATE#316422).
- ehci: Remove debugging at every interrupt (FATE#316422).
- ehci: no conditional compilation for interestingness
  (FATE#316422).
- ohci: no conditional debugging in root hub hadling
  (FATE#316422).
- ohci:always register debug files (FATE#316422).
- ohci: kill ohci_vdbg (FATE#316422).
- [PATCH 01/22] ohci: remove conditional compilation
  (FATE#316422).
- commit b24e291
* Wed Dec  4 2013 tiwai@suse.de
- config: CONFIG_CHECKPOINT_RESTORE=y and CONFIG_MEM_SOFT_DIRTY=y on x86_64
- commit 1922871
* Wed Dec  4 2013 mmarek@suse.cz
- set CONFIG_SUSE_KERNEL_SUPPORTED=y
  This splits unsupported modules into kernel-*-extra.
- commit 7d6bb64
* Tue Dec  3 2013 mgorman@suse.de
- mm: thp: give transparent hugepage code a separate copy_page
  (Automatic NUMA Balancing (fate#315482)).
- mm: hugetlbfs: fix hugetlbfs optimization (Automatic NUMA
  Balancing (fate#315482)).
- commit 8a1549e
* Tue Dec  3 2013 oneukum@suse.de
- xhci: replace xhci_write_64() with writeq() (FATE#316422).
- xhci: replace xhci_read_64() with readq() (FATE#316422).
- xhci: replace xhci_writel() with writel() (FATE#316422).
- xhci: replace xhci_readl() with readl() (FATE#316422).
- xhci: remove conversion from generic to pci device in xhci_mem.c
  (FATE#316422).
- xhci: fix incorrect type in assignment in
  xhci_count_num_dropped_endpoints() (FATE#316422).
- xhci: fix incorrect type in assignment in
  xhci_count_num_new_endpoints() (FATE#316422).
- xhci: remove unnecessary check in xhci_free_stream_info()
  (FATE#316422).
- xhci: fix SCT_FOR_CTX(p) macro (FATE#316422).
- xhci: replace USB_MAXINTERFACES with config->desc.bNumInterface
  (FATE#316422).
- xhci: fix incorrect type in assignment in xhci_address_device()
  (FATE#316422).
- xhci: fix sparse warning in xhci-trace.h (FATE#316422).
- xhci: fix derivation of TRB's DMA address in xhci_log_event
  Trace Event Class (FATE#316422).
- xhci: fix incorrect type in assignment in
  handle_device_notification() (FATE#316422).
- xhci: convert TRB_CYCLE to le32 before using it to set Link
  TRB's cycle bit (FATE#316422).
- commit ad000b6
* Mon Dec  2 2013 spargaonkar@suse.de
- sg: fix blk_get_queue usage (bnc#834808).
- commit b79258b
* Mon Dec  2 2013 oneukum@suse.de
- Delete
  patches.drivers/0001-usb-Disable-USB-2.0-Link-PM-before-device-reset.patch.
- Delete
  patches.drivers/0002-xhci-Set-L1-device-slot-on-USB2-LPM-enable-disable.patch.
- Delete
  patches.drivers/0003-usb-Don-t-enable-USB-2.0-Link-PM-by-default.patch.
- Delete
  patches.drivers/0004-xhci-Enable-LPM-support-only-for-hardwired-or-BESL-d.patch.
  collided with stable update
- commit 4c5c53a
* Mon Dec  2 2013 oneukum@suse.de
- usb: Push USB2 LPM disable on disconnect into USB core
  (FATE#315521).
- xhci: Enable LPM support only for hardwired or BESL devices
  (FATE#315521).
- usb: Don't enable USB 2.0 Link PM by default (FATE#315521).
- xhci: Set L1 device slot on USB2 LPM enable/disable
  (FATE#315521).
- usb: Disable USB 2.0 Link PM before device reset (FATE#315521).
- commit 4d3252a
* Mon Dec  2 2013 jkosina@suse.cz
- README.BRANCH: update to contain SLE 12 info
- commit a498989
* Fri Nov 29 2013 jslaby@suse.cz
- Update vanilla config files.
- commit c8af954
* Fri Nov 29 2013 jslaby@suse.cz
- Linux 3.12.2.
- Refresh patches.xen/xen3-patch-2.6.29.
- Delete
  patches.suse/btrfs-relocate-csums-properly-with-prealloc-extents.patch.
- commit 3b81e61
* Fri Nov 29 2013 oneukum@suse.de
- USB: fix substandard locking for the sysfs files (FATE#316422).
- commit df19030
* Fri Nov 29 2013 oneukum@suse.de
- usb: wusbcore: Add isoc transfer type enum and packet
  definitions (bnc#852581).
- usb: wusbcore: change WA_SEGS_MAX to a legal value (bnc#852581).
- usb: wusbcore: add a quirk for Alereon HWA device isoc behavior
  (bnc#852581).
- usb: wusbcore: combine multiple isoc frames in a single transfer
  request (bnc#852581).
- usb: wusbcore: set the RPIPE wMaxPacketSize value correctly
  (bnc#852581).
- USB: wusbcore: fix usb_dev leaks (bnc#852581).
- usb: wusbcore: preserve endianness of cached descriptors
  (bnc#852581).
- usb: wusbcore: serialize access to the HWA data out endpoint
  (bnc#852581).
- usb: wusbcore: fix string formatting warnings on 64-bit builds
  (bnc#852581).
- usb: wusbcore: add support for isoc out transfers (bnc#852581).
- usb: wusbcore: set the RPIPE bOverTheAirInterval for isoc
  endpoints (bnc#852581).
- usb: wusbcore: implement hwahc_op_get_frame_number (bnc#852581).
- usb: wusbcore: avoid stack overflow in URB enqueue error path
  (bnc#852581).
- usb: wusbcore: fix build warning on 64-bit builds (bnc#852581).
- usb: wusbcore: clean up urb dequeue process (bnc#852581).
- usb: wusbcore: include the xfer_id in debug prints (bnc#852581).
- usb: wusbcore: fix endianess issues when using dwTransferID
  (bnc#852581).
- usb: wusbcore: set pointers to NULL after freeing in error cases
  (bnc#852581).
- usb: wusbcore: clean up the sg list that was created for out
  transfers (bnc#852581).
- usb: wusbcore: resource cleanup fix in __wa_xfer_setup_segs
  (bnc#852581).
- usb: wusbcore: allow wa_xfer_destroy to clean up partially
  constructed xfers (bnc#852581).
- usb: wusbcore: rename fields in struct wahc (bnc#852581).
- usb: wusbcore: rename urb to tr_urb in struct wa_seg
  (bnc#852581).
- USB: WUSBCORE: use list_move_tail instead of
  list_del/list_add_tail (bnc#852581).
- commit 6e9be29
* Fri Nov 29 2013 tiwai@suse.de
- Build mei and mei_me as modules (bnc#852656)
- commit 61db771
* Fri Nov 29 2013 tiwai@suse.de
- Build mei and mei_me as modules (bnc#852656)
- commit 1a570dd
* Thu Nov 28 2013 jdelvare@suse.de
- supported.conf: Update paths to i2c/chips drivers
  drivers/i2c/chips was removed years ago and drivers in there moved
  to other locations in the kernel tree. Update supported.conf
  accordingly.
- commit 429299a
* Thu Nov 28 2013 oneukum@suse.de
- Update config files. ULT also for vanilla. (bnc#852391)
- commit 9bd4421
* Thu Nov 28 2013 oneukum@suse.de
- Update config files. Refresh of change for ULT (bnc#852391)
- commit 3349a87
* Thu Nov 28 2013 jdelvare@suse.de
- supported.conf: dd drivers/hwmon/smsc47b397
  That one is very simple and reliable and found in a number of
  enterprise-grade workstations. I believe it would make sense to support
  it.
- commit 3a2ac9d
* Thu Nov 28 2013 jdelvare@suse.de
- supported.conf: Add drivers/hwmon/smsc47b397
  That one is very simple and reliable and found in a number of
  enterprise-grade workstations. I believe it would make sense to support
  it.
- commit d1248ee
* Wed Nov 27 2013 duwe@suse.de
- pstore: automatically dump and clean dmesg entries
  (fate#315232).
- Update config files.
- commit 9525160
* Wed Nov 27 2013 oneukum@suse.de
- Revert "Revert "USB: EHCI: support running URB giveback in
  tasklet context"" (FATE#315841).
- commit 77abd24
* Wed Nov 27 2013 oneukum@suse.de
- usbcore: fix incorrect type in assignment in
  usb_set_lpm_parameters() (FATE#315521).
- commit 0708ac3
* Wed Nov 27 2013 oneukum@suse.de
- usb-core: Make usb_free_streams return an error (FATE#315595).
- USB: ehci-fsl: Remove casting the return value which is a void
  pointer (FATE#315595).
- commit 0d16a1f
* Wed Nov 27 2013 oneukum@suse.de
- USB: EHCI: handle isochronous underruns with tasklets
  (FATE#315841).
- USB: EHCI: code rearrangement in iso_stream_schedule()
  (FATE#315841).
- USB: see if URB comes from a completion handler (FATE#315841).
- commit 926bdb3
* Tue Nov 26 2013 agraf@suse.de
- omapdrm: fix compile with dma_addr_t > u32.
- commit 611f4eb
* Tue Nov 26 2013 oneukum@suse.de
- Update config files for Low Power SubSystem of ULT chips. (bnc#852391)
- commit 5cc6291
* Tue Nov 26 2013 oneukum@suse.de
- Update config files.(bnc#845706)
- commit 34fc67e
* Tue Nov 26 2013 oneukum@suse.de
- kernel/printk/printk.c: enable boot delay for earlyprintk
  (bnc#845706).
- commit 42acbb1
* Mon Nov 25 2013 oneukum@suse.de
- Update config files. (bnc#845706)
- commit 6af2cf1
* Mon Nov 25 2013 oneukum@suse.de
- x86/efi: Add EFI framebuffer earlyprintk support (bnc#845706).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen-x86_64-vread-pvclock.
- Refresh patches.xen/xen3-patch-3.10.
- Refresh patches.xen/xen3-patch-3.9.
- commit 4e2a0a4
* Thu Nov 21 2013 jslaby@suse.cz
- Linux 3.12.1.
- commit 1e06fbe
* Wed Nov 20 2013 jdelvare@suse.de
- patches.arch/iommu-vt-d-remove-stack-trace-from-broken-irq-remapping-warning.patch:
  Fix forward porting, sorry.
- commit b21093b
* Wed Nov 20 2013 jdelvare@suse.de
- iommu: Remove stack trace from broken irq remapping warning
  (bnc#844513).
- commit 333d4dc
* Wed Nov 20 2013 jslaby@suse.cz
- Update config files (fate#315172).
  Disable PROC_KCORE, enable STRICT_DEVMEM.
- commit f5a3cd8
* Wed Nov 20 2013 jslaby@suse.cz
- Update config files (fate#315172).
- commit a0984ed
* Wed Nov 20 2013 jslaby@suse.cz
- x86/dumpstack: Fix printk_address for direct addresses
  (bnc#845621).
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen-x86_64-dump-user-pgt.
- commit ce55b22
* Wed Nov 20 2013 mgorman@suse.de
- Update config files.
  For FATE#315482 which included support for using split pagetable locks
  when lock debugging is enabled.
- commit 51d4693
* Wed Nov 20 2013 mgorman@suse.de
- lockref: use BLOATED_SPINLOCKS to avoid explicit config
  dependencies (Automatic NUMA Balancing (fate#315482)).
- mm: create a separate slab for page->ptl allocation (Automatic
  NUMA Balancing (fate#315482)).
- mm: properly separate the bloated ptl from the regular case
  (Automatic NUMA Balancing (fate#315482)).
- mm: dynamically allocate page->ptl if it cannot be embedded
  to struct page (Automatic NUMA Balancing (fate#315482)).
- xtensa: use buddy allocator for PTE table (Automatic NUMA
  Balancing (fate#315482)).
- iommu/arm-smmu: handle pgtable_page_ctor() fail (Automatic
  NUMA Balancing (fate#315482)).
- xtensa: handle pgtable_page_ctor() fail (Automatic NUMA
  Balancing (fate#315482)).
- x86: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- unicore32: handle pgtable_page_ctor() fail (Automatic NUMA
  Balancing (fate#315482)).
- um: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- tile: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- sparc: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- sh: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- score: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- s390: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- powerpc: handle pgtable_page_ctor() fail (Automatic NUMA
  Balancing (fate#315482)).
- parisc: handle pgtable_page_ctor() fail (Automatic NUMA
  Balancing (fate#315482)).
- mips: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- metag: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- m68k: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- m32r: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- ia64: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- hexagon: handle pgtable_page_ctor() fail (Automatic NUMA
  Balancing (fate#315482)).
- frv: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- cris: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- avr32: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- arm64: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- arm: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- arc: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- alpha: handle pgtable_page_ctor() fail (Automatic NUMA Balancing
  (fate#315482)).
- openrisc: add missing pgtable_page_ctor/dtor calls (Automatic
  NUMA Balancing (fate#315482)).
- mn10300: add missing pgtable_page_ctor/dtor calls (Automatic
  NUMA Balancing (fate#315482)).
- microblaze: add missing pgtable_page_ctor/dtor calls (Automatic
  NUMA Balancing (fate#315482)).
- mm: allow pgtable_page_ctor() to fail (Automatic NUMA Balancing
  (fate#315482)).
- xtensa: fix potential NULL-pointer dereference (Automatic NUMA
  Balancing (fate#315482)).
- m32r: fix potential NULL-pointer dereference (Automatic NUMA
  Balancing (fate#315482)).
- cris: fix potential NULL-pointer dereference (Automatic NUMA
  Balancing (fate#315482)).
- x86: add missed pgtable_pmd_page_ctor/dtor calls for
  preallocated pmds (Automatic NUMA Balancing (fate#315482)).
- x86, mm: enable split page table lock for PMD level (Automatic
  NUMA Balancing (fate#315482)).
- mm: implement split page table lock for PMD level (Automatic
  NUMA Balancing (fate#315482)).
- mm: convert the rest to new page table lock api (Automatic
  NUMA Balancing (fate#315482)).
- mm, hugetlb: convert hugetlbfs to use split pmd lock (Automatic
  NUMA Balancing (fate#315482)).
- mm, thp: do not access mm->pmd_huge_pte directly (Automatic
  NUMA Balancing (fate#315482)).
- mm, thp: move ptl taking inside page_check_address_pmd()
  (Automatic NUMA Balancing (fate#315482)).
- mm, thp: change pmd_trans_huge_lock() to return taken lock
  (Automatic NUMA Balancing (fate#315482)).
- mm: introduce api for split page table lock for PMD level
  (Automatic NUMA Balancing (fate#315482)).
- mm: convert mm->nr_ptes to atomic_long_t (Automatic NUMA
  Balancing (fate#315482)).
- mm: rename USE_SPLIT_PTLOCKS to USE_SPLIT_PTE_PTLOCKS (Automatic
  NUMA Balancing (fate#315482)).
- mm: avoid increase sizeof(struct page) due to split page table
  lock (Automatic NUMA Balancing (fate#315482)).
- mm/mempolicy: use NUMA_NO_NODE (Automatic NUMA Balancing
  (fate#315482)).
- mm: thp: khugepaged: add policy for finding target node
  (Automatic NUMA Balancing (fate#315482)).
- mm: thp: cleanup: mv alloc_hugepage to better place (Automatic
  NUMA Balancing (fate#315482)).
- sched/fair: Avoid integer overflow (Automatic NUMA Balancing
  (fate#315482)).
- sched: Optimize task_sched_runtime() (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Cure update_numa_stats() vs. hotplug (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Fix NULL pointer dereference in task_numa_migrate()
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: return the number of base pages altered by protection
  changes (Automatic NUMA Balancing (fate#315482)).
- stop_machine: Fix race between stop_two_cpus() and stop_cpus()
  (Automatic NUMA Balancing (fate#315482)).
- sched: Remove extra put_online_cpus() inside sched_setaffinity()
  (Automatic NUMA Balancing (fate#315482)).
- sched: Remove get_online_cpus() usage (Automatic NUMA Balancing
  (fate#315482)).
- sched: Fix race in migrate_swap_stop() (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Reflow task_numa_group() to avoid a compiler warning
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Retry task_numa_migrate() periodically (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Use unsigned longs for numa group fault stats
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Skip some page migrations after a shared fault
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Revert temporarily disabling of NUMA migration
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Remove the numa_balancing_scan_period_reset sysctl
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Adjust scan rate in task_numa_placement (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Take false sharing into account when adapting scan
  rate (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Be more careful about joining numa groups (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Avoid migrating tasks that are placed on their
  preferred node (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Fix task or group comparison (Automatic NUMA
  Balancing (fate#315482)).
- sched/numa: Decide whether to favour task or group weights
  based on swap candidate relationships (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Add debugging (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Prevent parallel updates to group stats during
  placement (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Call task_numa_free() from do_execve() (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Use group fault statistics in numa placement
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Stay on the same node if CLONE_VM (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Do not batch handle PMD pages (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Do not group on RO pages (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: Copy cpupid on page migration (Automatic NUMA
  Balancing (fate#315482)).
- sched/numa: Report a NUMA task group ID (Automatic NUMA
  Balancing (fate#315482)).
- sched/numa: Use {cpu, pid} to create task groups for shared
  faults (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Change page last {nid,pid} into {cpu,pid} (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Fix placement of workloads spread across multiple
  nodes (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Favor placing a task on the preferred node
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Use a system-wide search to find swap/migration
  candidates (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Introduce migrate_swap() (Automatic NUMA Balancing
  (fate#315482)).
- stop_machine: Introduce stop_two_cpus() (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Trap pmd hinting faults only if we would otherwise
  trap PTE faults (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Do not trap hinting faults for shared libraries
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Increment numa_migrate_seq when task runs in
  correct location (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Retry migration of tasks to CPU on a preferred node
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Avoid overloading CPUs on a preferred NUMA node
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Limit NUMA scanning to migrate-on-fault VMAs
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Do not migrate memory immediately after switching
  node (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Set preferred NUMA node based on number of private
  faults (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Remove check that skips small VMAs (Automatic NUMA
  Balancing (fate#315482)).
- mm: numa: Scan pages with elevated page_mapcount (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Check current->mm before allocating NUMA faults
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Add infrastructure for split shared/private
  accounting of NUMA hinting faults (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Reschedule task on preferred NUMA node once selected
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Resist moving tasks towards nodes with fewer
  hinting faults (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Favour moving tasks towards the preferred node
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Update NUMA hinting faults once per scan (Automatic
  NUMA Balancing (fate#315482)).
- sched/numa: Select a preferred node with the most numa hinting
  faults (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Track NUMA hinting faults on per-node basis
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Slow scan rate if no NUMA hinting faults are being
  recorded (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Set the scan rate proportional to the memory
  usage of the task being scanned (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Initialise numa_next_scan properly (Automatic NUMA
  Balancing (fate#315482)).
- Revert "mm: sched: numa: Delay PTE scanning until a task
  is scheduled on a new node" (Automatic NUMA Balancing
  (fate#315482)).
- sched/numa: Continue PTE scanning even if migrate rate limited
  (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Mitigate chance that same task always updates PTEs
  (Automatic NUMA Balancing (fate#315482)).
- mm: numa: Do not migrate or account for hinting faults on the
  zero page (Automatic NUMA Balancing (fate#315482)).
- mm: Only flush TLBs if a transhuge PMD is modified for NUMA
  pte scanning (Automatic NUMA Balancing (fate#315482)).
- mm: Do not flush TLB during protection change if !pte_present &&
  !migration_entry (Automatic NUMA Balancing (fate#315482)).
- sched/numa: Fix comments (Automatic NUMA Balancing
  (fate#315482)).
- mm: numa: Document automatic NUMA balancing sysctls (Automatic
  NUMA Balancing (fate#315482)).
- mm: numa: Serialise parallel get_user_page against THP migration
  (Automatic NUMA Balancing (fate#315482)).
- sched, idle: Fix the idle polling state logic (Automatic NUMA
  Balancing (fate#315482)).
- sched: Micro-optimize by dropping unnecessary task_rq() calls
  (Automatic NUMA Balancing (fate#315482)).
- sched/balancing: Periodically decay max cost of idle balance
  (Automatic NUMA Balancing (fate#315482)).
- sched/balancing: Consider max cost of idle balance per sched
  domain (Automatic NUMA Balancing (fate#315482)).
- sched: Reduce overestimating rq->avg_idle (Automatic NUMA
  Balancing (fate#315482)).
- sched/balancing: Prevent the reselection of a previous
  env.dst_cpu if some tasks are pinned (Automatic NUMA Balancing
  (fate#315482)).
- sched/fair: Fix the group_capacity computation (Automatic NUMA
  Balancing (fate#315482)).
- sched/fair: Rework and comment the group_capacity code
  (Automatic NUMA Balancing (fate#315482)).
- sched/fair: Fix group power_orig computation (Automatic NUMA
  Balancing (fate#315482)).
- sched/fair: Reduce local_group logic (Automatic NUMA Balancing
  (fate#315482)).
- sched/fair: Rewrite group_imb trigger (Automatic NUMA Balancing
  (fate#315482)).
- commit 7a9d64a
* Tue Nov 19 2013 jdelvare@suse.de
- Delete patches.drivers/gpio-ucb1400-can-be-built-as-a-module.patch:
  no config file has support for UCB1400 in this branch so this
  patch was a no-op.
- commit b056d1a
* Tue Nov 19 2013 trenn@suse.de
- intel_pstate: skip the driver if ACPI has power mgmt option
  (bnc#850824).
- intel_pstate: Add Baytrail support (bnc#850824).
- intel_pstate: Refactor driver to support CPUs with different
  MSR layouts (bnc#850824).
- commit d2b9cfe
* Tue Nov 19 2013 jbohac@suse.cz
- supported.conf: marked net/netfilter/xt_set as supported (bnc#851066)
  xt_set should have been enabled together with the ip_set modules in
  fate#313309
- commit c2e046e
* Tue Nov 19 2013 mgorman@suse.de
- Refresh patches for clean application by series2git
- commit 889227e
* Fri Nov 15 2013 jeffm@suse.com
- config: build uncommon HID drivers as modules
- commit 09660bb
* Fri Nov 15 2013 jeffm@suse.com
- config: sync HID=y on x86_64/debug config
- commit c2c667b
* Fri Nov 15 2013 bp@suse.de
- Update config files.
  Argh, this should be the third time and it is supposed to be a charm, as
  they say. We'll see.
- commit 1a9f08e
* Fri Nov 15 2013 bp@suse.de
- Update config files.
  For FATE#315508. Forgot xen.
- commit 82b2711
* Fri Nov 15 2013 bp@suse.de
- Update config files.
  For FATE#315508.
- commit 5e81265
* Fri Nov 15 2013 bp@suse.de
- ACPI, APEI, CPER: Fix status check during error printing (fate#315508).
- ACPI, CPER: Update cper info (fate#315508).
- bitops: Introduce a more generic BITMASK macro (fate#315508).
- ACPI, x86: Extended error log driver for x86 platform
  (fate#315508).
- DMI: Parse memory device (type 17) in SMBIOS (fate#315508).
- ACPI, APEI, CPER: Add UEFI 2.4 support for memory error
  (fate#315508).
- ACPI, APEI, CPER: Enhance memory reporting capability
  (fate#315508).
- ACPI, APEI, CPER: Cleanup CPER memory error output format
  (fate#315508).
- EDAC, GHES: Update ghes error record info (fate#315508).
- Move cper.c from drivers/acpi/apei to drivers/firmware/efi
  (fate#315508).
- dmi: Avoid unaligned memory access in save_mem_devices()
  (fate#315508).
- ACPI, x86: Fix extended error log driver to depend on
  CONFIG_X86_LOCAL_APIC (fate#315508).
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
  [ Boris: wiggle it in so that it applies again. ]
- commit c025550
* Wed Nov 13 2013 mkubecek@suse.cz
- xfrm: prevent ipcomp scratch buffer race condition (bnc#842239).
- commit 190a936
* Tue Nov 12 2013 jdelvare@suse.de
- armv6hl, armv7hl: Update config files.
  Set CONFIG_BATMAN_ADV_BLA=y as all other kernel configuration files
  have.
- commit e7c00d8
* Fri Nov  8 2013 mmarek@suse.cz
- Drop 32bit configs
  So long and thanks for all the 0xffffffffs.
- commit 82fa709
* Fri Nov  8 2013 jdelvare@suse.de
- Update config files:
  * CONFIG_BATMAN_ADV_NC=y, because other BATMAN_ADV options are all
  enabled so why not this one.
  * CONFIG_GPIO_SCH=m, CONFIG_GPIO_PCH=m, because we support all other
  features of these pieces of hardware.
  * CONFIG_INTEL_POWERCLAMP=m, because this small driver might be
  useful in specific cases, and there's no obvious reason not to
  include it.
- commit 2e48a7d
* Fri Nov  8 2013 mmarek@suse.cz
- Delete patches.suse/kconfig-automate-kernel-desktop
  There is no use for it if there are no desktop configs
- commit f770507
* Fri Nov  8 2013 mmarek@suse.cz
- Drop desktop configs, they are not used in the product
- commit dda81f9
* Thu Nov  7 2013 jbeulich@suse.com
- Update Xen patches to 3.12-final.
- commit ec28986
* Wed Nov  6 2013 duwe@suse.de
- fate#316581: CONFIG_IBM_BSR y -> m
- commit f5eba64
* Tue Nov  5 2013 jeffm@suse.com
- config: Enable CRYPTO_FIPS (FATE#315804).
  CONFIG_CRYPTO_MANAGER_DISABLE_TESTS=n as a prerequisite.
- commit 79836b5
* Mon Nov  4 2013 jslaby@suse.cz
- Delete patches.kernel.org/patch-3.11.1.
- commit ec24572
* Mon Nov  4 2013 jeffm@suse.com
- Update config files.
- commit f7c27a2
* Mon Nov  4 2013 jeffm@suse.com
- Update to 3.12-final.
- commit bd2bcf1
* Mon Nov  4 2013 jeffm@suse.com
- Refresh
  patches.suse/btrfs-add-ability-to-query-change-feature-bits-online-ioctl.
- commit a58c8c5
* Mon Nov  4 2013 jeffm@suse.com
- Refresh patches.suse/btrfs-add-tracing-for-failed-reservations.
- Refresh patches.suse/btrfs-publish-allocation-data-in-sysfs.
  - No code change: missing 'quilt add' caused a chunk to be
    in the wrong patch.
- commit 0346b5c
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add extra chmap for 2.1 outputs on ASUS laptops
  (bnc#846531).
- commit 5fe5110
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add a fixup for ASUS N76VZ (bnc#846529).
- commit c8ca4fb
* Tue Oct 29 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc7 and c/s 1240.
- commit 49141ff
* Mon Oct 28 2013 jeffm@suse.de
- Update to 3.12-rc7.
- commit c59f68d
* Tue Oct 22 2013 jeffm@suse.com
- nouveau: Fix race with fence signaling (bnc#844177).
- commit db1113e
* Tue Oct 22 2013 jeffm@suse.com
- btrfs: add ioctl to export size of global metadata reservation.
- btrfs: add tracing for failed reservations.
- btrfs: publish allocation data in sysfs.
- btrfs: publish device membership in sysfs.
- btrfs: publish fs label in sysfs.
- btrfs: publish per-super attributes in sysfs.
- btrfs: publish per-super features in sysfs.
- btrfs: publish supported featured in sysfs.
- btrfs: publish unknown feature bits in sysfs.
- kobject: export kobj_sysfs_ops.
- Refresh
  patches.suse/btrfs-add-ability-to-change-features-via-sysfs.
- Refresh
  patches.suse/btrfs-use-feature-attributes-to-print-names-in-errors.
- Delete
  patches.suse/btrfs-add-per-super-attribute-publishing-to-sysfs.
- Delete
  patches.suse/btrfs-add-publishing-of-unknown-features-in-sysfs.
- Delete patches.suse/btrfs-export-supported-featured-to-sysfs.
- Delete patches.suse/btrfs-publish-per-super-features-to-sysfs.
- Delete patches.suse/introduce-kobj_completion.
- commit 28f62b4
* Mon Oct 21 2013 jeffm@suse.com
- Update to 3.12-rc6.
- commit 7244867
* Wed Oct 16 2013 jbeulich@suse.com
- Update x86 Xen config files (RTC_DRV_EFI=y).
- commit ac42dba
* Wed Oct 16 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- Delete patches.xen/xen3-010-acpi_initrd_override_tables.patch.
- commit 8673f3f
* Tue Oct 15 2013 oneukum@suse.de
- sha256_ssse3: also test for BMI2 (bnc#842459).
- commit 243990f
* Mon Oct 14 2013 jeffm@suse.com
- btrfs: Fix creation of per-super sysfs directories when using multiple
  subvolumes (bnc#845774)
- commit adcee6c
* Mon Oct 14 2013 jeffm@suse.com
- Update to 3.12-rc5.
- commit 6c5465f
* Fri Oct 11 2013 jeffm@suse.com
- Update to 3.12-rc4.
- commit 8fdbb19
* Fri Oct 11 2013 tiwai@suse.de
- drm/i915: Undo the PIPEA quirk for i845 (bnc#845503).
- commit e401a74
* Tue Oct  8 2013 tiwai@suse.de
- ALSA: hda - Add fixup for ASUS N56VZ (bnc#841645).
- commit 9f1b1d6
* Mon Oct  7 2013 jack@suse.cz
- supported.conf: Update support info
- commit fe619b0
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Remove IOMMU v2
  This is only needed for HSA.
- commit 1d0217b
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Add a bunch of AMD-specific drivers to the list
  + sb_edac which people wanted since SLE11-SP2.
- commit 942c03a
* Fri Oct  4 2013 bpoirier@suse.de
- supported.conf: update for network related modules
  based on FATE#313655
  +		drivers/net/ethernet/intel/i40e/i40e
  vhost_net depends on vhost
  +		drivers/vhost/vhost
  nf_nat is now nf_nat_ipv4, _ipv6 was introduced in v3.7
  - net/ipv4/netfilter/nf_nat
  +		net/ipv4/netfilter/nf_nat_ipv4
  +		net/ipv6/netfilter/nf_nat_ipv6
  based on the rationale that we already package `ss` and support inet_diag:
  +		net/ipv4/udp_diag
  +		net/netlink/netlink_diag
  +		net/packet/af_packet_diag
  +		net/unix/unix_diag
- commit 07a54e6
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Add newly requested drivers
- commit 199c169
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: More updates from SLE11-SP3
- commit 45bc81a
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Check module support only if the -extra package is requested
- commit add86bf
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Remove unused options
- commit 3736315
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix creating the kernel-*-extra package
  CONFIG_ENTERPRISE_SUPPORT has been renamed to CONFIG_SUSE_KERNEL_SUPPORTED
- commit 9e5b6fe
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Copy some missing changes from SLE11-SP3
- commit fdeb1a7
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Remove the kernel/ prefix from module paths.
- commit 9649d9f
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Allow wildcards in the Module.supported file.
- commit a464383
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Fix matching of dashes and underscores in Module.supported (bnc#719090).
- commit cab1abc
* Thu Oct  3 2013 mmarek@suse.cz
- Enable CONFIG_DRM_QXL and mark qxl.ko as supported (fate#316469)
- commit acad9db
* Tue Oct  1 2013 jeffm@suse.com
- Update to 3.12-rc3.
- commit e5ef0d0
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_TMIO (Sharp Zaurus) on non-arm configs.
- commit 977b235
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_GEODE, as the individual GEODE options are already disabled
- commit d10fe5f
* Mon Sep 30 2013 mmarek@suse.cz
- Always include the git commit in KOTD builds
  This allows us not to set it explicitly in builds submitted to the
  official distribution (bnc#821612, bnc#824171).
- commit a80e5ef
* Mon Sep 30 2013 mmarek@suse.cz
- Do not build udlfb, to avoid conflict with udl (fate#316407)
- commit 678681d
* Mon Sep 30 2013 mmarek@suse.cz
- Disable fb drivers that have been blacklisted for a long time
  via /etc/modprobe.d/50-blacklist.conf.
- commit b34e737
* Mon Sep 30 2013 dsterba@suse.cz
- Btrfs: relocate csums properly with prealloc extents.
- commit 6cf855e
* Sat Sep 28 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
  actually assign the divide result to hv_lapic_frequency
- commit 9e0a852
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add obsolete KMPs from sle11-sp1
- commit 221133c
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make sure that all KMP obsoletes are
  versioned (bnc#821465).
- commit d802bf2
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide obsoleted KMPs (bnc#753353)
- commit f5449e6
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unversioned provides/obsoletes
  for packages that were only seen in openSUSE releases up to 11.0.
  (bnc#821465).
- commit 7e1f4b6
* Fri Sep 27 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
- commit ff1e29f
* Fri Sep 27 2013 ohering@suse.de
- X86: Hyper-V: Get the local APIC timer frequency from the
  hypervisor.
- commit ca351ea
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit 0b0a3fa
* Fri Sep 27 2013 jeffm@suse.com
- config: disable DGAP on s390
  It requires ioremap, which isn't available on s390. It's a staging
  driver anyway.
- commit cf0bc41
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors, rpm/mkspec: Add version information to obsolete
  flavors (bnc#821465).
- rpm/kernel-binary.spec.in: Move the xenpae obsolete to the
  old-flavors file.
- commit 25c1b0d
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors: Convert the old-packages.conf file to a flat
  list.
- rpm/mkspec: Adjust.
- rpm/old-packages.conf: Delete.
- commit 4037e16
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-packages.conf: Drop bogus obsoletes for "smp" (bnc#821465)
- commit 50c4c23
* Fri Sep 27 2013 jdelvare@suse.de
- config/*/debug: Enable FSCACHE_DEBUG and CACHEFILES_DEBUG.
- commit 528f287
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit 954d4c1
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit fc372c0
* Wed Sep 25 2013 agraf@suse.de
- ARM: Update config files: Use lpae for multiarch, exynos for LPAE exynos5
- commit 957e65c
* Wed Sep 25 2013 agraf@suse.de
- Clean up ARM patches:
- Refresh patches.arch/arm-arndale-dma.patch.
- Delete patches.arch/arm-exynos-nosparse.patch.
- Delete
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Delete
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
- Delete
  patches.arch/arm-xen-0006-xen-arm-disable-cpuidle-when-linux-is-running-as-dom.patch.
- Delete
  patches.arch/arm-xen-0007-arm-choose-debug-uncompress.h-include-when-uncompres.patch.
- Delete
  patches.arch/arm-xen-0008-xen-arm-enable-PV-control-for-ARM.patch.
- commit 1cdc83d
* Wed Sep 25 2013 agraf@suse.de
- config.conf:
- Update config files for ARM on 3.12.
- commit 2503bec
* Tue Sep 24 2013 trenn@suse.de
- Delete patches.arch/010-acpi_initrd_override_tables.patch.
  This old one alone broke acpi initrd override -> delete it.
- commit a75f081
* Tue Sep 24 2013 jeffm@suse.com
- lustre/lloop: don't change the logical size for the queue.
- commit 4a2006a
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc2.
- Eliminated 3 patches.
- commit d7d9943
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc1.
- Eliminated 42 patches.
- Xen is disabled.
- ARM is disabled.
- commit c58d853
* Fri Sep 20 2013 jslaby@suse.cz
- power_supply: Prevent suspend until power supply events are
  processed (bnc#841596).
- commit 50dfbd0
* Wed Sep 18 2013 duwe@suse.de
- Increase NR_CPUS on ppc64 to 2048 (fate#315438)
- commit ddaa978
* Tue Sep 17 2013 jslaby@suse.cz
- Update config files.
  Fix ZSWAP on vanillas.
- commit 5a7a093
* Tue Sep 17 2013 jeffm@suse.com
- btrfs: use feature attribute names to print better error
  messages.
- btrfs: add ability to change features via sysfs.
- btrfs: add publishing of unknown features in sysfs.
- btrfs: publish per-super features to sysfs.
- btrfs: add per-super attributes to sysfs.
- btrfs: export supported featured to sysfs.
- kobject: introduce kobj_completion.
- btrfs: add ioctls to query/change feature bits online.
- btrfs: use btrfs_commit_transaction when setting fslabel.
- commit 7e40f1e
* Tue Sep 17 2013 jeffm@suse.com
- config: Update missing ZSWAP configs.
- commit 85bd223
* Mon Sep 16 2013 dsterba@suse.cz
- Btrfs: optimize key searches in btrfs_search_slot.
- Btrfs: remove ourselves from the cluster list under lock.
- Btrfs: do not clear our orphan item runtime flag on eexist.
- Btrfs: fix printing of non NULL terminated string.
- Btrfs: fix memory leak of orphan block rsv.
- Btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP.
- Btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler.
- Btrfs: move btrfs_free_qgroup_config() out of spin_lock and
  fix comments.
- Btrfs: fix oops when writing dirty qgroups to disk.
- Btrfs: fix heavy delalloc related deadlock.
- Btrfs: fix the error handling wrt orphan items.
- Btrfs: don't allow a subvol to be deleted if it is the default
  subovl.
- Btrfs: skip subvol entries when checking if we've created a
  dir already.
- Btrfs: fix possible memory leak in find_parent_nodes().
- Btrfs: return ENOSPC when target space is full.
- Btrfs: don't ignore errors from btrfs_run_delayed_items.
- Btrfs: fix inode leak on kmalloc failure in tree-log.c.
- Btrfs: stop using GFP_ATOMIC when allocating rewind ebs.
- Btrfs: deal with enomem in the rewind path.
- Btrfs: check our parent dir when doing a compare send.
- Btrfs: handle errors when doing slow caching.
- Btrfs: add missing error handling to read_tree_block.
- Btrfs: add missing error check to find_parent_nodes.
- Btrfs: don't bug_on when we fail when cleaning up transactions.
- Btrfs: change how we queue blocks for backref checking.
- Btrfs: add missing mounting options in btrfs_show_options().
- Btrfs: use u64 for subvolid when parsing mount options.
- Btrfs: don't bother autodefragging if our root is going away.
- Btrfs: cleanup reloc roots properly on error.
- Btrfs: reset ret in record_one_backref.
- btrfs: fix get set label blocking against balance.
- Btrfs: set qgroup_ulist to be null after calling ulist_free().
- Btrfs: add missing error checks to add_data_references.
- Btrfs: Release uuid_mutex for shrink during device delete.
- commit ded2bc7
* Sat Sep 14 2013 jslaby@suse.cz
- Linux 3.11.1.
- commit 1383321
* Thu Sep 12 2013 jeffm@suse.com
- config: Enable CONFIG_ZSWAP (bnc#839064).
  It's built-in but a no-op without zswap.enabled=1 on the kernel
  command line.
- commit 1441e59
* Thu Sep 12 2013 jeffm@suse.com
- Update
  patches.fixes/reiserfs-locking-handle-nested-locks-properly.
- Update
  patches.fixes/reiserfs-locking-push-write-lock-out-of-xattr-code.
- Update
  patches.fixes/reiserfs-locking-release-lock-around-quota-operations.
- commit fd0a178
* Fri Sep  6 2013 rgoldwyn@suse.de
- Update config files to enable GFS DLM locking.
- commit 712cff0
* Thu Sep  5 2013 ohering@suse.de
- Drivers: hv: util: Fix a bug in util version negotiation code
  (bnc#838346).
- commit 938aca5
* Wed Sep  4 2013 jbeulich@suse.com
- Update Xen patches to final 3.11.
- commit e71a103
* Tue Sep  3 2013 jeffm@suse.com
- Update to 3.11-final.
- commit 7561c6f
* Tue Aug 27 2013 jeffm@suse.com
- rpm/kernel-docs.spec.in: Fix missing whitespace error in description
- commit 280c88e
* Tue Aug 27 2013 jeffm@suse.com
- Update to 3.11-rc7.
- commit 99e1318
* Wed Aug 21 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc6.
- commit 7ee85be
* Mon Aug 19 2013 jeffm@suse.com
- Update to 3.11-rc6.
- commit b474038
* Thu Aug 15 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc5.
- config.conf: Re-enable Xen configs
- Delete patches.xen/xen-sections.
- commit adcd98b
* Tue Aug 13 2013 guillaume.gardet@oliseo.fr
- config: update armv6 default config to multi-arch armv6
- commit 25b5917
* Mon Aug 12 2013 jeffm@suse.com
- Update to 3.11-rc5.
- commit c33c981
* Thu Aug  8 2013 guillaume.gardet@oliseo.fr
- arm: update default config for 3.11.0-rc4
- Add sound modules
- Add TI wifi modules
- commit 448a93c
* Thu Aug  8 2013 dmueller@suse.com
- config/arm: update and reenable ARM64 config
- commit 327e5fc
* Thu Aug  8 2013 dmueller@suse.com
- Reenable ARMv6/ARMv7 configs
- commit 461df98
* Wed Aug  7 2013 jeffm@suse.com
- config: disable RCU_USER_QS
  RCU_USER_QS is used for hacking on debugging the full dynticks model,
  which we've disabled.
- commit 910e01d
* Mon Aug  5 2013 jeffm@suse.com
- reiserfs: locking, release lock around quota operations
  (bnc#815320).
- reiserfs: locking, handle nested locks properly (bnc#815320).
- reiserfs: locking, push write lock out of xattr code
  (bnc#815320).
- commit 01695c8
* Mon Aug  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid hardcoded runtime dependency on
  module-init-tools.
- commit 2889cef
* Mon Aug  5 2013 jeffm@suse.com
- Update to 3.11-rc4.
- commit 38e9077
* Tue Jul 30 2013 jslaby@suse.cz
- Delete patches.drivers/elousb.patch.
- Delete patches.kernel.org/patch-3.10.1-2.
  They are both obsolete.
- commit e924b54
* Mon Jul 29 2013 jeffm@suse.com
- Update to 3.11-rc3.
- Eliminated 3 patches.
- commit c0a4742
* Thu Jul 25 2013 jeffm@suse.com
- btrfs: check index in extent_buffer_page.
- commit 15eacb9
* Thu Jul 25 2013 jdelvare@suse.de
- Hu, OK, RapidIO can't be fully modularized on PPC (yet.)
- commit 4c2611f
* Thu Jul 25 2013 jdelvare@suse.de
- Update config files: build RapidIO support as modules
- commit 1c6c425
* Thu Jul 25 2013 jeffm@suse.com
- rpm/kernel-binary.spec.in: Obsolete microcode_ctl
  The kernel can request CPU microcode itself now and microcode_ctl is
  no longer required.
- commit 43e5ff5
* Wed Jul 24 2013 jeffm@suse.com
- config: enable early CPU microcode loading.
- commit 0911270
* Wed Jul 24 2013 jeffm@suse.com
- btrfs: fall back to global reservation when removing subvolumes.
- commit 026dc43
* Wed Jul 24 2013 jslaby@suse.cz
- drm/i915: correctly restore fences with objects attached
  (bnc#830492).
- commit e9259e0
* Tue Jul 23 2013 jeffm@suse.com
- config: disable USB_CHIPIDEA
- commit 00cdcf9
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/dmraid45-api-updates.
- commit 8e1fa8b
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 27c899f
* Tue Jul 23 2013 jeffm@suse.com
- Update to 3.11-rc2.
- Eliminated 1 patch.
- commit f6f5941
* Mon Jul 22 2013 jslaby@suse.cz
- Refresh
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Refresh
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
  Update usptream status.
- commit 17cddd7
* Mon Jul 22 2013 jslaby@suse.cz
- Linux 3.10.2.
- Delete
  patches.arch/arm-xen-0003-ARM-let-the-ASID-allocator-handle-suspended-animatio.patch.
- Delete
  patches.arch/arm-xen-0004-ARM-prevent-risks-of-out-of-bound-access-in-ASID-all.patch.
- Delete
  patches.arch/arm-xen-0005-ARM-Cortex-A15-fix-erratum-798181-implementation.patch.
- commit 16a6c33
* Mon Jul 22 2013 jslaby@suse.cz
- drm/i915: Only clear write-domains after a successful wait-seqno
  (bnc#830492).
- drm/i915: Fix write-read race with multiple rings (bnc#830492).
- commit d76b800
* Fri Jul 19 2013 ohering@suse.de
- Drivers: hv: balloon: Do not post pressure status if interrupted
  (bnc#829539).
- Drivers: hv: balloon: Fix a bug in the hot-add code
  (bnc#829539).
- Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- commit 0cd5432
* Thu Jul 18 2013 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7 (bnc#804198).
- commit 123639e
* Tue Jul 16 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit abd0978
* Tue Jul 16 2013 jslaby@suse.cz
- drm/nouveau: use vmalloc for pgt allocation (bnc#802347).
- commit 114f846
* Tue Jul 16 2013 jeffm@suse.com
- Updated patch-mainline headers.
- commit ba04848
* Tue Jul 16 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 13 patches.
- Xen needs updating and is disabled.
- commit 8ffe6ba
* Mon Jul 15 2013 jeffm@suse.com
- config: revert NO_HZ_FULL=y to NO_HZ_IDLE=y (bnc#826946)
  NO_HZ_FULL mode was introduced in v3.10 but still has some
  problems to be worked out. Most notably are issues with
  CPU accounting and how it interacts with power states.
  We'll re-enable it when it's been proven to be stable.
- commit 80c46a2
* Mon Jul 15 2013 jbeulich@suse.com
- Refresh Xen patches (bnc#814211, bnc#826374).
- commit 56bb9c2
* Mon Jul 15 2013 jslaby@suse.cz
- Revert "cpufreq: Fix cpufreq regression after suspend/resume".
- commit 3bcd588
* Sun Jul 14 2013 jslaby@suse.cz
- Linux 3.10.1.
- commit 062e800
* Mon Jul  8 2013 mmarek@suse.cz
- Require 14GB of free space in the buildservice
- commit e7a8371
* Mon Jul  8 2013 jdelvare@suse.de
- patches.suse/ida-remove-warning-dump-stack.patch: Add upstream commit ID
- commit 4fa2dc2
* Sat Jul  6 2013 agraf@suse.de
- ARM: Enable xen for lpae target
- arm: introduce psci_smp_ops.
- ARM: Enable selection of SMP operations at boot time.
- ARM: let the ASID allocator handle suspended animation.
- ARM: prevent risks of out-of-bound access in ASID allocator.
- ARM: Cortex-A15: fix erratum 798181 implementation.
- xen/arm: disable cpuidle when linux is running as dom0.
- arm: choose debug/uncompress.h include when uncompress debug
  is disabled.
- xen/arm: enable PV control for ARM.
- Update config files.
- Refresh patches.xen/xen3-fixup-xen.
- commit 5c7a1e8
* Fri Jul  5 2013 agraf@suse.de
- MMC: Exynos: Add module alias for dw mmc.
- commit 182d5ca
* Wed Jul  3 2013 agraf@suse.de
- ARM: Enable Arndale board with LPAE config
- ARM: EXYNOS: Set 64-bit DMA mask for EXYNOS5250.
- usb: phy: Fix phy-samsung-usb when built as module.
- USB: ehci-s5p: Fix phy reset.
- ARM: Update config files: Make LPAE Exynos only until Multiarch comes
- commit c521db7
* Tue Jul  2 2013 jbeulich@suse.com
- Update Xen patches to 3.10-final.
- commit c5ad3f9
* Mon Jul  1 2013 jeffm@suse.com
- Update to 3.10-final.
- commit f080c74
* Sat Jun 29 2013 dmueller@suse.com
- arm: cubox, use timer initialization directly in the machine descriptor
  Now that the only field in struct sys_timer is .init, delete the struct,
  and replace the machine descriptor .timer field with the
  initialization function itself.
- commit d522780
* Sat Jun 29 2013 dmueller@suse.com
- arm: add and reenable armv6hl
  We've recently decided to remove the softfp
  targets from the openSUSE ARM portfolio. Add
  a armv6hl default kernel flavor and remove
  traces of armv5tel.
- commit 51c5edf
* Thu Jun 27 2013 mszeredi@suse.cz
- Refresh patches.suse/ovl02-vfs-export-do_splice_direct-to-modules.patch.
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 0e47df9
* Thu Jun 27 2013 mszeredi@suse.cz
- Revert "overlayfs: api: do_splice_direct has changed."
  This reverts commit 6cbfbd0e38cefde22aef0daf8be435a26aa840f7.
  This does not work as new_file->f_pos will not get updated so the file position
  will never advance.
- commit 93bc660
* Thu Jun 27 2013 jeffm@suse.com
- overlayfs: api: do_splice_direct has changed.
- commit 6cbfbd0
* Thu Jun 27 2013 guillaume.gardet@oliseo.fr
- arm: build lpae kernel as zImage
- commit d8f6242
* Wed Jun 26 2013 jeffm@suse.com
- Update to 3.10-rc7.
- Eliminated 1 patch.
- commit 888aa58
* Wed Jun 26 2013 dmueller@suse.com
- arm: fix cubox build by reverting removal of mach-types
- commit ff0165e
* Fri Jun 21 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc6 and c/s 1235.
- commit 20cc894
* Mon Jun 17 2013 jeffm@suse.com
- config: update vanilla configs for -rc6.
- commit ca41cec
* Mon Jun 17 2013 jeffm@suse.com
- Update to 3.10-rc6.
- commit dbed8c7
* Tue Jun 11 2013 dmueller@suse.com
- arm: topology: export cpu_topology
- commit e3dca27
* Mon Jun 10 2013 dmueller@suse.com
- Update and reenable armv7hl configs
- commit 2d22236
* Mon Jun 10 2013 jeffm@suse.com
- Update to 3.10-rc5.
- commit 1ce1338
* Mon Jun 10 2013 schwab@suse.de
- Update arm64/default and reenable it
- commit 4d0acbd
* Wed Jun  5 2013 jeffm@suse.com
- powerpc: add missing include to book3s_xics.c.
- commit fc06ef7
* Wed Jun  5 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc4.
- use vCPU time info registration to support vread_pvclock().
- Delete patches.xen/xen-netback-nr-irqs.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4967b19
* Wed Jun  5 2013 jbeulich@suse.com
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- commit 8f640b2
* Wed Jun  5 2013 mszeredi@suse.cz
- Refreshed overlayfs patches
- commit 0c856a9
* Mon Jun  3 2013 jeffm@suse.com
- Update to 3.10-rc4.
- Eliminated 4 patches.
- commit b3d0118
* Mon Jun  3 2013 jeffm@suse.com
- vtime: Use consistent clocks among nohz accounting.
- commit 731983f
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix spurious multiple-fill in reiserfs_readdir_dentry
  (bnc#822722).
- commit 244eade
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix problems with chowning setuid file w/ xattrs
  (bnc#790920).
- commit 951bebc
* Fri May 31 2013 jeffm@suse.com
- iscsi-target: fix heap buffer overflow on error (CVE-2013-2850,
  bnc#821560).
- commit 0799911
* Wed May 29 2013 jdelvare@suse.de
- Update config files: Modularize HID drivers
  Modularize all HID drivers which can easily be. Some couldn't due to
  weird Kconfig dependencies.
- commit 02ccd70
* Wed May 29 2013 jdelvare@suse.de
- Update config files: disable RADIO_SI476X
  RADIO_SI476X selects SND_SOC_SI476X, which depends on SND_SOC which we do
  not have.
- commit e75c4a8
* Tue May 28 2013 jeffm@suse.com
- Update to 3.10-rc3.
- 2 patches eliminated.
- commit b74ef38
* Wed May 22 2013 jslaby@suse.cz
- Refresh
  patches.fixes/misdn-add-support-for-group-membership-check.
  Let's use the new UID/GID API.
- commit 17413bd
* Wed May 22 2013 jeffm@suse.com
- Remove unused 3.9-stable patches.
- commit d28ac96
* Wed May 22 2013 jeffm@suse.com
- config: remove sparc64 configs
  The sparc64 configs have been completely unmaintained for two years.
  If someone wants to resurrect support, we'll accept patches.
- commit 17364b5
* Wed May 22 2013 jeffm@suse.com
- sparc64: revert accidental changes during the 3.9-rc2 update
- commit b120c5a
* Wed May 22 2013 schwab@suse.de
- Update group-source-files.pl to handle symlink to directory
  Also add arch/[^/]+/boot/dts/include/dt-bindings to the list of devel
  files and avoid listing README.SUSE twice.
- commit af248e4
* Tue May 21 2013 jeffm@suse.com
- Update to 3.10-rc2.
- commit e454a38
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.9.3.
- Update config files.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.36.
- commit 00c4cdd
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid duplicates in the certifiate list.
- commit 9d687ad
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do an exit 0 at the end of each scriptlet
  (bnc#809617).
- commit 7d1a48f
* Thu May 16 2013 mmarek@suse.cz
- rpm/config.sh: Use openSUSE:Factory:{ARM,PowerPC}
  The openSUSE:Factory/ports repository does not work.
- commit 756ee56
* Thu May 16 2013 jdelvare@suse.de
- Update config files: CONFIG_ZSMALLOC=y
  Zsmalloc support can no longer be built as a module, so change
  CONFIG_ZSMALLOC=m to =y in all configuration files to fix the build.
- commit 861551b
* Tue May 14 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 10 patches.
- Xen is disabled.
- ARM configs are disabled pending updates.
- In-kernel Bootsplash has been removed.
- EXT4 rich acls are re-enabled after having the index officially reserved.
- commit 0ead2af
* Tue May 14 2013 jdelvare@suse.de
- Change CONFIG_OF_MDIO from y to m as needed
  Fix build after my previous commit, OF_MDIO depends on PHYLIB so when
  turning the latter into a module I should have done so with the former
  as well.
- commit 7e7365d
* Tue May 14 2013 jdelvare@suse.de
- Update config files : build PHYLIB as a module.
  All but armv7hl/cubox: make PHYLIB modular. Most systems don't
  need it, and it registers a mdio_bus driver. As a side effect,
  we have to disable PHY emulation support, as it is only availble
  when PHYLIB is built-in. This driver is rather weird anyway and
  hopefully no system we want to support needs it, so it should be
  OK.
  - CONFIG_PHYLIB=m
  - CONFIG_FIXED_PHY=n
- commit 49e25f5
* Sun May 12 2013 jslaby@suse.cz
- Linux 3.9.2.
- commit 7bb3aa9
* Fri May 10 2013 jbeulich@suse.com
- Update Xen patches to 3.9.1 and c/s 1231.
- commit 0eb4d0d
* Wed May  8 2013 jslaby@suse.cz
- Linux 3.9.1.
- Delete patches.arch/arm-highbank-sata.patch.
- commit 733bf04
* Wed May  8 2013 jslaby@suse.cz
- Refresh patches.rpmify/ptp-pch-depends-on-x86.
  Update upstream status -- it was rejected.
- commit 4173967
* Wed May  8 2013 neilb@suse.de
- Delete
  patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch.
  Patchset went upstream around about
  commit f16b6e8d838b2e2bb4561201311c66ac02ad67df
  in a form that didn't need this patch.
- commit 226d6be
* Wed May  8 2013 neilb@suse.de
- Delete patches.fixes/nfs-connect-timeout.
  Problem fixed upstream by
  commit 3ed5e2a2c394df4e03a680842c2d07a8680f133b
  Author: Trond Myklebust <Trond.Myklebust@netapp.com>
  Date:   Mon Mar 4 17:29:33 2013 -0500
    SUNRPC: Report network/connection errors correctly for SOFTCONN rpc tasks
- commit afa0a59
* Tue May  7 2013 dmueller@suse.com
- Fix -devel package for armv7hl
  armv7hl kernel flavors in the non-multiplatform configuration
  (which is the default for our openSUSE 12.3 release), needs
  more header files from the machine specific directories to
  be included in kernel-devel.
- commit 882120e
* Tue May  7 2013 jslaby@suse.cz
- Delete patches.fixes/nfs-adaptive-readdir-plus.
  Superseded by d69ee9b85541a69a1092f5da675bd23256dc62af.
- commit f35dac6
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/fs-partitions-efi-c-corrupted-guid-partition-tables-can-cause-kernel-oops.
  Superseded by 3eb8e74ec72736b9b9d728bad30484ec89c91dde.
- commit 7838036
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch.
  Superseded by 0773a6cf673316440999752e23f8c3d4f85e48b9.
- commit 36f8ff4
* Mon May  6 2013 jeffm@suse.com
- config.conf: disable s390 support for openSUSE kernels
  There is no community project to build openSUSE on s390 so we don't need
  to waste resources building the kernel for it.
- commit 5e6ccae
* Mon May  6 2013 jdelvare@suse.de
- S390: Disable CONFIG_PHYLIB on 32-bit kernels
  libphy depends on irq code which is only available on 64-bit S390,
  so disable it on 32-bit kernels.
- commit dd79db9
* Sun May  5 2013 jdelvare@suse.de
- idr: Print a stack dump after ida_remove warning
  (http://lists.opensuse.org/opensuse-kernel/2013-04/msg00102.html).
- commit 4c487a5
* Sun May  5 2013 jdelvare@suse.de
- Update config files: enable CC_STACKPROTECTOR
  All other major Linux distributions are building their kernel
  with -fstack-protector, so do the same. See the discussion at:
  http://lists.opensuse.org/opensuse-kernel/2012-06/msg00088.html
  http://lists.opensuse.org/opensuse-kernel/2012-07/msg00000.html
  http://lists.opensuse.org/opensuse-kernel/2013-05/msg00013.html
  - CONFIG_CC_STACKPROTECTOR=y
- commit fc6f988
* Fri May  3 2013 mmarek@suse.cz
- rpm/config.sh: Drop the ARM repository in Kernel:HEAD
  Use the "ports" repository of openSUSE:Factory instead.
- commit 6fc0bd5
* Fri May  3 2013 mmarek@suse.cz
- rpm/mkspec: Stop generating the get_release_number.sh file
  It was only needed for the old KOTD.
- commit ee71b69
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Properly handle KOTD release numbers with
  .g<commit> suffix
- commit ccb20c3
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Drop the %%release_num macro
  We no longer put the -rcX tag into the release string.
- commit b88e78f
* Mon Apr 29 2013 jeffm@suse.de
- Update to 3.9-final.
- commit b4b0bc4
* Mon Apr 29 2013 agraf@suse.de
- Fix highbank sata proc_name.
- commit 1c2686d
* Fri Apr 26 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc8 and c/s 1229.
- commit dd1fbd8
* Wed Apr 24 2013 jeffm@suse.com
- config: disable SCSI_UFSHCD on s390/x
  It depends on PCI and can be re-enabled when PCI is enabled
  on s390/x. I expect eventually another module will be added to use
  a different bus technology so adding a depends PCI on SCSI_UFSHCD
  won't really help.
- commit 754e58e
* Wed Apr 24 2013 jeffm@suse.com
- patches.arch/ppc-prom-nodisplay.patch: Fix build failure.
  Commit 3bf3dbf8 (Update to 3.9-rc2) missed removing an
  instance of the now-gone RELOC macro, causing build failures.
- commit 674c7b1
* Wed Apr 24 2013 jeffm@suse.com
- Update to 3.9-rc8.
  Eliminated 2 patches.
- commit a86daba
* Wed Apr 24 2013 mmarek@suse.cz
- rpm/macros.kernel-source: Fix the -c option if -n is not given
- commit d704806
* Thu Apr 18 2013 mmarek@suse.cz
- Remove set -x and set +e statements in KMP scripts
- commit 5575c3c
* Fri Apr 12 2013 agraf@suse.de
- cpuidle: calxeda: disable power gating by default.
- commit 1f54900
* Thu Apr 11 2013 sleep_walker@suse.cz
- Enable FRAMEBUFFER_CONSOLE_ROTATION in our kernels
  More and more monitors have insane aspect ratio and can be better used when
  rotated. This may help when X.org is not running and for boot.
- commit f592a19
* Tue Apr  9 2013 jeffm@suse.com
- Refresh patches.xen/xen3-patch-3.9-rc5.
  Previous commit removed a move of a variable declaration to an ifdef section.
- commit 372aad5
* Tue Apr  9 2013 jeffm@suse.com
- Update to 3.9-rc6.
  Eliminated 1 patch.
- commit 68d380d
* Tue Apr  9 2013 agraf@suse.de
- Refresh patches.arch/arm-fec.patch.
- commit 41b3194
* Tue Apr  9 2013 agraf@suse.de
- ARM: cache-l2x0: fix masking of RTL revision numbering and
  set_debug init.
- commit bd5dc17
* Mon Apr  8 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix bootsplash breakage due to stable fix (bnc#813963)
- commit 5d7fc50
* Mon Apr  8 2013 agraf@suse.de
- ARM: Exynos: Update config files: Use DRM instead of FB
- commit 7e7c136
* Sun Apr  7 2013 agraf@suse.de
- ARM: DMA: PL330: Add check if device tree compatible.
- commit 73c94ff
* Sun Apr  7 2013 agraf@suse.de
- ARM: exynos: only use device tree when it exists.
- commit afed1f3
* Sun Apr  7 2013 agraf@suse.de
- rpm/package-descriptions: add lpae config for ARM
- ARM: Update config files (fix default, split out lpae).
- ARM: xen: Add missing define.
- config.conf: add lpae config for ARM
- rpm/package-descriptions: add lpae config for ARM
- commit 958fe54
* Fri Apr  5 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 0100be6
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: enable ViperBoard drivers
  All kernels which include core (MFD) support for the ViperBoard
  should also include the actual drivers for its functions:
  - CONFIG_I2C_VIPERBOARD=m
  - CONFIG_GPIO_VIPERBOARD=m
- commit 688764f
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: disable UCB1400 on all but ARM
  Currently UCB1400 is only used on ARM OMAP systems, and part of the
  code is dead code that can't even be modularized.
  - CONFIG_UCB1400_CORE=n
  - CONFIG_TOUCHSCREEN_UCB1400=n
  - CONFIG_GPIO_UCB1400=n
- commit c81a0de
* Wed Apr  3 2013 jeffm@suse.com
- Update to 3.9-rc5.
  EFI_VARS_PSTORE is disabled. It is potentially useful but can brick
  certain models of notebooks. Until it's been confirmed as safe, we
  should keep this disabled.
- commit 7fd0ea3
* Sat Mar 30 2013 jdelvare@suse.de
- Update config files: Build DSA drivers as modules
  DSA drivers can be built as modules since kernel v3.3, so do that:
  - CONFIG_NET_DSA=m
  - CONFIG_NET_DSA_MV88E6XXX=m
  - CONFIG_NET_DSA_MV88E6060=m
  - CONFIG_NET_DSA_MV88E6131=m
  - CONFIG_NET_DSA_MV88E6123_61_65=m
- commit ab03c84
* Fri Mar 29 2013 jdelvare@suse.de
- Update config file config/sparc64/default: drop X86-only GPIO drivers
- commit 931180e
* Fri Mar 29 2013 jeffm@suse.com
- config: enable GPIO_[PS]CH, disable INTEL_MID_DMAC
- commit 46bdeb9
* Fri Mar 29 2013 jdelvare@suse.de
- Update config files: CONFIG_I2C_COMPAT
  Disable compatibility with lm-sensors <= 3.1.1, version 3.1.2 was
  released 3 years ago.
- commit c1b3c2d
* Wed Mar 27 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Fix description and summary.
- commit a4cd5e1
* Tue Mar 26 2013 agraf@suse.de
- Delete config/armv7hl/u8500.
- commit b9fe3d9
* Mon Mar 25 2013 jeffm@suse.com
- Updated to 3.9-rc4.
  Eliminated 2 patches.
- commit 894fec7
* Thu Mar 21 2013 agraf@suse.de
- SMDKV310: Fix compilation.
- commit cf345eb
* Thu Mar 21 2013 agraf@suse.de
- ARM: FEC: Fix module compilation.
- ARM: kvm: fix IOMMU dependency check.
- omap3isp: fix miscompile.
- VT8500: fix miscompile in clk driver.
- config.conf: Remove imx51 and omap2plus, reenable arm
- Update config files.
- Delete config/armv7hl/imx51.
- Delete config/armv7hl/omap2plus.
- commit 7d60e2d
* Mon Mar 18 2013 jeffm@suse.com
- Update to 3.9-rc3.
- 2 patches were eliminated
  CONFIG_EXPERIMENTAL was eliminated, so I've updated the Xen patches for
  that. DMRAID45 and Rich ACLs also needed updating.
- commit 228c5dd
* Mon Mar 18 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix sed command with multiple certificates
- commit 59405a2
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install the used certificates below
  /etc/uefi/certs (fate#314507).
- commit 19b4300
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Make the template work with multiple
  certificates.
- commit 3bf5898
* Thu Mar 14 2013 jeffm@suse.com
- Updated to 3.9-rc2.
- Eliminated 52 patches.
- Xen is disabled.
- ARM configs need updating and are disabled.
- commit 3bf3dbf
* Thu Mar 14 2013 jeffm@suse.com
- Updated Patch-mainline headers for HyperV patches.
- commit 2e0d7a5
* Thu Mar 14 2013 jeffm@suse.com
- supported-flag: clean up patches and merge into one
  The config option is renamed to CONFIG_SUSE_KERNEL_SUPPORTED and
  the text has been updated to reflect that SUSE is no longer a
  unit of Novell.
- commit 7761647
* Thu Mar 14 2013 tiwai@suse.de
- drm/i915: bounds check execbuffer relocation count
  (bnc#808829,CVE-2013-0913).
- commit 72202f0
* Wed Mar 13 2013 jeffm@suse.com
- config: disabled CONFIG_SPI and CONFIG_IIO on non-ARM architectures
  These devices are found almost entirely on embedded platforms and
  end up adding hundreds of drivers for hardware that most users won't
  have. On systems using them, they are more likely to be embedded
  systems that should probably have a specialized kernel anyway.
- commit 33d736f
* Wed Mar 13 2013 jeffm@suse.com
- Updated patch-mainline for patches.rpmify/apm-honor-config_apm_cpu_idle-n
- commit 1008856
* Tue Mar 12 2013 ohering@suse.de
- Drivers: hv: balloon: Do not request completion notification
  (fate#314663).
- commit 6b249cb
* Tue Mar 12 2013 jslaby@suse.cz
- e1000e: fix runtime power management transitions (bnc#806966).
- e1000e: fix pci-device enable-counter balance (bnc#806966).
- e1000e: fix accessing to suspended device (bnc#806966).
- commit 48a333b
* Mon Mar 11 2013 rw@suse.de
- supported.conf: add drivers/s390/block/scm_block
  (fate#314095, bnc#807237)
- commit 09836cb
* Sun Mar 10 2013 mmarek@suse.cz
- KMP: Add -c <cert> option to the %%kernel_module_package macro
  This produces an -ueficert subpackage that imports the certificate into
  the MokList when installed (fate#314511)
- commit d8f177c
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: Add the -kmp suffix inside the subpackage definition
- commit 7c6395d
* Tue Mar  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require new mkinitrd in kernel-vanilla
- commit 26431d8
* Tue Mar  5 2013 jbeulich@suse.com
- Update Xen patches to 3.8.2 and c/s 1226.
- commit eee1405
* Tue Mar  5 2013 jdelvare@suse.de
- gpio-ich: Fix ichx_gpio_check_available() return what callers expect.
  Conflicts:
  series.conf
- commit 051149b
* Mon Mar  4 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash-mgadrmfb-workaround.
  Add the same w/a for ast and cirrus KMS, too (bnc#806990).
- commit 0422575
* Sun Mar  3 2013 jslaby@suse.cz
- Linux 3.8.2 (bnc#802153).
- Delete patches.arch/009-acpi_initrd_override_tables.patch.
- Delete
  patches.fixes/quota-autoload-the-quota_v2-module-for-qfmt_vfs_v1-quota-format.
- commit 3611cf6
* Fri Mar  1 2013 tiwai@suse.de
- Fix broken VT1 output with mgadrmfb (bnc#806990).
- commit 0934989
* Fri Mar  1 2013 jslaby@suse.cz
- PCI/PM: Clear state_saved during suspend (bnc#806966).
- commit cdd289b
* Thu Feb 28 2013 agraf@suse.de
- Add AArch64 support
- commit 09220ef
* Thu Feb 28 2013 jslaby@suse.cz
- Update config files.
- commit 9ad7236
* Thu Feb 28 2013 jslaby@suse.cz
- Linux 3.8.1.
- Refresh patches.xen/xen3-patch-2.6.31.
- Delete
  patches.suse/suse-hv-register-clocksource-only-if-its-adverti.patch.
- commit 0c01cac
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy kernel signing changes from 12.3 to the
  packaging branch
- commit 59d2acf
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: 'bc' is required since v3.9-rc1
- commit 4a9a926
* Thu Feb 28 2013 mmarek@suse.cz
- Copy packaging changes from master to the packaging branch
- commit dd227e2
* Wed Feb 27 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit 4687d79
* Tue Feb 26 2013 agraf@suse.de
- ARM: Update config files: Drop mmap min addr to at most 32k
- commit db497a6
* Tue Feb 26 2013 agraf@suse.de
- ARM: default: Update config file: Compile RTC drivers =y
- commit dfccf37
* Tue Feb 26 2013 aj@suse.de
- Mention Linux 3.x as well
- commit 3d86a6c
* Mon Feb 25 2013 jslaby@suse.cz
- TTY: do not update atime/mtime on read/write (bnc#797175
  CVE-2013-0160).
- commit 821f03c
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: balloon: Execute hot-add code in a separate context
  (fate#314663).
- Drivers: hv: balloon: Execute balloon inflation in a separate
  context (fate#314663).
- commit 2c746be
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: vmbus: Handle channel rescind message correctly
  (fate#314665).
- commit bd98cf4
* Thu Feb 21 2013 jbeulich@suse.com
- update Xen patches to 3.8 final and c/s 1224
- add symbols to hypercall stubs
- commit 88b4228
* Wed Feb 20 2013 jslaby@suse.cz
- Delete patches.drivers/x86_acpi_cpufreq_autoload.patch.
  Substituted by efa17194581bdfca0986dabc178908bd7c21ba00 upstream.
- commit a060c45
* Wed Feb 20 2013 trenn@suse.de
- Disable efi pstore by default (bnc#804482).
- commit 5986b31
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_BGRT on ia64
  bgrt_image is only defined on x86.
- commit e252f7f
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_INITRD_TABLE_OVERRIDE on ia64
  It requires max_low_pfn_mapped, which is x86 only.
- commit 9901a64
* Wed Feb 20 2013 jeffm@suse.com
- Update to 3.8-final.
- commit c9c649c
* Tue Feb 19 2013 jslaby@suse.cz
- Revert "USB: EHCI: remove ASS/PSS polling timeout" (bnc#804367).
- commit 83cb8d1
* Sun Feb 17 2013 ohering@suse.de
- video: Add Hyper-V Synthetic Video Frame Buffer Driver
- Update config files.
- commit f3ee42f
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 31ecddc
* Mon Feb 11 2013 jeffm@suse.de
- Update to 3.8-rc7.
  Eliminated 1 patch.
- commit 82fec2f
* Wed Feb  6 2013 jbeulich@suse.com
- Refresh.
- commit 1001e0b
* Wed Feb  6 2013 jbeulich@suse.com
- xen-pciback: rate limit error messages from
  xen_pcibk_enable_msi{,x}() (CVE-2013-0231 XSA-43 bnc#801178).
- Update Xen patches to 3.8-rc6 and c/s 1222.
- commit e6b44d3
* Wed Feb  6 2013 ohering@suse.de
- Drivers: hv: Bind all vmbus interrupts to the boot CPU
  (fate#314665).
- Drivers: hv: vmbus: Use the new infrastructure for delivering
  VMBUS interrupts (fate#314665).
- Delete patches.suse/suse-hv-fate314665-force-win2008.patch.
- commit 444d3d1
* Tue Feb  5 2013 ohering@suse.de
- X86: Handle Hyper-V vmbus interrupts as special hypervisor
  interrupts (fate#314665).
- hv: deliver vmbus interrupts to all vcpus
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-2.6.27.
- commit 3a682f8
* Tue Feb  5 2013 ohering@suse.de
- X86: Add a check to catch Xen emulation of Hyper-V
  (fate#314665).
- commit 3f41db6
* Tue Feb  5 2013 jeffm@suse.com
- quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit bdeb401
* Sun Feb  3 2013 jeffm@suse.com
- Update to 3.8-rc6.
- commit afa3941
* Thu Jan 31 2013 tiwai@suse.de
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
  Conflicts:
  series.conf
- commit 86d0404
* Wed Jan 30 2013 jeffm@suse.com
- ptp: PTP_1588_CLOCK_PCH depends on x86.
- commit 99fbe25
* Wed Jan 30 2013 ohering@suse.de
- scsi: storvsc: avoid usage of WRITE_SAME.
- Drivers: scsi: storvsc: Initialize the sglist.
- Drivers: hv: Execute shutdown in a thread context.
- commit 1b6d4ef
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on s390/x
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else. Not sure why s390 got skipped in the previous commit.
- commit f0b494a
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on non-ARM arches
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else.
- commit 2bf6fb1
* Wed Jan 30 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc5 and c/s 1218.
- commit 36b617a
* Wed Jan 30 2013 jbeulich@suse.com
- Comment out patches.drivers/x86_acpi_cpufreq_autoload.patch as
  conflicting with 3.8.-rc5. Refresh patches.xen/xen3-auto-common.diff.
- commit 737e677
* Wed Jan 30 2013 jeffm@suse.com
- Update to 3.8-rc5.
  Eliminated 4 patches.
- commit e8b3b53
* Tue Jan 29 2013 jeffm@suse.com
- sysctl: Fixed vm.dirty_ratio sysctl name for desktop flavors
- commit 8e77fa9
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/config.sh: Update $IBS_PROJECT_ARM
- commit 3e873c5
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 3c7bac7
* Thu Jan 24 2013 jeffm@suse.com
- Updated to 3.8-rc2.
  Eliminated 1 patch.
- commit e466109
* Sun Jan 20 2013 agraf@suse.de
- ARM: fix imx usb driver build issue.
- commit 4f2d1a3
* Sun Jan 20 2013 agraf@suse.de
- Delete config/armv7hl/highbank (included in default now)
- commit c0e90d8
* Sun Jan 20 2013 agraf@suse.de
- ARM: Default: Update config file (enable multiarch)
- commit 8a5d039
* Sat Jan 19 2013 agraf@suse.de
- Delete config/armv7hl/tegra
- commit 77424cc
* Sat Jan 19 2013 agraf@suse.de
- ARM: IMX51: Update config file (enable drm)
- commit 8e98c0c
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file (set drm+video =y)
- commit 7904ca2
* Sat Jan 19 2013 agraf@suse.de
- staging/omapdrm: garbage collect OMAP_DSS_DISPLAY_SUSPENDED.
- OMAP: Fix missing usb.h include.
- OMAP: Fix missing cm3xxx.h include.
- commit c3f4aa6
* Sat Jan 19 2013 agraf@suse.de
- ARM: use zImage for "default" flavor
- commit 0d71552
* Tue Jan 15 2013 dmueller@suse.com
- Fix build of omap2plus kernel
- commit 48790e9
* Tue Jan 15 2013 dmueller@suse.com
- reenable armv7hl configs
- commit a996303
* Tue Jan 15 2013 ohering@suse.de
- hyperv: force vmbus interrupts to cpu 0.
  (instead of forcing ws2008 during vmbus negotiation.)
- commit 5a7c533
* Tue Jan 15 2013 ohering@suse.de
- x86: Hyper-V: register clocksource only if its advertised
  (bnc#792500).
- commit adcc013
* Tue Jan 15 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc3.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4de2e49
* Thu Jan 10 2013 jeffm@suse.com
- Update to 3.8-rc3.
- commit 7ce28dd
* Thu Jan 10 2013 dmueller@suse.com
- config: update armv5tel config for 3.8-rc2
- commit df5a66e
* Tue Jan  8 2013 jeffm@suse.com
- supported.conf: Mark jfs.ko unsupported (FATE#314422).
- commit 4ff6270
* Mon Jan  7 2013 ohering@suse.de
- force ws2008 during vmbus negotiation.
- commit f68af45
* Thu Jan  3 2013 jeffm@suse.com
- staging/sb105x: remove asm/segment.h dependency.
- commit 473afce
* Thu Jan  3 2013 jeffm@suse.com
- config: Update vanilla configs.
- commit 0d2a457
* Thu Jan  3 2013 jeffm@suse.com
- Updated to 3.8-rc2.
- commit 79d206a
* Thu Dec 27 2012 jslaby@suse.cz
- drm/i915: TLB invalidation with MI_FLUSH_DW requires a post-sync
  op v3 (bnc#795963).
- commit db55aa9
* Tue Dec 25 2012 jeffm@suse.com
- Updated to 3.8-rc1.
- Eliminated 13 patches.
- Xen is disabled.
- ARM configs need updating.
- ext4 richacls are disabled until the upstream index can be reserved.
- commit a952042
* Tue Dec 18 2012 jbeulich@suse.com
- Update Xen patches to 3.7.1 and c/s 1213.
- commit 756a7d4
* Mon Dec 17 2012 jslaby@suse.cz
- Linux 3.7.1.
- Delete patches.rpmify/ezusb-add-dependency-to-usb.
- commit 7c5f8a6
* Wed Dec 12 2012 jeffm@suse.com
- ezusb: add dependency to USB.
  This prevents build failures by making it depend on the value of CONFIG_USB.
  Commit 36e0f0bd did this for architectures other than ARM manually.
- commit b89db5d
* Tue Dec 11 2012 ohering@suse.de
- Drivers: hv: balloon: Fix a memory leak.
- commit 26cdad5
* Tue Dec 11 2012 jeffm@suse.com
- Update to 3.7-final.
- commit 1771a73
* Tue Dec 11 2012 ohering@suse.de
- Update patch headers for fate314663 and fate314665 changes
- commit 44044f1
* Tue Dec 11 2012 jack@suse.cz
- Disable ext3 driver in all kernels and use ext4 driver instead. Eventually
  ext3 will be removed upstream so let's do the transition.
- commit dadc8ea
* Fri Dec  7 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (armv7) config: Enable TWL* USB drivers
- commit 28c09f5
* Fri Dec  7 2012 jbeulich@suse.com
- rpm/kernel-binary.spec.in: Conditionalize the use of vmlinuz instead
  of bzImage for Xen flavors.
- commit 713a73c
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen config files (enable XEN_BZIMAGE and EFI_STUB).
- commit d1ec1be
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen patches to 3.7-rc7 and c/s 1211.
- allow non-pv-ops kernel to be built as bzImage.
- commit 2a7feb8
* Thu Dec  6 2012 ohering@suse.de
- fate#314663 hyper-v memory ballooning support
- mm: Export a function to get vm committed memory.
- Drivers: hv: Add Hyper-V balloon driver.
- Drivers: hv: balloon: Fix a bug in the definition of struct
  dm_info_msg.
- Update config files.
  fate#314665 hyper-v: Update the Vmbus protocol
- Drivers: hv: Implement routines for read side signaling
  optimization.
- Drivers: hv: Add state to manage batched reading.
- Drivers: hv: Turn off batched reading for util drivers.
- Drivers: hv: Optimize signaling in the read path.
- Drivers: hv: Optimize the signaling on the write path.
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask().
- Drivers: hv: Support handling multiple VMBUS versions.
- Drivers: hv: Update the ring buffer structure to match win8
  functionality.
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for
  win7 and beyond.
- Drivers: hv: Save and export negotiated vmbus version.
- Drivers: hv: Change the signature for hv_signal_event().
- Drivers: hv: Change the signature of vmbus_set_event().
- Drivers: hv: Move vmbus version definitions to hyperv.h.
- Drivers: hv: Manage signaling state on a per-connection basis.
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and
  beyond.
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID.
- Drivers: hv: Add state to manage incoming channel interrupt
  load.
- Drivers: hv: Modify the interrupt handling code to support
  win8 and beyond.
- Drivers: hv: Add code to distribute channel interrupt load.
- Drivers: hv: Get rid of the unused global signaling state.
- Drivers: hv: Get rid of unnecessary request for offers.
- Drivers: hv: Manage event tasklets on per-cpu basis.
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus.
- Drivers: hv: Add a check to deal with spurious interrupts.
- Drivers: hv: Enable protocol negotiation with win8 hosts.
- Drivers: hv: Implement flow management on the send side.
- Drivers: hv: Capture the host build information.
- Drivers: hv: Cleanup and consolidate reporting of build/version
  info.
- commit 4fccd03
* Wed Dec  5 2012 jeffm@suse.com
- Update to 3.7-rc8.
- Delete patches.rpmify/net-fix-build-failure-in-xilinx.
- commit 76b3d92
* Tue Dec  4 2012 ohering@suse.de
- add splash=black option to bootsplash code,
  to keep a black background, useful for remote access to VMs
  (bnc#773487)
- commit c060ae1
* Fri Nov 23 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not remove fillup from the buildsystem
  (bnc#781327)
- commit 841d864
* Tue Nov 20 2012 jeffm@suse.com
- net: fix build failure in xilinx.
- commit 28be621
* Tue Nov 20 2012 sjayaraman@suse.com
- Update config files. Enable CONFIG_SMB2 to 'y'.
- commit 25bdfaf
* Mon Nov 19 2012 jeffm@suse.com
- Update to 3.7-rc6.
- commit daac70a
* Fri Nov 16 2012 mmarek@suse.cz
- rpm/config.sh: Set projects for ARM
- commit 55bac79
* Thu Nov 15 2012 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (fix FPU handling related
  crash in context switch code).
- commit bb1d12d
* Wed Nov 14 2012 jbeulich@novell.com
- Update to 3.7-rc5.
- Update Xen patches additionally to c/s 1204:
- commit d5de9cf
* Tue Nov  6 2012 jeffm@suse.com
- config: sync x86_64 configs for NR_UARTS
  This commit sets both CONFIG_SERIAL_8250_RUNTIME_UARTS and
  CONFIG_SERIAL_8250_NR_UARTS to 32.
- commit ddf88e6
* Tue Nov  6 2012 jeffm@suse.com
- Delete patches.arch/s390-remove-kvm-para.patch.
- commit f759e1e
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64 configs for LIB80211, NET_SDA_MV*
  This commit changes the following options to be modular:
  LIB80211
  NET_DSA_MV88E6XXX
  NET_DSA_MV88E6060
- commit caa5a52
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64/debug with ppc64/default
  The debug config should be identical to default with the exception of
  the debug options. This patch brings ppc64/debug in line with ppc64/default
  with the exception of a few things that are modular in debug that should
  also be modular in default.
- commit b981fcd
* Tue Nov  6 2012 jeffm@suse.com
- config: sync kvm options between ppc64 flavors.
- commit 8a389d5
* Tue Nov  6 2012 jeffm@suse.com
- config: disable HW_RANDOM_AMD on ppc64
  This chip is only on AMD hardware and an old ppc64 eval board. We can skip
  it on ppc64.
- commit 03001a4
* Tue Nov  6 2012 jeffm@suse.com
- config: Eliminate unused ppc/ppc64 configs.
  The history of the ppc/ppc64 configs is a convoluted one that started
  before the kernel source could support multiple machine types with a
  single image and before there was a usable 64-bit userspace.
  In the subsequent years, the powerpc code has been unified and we've
  released a 64-bit powerpc userspace. The "default" and "ppc64" configs
  on ppc64 are essentially identical and just waste space. The "ppc64"
  config on 32-bit ppc address a long since unnecessary corner case. Users
  who still want a 32-bit userspace with a 64-bit kernel can install and
  update it themselves using the 64-bit repository like i386/x86_64 users
  can do.
  This commit can be summarized thusly:
  rm config/ppc/ppc64
  rm config/ppc/ps3 (already unused)
  mv config/ppc64/ppc64 config/ppc64/default
- commit a9cc3d5
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Add kernel-versatile description
- commit 5424cf2
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Enable armv5 in arch-symbols
- commit 401de81
* Mon Nov  5 2012 jeffm@suse.com
- config: sync vanilla flavor with default flavor for each platform
  The vanilla configs have drifted away from the default configuration
  for each platform. This patch brings them back in sync.
- commit 8d4661f
* Mon Nov  5 2012 jeffm@suse.com
- config: -ec2 still had CONFIG_ENTERPRISE_SUPPORT enabled.
- commit 9907c37
* Mon Nov  5 2012 jeffm@suse.com
- Updated to 3.7-rc4.
  Eliminated 1 patch.
- commit 5168053
* Mon Nov  5 2012 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (make "unmodified drivers" build again).
- commit 5feff7e
* Fri Nov  2 2012 jbeulich@novell.com
- Update Xen patches to 3.7-rc3 and c/s 1202.
- extend base interfaces to support multi-page rings for
  frontend/backend communication.
- blkback: allow using multiple page frontend communication ring.
- blkfront: allow using multiple page backend communication ring.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Fix build when disabled.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- Delete patches.xen/xen3-acpi_override_2_2.patch.
- commit f042386
* Wed Oct 31 2012 guillaume.gardet@oliseo.fr
- Add support to armv5 versatile kernel
- commit 99d34f3
* Wed Oct 31 2012 jeffm@suse.com
- Update to 3.7-rc3.
- commit 48e5027
* Tue Oct 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require coreutils in kernel-*-devel (bnc#783615)
- commit 2520563
* Tue Oct 30 2012 agraf@suse.de
- ARM: Update config files: Fix vexpress (default) config
- commit be072b4
* Thu Oct 25 2012 hare@suse.de
- Fixup kvm for s390.
- commit 503388b
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable 8bit sd mode to support wifi
- commit 336ead7
* Mon Oct 22 2012 agraf@suse.de
- Revert "disable non-compiling irrelevant I2C module"
- commit d5a21c5
* Mon Oct 22 2012 agraf@suse.de
- thermal: exynos: Fix wrong name of MODULE_DEVICE_TABLE.
- commit 8e108ab
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 565b450
* Mon Oct 22 2012 agraf@suse.de
- Refresh patches.arch/arm-exynos-nosparse.patch.
- commit 55fbf60
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 118f2f9
* Mon Oct 22 2012 agraf@suse.de
- ARM: Exynos: Fix MMC driver
- ARM: Exynos: Update configs
- commit 37a1704
* Mon Oct 22 2012 jeffm@suse.com
- config: change CONFIG_USB_EZUSB_FX2 to module
- commit 36e0f0b
* Mon Oct 22 2012 jeffm@suse.com
- Actually use kthread_run in crasher.ko.
  The previous commit was incomplete.
- commit b8b35ae
* Mon Oct 22 2012 jeffm@suse.com
- crasher: use kthread_run() instead of kernel_thread().
  Linux 3.7-rc2 no longer exports kernel_thread on all architectures.
- commit f17d925
* Mon Oct 22 2012 jeffm@suse.com
- Updated to 3.7-rc2.
- commit e00a663
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable gfx and highmem
- commit e8b3bd9
* Sun Oct 21 2012 jslaby@suse.cz
- Linux 3.6.3.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-3.2.
- Refresh patches.xen/xen3-patch-3.6.
- Delete patches.fixes/hv-storvsc-reset-wait.patch.
- Delete
  patches.rpmify/x86-kbuild-archscripts-depends-on-scripts_basic.
- commit cfee26b
* Thu Oct 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use a macro instead of /etc/IGNORE-KABI-BADNESS
- commit 19e7e54
* Thu Oct 18 2012 agraf@suse.de
- ARM: Update config files: Fix exynos uart
- commit 1b4b5c5
* Thu Oct 18 2012 trenn@suse.de
- Cleanup ACPI table override patches with latest x86-tip commits
  and proper git-xy: meta tags:
- lib: Add early cpio decoder.
- x86, acpi: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Implement physical address table override.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Fix build when disabled.
- X86 ACPI: Use #ifdef not #if for CONFIG_X86 check.
- ACPI: Overriding ACPI tables via initrd only works with
  an initrd.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- Delete patches.arch/acpi_fix_custom_method_acc.patch.
- Delete patches.arch/acpi_override_2_2.patch.
- Delete patches.arch/acpi_override_documentation.
- Delete patches.arch/acpi_override_introduce_taint_func.patch.
- Delete patches.arch/acpi_physical_override.patch.
- Delete patches.arch/lib_earlycpio.patch.
- Delete patches.arch/x86_introduce_reserve_mem_area.patch.
- commit c45da8f
* Wed Oct 17 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Also check for /etc/IGNORE-KABI-BADNESS file
  This allows to control the kabi checker from outside of the package.
- commit 0a0900c
* Wed Oct 17 2012 jeffm@suse.com
- Update to 3.7-rc1.
- Eliminated 38 patches.
- Xen is disabled.
- ARM configs need updating.
- Module signing is disabled until the build infrastructure can support it.
- commit fce087a
* Sat Oct 13 2012 jslaby@suse.cz
- x86/kbuild: archscripts depends on scripts_basic.
- commit 007718d
* Fri Oct 12 2012 jslaby@suse.cz
- Linux 3.6.2.
- commit 798d597
* Thu Oct 11 2012 guillaume.gardet@oliseo.fr
- ARM (omap2plus) : re-enable OMAP DRM module
- commit 379798d
* Wed Oct 10 2012 jslaby@suse.cz
- Delete
  patches.suse/msft-hv-0394-tools-hv-Fix-file-handle-leak.patch.
- Delete
  patches.suse/msft-hv-0395-tools-hv-Fix-exit-error-code.patch.
- Delete
  patches.suse/msft-hv-0396-tools-hv-Check-for-read-write-errors.patch.
  These are in 3.6.1.
- commit 2a321c4
* Mon Oct  8 2012 dmueller@suse.com
- Remove noncompiling modules
- commit b7cdd5a
* Mon Oct  8 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable serial console
- commit a8d41ec
* Sun Oct  7 2012 jslaby@suse.cz
- Linux 3.6.1.
- commit 1f7626a
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: enable Conflicts for
  apparmor, udev and lvm2 also for vanilla kernel
- commit a24206f
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: add Conflicht: hyper-v < 4
  to make sure the daemon is in sync with the kernel
  (bnc#770763 , fate#314441)
- commit 86f9ba3
* Thu Oct  4 2012 jbeulich@novell.com
- Update Xen patches to 3.6-final and c/s 1197.
- Update Xen config files.
- commit 338be2c
* Thu Oct  4 2012 ohering@suse.de
- Hyper-V KVP IP injection (fate#31441)
- hyperv: Add comments for the extended buffer after RNDIS message.
- Drivers: hv: Cleanup the guest ID computation.
- Drivers: hv: vmbus: Use the standard format string to format
  GUIDs.
- Drivers: hv: Add KVP definitions for IP address injection.
- Drivers: hv: kvp: Cleanup error handling in KVP.
- Drivers: hv: Explicitly size elements of protocol structures.
- Drivers: hv: kvp: Support the new IP injection messages.
- Tools: hv: Prepare to expand kvp_get_ip_address() functionality.
- Tools: hv: Further refactor kvp_get_ip_address().
- Tools: hv: Gather address family information.
- Tools: hv: Gather subnet information.
- Tools: hv: Represent the ipv6 mask using CIDR notation.
- Tools: hv: Gather ipv[4,6] gateway information.
- hv: fail the probing immediately when we are not in hyperv
  platform.
- hv: vmbus_drv: detect hyperv through x86_hyper.
- Tools: hv: Get rid of some unused variables.
- Tools: hv: Correctly type string variables.
- Tools: hv: Add an example script to retrieve DNS entries.
- Tools: hv: Gather DNS information.
- Drivers: hv: kvp: Copy the address family information.
- Tools: hv: Add an example script to retrieve dhcp state.
- Tools: hv: Gather DHCP information.
- Tools: hv: Add an example script to configure an interface.
- Tools: hv: Implement the KVP verb - KVP_OP_SET_IP_INFO.
- Tools: hv: Rename the function kvp_get_ip_address().
- Tools: hv: Implement the KVP verb - KVP_OP_GET_IP_INFO.
- tools/hv: Fix file handle leak.
- tools/hv: Fix exit() error code.
- tools/hv: Check for read/write errors.
- tools/hv: Parse /etc/os-release.
- hyperv: Fix the max_xfer_size in RNDIS initialization.
- hyperv: Fix the missing return value in
  rndis_filter_set_packet_filter().
- hyperv: Fix page buffer handling in rndis_filter_send_request().
- hyperv: Remove extra allocated space for recv_pkt_list elements.
- hyperv: Report actual status in receive completion packet.
- hyperv: Add buffer for extended info after the RNDIS response
  message.
- Delete
  patches.suse/suse-hv-Cleanup-the-guest-ID-computation.patch.
- commit 08d283b
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable broken config options
- commit 8d7f8ab
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: disable VFIO
- commit 80abd68
* Mon Oct  1 2012 jeffm@suse.com
- Update to 3.6-final.
- commit 6066894
* Sat Sep 29 2012 dmueller@suse.com
- ARM/u5800: Fix build of ux500 driver
- commit 0ea37a0
* Sat Sep 29 2012 dmueller@suse.com
- disable non-compiling irrelevant I2C module
- commit 0ba9bac
* Sat Sep 29 2012 dmueller@suse.com
- ARM/tegra: Remove optional parts to fix build
- commit d729a16
* Sat Sep 29 2012 dmueller@suse.com
- ARM: enable zcache support
- commit 17b147b
* Sat Sep 29 2012 dmueller@suse.com
- ARM/cubox: set cachefilesd to module
- commit c1fb243
* Fri Sep 28 2012 trenn@suse.de
- Remove old patchset to override ACPI tables via initrd.
  Also remove a stale xen patch related to that.
- Delete
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- Delete
  patches.arch/acpica_fix_wrongly_mapped_acpi_table_header_when_overriding_via_initrd.patch.
- Delete
  patches.arch/acpica_introduce_acpi_os_phys_table_override_function.patch.
- Delete
  patches.xen/xen3-acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- commit dd8f1b0
* Fri Sep 28 2012 trenn@suse.de
- Refresh patches.arch/acpi_override_2_2.patch.
- commit 80dcdb8
* Fri Sep 28 2012 mszeredi@suse.cz
- Update config files to enable building overlayfs as a module.
- commit 42f70e6
* Fri Sep 28 2012 trenn@suse.de
- Update config files.
  Enable ACPI table override capability via initrd for
  all i386/x86_64 flavors:
  +CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
- commit 08721cc
* Fri Sep 28 2012 trenn@suse.de
- ACPI: Only allow users with CAP_SYS_RAWIO rights to overwrite
  ACPI funcs at runtime.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Implement physical address table override.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- X86 ACPI: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- lib: Add early cpio decoder.
- commit dfdfcd3
* Fri Sep 28 2012 mszeredi@suse.cz
- overlayfs: copy up i_uid/i_gid from the underlying inode.
- ovl: switch to __inode_permission().
- vfs: export __inode_permission() to modules.
- overlayfs: create new inode in ovl_link.
- overlayfs: fix possible leak in ovl_new_inode.
- fs: limit filesystem stacking depth.
- overlay: overlay filesystem documentation.
- overlayfs: implement show_options.
- overlayfs: add statfs support.
- overlay filesystem.
- vfs: introduce clone_private_mount().
- vfs: export do_splice_direct() to modules.
- vfs: add i_op->dentry_open().
- commit f3e02da
* Thu Sep 27 2012 agraf@suse.de
- Update config files: Disable JTAG HVC, when enabled the kernel hangs on access
- commit cdf0705
* Tue Sep 25 2012 jeffm@suse.com
- Update to 3.6-rc7.
  Eliminated one patch.
- commit 91c0ddc
* Tue Sep 25 2012 mmarek@suse.cz
- Delete scripts/config.sh, rpm/config.sh has all the needed information
- commit 06c7ff0
* Thu Sep 20 2012 jeffm@suse.com
- x86/kbuild: archscripts depends on scripts_basic.
  patches.rpmify/makefile-fix-scripts_basic-archscripts-build-order is
  now obsolete.
- commit 33eb1e6
* Wed Sep 19 2012 jeffm@suse.com
- Makefile: Fix scripts_basic / archscripts build order.
- commit 65590b3
* Wed Sep 19 2012 agraf@suse.de
- Delete patches.arch/arm-phys-offset.patch.
- commit 50837bd
* Mon Sep 17 2012 jeffm@suse.com
- Update to 3.6-rc6.
- Eliminated 1 patch.
  patches.arch/arm-phys-offset.patch needs review.
- commit d6432fe
* Tue Sep 11 2012 dmueller@suse.com
- (ARM/tegra) remove non-building module from config
- commit 4cdd491
* Tue Sep 11 2012 jeffm@suse.com
- config: disabled MFD drivers that aren't buildable as modules
  This allows MFD_CORE to be modular on all arch/flavors except for
  ARM and the non-PAE flavors on i386, since it's used with the OLPC XO-1.
- commit ff91de4
* Mon Sep 10 2012 jeffm@suse.com
- Update to 3.6-rc5.
- commit 11b8e7e
* Mon Sep 10 2012 jbeulich@novell.com
- patches.arch/s390-message-catalog.diff: Properly handle pr_cont() and fold
  in the below two trivial fixes.
- Delete patches.arch/s390-message-catalog-fix.diff.
- Delete patches.arch/s390-message-catalog-perl-fix.diff.
- Refresh patches.arch/kmsg-fix-parameter-limitations.
- commit 71b4cc3
* Fri Sep  7 2012 dmueller@suse.com
- fix build of imx51 flavor by removing irrelevant drivers
- commit 7ea6615
* Fri Sep  7 2012 dmueller@suse.com
- remove drivers that do not exist and do not build on ARM (default)
- commit 2319db4
* Thu Sep  6 2012 ohering@suse.de
- Refresh
  patches.suse/suse-hv-identify-virtual-pc-in-ata_piix.patch.
- commit fb4b7f9
* Thu Sep  6 2012 ohering@suse.de
- identify Virtual PC guests in ata_piix (bnc#737532).
- commit 13500ed
* Thu Sep  6 2012 mmarek@suse.cz
- rpm/package-descriptions: Fix typo
- commit c08c34b
* Thu Sep  6 2012 jbeulich@novell.com
- Update Xen patches to 3.6-rc4 and c/s 1188.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 4cdebd8
* Tue Sep  4 2012 jeffm@suse.com
- Update to 3.6-rc4.
- Eliminated one patch.
- commit 9fe3afb
* Tue Sep  4 2012 mmarek@suse.cz
- Disable CONFIG_KMSG_IDS on s390x, because it is currently broken
- commit c1db24a
* Mon Sep  3 2012 jslaby@suse.cz
- Update config files. (vanilla ones)
- commit ca19bfb
* Fri Aug 31 2012 dmueller@suse.com
- ARM(omap2plus): Remove optional parts that don't compile
- commit 77105c2
* Fri Aug 31 2012 jslaby@suse.cz
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- Delete
  patches.fixes/i2c-busses-fix-build-error-if-config_i2c_designware_platform-y-config_i2c_design.
  Move it to rpmify, so that vanilla builds fine too.
- commit 0217ad5
* Thu Aug 30 2012 agraf@suse.de
- Update config files: Add highbank (forgot in last patch)
- commit e86b000
* Thu Aug 30 2012 agraf@suse.de
- config.conf: Enable ARM
- Update ARM config files.
- Add highbank definition
- commit 835e93d
* Thu Aug 30 2012 mmarek@suse.cz
- rpm/kernel-module-subpackage: Provide name-kmp = %%version in KMPs
  This allows userspace packages to require a specific version of a KMP,
  wothout worrying about the _k<kernel version> suffix.
- commit caaaa9a
* Tue Aug 28 2012 jeffm@suse.com
- config: Update -vanilla for ChipIdea fix
- commit c45f0ac
* Mon Aug 27 2012 jeffm@suse.com
- chipidea: Allow user to select PCI/IMX options.
  This allows us to disable the ChipIdea IMX code on powerpc,
  where it was causing build problems.
- commit 278cad2
* Mon Aug 27 2012 jeffm@suse.com
- config: Disable EXYNOS_VIDEO and HW_RANDOM_EXYNOS on all configs except exynos
  This hardware is only found on the Samsung EXYNOS boards.
- commit 429a008
* Mon Aug 27 2012 jeffm@suse.com
- Revert "clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK)."
  This reverts commit 54e1c0025e4757174d8d648e8224bf74009b3c2b.
  The issue is either an incomplete clk API on powerpc or clk_devm needs
  to be made generic. Discussion continues upstream.
- commit 8c9a4e9
* Mon Aug 27 2012 jeffm@suse.com
- clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK).
  This fixes the clk_devm_get build failures on ppc.
- commit 54e1c00
* Mon Aug 27 2012 jeffm@suse.com
- Update to 3.6-rc3.
- commit 0a688a0
* Tue Aug 21 2012 jeffm@suse.com
- config: update vanilla configs for 3.6-rc2.
- commit e0fa472
* Fri Aug 17 2012 jeffm@suse.com
- Update to 3.6-rc2.
  - Eliminated 1 patch.
- commit 71963b0
* Fri Aug 10 2012 jeffm@suse.com
- printk: Fix calculation of length used to discard records.
- commit bfdd968
* Thu Aug  9 2012 jslaby@suse.cz
- ubifs: remove __DATE__ and __TIME__.
- commit 6702208
* Thu Aug  9 2012 jslaby@suse.cz
- Refresh
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-setup-for-HP-Mini-210.
  Update git-commit tag.
- commit f3a1eba
* Thu Aug  9 2012 jeffm@suse.com
- Update to 3.6-rc2. - Eliminated 2 patches.
- commit b073c66
* Thu Aug  9 2012 jeffm@suse.com
- reiserfs: fix deadlock with nfs racing on create/lookup
  (bnc#762693).
- commit 5b2dce3
* Thu Aug  9 2012 mmarek@suse.cz
- Delete patches.suse/s390-Kerntypes.diff until we get an updated version.
- commit 78f2edc
* Thu Aug  9 2012 mmarek@suse.cz
- Disable CONFIG_DRM_NOUVEAU on ia64 due to build errors
- commit 38e08ef
* Wed Aug  8 2012 mmarek@suse.cz
- Update config files to fix build.
- commit 9c9630c
* Wed Aug  8 2012 dmueller@suse.com
- config: enable various ARM errata workarounds to improve stability
- commit 4e28647
* Mon Aug  6 2012 tiwai@suse.de
- ASoC: omap: Add missing modules aliases to get sound working
  on omap devices.
- commit cbda3c2
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled DMRAID45.
- commit 6b8bedd
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled richacl support.
- commit 001594d
* Fri Aug  3 2012 jeffm@suse.com
- Update to 3.6-rc1.
  - Eliminated 11 patches.
  - Rich ACLs are disabled.
  - Xen is disabled.
  - ARM is disabled.
  - DMRAID45 is disabled.
- commit 5807d6b
* Fri Aug  3 2012 jeffm@suse.com
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- commit 3bec42b
* Fri Aug  3 2012 jeffm@suse.com
- reiserfs: fix deadlocks with quotas.
- commit 77ba55a
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh Xen patches (fixing a major bug in the most recent Xen commit).
- commit 5df2b91
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh patches.suse/stack-unwind (to work with older tool chains).
- commit 30e4ab0
* Tue Jul 31 2012 jeffm@suse.com
- rpm/kernel-binary.spec.in: Add dependency on mkinitrd >= 2.7.1 (bnc#773559).
- commit 2f75710
* Tue Jul 31 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO initialization for IDT codecs
  (bnc#772923).
- ALSA: hda - Fix polarity of mute LED on HP Mini 210
  (bnc#772923).
- commit f3c90ee
* Mon Jul 30 2012 jeffm@suse.com
- Update config files: HID_GENERIC=y where USBHID=y (bnc#773559).
  On flavors where USBHID is built-in statically, we want HID_GENERIC to
  be built statically as well. This, notably, includes i386/x86_64's desktop
  flavors.
- commit 6d995bc
* Mon Jul 30 2012 jeffm@suse.com
- Synced configs after commit 940e57e2 (Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.)
- commit 104f550
* Mon Jul 30 2012 dmueller@suse.com
- Enable RTL8150 for omap2plus
  Generic USB Network device that also works fine on ARM, so enable it
- commit 400dcb7
* Mon Jul 30 2012 ohering@suse.de
- Drivers: hv: Cleanup the guest ID computation.
- hyperv: Add a check for ring_size value.
- hyperv: Add error handling to rndis_filter_device_add().
- Drivers: hv: Change the hex constant to a decimal constant.
- hyperv: Add support for setting MAC from within guests.
- commit 73d4430
* Fri Jul 27 2012 trenn@suse.de
- ACPI: Only count valid srat memory structures (bnc#757888).
- ACPI: Untangle a return statement for better readability
  (bnc#757888).
- commit 876d6b9
* Fri Jul 27 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix wrong vfree() (bnc#773406)
- commit a637a16
* Thu Jul 26 2012 tiwai@suse.de
- Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.
  This feature was dropped from 12.2/FACTORY packages due to instability
  (bnc#768506,bnc#765524)
- commit 940e57e
* Thu Jul 26 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO setup for HP Mini 210
  (bnc#772923).
- commit 0ac6c27
* Thu Jul 26 2012 jeffm@suse.com
- Enabled patches.fixes/brcmsmac-firmware.
- commit 4ed5cb4
* Thu Jul 26 2012 jeffm@suse.com
- brcmsmac: document firmware dependencies (bnc#733148).
- commit f489263
* Wed Jul 25 2012 jbeulich@novell.com
- Update Xen patches to 3.5-final and c/s 1184.
- Delete patches.xen/xen3-apei_allow_drivers_access_nvs_ram.patch.
- commit 341366d
* Tue Jul 24 2012 jeffm@suse.com
- Update to 3.5-final.
  patches.suse/dm-raid45-26-Nov-2009.patch needs updating to new kmsg
  interface but, since powerpc isn't officially supported by opensuse, the
  update can happen later.
- commit fb9c50b
* Mon Jul 23 2012 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Update mainline tag.
- commit 4e207cd
* Wed Jul 18 2012 ohering@suse.de
- Delete patches.suse/led_classdev.sysfs-name.patch.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
- commit 13b12c9
* Tue Jul 17 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix a typo in the capability bit check (bnc#768506).
- commit 5aa2a0b
* Mon Jul 16 2012 jeffm@suse.com
- Updated to 3.5-rc7.
- Eliminated 1 patch.
- commit 58a8fc5
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Updates vanilla config files to include NFS_DEBUG implied by SUNRPC_DEBUG
- commit f36b6ed
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add SUNRPC_DEBUG - a new option for functionality that was
  previously always present.
  Without this, "rpcdebug" doesn't work.
  We often request customers enable this to analyse problems.
- commit b4fa24f
* Thu Jul 12 2012 mmarek@suse.cz
- Update vanilla config files.
- commit a0c6b82
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 8442da0
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc6.
- Eliminated 1 patch.
- commit 93575a7
* Mon Jul  9 2012 jeffm@suse.com
- coretemp-xen: Fix usage of X86_FEATURE_DTS -> X86_FEATURE_DTHERM
  Upstream commit 4ad33411308596f2f918603509729922a1ec4411 renamed _DTS to
  _DTHERM, so fix its usage in the Xen driver.
- commit 1732d37
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=y.
- commit 72cd989
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=m.
- commit cdced94
* Sun Jul  8 2012 jeffm@suse.com
- Updated to 3.5-rc5.
- Eliminated 2 patches.
- commit ec675c6
* Thu Jul  5 2012 agraf@suse.de
- Update config files: use PR KVM on ppc/ppc64
- commit c902ea5
* Wed Jul  4 2012 hare@suse.de
- mach-dove: define TIMER_PHYS_BASE.
- Update config files.
- commit 0ea0e05
* Wed Jul  4 2012 trenn@suse.de
- Fix NULL pointer derference in acpi_ns_check_object_type()
  (kernel bug 44171).
- commit 10f1915
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/dell_latitude_e6xxx_e5xxx__fix_reboot.patch.
- Delete patches.drivers/apei_allow_drivers_access_nvs_ram.patch.
- commit c6e9e42
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/acpi_fix_fadt_32_bit_zero_length.patch.
- Delete patches.suse/acpi_osi_sle11_ident.patch.
- commit d8799fb
* Tue Jul  3 2012 agraf@suse.de
- omap2+: Revert "mmc: omap_hsmmc: Enable Auto CMD12".
- omap2+: Revert "Fix OMAP EHCI suspend/resume failure (i693)".
- omap2+: add drm device for the new Xorg driver.
- commit 4829a29
* Mon Jul  2 2012 dsterba@suse.cz
- btrfs: allow cross-subvolume file clone (bnc#698540).
- btrfs: use correct device for maps (bnc#672923 bnc#769545).
- commit 25d8571
* Tue Jun 26 2012 vojtech@suse.com
- Update post.sh to make the RT kernel default in the bootloader
  after installation.
- commit 3c10ce7
* Tue Jun 26 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (ARM) config
- commit 466b846
* Mon Jun 25 2012 jeffm@suse.com
- Updated to 3.5-rc4.
- Eliminated 1 patch.
- commit 65cee14
* Sun Jun 24 2012 awafaa@opensuse.org
- Add support for Samsung Exynos SoC
- commit 81fc687
* Sun Jun 24 2012 awafaa@opensuse.org
- Update configs for cubox/default/imx51/tegra/u8500
- commit 65b18f1
* Tue Jun 19 2012 jbeulich@novell.com
- Update Xen patches to 3.5-rc3 and c/s 1182.
- Update x86 config files.
- Delete patches.xen/add-console-use-vt.
- commit d11f278
* Mon Jun 18 2012 jeffm@suse.com
- Fixed up post-3.5-merge conflicts.
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch.
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch.
- commit 7a3a50c
* Mon Jun 18 2012 jeffm@suse.com
- Updated to 3.5-rc3.
- commit 3ee859e
* Mon Jun 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Revert "Add provides and make most obsoletes
  versioned." (commit e3023c7). This change is wrong, the packages have
  their own versioning schemes.
- commit 29957f5
* Mon Jun 18 2012 jbeulich@novell.com
- Delete patches.xen/frontswap-config.
- Delete patches.xen/frontswap-core.
- Delete patches.xen/frontswap-header.
- Delete patches.xen/frontswap-hooks.
- commit cb6120e
* Mon Jun 18 2012 jbeulich@novell.com
- Refresh an re-enable patches.arch/x86_64-unwind-annotations.
- commit 9ed2387
* Fri Jun 15 2012 mhocko@suse.cz
- mm: correctly synchronize rss-counters at exit/exec (bnc#767152).
- commit d161b60
* Thu Jun 14 2012 jeffm@suse.com
- CONFIG_RTC_DRV_CMOS=y on all x86/x86_64 flavors (bnc#755525).
  When rtc_cmos is module, hctosys fails to set the clock on boot, issuing
  ominious error messages to the console.
- commit cddcbe7
* Thu Jun 14 2012 jbeulich@novell.com
- Update x86 config files (ATA_PIIX=m, bnc#766284).
- commit d80afa8
* Thu Jun 14 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Add product ID 0x84 that may have the LED support (bnc#764339)
- commit 6e5a834
* Wed Jun 13 2012 hare@suse.de
- Rediff patch
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch:
  Rediff after backport from upstream.
- commit fa58c5e
* Wed Jun 13 2012 hare@suse.de
- Fixup patch to apply
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch
  backported from upstream.
- commit 2507393
* Wed Jun 13 2012 hare@suse.de
- Add SolidRun Cubox configuration
- Update config files.
- Add separate cubox configuration.
- mach-dove: Fixup ge00 initialisation.
- spi-orion: convert to new infrastructure.
- config.conf: Add cubox configuration
- rpm/package-descriptions: Add cubox description
- commit bfddec4
* Mon Jun 11 2012 jeffm@suse.com
- Update to 3.5-rc2.
  - Xen needs update.
  - ARM needs update.
  - Eliminated 13 patches.
- commit 3f461b1
* Fri Jun  8 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Use depends instead of reverse selection for avoiding the inconsitent
  Kconfig state.
- commit 316d77d
* Wed Jun  6 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix the detection of LED on the recent HP laptops (bnc#765524)
- commit 27c3276
* Tue Jun  5 2012 ohering@suse.de
- usb/net: rndis: merge command codes.
  only net/hyperv part
- usb/net: rndis: remove ambigous status codes.
  only net/hyperv part
- usb/net: rndis: break out <linux/rndis.h> defines.
  only net/hyperv part
- net/hyperv: Add flow control based on hi/low watermark.
- hv: fix return type of hv_post_message().
- Drivers: hv: util: Properly handle version negotiations.
- Drivers: hv: Get rid of an unnecessary check in vmbus_prep_negotiate_resp().
- HID: hyperv: Set the hid drvdata correctly.
- HID: hid-hyperv: Do not use hid_parse_report() directly.
- commit cfebefe
* Mon Jun  4 2012 ohering@suse.de
- [SCSI] storvsc: Properly handle errors from the host
  (bnc#747404).
- Delete patches.suse/suse-hv-storvsc-ignore-ata_16.patch.
- commit ad28e23
* Fri Jun  1 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago...
- commit 86629f1
* Fri Jun  1 2012 guillaume.gardet@oliseo.fr
- Update ARM configs
- commit 550ef37
* Thu May 31 2012 ohering@suse.de
- replace our version of this patch with upstream variant:
  ata_piix: defer disks to the Hyper-V drivers by default
  libata: add a host flag to ignore detected ATA devices.
- commit bf70e35
* Wed May 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the right -kdump initrd (bnc#764500)
- commit 5c85db8
* Tue May 29 2012 mhocko@suse.cz
- Refresh
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control.
  Fix a compile error due to anonymous union initialization not supported
  by earlier gcc versions (<4.6.x).
- commit 790f341
* Tue May 29 2012 jbeulich@novell.com
- Update Xen config files (XEN_SPINLOCK_ACQUIRE_NESTING=1).
- commit d03820c
* Fri May 25 2012 jeffm@suse.com
- Renamed armv7l to armv7hl, following %%_cpu_target convention.
- commit 64b97cd
* Wed May 23 2012 jbeulich@novell.com
- Update Xen patches to 3.4-final and c/s 1177.
- commit a3c5f2c
* Tue May 22 2012 trenn@suse.de
- X86 acpi_cpufreq: Do not use request_module for autoloading
  (bnc#756085).
- Refresh patches.xen/xen3-auto-common.diff.
- patches.xen/xen3-patch-3.3:
- commit caf270e
* Mon May 21 2012 jeffm@suse.com
- Update to 3.4-final.
- commit 91b2c6e
* Tue May 15 2012 agraf@suse.de
- Update config files: ppc64: use PR instead of HV KVM which is usable by more people
- commit 5e7640a
* Tue May 15 2012 jeffm@suse.com
- Make CRYPTO_CRC32C modular (bnc#762344)
  It was pulled in =y via CEPH_LIB=y, so we change the
  following options to =m:
- CONFIG_CEPH_LIB
- CONFIG_CRYPTO_CRC32C
- CONFIG_LIBCRC32C
  Making it modular allows the Intel-optimized crc32c implementation
  to be loaded, improving performance of things like btrfs.
- commit d569763
* Mon May 14 2012 jeffm@suse.com
- Disabled more Intel embedded drivers.
  Disabled:
- CONFIG_GPIO_LANGWELL
- CONFIG_GPIO_PCH
- CONFIG_GPIO_SCH
- commit f554d8b
* Mon May 14 2012 jeffm@suse.com
- USB storage on -desktop should be modular.
- commit 9331d48
* Mon May 14 2012 jeffm@suse.com
- Disabled more testing options.
  Disables:
  - CONFIG_TEST_POWER
  - CONFIG_VIDEO_MEM2MEM_TESTDEV
- commit ef1f4ca
* Mon May 14 2012 jeffm@suse.com
- Update to 3.4-rc7.
  - Eliminated 1 patch.
- commit 4cd9e9b
* Wed May  9 2012 jeffm@suse.com
- geodefb: Depend on X86_32.
  Disables:
- CONFIG_FB_GEODE_GX1
- CONFIG_FB_GEODE_GX
- CONFIG_FB_GEODE_LX
- CONFIG_FB_GEODE
- commit 1f260fb
* Wed May  9 2012 jeffm@suse.com
- Disabled testing config options on !debug
- CONFIG_CRYPTO_TEST
- CONFIG_DMATEST
- CONFIG_RTC_DRV_TEST
- commit d7c9a65
* Wed May  9 2012 guillaume.gardet@opensuse.org
- Update ARM configs
- commit aac8787
* Tue May  8 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc6.
- commit 8ed7ef0
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support. (Xen version)
- commit 1c19c30
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support.
- commit ad06d7d
* Mon May  7 2012 jeffm@suse.com
- Update to 3.4-rc6.
  - Eliminated 2 patches.
- commit 749ea8f
* Fri May  4 2012 jeffm@suse.com
- Disabled MMC_TEST (bnc#760077).
- commit c36bb06
* Fri May  4 2012 jeffm@suse.com
- sysctl/defaults: kernel.hung_task_timeout -> kernel.hung_task_timeout_secs (bnc#700174)
- commit 94b5c35
* Thu May  3 2012 guillaume.gardet@opensuse.org
- Update config/armv7l/omap2plus
- commit db627f7
* Wed May  2 2012 jeffm@suse.com
- patches.drivers/ehea-modinfo.patch: Updated patch-mainline for submission.
- commit e0eb735
* Wed May  2 2012 jeffm@suse.com
- omap-usb-host: include <plat/cpu.h>.
- commit 4d1394a
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require distribution-release
  during build.
- commit 3cd703f
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Depend on distribution-release, so that
  the grub entry has correct title (bnc#757565).
- commit 30145a4
* Mon Apr 30 2012 jeffm@suse.com
- Updated and re-enabled armv7l.
  Thanks to Guillaume GARDET <guillaume.gardet@opensuse.org>
- commit d5a693e
* Mon Apr 30 2012 neilb@suse.de
- Update config files.
  Add CONFIG options for NFSv4v1 support.
  bnc#730444
- commit bd05821
* Mon Apr 30 2012 jeffm@suse.com
- Update to 3.4-rc5.
- commit e4e6b33
* Fri Apr 27 2012 jeffm@suse.com
- Disabled more Moorestown/Medfield drivers.
  Specific options disabled:
  I2C_INTEL_MID
  CONFIG_SFI
  MTD_NAND_DENALI
  SERIAL_MRST_MAX3110
  DRM_GMA600
  SPI_DW_MID_DMA
  APDS9802ALS
- commit 9a9ecdf
* Thu Apr 26 2012 jeffm@suse.com
- Disabled DECNet and ARCNet.
  Specific config options disabled:
  CONFIG_ARCNET
  CONFIG_ARCNET_1051
  CONFIG_ARCNET_1201
  CONFIG_ARCNET_CAP
  CONFIG_ARCNET_COM20020_CS
  CONFIG_ARCNET_COM20020
  CONFIG_ARCNET_COM20020_PCI
  CONFIG_ARCNET_COM90xxIO
  CONFIG_ARCNET_COM90xx
  CONFIG_ARCNET_RAW
  CONFIG_ARCNET_RIM_I
  CONFIG_DECNET
  CONFIG_DECNET_NF_GRABULATOR
- commit 272dd14
* Thu Apr 26 2012 jeffm@suse.com
- Disabled embedded hardware on all architectures except armv7l.
  Regulator drivers, except those needed by Via vx885/875 and OLPC
  are disabled.  IIO drivers are disabled.  SPI drivers are disabled.
  Drivers used only with Intel Medfield or Moorestown have been disabled.
  Specific options disabled:
  CONFIG_AD2S1200, CONFIG_AD2S1210, CONFIG_AD2S90, CONFIG_AD5064,
  CONFIG_AD5360, CONFIG_AD5380, CONFIG_AD5421, CONFIG_AD5446, CONFIG_AD5504,
  CONFIG_AD5624R_SPI, CONFIG_AD5686, CONFIG_AD5764, CONFIG_AD5791,
  CONFIG_AD5930, CONFIG_AD5933, CONFIG_AD7150, CONFIG_AD7152, CONFIG_AD7192,
  CONFIG_AD7280, CONFIG_AD7291, CONFIG_AD7298, CONFIG_AD7476,
  CONFIG_AD7606_IFACE_PARALLEL, CONFIG_AD7606_IFACE_SPI, CONFIG_AD7606,
  CONFIG_AD7746, CONFIG_AD7780, CONFIG_AD7793, CONFIG_AD7816, CONFIG_AD7887,
  CONFIG_AD799X, CONFIG_AD799X_RING_BUFFER, CONFIG_AD9832, CONFIG_AD9834,
  CONFIG_AD9850, CONFIG_AD9852, CONFIG_AD9910, CONFIG_AD9951,
  CONFIG_ADE7753, CONFIG_ADE7754, CONFIG_ADE7758, CONFIG_ADE7759,
  CONFIG_ADE7854_I2C, CONFIG_ADE7854, CONFIG_ADE7854_SPI, CONFIG_ADIS16060,
  CONFIG_ADIS16080, CONFIG_ADIS16130, CONFIG_ADIS16201, CONFIG_ADIS16203,
  CONFIG_ADIS16204, CONFIG_ADIS16209, CONFIG_ADIS16220, CONFIG_ADIS16240,
  CONFIG_ADIS16260, CONFIG_ADIS16400, CONFIG_ADT7310, CONFIG_ADT7316_I2C,
  CONFIG_ADT7316, CONFIG_ADT7316_SPI, CONFIG_ADT7410, CONFIG_ADXRS450,
  CONFIG_BACKLIGHT_WM831X, CONFIG_CAN_JANZ_ICAN3, CONFIG_FB_SM501,
  CONFIG_GPIO_JANZ_TTL, CONFIG_GPIO_RDC321X, CONFIG_GPIO_STMPE,
  CONFIG_GPIO_TIMBERDALE, CONFIG_GPIO_WM831X, CONFIG_IIO_BUFFER,
  CONFIG_IIO_CONSUMERS_PER_TRIGGER=2, CONFIG_IIO_GPIO_TRIGGER,
  CONFIG_IIO_KFIFO_BUF, CONFIG_IIO, CONFIG_IIO_PERIODIC_RTC_TRIGGER,
  CONFIG_IIO_SIMPLE_DUMMY, CONFIG_IIO_ST_HWMON, CONFIG_IIO_SW_RING,
  CONFIG_IIO_SYSFS_TRIGGER, CONFIG_IIO_TRIGGER,
  CONFIG_INPUT_MC13783_PWRBUTTON, CONFIG_INPUT_WM831X_ON,
  CONFIG_KEYBOARD_STMPE, CONFIG_KXSD9, CONFIG_LEDS_MC13783,
  CONFIG_LEDS_REGULATOR, CONFIG_LEDS_WM831X_STATUS,
  CONFIG_LIS3L02DQ_BUF_KFIFO, CONFIG_LIS3L02DQ, CONFIG_MAX1363,
  CONFIG_MAX1363_RING_BUFFER, CONFIG_MAX517, CONFIG_MFD_CORE,
  CONFIG_MFD_JANZ_CMODIO, CONFIG_MFD_MC13783, CONFIG_MFD_MC13XXX,
  CONFIG_MFD_RDC321X, CONFIG_MFD_SM501_GPIO, CONFIG_MFD_SM501,
  CONFIG_MFD_STMPE, CONFIG_MFD_TIMBERDALE, CONFIG_MFD_TPS65217,
  CONFIG_MFD_WM831X_SPI, CONFIG_MFD_WM831X, CONFIG_MFD_WM8400,
  CONFIG_RADIO_TIMBERDALE, CONFIG_REGMAP_I2C, CONFIG_REGMAP_SPI,
  CONFIG_REGMAP, CONFIG_REGULATOR_AD5398, CONFIG_REGULATOR_DA903X,
  CONFIG_REGULATOR_DEBUG, CONFIG_REGULATOR_DUMMY,
  CONFIG_REGULATOR_FIXED_VOLTAGE, CONFIG_REGULATOR_GPIO,
  CONFIG_REGULATOR_ISL6271A, CONFIG_REGULATOR_LP3971,
  CONFIG_REGULATOR_LP3972, CONFIG_REGULATOR_MAX1586,
  CONFIG_REGULATOR_MAX8649, CONFIG_REGULATOR_MAX8660,
  CONFIG_REGULATOR_MAX8952, CONFIG_REGULATOR_MC13783,
  CONFIG_REGULATOR_MC13892, CONFIG_REGULATOR_MC13XXX_CORE,
  CONFIG_REGULATOR_PCAP, CONFIG_REGULATOR_TPS6105X,
  CONFIG_REGULATOR_TPS62360, CONFIG_REGULATOR_TPS65023,
  CONFIG_REGULATOR_TPS6507X, CONFIG_REGULATOR_TPS65217,
  CONFIG_REGULATOR_TPS6524X, CONFIG_REGULATOR_USERSPACE_CONSUMER,
  CONFIG_REGULATOR_VIRTUAL_CONSUMER, CONFIG_REGULATOR_WM831X,
  CONFIG_REGULATOR_WM8400, CONFIG_REGULATOR, CONFIG_RFKILL_REGULATOR,
  CONFIG_RTC_DRV_MC13XXX, CONFIG_RTC_DRV_WM831X, CONFIG_SCA3000,
  CONFIG_SENSORS_AK8975, CONFIG_SENSORS_HMC5843, CONFIG_SENSORS_ISL29018,
  CONFIG_SENSORS_MC13783_ADC, CONFIG_SENSORS_TSL2563, CONFIG_SENSORS_WM831X,
  CONFIG_SERIAL_MFD_HSU, CONFIG_SERIAL_UARTLITE, CONFIG_STMPE_I2C,
  CONFIG_STMPE_SPI, CONFIG_TOUCHSCREEN_MC13783, CONFIG_TOUCHSCREEN_STMPE,
  CONFIG_TOUCHSCREEN_WM831X, CONFIG_TPS6105X, CONFIG_TSL2583,
  CONFIG_WM831X_BACKUP, CONFIG_WM831X_POWER, CONFIG_WM831X_WATCHDOG
- commit 0f27f25
* Thu Apr 26 2012 jeffm@suse.com
- Disabled CONFIG_COPS and CONFIG_LTPC: Ancient ISA LocalTalk hardware.
- commit 43b6598
* Wed Apr 25 2012 jeffm@suse.com
- dl2k: Tighten ioctl permissions (bnc#758813).
- commit 8d00242
* Wed Apr 25 2012 jeffm@suse.com
- Update to 3.4-rc4.
- commit 37113a8
* Sun Apr 22 2012 jeffm@suse.com
- Update config files: Merged omap2plus changes.
- commit f0e2149
* Fri Apr 20 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc3 and c/s 1172.
- config.conf: Re-enabled Xen configs.
- Update config files.
- commit 9f943f6
* Tue Apr 17 2012 jeffm@suse.com
- Update to 3.4-rc3.
  - Eliminated 1 patch.
- commit 2fde7e0
* Fri Apr 13 2012 jbeulich@novell.com
- Drivers: scsi: storvsc: Account for in-transit packets in the
  RESET path.
- commit 4c1e258
* Mon Apr  9 2012 jeffm@suse.com
- Update to 3.4-rc2.
- commit 976094f
* Fri Apr  6 2012 jeffm@suse.com
- Update AppArmor for 3.4.
  - apparmor: Add "profiles" list to sysfs.
- commit 59517ac
* Thu Apr  5 2012 jeffm@suse.com
- Update richacl patchset for 3.4.
- commit f13764e
* Thu Apr  5 2012 jeffm@suse.com
- Updated to 3.4-rc1.
  - Eliminated 121 patches.
  - Xen is unavailable.
  - ACPI overrides are unavailable.
  - AppArmor network feature are unavailable.
- commit 3ac7e79
* Thu Apr  5 2012 jeffm@suse.de
- Updated patch headers
- commit 09c9338
* Tue Apr  3 2012 ohering@suse.de
- Drivers: scsi: storvsc: Properly handle errors from the host
  (bnc#747404).
- commit 2f7920e
* Mon Apr  2 2012 jeffm@suse.de
- armv7l: Disable CONFIG_TOUCHSCREEN_EGALAX on default and u8500 due to missing infrastructure.
- commit b614c98
* Mon Apr  2 2012 jslaby@suse.cz
- samsung-laptop: make the dmi check less strict (bnc#746695).
- commit 170a6a2
* Fri Mar 30 2012 tiwai@suse.de
- drm/i915: suspend fbdev device around suspend/hibernate
  (bnc#732908).
- commit 028c29f
* Wed Mar 28 2012 jeffm@suse.com
- net: fix a potential rcu_read_lock() imbalance in
  rt6_fill_node() (bnc#754186).
- commit 8d5a9e4
* Mon Mar 26 2012 ohering@suse.de
- net/hyperv: Fix the code handling tx busy.
- Tools: hv: Support enumeration from all the pools.
- Tools: hv: Fully support the new KVP verbs in the user level
  daemon.
- Drivers: hv: Support the newly introduced KVP messages in
  the driver.
- Drivers: hv: Add new message types to enhance KVP.
- net/hyperv: Add support for vlan trunking from guests.
- net/hyperv: Fix data corruption in rndis_filter_receive().
- drivers: hv: Increase the number of VCPUs supported in the
  guest.
- drivers: hv: kvp: Cleanup the kernel/user protocol.
- tools: hv: Use hyperv.h to get the KVP definitions.
- drivers: hv: Cleanup the kvp related state in hyperv.h.
- net/hyperv: Remove the unnecessary memset in
  rndis_filter_send().
- net/hyperv: Correct the assignment in netvsc_recv_callback().
- net/hyperv: Convert camel cased variables in rndis_filter.c
  to lower cases.
- drivers: hv: kvp: Move the contents of hv_kvp.h to hyperv.h.
- drivers: hv: kvp: Add/cleanup connector defines.
- drivers: hv: Get rid of some unnecessary code.
- commit 78acc3b
* Sat Mar 24 2012 dsterba@suse.cz
- Revert "Btrfs: increase the global block reserve estimates"
- commit 7e9dd21
* Sat Mar 24 2012 dsterba@suse.cz
- Refresh patches.suse/btrfs-handle-EIO.
- Refresh
  patches.suse/btrfs-volumes-schedule_bio-should-return-void.
- commit d97ade6
* Fri Mar 23 2012 jbeulich@novell.com
- Update Xen patches to 3.3 final and c/s 1165.
- commit 6c5f5ef
* Thu Mar 22 2012 jeffm@suse.com
- Update config files: Disable CONFIG_INTEL_IOMMU_DEFAULT_ON (bnc#740102 and others)
- commit b244b17
* Thu Mar 22 2012 jeffm@suse.de
- Update config files: Disabled CONFIG_COMPAT_BRK and CONFIG_COMPAT_VDSO (FATE#313171)
- commit 990b059
* Wed Mar 21 2012 meissner@suse.de
- rpm: include crtsavres.o on ppc
- commit 854a031
* Mon Mar 19 2012 jeffm@suse.com
- Update vanilla config files.
- commit bd476d4
* Mon Mar 19 2012 jslaby@suse.cz
- Update (vanilla) config files.
- commit 55a0a56
* Mon Mar 19 2012 jslaby@suse.cz
- Delete
  patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch.
- Delete patches.arch/dell_optiplex_990_fix_reboot.patch.
- Delete
  patches.drivers/alsa-hda-0004-Add-missing-static-ADC-tables-for-ALC269-qu.
- Delete patches.drivers/libata-unlock-hpa-by-default.
- Delete patches.fixes/scsi-add-tgps-setting.
- Delete patches.fixes/scsi-dh-rdac-add-stk.
- Delete patches.suse/dm-mpath-evaluate-request-result-and-sense.
- Delete patches.suse/richacl-fix.
  Remove unused patches.
- commit 2cbabfe
* Mon Mar 19 2012 jeffm@suse.com
- Update to 3.3-final.
- commit a9ab64a
* Fri Mar 16 2012 ohering@suse.de
- Update bugnumber patches.suse/sd_init.mark_majors_busy.patch (bnc#744658).
- commit e60f2c3
* Mon Mar 12 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc7 and c/s 1163.
- commit 0054c83
* Mon Mar 12 2012 ohering@suse.de
- Staging: hv: storvsc: Cleanup some comments.
- Staging: hv: storvsc: Cleanup storvsc_probe().
- Staging: hv: storvsc: Cleanup storvsc_queuecommand().
- Staging: hv: storvsc: Introduce defines for srb status codes.
- Staging: hv: storvsc: Cleanup storvsc_host_reset_handler().
- Staging: hv: storvsc: Move and cleanup storvsc_remove().
- Staging: hv: storvsc: Add a comment to explain life-cycle
  management.
- Staging: hv: storvsc: Get rid of the on_io_completion in
  hv_storvsc_request.
- Staging: hv: storvsc: Rename the context field in
  hv_storvsc_request.
- Staging: hv: storvsc: Miscellaneous cleanup of storvsc driver.
- Staging: hv: storvsc: Cleanup the code for generating protocol
  version.
- Staging: hv: storvsc: Cleanup some protocol related constants.
- Staging: hv: storvsc: Get rid of some unused defines.
- Staging: hv: storvsc: Consolidate the request structure.
- Staging: hv: storvsc: Consolidate all the wire protocol
  definitions.
- Staging: hv: storvsc: Move the storage driver out of the
  staging area.
- Rename patches.suse/staging-hv-pata_piix-ignore-disks.patch to
  patches.suse/suse-hv-pata_piix-ignore-disks.patch
- commit 7487199
* Mon Mar 12 2012 jeffm@suse.com
- Update to 3.3-rc7.
- commit 81a18ea
* Sun Mar 11 2012 jeffm@suse.com
- btrfs: Handle EIO.
- btrfs: add varargs to btrfs_error.
- btrfs: Remove BUG_ON from __finish_chunk_alloc().
- btrfs: Remove BUG_ON from __btrfs_alloc_chunk().
- btrfs: Don't BUG_ON insert errors in btrfs_alloc_dev_extent().
- btrfs: Go readonly on tree errors in balance_level.
- btrfs: Don't BUG_ON errors from update_ref_for_cow().
- btrfs: Go readonly on bad extent refs in update_ref_for_cow().
- btrfs: Don't BUG_ON errors in __finish_chunk_alloc().
- btrfs: Don't BUG_ON kzalloc error in btrfs_lookup_csums_range().
- btrfs: Don't BUG_ON() errors in update_ref_for_cow().
- btrfs: Don't BUG_ON errors from btrfs_create_subvol_root().
- btrfs: btrfs_drop_snapshot should return int.
- brfs: split extent_state ops.
- btrfs: drop gfp_t from lock_extent.
- btrfs: scrub functions should return void.
- btrfs: btrfs_set_item_key_safe should BUG on error and return
  void.
- btrfs: Add extent_state alloc/free tracing.
- btrfs: btrfs_destroy_pending_snapshots should return void.
- btrfs: btrfs_destroy_ordered_extents should return void.
- btrfs: btrfs_destroy_ordered_operations should return void.
- btrfs: del_fs_roots should return void.
- btrfs: btrfs_free_fs_root should return void.
- btrfs: btrfs_add_ordered_sum should return void.
- btrfs: btrfs_add_ordered_operation should return void.
- btrfs: btrfs_run_ordered_operations should return void.
- btrfs: btrfs_wait_ordered_range should return void.
- btrfs: btrfs_wait_ordered_extents should return void.
- btrfs: __btrfs_remove_ordered_extent should return void.
- btrfs: btrfs_put_ordered_extent should return void.
- btrfs: update_inline_extent_backref should return void.
- btrfs: copy_for_split should return void.
- btrfs: end_compressed_writeback should return void.
- btrfs: btrfs_extend_item should return void.
- btrfs: btrfs_truncate_item should return void.
- btrfs: add_delayed_data_ref should return void.
- btrfs: add_delayed_tree_ref should return void.
- btrfs: add_delayed_ref_head should return void.
- btrfs: insert_ptr should return void.
- btrfs: del_ptr should return void.
- btrfs: setup_items_for_insert should return void.
- btrfs: fixup_low_keys should return void.
- btrfs: __add_reloc_root error push-up.
- btrfs: ->submit_bio_hook error push-up.
- btrfs: Factor out tree->ops->merge_bio_hook call.
- btrfs: Simplify btrfs_submit_bio_hook.
- btrfs: Fix kfree of member instead of structure.
- btrfs: setup_inline_extent_backref should return void.
- btrfs: btrfs_set_block_group_rw should return void.
- btrfs: btrfs_prepare_extent_commit should return void.
- btrfs: btrfs_destroy_delalloc_inodes should return void.
- btrfs: __setup_root should return void.
- btrfs: btrfs_invalidate_inodes should return void.
- btrfs: btrfs_init_compress should return void.
- btrfs: wait_for_writer should return void.
- btrfs: btrfs_end_log_trans should return void.
- btrfs: btrfs_requeue_work should return void.
- btrfs: btrfs_stop_workers should return void.
- btrfs: run_ordered_completions should return void.
- btrfs: fill_device_from_item should return void.
- btrfs: schedule_bio should return void.
- btrfs: btrfs_close_extra_devices should return void.
- btrfs: run_scheduled_bios should return void.
- btrfs: btrfs_cleanup_fs_uuids should return void.
- btrfs: clear_extent_buffer_dirty should return void.
- btrfs: check_page_writeback should return void.
- btrfs: check_page_locked should return void.
- btrfs: check_page_uptodate should return void.
- btrfs: __unlock_for_delalloc should return void.
- btrfs: wait_extent_bit should return void.
- btrfs: wait_on_state should return void.
- btrfs: btrfs_update_root error push-up.
- btrfs: find_and_setup_root error push-up.
- btrfs: Remove set bits return from clear_extent_bit.
- btrfs: avoid NULL deref in btrfs_reserve_extent with
  DEBUG_ENOSPC.
- btrfs: clean_tree_block should panic on observed memory
  corruption and return void.
- btrfs: btrfs_tree_{,un}lock should return void.
- btrfs: Simplify btrfs_insert_root.
- btrfs: Panic on bad rbtree operations.
- btrfs: Catch locking failures in {set,clear,convert}_extent_bit.
- btrfs: Add btrfs_panic().
- commit fd31baf
* Fri Mar  9 2012 ohering@suse.de
- mark busy sd majors as allocated (bug#744658).
- commit b2a640b
* Thu Mar  8 2012 mmarek@suse.cz
- Fix vanilla config files.
- commit b343c8a
* Thu Mar  8 2012 mmarek@suse.cz
- Delete patches.rpmify/nvme-broken, nvme builds again on 32bit.
- commit d60272f
* Thu Mar  8 2012 jbeulich@novell.com
- patches.suse/crasher-26.diff: Eliminate build warnings.
- commit 67c3c8d
* Thu Mar  8 2012 agraf@suse.de
- armv7l: config: omap: disable HDMI output (breaks build)
- commit 6a871bd
* Tue Mar  6 2012 agraf@suse.de
- armv7l: omap2plus: Enable TIDSPBRIDGE and SND codecs
- commit 0d8ec4d
* Mon Mar  5 2012 jeffm@suse.com
- Refresh patches.xen/xen3-fixup-arch-x86.
- commit f4b95ae
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6. Previous commit was configs.
- commit 639167f
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6.
- commit ebec13a
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit adb37b7
* Wed Feb 29 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc5 and c/s 1157.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit f225622
* Mon Feb 27 2012 jeffm@suse.com
- Updated to 3.3-rc5.
- commit 0b7f048
* Sun Feb 19 2012 jeffm@suse.com
- Updated to 3.3-rc4.
- commit 8831dca
* Mon Feb 13 2012 trenn@suse.de
- cpufreq/gx: Fix the compile error.
- commit 4ba1d8b
* Mon Feb 13 2012 mmarek@suse.cz
- nvme: Mark as broken on x86_32.
- commit 28ad576
* Sun Feb 12 2012 trenn@suse.de
- Add driver auto probing for x86 features v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Fix overrun check in arch_print_cpu_modalias()
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- crypto: Add support for x86 cpuid
  auto loading for x86 crypto drivers
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Clean up modalias feature matching
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel-idle: convert to x86_cpu_id auto probing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Fix ID for Nehalem-EX Xeon in device ID table
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert via-cputemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k7: Fix CPU family number
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: Load acpi-cpufreq from processor driver automatically
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Revert change of auto_demotion_flags for Nehalem
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert coretemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k6: Really enable auto-loading
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- X86: Introduce HW-Pstate scattered cpuid feature
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- cpufreq: Add support for x86 cpuinfo auto loading v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86: autoload microcode driver on Intel and AMD systems v2
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- CPU: Introduce ARCH_HAS_CPU_AUTOPROBE and X86 parts
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: remove duplicated lines of merging
  problems with acpi_processor_start
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- Update config files.
- commit 6efe9b5
* Fri Feb 10 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build x86 packages as i686, except for
  - default (bnc#745632). KMPs are still built as i586.
- commit 88a632b
* Thu Feb  9 2012 jeffm@suse.com
- Update to 3.3-rc3.
- commit 07ec27c
* Thu Feb  9 2012 agraf@suse.de
- armv7l: Update config files.
- commit d223353
* Thu Feb  9 2012 agraf@suse.de
- armv7l: config: integrate bmwiedemann's updates to make it usable
- commit 76d12ed
* Tue Feb  7 2012 jeffm@suse.com
- Update vanilla config files.
- commit fd3673f
* Tue Feb  7 2012 jeffm@suse.com
- Update to 3.3-rc2.
  - Eliminated 5 patches.
  - Xen is disabled.
- commit d017ea1
* Wed Jan 25 2012 dkukawka@suse.de
- fix NULL pointer dereference in DSS2 VENC sysfs debug attr on OMAP4.
- commit 2206a5c
* Wed Jan 25 2012 mmarek@suse.cz
- proc: clean up and fix /proc/<pid>/mem handling (bnc#742279,
  CVE-2012-0056).
- commit 4fb112d
* Tue Jan 17 2012 trenn@suse.de
- Delete patches.fixes/intel_idle_add_flush_tlb_param.patch.
- Delete patches.fixes/intel_idle_lapic_param.patch.
- commit e18e852
* Tue Jan 17 2012 agraf@suse.de
- KVM: PPC: Add HPT preallocator.
- KVM: PPC: Convert RMA allocation into generic code.
- commit a6da6a5
* Fri Jan 13 2012 agraf@suse.de
- ARM: Update config files: Enable highmem everywhere
- commit 4522c1c
* Fri Jan 13 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
- add a proper support for Xen fb (bnc#739020);
- fix the bootsplash-verbose switch race (bnc#734213)
- commit 6f3d77f
* Wed Jan 11 2012 jbeulich@novell.com
- patches.suse/stack-unwind: Fix more 2.6.29 merge problems plus a glue code problem.
- commit 9166360
* Mon Jan  9 2012 mmarek@suse.cz
- Set CONFIG_LOCALVERSION for armv7l/u8500.
- commit dde56d0
* Fri Jan  6 2012 awafaa@opensuse.org
- add support for ST-Ericsson Nova based SoCs
- commit 06d2b6e
* Fri Jan  6 2012 jbeulich@novell.com
- Update Xen patches to 3.2-final and c/s 1140.
- commit 917dd7e
* Thu Jan  5 2012 jeffm@suse.com
- Update to 3.2-final.
- commit 778e265
* Mon Jan  2 2012 jeffm@suse.com
- Updated to 3.2-rc7.
- commit f458508
* Thu Dec 22 2011 jeffm@suse.com
- Update config files.
- CONFIG_X86_INTEL_MID -> CONFIG_X86_WANT_INTEL_MID
- commit c4246bf
* Wed Dec 21 2011 jbeulich@novell.com
- Update Xen patches to 3.2-rc6 and c/s 1133.
- kexec: properly handle pCPU hotplug.
- x86: pCPU handling.
- commit cbe54a1
* Tue Dec 20 2011 jeffm@suse.com
- Update to 3.2-rc6.
  - Eliminated 1 patch.
- commit d5a489e
* Tue Dec 20 2011 trenn@suse.de
- These should all be mainline in some form:
- Delete
  patches.arch/implement_stop_machine_from_offline_cpu.patch.
- Delete patches.arch/kill-__stop_machine.patch.
- Delete patches.arch/reorganize_stop_cpus.patch.
- Delete patches.arch/use_stop_machine_for_mtrr_rendezvous.patch.
- commit 78eb159
* Sun Dec 18 2011 aj@suse.de
- rpm/kernel-source.rpmlintrc: The hidden files are fine, silence rpmlint.
- commit a7813dd
* Fri Dec 16 2011 aj@suse.de
- rpm/kernel-binary.spec.in: Add provides and make most obsoletes versioned.
  This silences rpmlint warnings.
- commit e3023c7
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix tarball URL for -rcX and
  do not generate any URL for linux-next and vanilla snapshots.
- commit 1548daf
* Tue Dec 13 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix linux tarball URL
- commit 5453f99
* Tue Dec 13 2011 agraf@suse.de
- doc/config-options.changes: add CONFIG_DEBUG_STACKOVERFLOW change
- commit 42de6ff
* Tue Dec 13 2011 agraf@suse.de
- PPC: Update config files: disable CONFIG_DEBUG_STACKOVERFLOW
- commit 4d462dd
* Mon Dec 12 2011 aj@suse.de
- Silence missing defattr warning.
- commit e7e3743
* Mon Dec 12 2011 aj@suse.de
- Silence warning about dangling symlink and vdsos
- commit 701c5c7
* Fri Dec  9 2011 aj@suse.de
- No self-obsoletions.
- commit 1d2e747
* Fri Dec  9 2011 aj@suse.de
- Do not show rpmlint warnings.
- commit bb45b41
* Fri Dec  9 2011 aj@suse.de
- Use versioned provides/obsoletes.
- commit cf4f296
* Fri Dec  9 2011 aj@suse.de
- Adjust kernel-source.rpmlintrc for Linux 3.x
- commit bc1534e
* Thu Dec  8 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not package the vmlinux image in the devel
  package.
- commit 02bb976
* Wed Dec  7 2011 aj@suse.de
- Use GPL-2.0 as license tag (from http://spdx.org/licenses/)
  Only have one licenses line per file, the rest was just duplicated.
- commit f7c443c
* Wed Dec  7 2011 aj@suse.de
- Fix typo: Base package should not conflict with itself but with main package.
- commit e961ef0
* Tue Dec  6 2011 jeffm@suse.com
- Update to 3.2-rc4.
  - Eliminated 1 patch.
- commit a7d546d
* Mon Dec  5 2011 agraf@suse.de
- ARM: Update config files: omap: enable power management
- commit b97f846
* Tue Nov 29 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make the -base package conflict with the main
  one.
- commit 45ada0d
* Mon Nov 28 2011 jeffm@suse.com
- Fix kernel-source spec to give ownership of the /usr/src/linux link
  to kernel-devel. kernel-source depends on kernel-devel, so this is correct.
- commit 7160a9c
* Mon Nov 28 2011 jbeulich@novell.com
- Refresh patches.xen/xen-pcpu-hotplug.
- Refresh patches.xen/xen3-patch-3.2-rc3.
- commit 7956240
* Mon Nov 28 2011 jbeulich@novell.com
- Update Xen patches to 3,2-rc3 and c/s 1127.
- Update frontswap patches to v10.
- config.conf: Re-enable Xen.
- Update config files.
- commit b08ea4f
* Mon Nov 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Ignore staging failures only in vanilla only
  branches.
- commit eeaaaf1
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: set omap_fb=y
- commit c1efd33
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: disable OMAP2 to fix reboots
- commit 2d07cf1
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable DVI
- commit 40ecc5c
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable ehci
- commit 96a74f9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard usb
- commit bab20e3
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard LAN
- commit db7157b
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: Align with non-arm configs
- commit 9a9b9ee
* Fri Nov 25 2011 agraf@suse.de
- new script common_config.sh: find identical config options
- commit 1562f91
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: enable devtmpfs on all targets
- commit 5c31b37
* Fri Nov 25 2011 jeffm@suse.com
- Update config files for vanilla.
- commit 4c5b0b9
* Fri Nov 25 2011 jeffm@suse.com
- Update to 3.2-rc3.
  - stack unwind: cfi_ignore takes more arguments.
  - iio: Fix build error in industrialio-core.c.
- commit 48ef020
* Thu Nov 24 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- commit d0bebdb
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/try-disable-staging-driver: Script to disable failing staging
  driver and restart make.
- commit 819d1fa
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not have a separate make invocation for
  s390 and the rest.
- commit d72f6c1
* Thu Nov 24 2011 agraf@suse.de
- ARM: Update config file file i.MX51 (disable i.MX53)
- commit 6557e92
* Wed Nov 23 2011 agraf@suse.de
- ARM: Refresh patches.arch/arm-phys-offset.patch. (fix warnings)
- commit 519c94a
* Wed Nov 23 2011 agraf@suse.de
- ARM: create uImage, not zImage, so we can boot with u-boot
- commit 63a7b2c
* Wed Nov 23 2011 agraf@suse.de
- ARM: Fix compile breakage for generic kernel.
- commit 9d31b12
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: fix several issues in 3.2
- commit 3488f8d
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: disable broken eth driver
- commit 3729fdf
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: run_oldconfig.sh
- commit ae90ef9
* Tue Nov 22 2011 agraf@suse.de
- ARM: fix run_oldconfig.sh
- commit 0362ed5
* Tue Nov 22 2011 agraf@suse.de
- ARM: Use zImage, not vmlinux
  On ARM we use the arch/arm/boot/zImage file similar to x86 to boot systems.
  Put that into the rpm as vmlinuz instead of the vmlinux ELF binary.
- commit 4c08eb0
* Tue Nov 22 2011 agraf@suse.de
- ARM: Dont generalize the target
  On ARM we can not build generic kernels that work through different generations,
  such as armv5 and armv7. So we better list them explicitly and not export an rpm
  that wouldn't even work on the respective architecture :).
- commit 854928d
* Thu Nov 17 2011 bpoirier@suse.de
- dm-raid45: split region hash and log, used by mirror and raid45.
- Update config files.
- commit a85f754
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc2.
  - Eliminated 1 patch.
- commit 85c9930
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc1.
  - Eliminate 212 patches.
- commit 6318d5b
* Mon Nov 14 2011 awafaa@opensuse.org
- Add package descriptions for ARM kernels
- Add ARM support for iMX51, OMAP2plus & Tegra SoC
- commit 51ebb2d
* Mon Nov 14 2011 jeffm@suse.com
- Updated incorrect Patch-mainline header.
- commit ef7dc61
* Sat Nov 12 2011 adrian@suse.de
- initial armv7l default kernel config, everything enable except the non compiling modules
- commit 7a5cd10
* Mon Nov  7 2011 neilb@suse.de
- sunrpc: wake up SOFTCONN tasks when a connection error happens
  (bnc#679059).
- commit f97b834
* Sat Nov  5 2011 trenn@suse.de
- X86: Solve Dell Latitudes do not reboot on x86_64 more
  generally.
- commit b3cc84a
* Thu Nov  3 2011 mszeredi@suse.cz
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
  hfs: fix hfs_find_init() sb->ext_tree NULL ptr oops
  (CVE-2011-2203 bnc#699709).
- commit 7923119
* Thu Nov  3 2011 tiwai@suse.de
- ALSA: hda/realtek - Skip invalid digital out pins (bnc#727348).
- ALSA: hda - Add missing static ADC tables for ALC269 quirks.
- commit 102bac3
* Thu Nov  3 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Add git commit ID.
- commit ee8439f
* Thu Nov  3 2011 jeffm@suse.com
- Re-disabled patches.xen/xencons-tty_mutex.patch
- commit 187dde0
* Thu Nov  3 2011 jeffm@suse.com
- Re-added patches accidentally dropped with commit 28551a0c.
- commit 3795fde
* Thu Nov  3 2011 jbeulich@novell.com
- Update Xen patches to 3.1-final and c/s 1123.
- commit 35973e8
* Wed Nov  2 2011 jeffm@suse.com
- Add Elantech touchpad v3/v4 support (bnc#716852):
  - Input: elantech - add v3 hardware support.
  - Input: elantech - add v4 hardware support.
  - Input: elantech - better support all those v2 variants.
  - Input: elantech - clean up elantech_init.
  - Input: elantech - correct x, y value range for v2 hardware.
  - Input: elantech - get rid of ETP_2FT_* in elantech.h.
  - Input: elantech - packet checking for v2 hardware.
  - Input: elantech - remove ETP_EDGE_FUZZ_V2.
  - Input: elantech - remove module parameter force_elantech.
  - Input: elantech - use firmware provided x, y ranges.
- commit 28551a0
* Sun Oct 30 2011 mmarek@suse.cz
- rpm/{arch-symbols,mkspec}: Add support for ARM
  The various ARM families need similar handling like i?86.
- commit 0c6be6b
* Thu Oct 27 2011 tiwai@suse.de
- ALSA: hda - Fix ADC input-amp handling for Cx20549 codec.
- ALSA: hda - Keep EAPD turned on for old Conexant chips.
- ALSA: hda/realtek - Fix missing volume controls with ALC260
  (bnc#726812).
- commit 08229b0
* Tue Oct 25 2011 ohering@suse.de
- tty deadlock in kernel-xen, xenconsole (bnc#726333).
- commit 68289aa
* Tue Oct 25 2011 eich@suse.de
-  patches.suse/SUSE-bootsplash: remove DEBUG macro which was
  left in the code by accident.
- commit a56ba15
* Mon Oct 24 2011 jeffm@suse.com
- Update to 3.1-final.
- commit ec0449c
* Mon Oct 24 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  Update comments in code and reduce patch size
- commit 8913d07
* Thu Oct 20 2011 eich@suse.de
- bootsplash: fix logo location when a splash image with an off-center
  logo is rescaled (bnc #722471).
- commit f6d77d4
* Tue Oct 18 2011 jeffm@suse.com
- -Update to 3.1-rc10.
- commit 239957e
* Fri Oct 14 2011 trenn@suse.de
- x86: Fix reboot issue for Dell Optiplex 990.
- commit 00ea2b5
* Fri Oct 14 2011 mmarek@suse.cz
- rpm/*.spec.in, rpm/mkspec: Generate specfiles according to Factory
  requirements.
- commit aebe2d9
* Thu Oct 13 2011 ohering@suse.de
- series.conf: really apply all hv_mouse patches
- commit 11f65b5
* Wed Oct 12 2011 ohering@suse.de
- Various updates for hv drivers, which fix also the hv_mouse driver
- staging: hv: storvsc: ignore SET_WINDOWN scsi command
  (bnc#722646).
- staging/hv: advertise hv_storvsc instead of storvsc as sysfs
  driver name (bnc#716708).
- staging/hv: fill scsi/proc_name for the sake of mkinitrd
  (bnc#716708).
- Staging: hv: util: Invoke cn_netlink_send() in a work context.
- Refresh patches.suse/staging-hv-pata_piix-ignore-disks.patch.
- Refresh patches.xen/xen3-patch-2.6.32.
- Delete patches.suse/staging-hv-vmbus-modalias-show.patch.
- commit c836841
* Wed Oct 12 2011 eich@suse.de
- SUSE-bootsplash: Don't crash when splash is turned off.
  Fix crash when splash is off (ie. (struct fb_info *)->splash_data == NULL)
  but someone tries to manipulate the splash image thru the /proc interface.
  All other functions in render.c seem to be save - ie. upper level code
  already protects them from being called if the splash_data member is NULL
  (bnc #718666).
- commit 2fc2aaf
* Tue Oct 11 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit d4a7ce4
* Fri Oct  7 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc9 and c/s 1116.
- commit 8f986a2
* Wed Oct  5 2011 jbeulich@novell.com
- patches.suse/supported-flag: Also look for Module.supported in the
  source tree.
- Refresh patches.suse/supported-flag-enterprise.
- commit 9c8680a
* Wed Oct  5 2011 jeffm@suse.com
- Update to 3.1-rc9.
- commit a477439
* Mon Oct  3 2011 jeffm@suse.com
- Update to 3.1-rc8.
- commit 6c33ac4
* Wed Sep 28 2011 jbeulich@novell.com
- Update Xen config files.
- commit 50fb02f
* Tue Sep 27 2011 eich@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix crash when updating boxes: Don't reallocate
  picture.
- commit ba0cfdc
* Mon Sep 26 2011 mmarek@suse.cz
- rpm/host-memcpy-hack.h: Hack to use older version of the memcpy symbol
  in userspace programs, so that they keep working on older systems.
- rpm/kernel-binary.spec.in: Pass -include
  %%_sourcedir/host-memcpy-hack.h to the compiler when compiling
  userspace programs.
- commit e3c78cf
* Mon Sep 26 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc7 and c/s 1105.
- pass PCI segment information to Xen.
- ACPI: Implement overriding of arbitrary ACPI tables via initrd.
- x86: allow NVS can be accessed by driver.
- commit 7de39e8
* Mon Sep 26 2011 jeffm@suse.com
- Update to 3.1-rc7.
- commit ee8cc90
* Thu Sep 22 2011 mmarek@suse.cz
- rpm/split-modules: Print the full path for modules missing in supported.conf
- commit e55e4c6
* Thu Sep 22 2011 mmarek@suse.cz
- supported.conf: Fix stray line making net/atm/atm suddenly unsupported.
- commit 58dbd06
* Wed Sep 21 2011 mmarek@suse.cz
- Add support for wildcards in supported.conf
- rpm/kernel-binary.spec.in: Generate Module.supported with all
  lines from supported conf, unsupported modules are marked as "no"
- rpm/split-modules: Use the supported flag in modules, instead of
  parsing the Module.supported file and report modules that have no
  supported marking.
- rpm/check-supported-list: Delete, this is done by split-modules
  now.
- commit edfdc2a
* Wed Sep 21 2011 trenn@suse.de
- Refresh
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
  - > Fix build on ia64, by moving asm/e820.h into ifdef config protected region.
- commit 0ac4276
* Wed Sep 21 2011 mhocko@suse.cz
- Provide memory controller swap extension.
  Keep the feature disabled by default. Use swapaccount=1 kernel
  boot parameter for enabling it.
- commit 000742c
* Wed Sep 21 2011 mhocko@suse.cz
- Update config files.
  Clean run_oldconfig.sh run to get configs into sync
- commit c985824
* Tue Sep 20 2011 trenn@suse.de
- ACPI: Implement overriding of arbitrary ACPI tables via initrd
  (none).
- ACPICA: Fix wrongly mapped acpi table header when overriding
  via initrd (none).
- ACPICA: Introduce acpi_os_phys_table_override function (none).
- x86: allow NVS can be accessed by driver (none).
- Update config files:
  CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
  on i386 and x86_64 flavors
- commit 34bb195
* Thu Sep 15 2011 jeffm@suse.de
- Update to 3.1-rc6.
- commit 8f0eaba
* Thu Sep 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix unwinding through
  interrupt frames, requiring ...
- patches.suse/stack-unwind: ... support for DW_CFA_def_cfa_expression.
- commit 4d917a5
* Wed Sep 14 2011 agraf@suse.de
- KVM: PPC: Fix incorrect CBE KVM hooks.
  There is another issue with KVM_HV and CBE that I only saw building
  this tree, so the patch is on its way to the kvm tree now.
- KVM: PPC: Assemble book3s{,_hv}_rmhandlers.S separately
  When building KVM HV mode with plenty other options enabled, the build
  fails. That's fixed upstream, but 3.1-rc5 doesn't have the patch yet.
  So I pulled it in from the kvm tree.
- commit 2be41bd
* Mon Sep 12 2011 jbeulich@novell.com
- Re-enabled patches.arch/x86_64-unwind-annotations.
- commit bfd10a0
* Mon Sep 12 2011 jbeulich@novell.com
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh patches.suse/supported-flag.
- commit aa89174
* Mon Sep 12 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc5 and c/s 1104.
- mm: frontswap: config and doc files.
- mm: frontswap: core code.
- mm: frontswap: add swap hooks and extend try_to_unuse.
- mm: frontswap: swap data structure changes.
- In HVM guests do not take over the CDROM device (bnc#645893).
- x86: report ACPI-reserved state of PCI MMCONFIG region to
  hypervisor.
- config.conf: Re-enable Xen flavors.
- Update config files.
- commit 3692f47
* Sun Sep 11 2011 agraf@suse.de
- Update config files (disable EHCA on PPC - gcc bug)
- commit 03a0c8c
* Sun Sep 11 2011 agraf@suse.de
- Update config files (enable KVM on PPC64 for OBS)
- commit 00b922d
* Mon Sep  5 2011 mmarek@suse.cz
- Update to 3.1-rc5 from https://github.com/torvalds/linux.git.
- commit 8a211c9
* Fri Sep  2 2011 ohering@suse.de
- Staging: hv: vmbus: Show the modalias in /sys/bus/vmbus/devices/*/
  (fate#311487).
- commit 94054c9
* Thu Sep  1 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- Staging: hv: vmbus: Don't wait indefinitely for IRQ resouces.
- Staging: hv: tools: Fix a checkpatch warning in hv_kvp_daemon.c.
- Staging: hv: vmbus: Fix checkpatch warnings.
- Staging: hv: util: kvp: Fix the reported OSVersion string.
- Staging: hv: util: kvp: Cleanup kvp_get_domain_name().
- Staging: hv: Fix macros, tab errors and warning in
  drivers/staging/hv/hv_mouse.c.
- Staging: hv: vmbus: VMBUS is an ACPI enumerated device, get
  rid of the PCI signature.
- Staging: hv: Replace struct hv_guid with the uuid type already
  defined in Linux.
- Staging: hv: vmbus: Introduce vmbus ID space in struct
  hv_driver.
- Staging: hv: blkvsc: Use the newly introduced vmbus ID in the
  blockvsc driver.
- Staging: hv: storvsc: Use the newly introduced vmbus ID in
  storvsc driver.
- Staging: hv: netvsc: Use the newly introduced vmbus ID in
  netvsc driver.
- Staging: hv: mousevsc: Use the newly introduced vmbus ID in
  mouse driver.
- Staging: hv: util: Make hv_utils a vmbus device driver.
- Staging: hv: create VMBUS_DEVICE macro and use it.
- Staging: hv: vmbus: Cleanup vmbus_match().
- Staging: hv: vmbus: Cleanup vmbus_uevent() code.
- Staging: hv: vmbus: Support the notion of id tables in
  vmbus_match().
- Staging: hv: vmbus: Get rid of an unnecessary include line
  in vmbus_drv.c.
- Staging: hv: storvsc: Get rid of the DMI signature.
- Staging: hv: netvsc: Get rid of the PCI signature.
- Staging: hv: netvsc: Get rid of the DMI signature in
  netvsc_drv.c.
- Staging: hv: util: Get rid of the DMI signature in hv_util.c.
- Staging: hv: util: Get rid of the PCI signature in hv_util.c.
- Staging: hv: fix up driver registering mess.
- Staging: hv: vmbus: Get rid of some unnecessary comments.
- Staging: hv: vmbus: Cleanup unnecessary comments in hv.c.
- Staging: hv: vmbus: Cleanup error handling in hv_init().
- Staging: hv: vmbus: Get rid of unnecessay comments in
  connection.c.
- Staging: hv: vmbus: Get rid of the function dump_gpadl_body().
- Staging: hv: vmbus: Get rid of the function dump_gpadl_header().
- Staging: hv: vmbus: Rename openMsg to open_msg in channel.c.
- Staging: hv: vmbus: Get rid of unnecessary comments in
  channel.c.
- Staging: hv: vmbus: Change the variable name openInfo to
  open_info in channel.c.
- Staging: hv: vmbus: Cleanup error values in ringbuffer.c.
- Staging: hv: vmbus: Cleanup the error return value in
  vmbus_recvpacket_raw().
- Staging: hv: netvsc: Get rid of an unnecessary print statement
  in netvsc_probe().
- Staging: hv: vmbus: Retry vmbus_post_msg() before giving up.
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_dev_add().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_channel_init().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_connect_to_vsp().
- Staging: hv: storvsc: Cleanup error handling in storvsc_do_io().
- Storage: hv: storvsc: Get rid of some unnecessary DPRINTs
  from storvsc.c.
- Staging: hv: storvsc: Fix/cleanup some dated comments in
  storvsc.c.
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_host_reset().
- Staging: hv: storvsc: Cleanup error code returned in
  storvsc_probe().
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_drv_init().
- Staging: hv: netvsc: Cleanup the returned error code in
  netvsc_probe().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_destroy_recv_buf().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_init_recv_buf().
- Staging: hv: netvsc: Cleanup error returns in
  netvsc_connect_vsp().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_send().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_device_add().
- Staging: hv: netvsc: Cleanup error codes in
  rndis_filter_receive().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_query_device().
- Staging: hv: netvsc: Cleanup error return values in
  rndis_filter_set_packet_filter().
- Staging: hv: netvsc: Cleanup error returns in
  rndis_filter_init_device().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_device_add().
- Staging: hv: mouse: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Exit to exit.
- Staging: hv: mouse: Get rid of the unused PCI signature.
- Staging: hv: hv_mouse: remove deviceinfo_callback function.
- Staging: hv: hv_mouse: remove inputreport_callback function.
- Staging: hv: hv_mouse: remove a forward declaration.
- Staging: hv: hv_mouse: fix up remove() function.
- Staging: hv: Add struct hv_vmbus_device_id to mod_devicetable.h.
- Staging: hv: add driver_data to hv_vmbus_device_id.
- Staging: hv: Add code to parse struct hv_vmbus_device_id table.
- Staging: hv: file2alias: fix up alias creation logic for
  hv_vmbus_device_id.
- Staging: hv: storvsc: Inline free_stor_device().
- Staging: hv: storvsc: Do not aquire an unnecessary reference
  on stor_device.
- Staging: hv: storvsc: Rename must_get_stor_device().
- Staging: hv: storvsc: Rename get_stor_device().
- Staging: hv: storvsc: Cleanup alloc_stor_device().
- Staging: hv: storvsc: Introduce state to manage the lifecycle
  of stor device.
- Staging: hv: storvsc: Prevent outgoing traffic when stor dev
  is being destroyed.
- Staging: hv: storvsc: Get rid of release_stor_device() by
  inlining the code.
- Staging: hv: storvsc: Get rid of final_release_stor_device()
  by inlining code.
- Staging: hv: storvsc: Get rid of the reference counting in
  struct storvsc_device.
- Staging: hv: netvsc: Inline the code for free_net_device().
- Staging: hv: netvsc: Cleanup alloc_net_device().
- Staging: hv: netvsc: Introduce state to manage the lifecycle
  of net device.
- Staging: hv: netvsc: Prevent outgoing traffic when netvsc dev
  is destroyed.
- Staging: hv: netvsc: Get rid of release_outbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of release_inbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of the refcnt field in struct
  netvsc_device.
- Staging: hv: storvsc: Add code to handle IDE devices using
  the storvsc driver.
- Staging: hv: storvsc: Handle IDE devices using the storvsc
  driver.
- Staging: hv: blkvsc: Get rid of blkvsc_drv.c as this code is
  not used.
- Staging: hv: storvsc: Optimize bounce buffer handling for the
  "write" case.
- Staging: hv: storvsc: Optimize the bounce buffer handling in
  the "read" case.
- Staging: hv: storvsc: Include storvsc.c in storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of storvsc.c.
- Staging: hv: storvsc: Add the contents of hyperv_storage.h
  to storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of hyperv_storage.h.
- Staging: hv: storvsc: Fixup srb and scsi status for INQUIRY
  and MODE_SENSE.
- Staging: hv: storvsc: Fix a typo.
- Staging: hv: storvsc: In case of scsi errors offline the device.
- Staging: hv: storvsc: No need to copy from bounce buffer in
  case of a failure.
- Staging: hv: util: Forcefully shutdown when shutdown is
  requested.
- Staging: hv: util: Adjust guest time in a process context.
- Staging: hv: vmbus: Check before invoking the channel callback.
- Staging: hv: vmbus: Properly deal with de-registering channel
  callback.
- Staging: hv: Fix a bug in vmbus_match().
- Staging: hv: vmbus: Get rid of vmbus_on_isr() by inlining
  the code.
- Staging: hv: vmbus: Do not enable auto eoi.
- Staging: hv: vmbus: Fixup indentation in vmbus_acpi_add().
- Staging: hv: vmbus: Get rid of some dated/redundant comments.
- Staging: hv: vmbus: Get rid of an unnecessary check in
  vmbus_connect().
- Staging: hv: vmbus: Fix a checkpatch warning in ring_buffer.c.
- Staging: hv: vmbus: Fix checkpatch warnings in connection.c.
- Staging: hv: mousevsc: Fix checkpatch errors and warnings.
- Staging: hv: netvsc: return negative error codes.
- Delete patches.suse/staging-hv-vmbus-init-on-dmi-match.patch.
- commit d77df1b
* Tue Aug 30 2011 jdelvare@suse.de
- Delete patches.fixes/net-tulip-debug-off-by-default.patch.
  Obsoleted by upstream commit 0b8f6273eb6fd0611849d6fb432151f04e042434.
- commit bd9ecd2
* Tue Aug 30 2011 gregkh@suse.de
- supported.conf: xhci-hcd not xhci. Also move it to base so you can boot
  off of a USB3 device (bnc#712752)
- commit f6522ba
* Mon Aug 29 2011 jeffm@suse.com
- Re-Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit 626749c
* Mon Aug 29 2011 jeffm@suse.com
- Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit e82bcac
* Mon Aug 29 2011 jeffm@suse.com
- Disabled patches.rpmify/pti-depends-on-x86-pci
- commit 0baba30
* Mon Aug 29 2011 jeffm@suse.com
- Update to 3.1-rc4.
- commit 68e08b1
* Wed Aug 24 2011 jeffm@suse.com
- PTI: depends on X86 && PCI.
- commit e975e4b
* Wed Aug 24 2011 jeffm@suse.com
- scsi_dh_alua: always update TPGS status on activate.
- scsi_dh: Check for sdev state in store_dh_state() (bnc#616080).
- scsi_dh_alua: Evaluate TPGS setting from inquiry data.
- scsi_dh: Implement match callback function.
- Delete patches.fixes/scsi-dh-alua-retry-UA.
- Delete patches.fixes/scsi-dh-alua-send-stpg.
- commit 58d8073
* Wed Aug 24 2011 jeffm@suse.com
- Refresh and re-enable patches.arch/x86_64-hpet-64bit-timer.patch.
- commit 7d43f4b
* Wed Aug 24 2011 jeffm@suse.com
- Refreshed and re-enabled dm-path patches:
  - patches.suse/dm-mpath-accept-failed-paths.
  - patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit 70cadcd
* Wed Aug 24 2011 jeffm@suse.com
- Update to 3.1-rc3.
  - Eliminated 8 patches.
  - Xen is disabled.
- commit eccefcc
* Thu Aug 18 2011 eich@suse.de
- * Refresh patches.suse/SUSE-bootsplash.
  * Fix bootsplash code for 15bpp framebuffers.
  These framebuffers are rare these days, the legendary and still
  popular server chipset Radeon ES1000 supports it, though.
- commit f25ce3e
* Sun Aug 14 2011 trenn@suse.de
- Properly destroy pmsr devices:
  Refresh patches.xen/xen-x86-msr-on-pcpu.
- commit 934d81a
* Sat Aug 13 2011 gregkh@suse.de
- Update config files, enabling CONFIG_RT2800PCI as requested.
- commit b2f65f0
* Mon Aug  8 2011 trenn@suse.de
- Update config files:
  bnc#674988, change:
  - CONFIG_ACPI_CUSTOM_METHOD=m
  +# CONFIG_ACPI_CUSTOM_METHOD is not set
  for all flavors
- commit f1af972
* Mon Aug  1 2011 mmarek@suse.cz
- rpm/modversions: Support for new genksyms format with E# tags for enum
  constants.
- commit ee6da8c
* Fri Jul 29 2011 jslaby@suse.cz
- tg3: Fix io failures after chip reset (bnc#705962).
- commit c8d864c
* Mon Jul 25 2011 mmarek@suse.cz
- Fix format of patches to apply with series2git:
  patches.arch/s390-message-catalog.diff
  patches.drivers/input-Add-LED-support-to-Synaptics-device
  patches.fixes/kvm-macos.patch
  patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch
  patches.fixes/nfs-slot-table-alloc
  patches.fixes/oom-warning
  patches.fixes/scsi-dh-alua-send-stpg
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch
  patches.suse/0015-ext4-Use-IS_POSIXACL-to-check-for-POSIX-ACL-support.patch
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch
  patches.suse/dm-mpath-no-activate-for-offlined-paths
  patches.suse/dm-mpath-no-partitions-feature
  patches.suse/no-frame-pointer-select
  patches.suse/no-partition-scan
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops
  patches.suse/setuid-dumpable-wrongdir
  patches.suse/stack-unwind
  patches.suse/supported-flag-enterprise
- commit b5f5212
* Mon Jul 25 2011 meissner@suse.de
- Powerpc config adjustments
  This makes CONFIG_POWER_SUPPLY=y like in the other architectures,
  it also disables the EHCA driver as gcc 4.6 currently fails to compile
  it correctly.
- commit aa27d23
* Sun Jul 24 2011 jslaby@suse.cz
- fix crash in scsi_dispatch_cmd() (bnc#707853).
- commit dfe0dcf
* Fri Jul 22 2011 mmarek@suse.cz
- Update to 3.0.
- commit 50c05d7
* Thu Jul 21 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc7 and c/s 1098.
- Update Xen config files.
- commit f4eb207
* Mon Jul 18 2011 jdelvare@suse.de
- tulip: Disable debugging messages by default
- commit 141a54f
* Fri Jul 15 2011 ohering@suse.de
- hv: only load the driver in a hyper-v guest (bnc#704957).
- commit f2f7449
* Thu Jul 14 2011 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.  Fix for nouveau.
- commit 27de298
* Thu Jul 14 2011 tiwai@suse.de
- ALSA: hda - Add Kconfig for the default buffer size
  (bnc#682725).
- Update config files.
- Delete, replaced with the new upstream patch
  patches.drivers/alsa-hda-0019-Increase-default-buffer-size.
- commit 40c7644
* Wed Jul 13 2011 jeffm@suse.com
- Update to 3.0-rc7.
- commit 0de37e1
* Sat Jul  9 2011 jslaby@suse.cz
- Delete patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Delete patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
  They were superseded by other patches in
  aa3d6e2b140aac24a432f830d30047b1842aed0b.
- commit e95707d
* Wed Jul  6 2011 jeffm@suse.com
- Update to 3.0-rc6.
  - Eliminated 1 patch.
- commit 56e99da
* Tue Jul  5 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc5 and c/s 1095.
- xen: prepare tmem shim to handle frontswap.
- support booting Xen from EFI (fate#311376, fate#311529,
  bnc#578927, bnc#628554).
- config.conf: Re-enabled Xen flavors.
- Update x86 config files.
- Delete patches.xen/xen-blkback-bimodal-suse.
- commit 4c2a76f
* Mon Jul  4 2011 tiwai@suse.de
- Fix invalid colormap override in SUSE-bootsplash patch (bnc#584493)
- commit ac30089
* Wed Jun 29 2011 jeffm@suse.com
- Update to 3.0-rc5.
- commit 9eb1a0f
* Wed Jun 29 2011 jslaby@suse.cz
- TTY: ldisc, do not close until there are readers (bnc#698247
  bnc#693374).
- commit b3afb1a
* Fri Jun 24 2011 jeffm@suse.com
- Enable TOMOYO (FATE#310292, bnc#668381).
- commit 997e757
* Tue Jun 21 2011 mmarek@suse.cz
- Update vanilla configs.
- commit 1738011
* Tue Jun 21 2011 mmarek@suse.cz
- Update to 3.0-rc4
- commit 1b6bf5d
* Fri Jun 17 2011 mmarek@suse.cz
- rpm/post.sh: Touch /boot/do_purge_kernels on package install
  (fate#312018).
- rpm/postun.sh: Remove it again if it still exists on package
  uninstall.
- commit 82f4a5d
* Fri Jun 17 2011 trenn@suse.de
- stop_machine: implement stop_machine_from_offline_cpu()
  (bnc#697859).
- stop_machine: kill __stop_machine() (bnc#697859).
- x86, mtrr: lock stop machine during MTRR rendezvous sequence
  (bnc#697859).
- stop_machine: reorganize stop_cpus() implementation
  (bnc#697859).
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#697859).
- commit aa3d6e2
* Thu Jun 16 2011 mmarek@suse.cz
- Remove the novfs patches, it should be packaged as a KMP, or
  ideally, reimplemented as a fuse filesystem (which is the reason why
  the current implementation it is never going to be accepted upstream).
- Delete patches.fixes/novfs-copy_user-fixes.diff.
- Delete patches.fixes/novfs-minsize-fixes.
- Delete patches.fixes/novfs-nwcapi.patch.
- Delete patches.suse/novfs-client-module.
- Delete patches.suse/novfs-remove-bkl.
- commit bc3a79d
* Thu Jun 16 2011 ohering@suse.de
- Update vanilla config files.
- commit a642909
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  jobs is not defined for home: projects, use the new _smp_mflags to enable parallel build
- commit 1009eaf
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  Update comment, get the number of cpus from /proc/stat
- commit b4cf18c
* Wed Jun 15 2011 jeffm@suse.com
- Update config files: Disable BRCMSMAC on ppc/ppc64.
- commit 20b3d8e
* Wed Jun 15 2011 jack@suse.cz
- "Unable to save Login Script" appears when trying to save a
  user login script (bnc#638985).
- commit 7c243a4
* Wed Jun 15 2011 jack@suse.cz
- fs: novfs: Limit check for datacopy between user and kernel space.
- commit 5fbc5ed
* Wed Jun 15 2011 jeffm@suse.com
- Update to 3.0-rc3.
  - Eliminated 2 patches.
- commit a1fe999
* Tue Jun 14 2011 mmarek@suse.cz
- scripts/config.sh: Remove MIRROR handling, _find_tarball() does it
  itself.
- commit 18ad47f
* Mon Jun 13 2011 jeffm@suse.com
- nouveau: Make vga_switcheroo code depend on VGA_SWITCHEROO.
- commit b3f32a6
* Mon Jun 13 2011 jeffm@suse.com
- apm: Honor CONFIG_APM_CPU_IDLE=n.
- commit 8ad9b51
* Mon Jun 13 2011 jeffm@suse.com
- Update config files.
- commit 2cd7359
* Mon Jun 13 2011 jeffm@suse.com
- Delete patches.rpmify/qla4xx-missing-readq-definition.
- commit b48337d
* Mon Jun 13 2011 mmarek@suse.cz
- Remove copypasted lines from vanilla configs.
- commit b395e52
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Call gzip with -n.
- commit 9a65e48
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/mkspec: Put the -rcX tag into the rpm version instead of the
  trailing zero. Rpm considers "rc" older than "0", so this will sort
  properly.
- commit 8d9b2b9
* Mon Jun 13 2011 mmarek@suse.cz
- x86, build: Do not set the root_dev field in bzImage.
- commit 15e4a82
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/kernel-binary.spec.in: Revert the previous hack.
- commit 95c9977
* Sat Jun 11 2011 jeffm@suse.de
- kbuild: Fix KERNELVERSION for empty SUBLEVEL or PATCHLEVEL.
- kbuild: Fix <linux/version.h> for empty SUBLEVEL or PATCHLEVEL.
- Refresh patches.suse/supported-flag.
- rpm/kernel-binary.spec.in: Hack to work around v3.0 vs v3.0.0
- commit a95ebd8
* Fri Jun 10 2011 jeffm@suse.com
- Delete patches.suse/file-capabilities-disable-by-default.diff.
- commit 2694a88
* Fri Jun 10 2011 jeffm@suse.com
- x86: Remove warning and warning_symbol from struct
  stacktrace_ops.
- Delete
  patches.fixes/asus-wmi-Remove-__init-from-asus_wmi_platform_init.patch.
- commit 608ce9e
* Fri Jun 10 2011 trenn@suse.de
- Update Suresh's patchset to version 3:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 9f2e923
* Wed Jun  8 2011 jeffm@suse.com
- Revert "Revert "- Updated to 3.0-rc1.""
  This reverts commit b2d9e72dc9cd8e62d49e0565babd76332f7c2114.
  Conflicts:
  rpm/config.sh
  series.conf
- commit 408e273
* Wed Jun  8 2011 jeffm@suse.com
- Update to 3.0-rc2.
- commit b97d26c
* Wed Jun  8 2011 trenn@suse.de
- Update Suresh's version 2 of the patchseries:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 4ef8999
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for empty EXTRAVERSION
- commit a0a1386
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for 3.0
- commit dca1465
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/mkspec: Fix perl warning
- commit 395d7d8
* Tue Jun  7 2011 trenn@suse.de
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#672008).
- stop_machine: enable __stop_machine() to be called from the
  cpu online path (bnc#672008).
- commit 684cd78
* Mon Jun  6 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Loosen the mkinitrd requirement, this was
  only a workaround for a 11.3 update problem (cf bnc#615680).
- commit 05ade7d
* Sun Jun  5 2011 jslaby@suse.cz
- asus-wmi: Remove __init from asus_wmi_platform_init
  (bnc#696212).
- commit 2e6cc6b
* Fri Jun  3 2011 mmarek@suse.cz
- Temporarily set PPC_DISABLE_WERROR=y in power to fix build
- commit 5e9cb3b
* Fri Jun  3 2011 mmarek@suse.cz
- scripts/kmsg-doc: Do not require Switch.pm.
- commit 83a39c7
* Fri Jun  3 2011 mmarek@suse.cz
- rpm/macros.kernel-source: Add -b option to %%kernel_module_package
  to unconditionally call mkinitrd on kmp install (fate#309400).
- rpm/kernel-module-subpackage: Pass KMP_NEEDS_MKINITRD=1 to
  weak-modules2 if the -b option is used.
- commit 83331f5
* Wed Jun  1 2011 jbeulich@novell.com
- Delete patches.xen/sfc-* (as advised by Solarflare).
- commit a144c73
* Tue May 31 2011 jeffm@suse.com
- Revert "- Updated to 3.0-rc1."
  This reverts commit 5710413eb834b0f215f6f4249d6ff7c3f7673eb7.
  Should have been committed to the merge-v3.0 branch.
- commit b2d9e72
* Tue May 31 2011 jeffm@suse.com
- Updated to 3.0-rc1.
  - Eliminated 9 patches.
- commit 5710413
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit d3e465a
* Mon May 30 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
- aic94xx: world-writable sysfs update_bios file.
  Update upstream info.
- commit 8912816
* Fri May 27 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Set KBUILD_BUILD_{USER,HOST} to
  geeko@buildhost, obsoleting the patch to scripts/mkcompile_h.
- commit b4b7255
* Mon May 23 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39 final and c/s 1085.
- xen/sfc_netfront: fix an unused variable error.
- commit 3b6edff
* Fri May 20 2011 jslaby@suse.cz
- PM: Print a warning if firmware is requested when tasks are
  frozen (bnc#695219).
- commit e78f4ce
* Fri May 20 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
  Bah, cherry-picked a wrong version. Fix it.
- commit f9674b8
* Fri May 20 2011 jslaby@suse.cz
- Delete patches.suse/slab-handle-memoryless-nodes-v2a.patch.
  It was part of removed SoN patches.
- commit 1d0599a
* Fri May 20 2011 jeffm@suse.com
- Updated to 2.6.39-final.
- commit 7c72384
* Thu May 19 2011 jbeulich@novell.com
- supported.conf: blktap2 modules are supported.
- commit fa60394
* Mon May 16 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add the commit hash to uname -v, cleanup.
- commit f3bdb4c
* Fri May 13 2011 jeffm@suse.com
- Update to 2.6.39-rc7.
  - Eliminated 5 patches.
- commit a8a170f
* Thu May 12 2011 jslaby@suse.cz
- block: add proper state guards to __elv_next_request.
- commit bcb6433
* Thu May 12 2011 jslaby@suse.cz
- Delete
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  It's fixed differently by commits 43f12d47f and f844a709a7 in .39-rc1
- commit 7934e2d
* Thu May 12 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  Note about submission.
- commit 9922e20
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/files-slab-rcu.patch.
- commit 6547edf
* Tue May 10 2011 mhocko@suse.cz
- patches.fixes/aggressive-zone-reclaim.patch: delete because
  the patch is very workload specific and can lead to unexpected
  reclaims in parallel node local workloads.
- commit 56cf10e
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/mm-devzero-optimisation.patch: we do not need
  it anymore as we have zero page back since 2.6.32
- commit 323a093
* Tue May 10 2011 mmarek@suse.cz
- Really delete patches.fixes/aggressive-zone-reclaim.patch.
- commit b21d4b6
* Mon May  9 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc6.
- commit b976a7e
* Mon May  9 2011 jbeulich@novell.com
- patches.suse/kconfig-automate-kernel-desktop: Remove stray blank
  lines (for older versions of "patch" to grok).
- commit 4dfa74d
* Sat May  7 2011 jeffm@suse.com
- Removed network driver entropy patches. haveged is installed by default
  and should be enabled to generate entropy from non-predictable sources.
  - Delete patches.drivers/bnx2-entropy-source.patch.
  - Delete patches.drivers/e1000-entropy-source.patch.
  - Delete patches.drivers/e1000e-entropy-source.patch.
  - Delete patches.drivers/igb-entropy-source.patch.
  - Delete patches.drivers/ixgbe-entropy-source.patch.
  - Delete patches.drivers/tg3-entropy-source.patch.
- commit c88b893
* Fri May  6 2011 jeffm@suse.com
- Update
  patches.fixes/netfilter-implement-rfc-1123-for-ftp-conntrack
  (bnc#466279 bnc#681639).
- commit 72e779f
* Fri May  6 2011 jeffm@suse.com
- Disabled patches.drivers/libata-unlock-hpa-by-default; It may have
  been obsoleted by upstream commit d8d9129e.
- commit 1a21ab3
* Fri May  6 2011 jeffm@suse.com
- sysctl: Increase IPC defaults (bnc#146656)
  - Delete patches.suse/shmall-bigger.
- commit a70e34f
* Fri May  6 2011 jeffm@suse.com
- sysctl/i386/desktop, sysctl/x86_64/desktop: Add vm.dirty_ratio = 20
  for desktop flavors (bnc#552883)
  - Delete patches.suse/mm-tune-dirty-limits.patch.
- commit dbe73e2
* Fri May  6 2011 jeffm@suse.com
- sysctl/defaults: Added kernel.hung_task_timeout=0
  - Delete patches.suse/hung_task_timeout-configurable-default.
- commit 78f9eed
* Fri May  6 2011 mmarek@suse.cz
- rpm/kernel-{binary,source}.spec.in: Install per-kernel /boot/sysctl-*
  files (patch from Jeff Mahoney).
- commit 473f2d1
* Thu May  5 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 97ce5d8
* Thu May  5 2011 jeffm@suse.com
- Updated to 2.6.39-rc6.
  - 2 patches eliminated.
- commit 2643e59
* Tue May  3 2011 tonyj@suse.de
- Delete patches.fixes/oprofile_bios_ctr.patch.
- Delete patches.suse/kdump-dump_after_notifier.patch.
- commit 012455a
* Fri Apr 29 2011 jeffm@suse.com
- rpm/compute-PATCHVERSION.sh: Replace ^+++ with ^\+\+\+ as an
    awk regex. It's technically invalid.
- commit 52dd0f0
* Fri Apr 29 2011 sjayaraman@suse.de
- Delete patches.suse/sched-revert-latency-defaults.
- commit 90be226
* Fri Apr 29 2011 tiwai@suse.de
- Delete patches.arch/ppc-ipic-suspend-without-83xx-fix.
- Delete patches.arch/x86-hpet-pre-read.
- commit 3489146
* Thu Apr 28 2011 gregkh@suse.de
- Delete patches.suse/linux-2.6.29-dont-wait-for-mouse.patch.
- Delete patches.suse/linux-2.6.29-even-faster-kms.patch.
- Delete
  patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch.
- Delete patches.suse/linux-2.6.29-kms-after-sata.patch.
- Delete patches.suse/linux-2.6.29-touchkit.patch.
- commit c13427d
* Thu Apr 28 2011 jbenc@suse.cz
- Delete patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch.
- commit df46fe0
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.xen/xen3-x86-mcp51-no-dac.
  Also remove the series.conf entires for the x86-mcp-no-dac patches.
- commit 574577b
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.arch/x86-mcp51-no-dac.  (This is a blacklist entry that
  has been rejected by the mainline, the problem reporter is gone and
  it's next to impossible to verify it now.)
- commit 195b113
* Thu Apr 28 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
- commit a2662ae
* Thu Apr 28 2011 jslaby@suse.cz
- Delete patches.suse/wireless-no-aes-select.
  Optimized x86 AES implementations select CRYPTO_AES themselves. So we
  don't need the patch anymore -- AES is selected always.
- commit 88f80fa
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch.
- commit 9917206
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch.
- commit 08374b3
* Thu Apr 28 2011 jeffm@suse.com
- Delete patches.suse/audit-export-logging.patch.
- commit de054eb
* Thu Apr 28 2011 jbeulich@novell.com
- Update i386 Xen config files.
- commit 7b776ee
* Thu Apr 28 2011 jack@suse.cz
- Fix checking of login id (bnc#626119).
- commit 3f71ac4
* Thu Apr 28 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc5.
- Delete patches.xen/xen3-seccomp-disable-tsc-option.
- Delete patches.xen/xen3-x86-mark_rodata_rw.patch.
- commit 81fdf67
* Wed Apr 27 2011 jeffm@suse.com
- Delete
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch.
- commit 399a100
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/x86_agpgart-g33-stoeln-fix-2.patch.
- commit e5c964a
* Wed Apr 27 2011 jeffm@suse.com
- Merged patches.fixes/fix-nf_conntrack_slp into patches.suse/netfilter-ip_conntrack_slp.patch.
- commit 213a0d5
* Wed Apr 27 2011 jeffm@suse.com
- Removed Swap-over-NFS patches.
- commit e061d16
* Wed Apr 27 2011 jeffm@suse.com
- Unified novfs patches into patches.suse/novfs-client-module.
- commit 3f8a199
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/reiserfs-remove-2-tb-file-size-limit.
- commit 2d63b14
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/mm-increase-dirty-limits.patch: Replaced by patches.suse/mm-tune-dirty-limits.patch
- commit 4f8033f
* Wed Apr 27 2011 jeffm@suse.com
- series.conf: Removed commented out patches for cpuidle. The patches themselves are long gone.
- commit 93ce9f3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/acpi-export-hotplug_execute: ACPI_DOCK is now a boolean.
- commit f178332
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch.
- commit 5a2eae2
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-don-t-preempt-until-the-system-is-up.
- Delete
  patches.suse/acpi-generic-initramfs-table-override-support.
- Delete patches.suse/add-initramfs-file_read_write.
- Delete
  patches.suse/init-move-populate_rootfs-back-to-start_kernel.
- commit d4910b3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/nfs-acl-caching.diff.
- Delete patches.suse/nfsacl-client-cache-CHECK.diff.
- commit e1a5c5c
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/osync-error. It was unused and the issue it fixed in
  kernels prior to 2.6.32 doesn't exist anymore.
- commit 52cc654
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/s390-System.map.diff: Proper fix in binutils has
  long since been upstream.
- commit 2847a36
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/x86-mark_rodata_rw.patch: Removed as promised.
- commit f196f98
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/ia64-page-migration.
- Delete patches.arch/ia64-page-migration.fix.
- Delete patches.arch/mm-avoid-bad-page-on-lru.
- commit e469a91
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default: Update patch-mainline.
- commit 4bcc987
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/seccomp-disable-tsc-option: Unused in all configs.
- commit 0833556
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/unmap_vmas-lat: No bug report or signed-off-by.
  - Delete patches.arch/s390-add-FREE_PTE_NR.
- commit 2a392c2
* Wed Apr 27 2011 jeffm@suse.com
- Updated Patch-mainline for  patches.fixes/ia64-sparse-fixes.diff.
- commit d79b32f
* Wed Apr 27 2011 jeffm@suse.com
- Update to 2.6.39-rc5.
  - Eliminated 2 patches.
- commit 5288a05
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/export-release_open_intent.
- Delete patches.suse/export-security_inode_permission.
- commit 5cd669f
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.trace/utrace-core.
- commit a9639aa
* Tue Apr 26 2011 jkosina@suse.cz
- HID: add noget quirk barcode scanners from Symbol Technologies
  (bnc#689290).
- commit f5b999f
* Thu Apr 21 2011 jeffm@suse.com
- Delete patches.suse/nameif-track-rename.patch: The same info is made available via udev.
- commit e74929e
* Tue Apr 19 2011 jack@suse.cz
- Revert changes to sparc configs to not make life harder for Jan Engelhardt
  maintaining sparc architecture.
- commit cdac873
* Tue Apr 19 2011 jack@suse.cz
- config.conf: Remove sparc as it is maintained separately by Jan Engelhardt
- commit 91307e3
* Tue Apr 19 2011 jack@suse.cz
- Update vanilla config files.
- commit 5e3c232
* Tue Apr 19 2011 jeffm@suse.com
- Updated to 2.6.39-rc4.
  - Eliminated 1 patch.
- commit 3f654c8
* Tue Apr 19 2011 jeffm@suse.com
- libata: DVR-216D can't do SETXFER DVD-RW DVR-216D (bnc#679143).
- commit b09d00e
* Mon Apr 18 2011 eich@suse.de
- Combined and consolidated bootsplash patch (bnc#669777,
  bnc#570082, bnc#595657, bnc#594209, bnc#544645).
  - Delete patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch.
  - Delete patches.suse/bootsplash.
  - Delete patches.suse/bootsplash-console-fix.
  - Delete patches.suse/bootsplash-keep-multiple-data.
  - Delete patches.suse/bootsplash-scaler.
  - Reformatted code, fixed some minor bugs that became obvious.
  - Fixed race that led to null pointer dereference in splash_read_proc():
    bnc#669777.
- commit 95844c5
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Add a boot param to keep flushing TLBs (bnc#675161).
- commit 02c0d8a
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Make lapic_timer_reliable_states a boot param
  (bnc#675161).
- commit 85b156b
* Fri Apr 15 2011 jack@suse.cz
- Disable ext2, use ext4 instead as a driver
- Update config files.
- commit 2601b15
* Fri Apr 15 2011 jeffm@suse.com
- Enabled CONFIG_GIGASET_CAPI (bnc#686008).
  - This results in automatically disabling CONFIG_GIGASET_I4L.
- commit 697e68b
* Fri Apr 15 2011 jack@suse.cz
- novfs: Set the sticky bit for the novfs mountpoint (bnc#686412).
- commit 860f111
* Fri Apr 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add.
- commit 728e154
* Fri Apr 15 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc3 and c/s 1079.
- blktap2: replace hard-coded limit of tap devices with
  configurable one.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit d3bfd6c
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
- commit 385b393
* Thu Apr 14 2011 jeffm@suse.com
- scsi: aic94xx: world-writable sysfs update_bios file.
- commit 7f827e6
* Wed Apr 13 2011 jeffm@suse.com
- mpc5xxx_can: Fix typo causing build failure (of_dev -> ofdev).
- ft1000: Remove unnecessary EXPORT_SYMBOLs.
- commit 62653bb
* Wed Apr 13 2011 jeffm@suse.de
- fhandle: Add <linux/personality.h> for ia64.
- commit 83cec5a
* Wed Apr 13 2011 jeffm@suse.com
- kvm: Fix off by one in kvm_for_each_vcpu iteration.
- commit 4e5c2b7
* Wed Apr 13 2011 jeffm@suse.com
- rts_pstor: Add <linux/vmalloc.h>.
- rts_pstor: use #ifdef instead of #if.
- commit caa5347
* Tue Apr 12 2011 jeffm@suse.com
- gma500: Depend on X86.
- commit 3aa298c
* Tue Apr 12 2011 jeffm@suse.com
- Updated to 2.6.39-rc3.
  - Eliminated 2 patches.
- commit 200c913
* Tue Apr 12 2011 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: remove <linux/smp_lock.h>
- commit d7c79f2
* Tue Apr 12 2011 jeffm@suse.com
- olpc: Add <linux/delay.h>.
- commit 58ce0db
* Tue Apr 12 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 52fe306
* Tue Apr 12 2011 jeffm@suse.com
- Update to 2.6.39-rc2.
  - Eliminated 18 patches.
  - Added 3 patches.
  - hv_mouse: needs <linux/delay.h>.
  - dm-raid45: Remove blk_unplug calls.
  - novfs: 2.6.39 API update.
  - Xen, Swap-over-NFS, and certain SCSI multipath features are disabled.
  - patches.kernel.org is no longer used to contain upstream patches
    for -rc releases. Users planning on building their own kernel should
    have a copy of the tarball corresponding to the -rc releases.
- commit adf9d16
* Mon Apr 11 2011 neilb@suse.de
- Make selection of 'readdir-plus' adapt to usage patterns
  (bnc#678123).
- commit 5de99a8
* Wed Apr  6 2011 jeffm@suse.de
- reiserfs: Force inode evictions before umount to avoid crash
  (bnc#610598 bnc#680073 bnc#684112).
- Delete patches.fixes/reiserfs-xattr-crash-fix.
- commit bf57d20
* Tue Apr  5 2011 jslaby@suse.cz
- remove obsolete comment from series.conf
- commit 4bad172
* Wed Mar 30 2011 jeffm@suse.com
- Delete patches.suse/twofish-2.6.
  - This was for 2.4 compatibility and has been moved to KMP purgatory.
- commit dcca506
* Wed Mar 30 2011 jslaby@suse.cz
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
  (bnc#681826).
- commit 2e71042
* Mon Mar 28 2011 trenn@suse.de
- Update config files, remove CONFIG_X86_MCE_XEON75XX=m
  - >driver got reverted with previous commit
- Refresh patches.xen/xen3-auto-arch-x86.diff.
- commit b367e7b
* Mon Mar 28 2011 trenn@suse.de
- Remove xeon75xx driver, was intended as a SLE11 SP1 workaround
  to decode physical memory address on Boxboro-EX for MCEs.
  APEI implementation should take care of that in recent kernels.
- Delete patches.arch/x86_mce_intel_decode_physical_address.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch.
- commit 1fe7a22
* Mon Mar 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not install unneeded packages in the
  build chroot.
- commit 7f4c49d
* Mon Mar 28 2011 tiwai@suse.de
- ALSA: hda - Increase the default buffer size (682725).
- ALSA: hda - Fix pin-config of Gigabyte mobo (bnc#677256).
- commit 8088cec
* Thu Mar 24 2011 tiwai@suse.de
- ALSA: hda - Fix SPDIF out regression on ALC889 (bnc#679588).
- commit 5253098
* Thu Mar 24 2011 jslaby@suse.cz
- Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing
  the signal code (bnc#681826 CVE-2011-1020).
- commit 2e42fd4
* Thu Mar 24 2011 tiwai@suse.de
- sound/oss/opl3: validate voice and channel indexes (bnc#681999).
- sound/oss: remove offset from load_patch callbacks (bnc#681999).
- ALSA: sound/pci/asihpi: check adapter index in hpi_ioctl
  (bnc#680816).
- commit 09ff6e9
* Mon Mar 21 2011 jack@suse.cz
- Fix almost-infinite slab cache growing (bnc#554081).
- commit 52eabac
* Mon Mar 21 2011 jkosina@suse.cz
- HID: add support for Skycable 0x3f07 wireless presenter
  (bnc#681297).
- commit 892e8d4
* Mon Mar 21 2011 mmarek@suse.cz
- Delete config/i386/vmi, it was an artifact from SLE11-SP1 development.
- commit 9c2342b
* Fri Mar 18 2011 jslaby@suse.cz
- NET: cdc-phonet, handle empty phonet header (bnc#673992).
- commit da6e6d1
* Fri Mar 18 2011 jslaby@suse.cz
- SPI: dw_spi, fix PPC build.
- commit 80ca063
* Fri Mar 18 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38 and c/s 1073.
- commit 89cb2b4
* Thu Mar 17 2011 sjayaraman@suse.de
- netvm: Do not mark requests for swapfile writes as dirty or
  kswapd fails to free the page (bnc#678472).
- nfs: Use page_file_offset during page writeback (bnc#677738).
- nfs: Convert nfs_mark_request_dirty() to use page_file_mapping()
  (bnc#677738).
- netvm: Remove duplicated initialization in net/ipv4/route.c
  (bnc#678970).
- collapse: mm: Report the low watermark correctly (bnc#678497).
- commit a798dd1
* Tue Mar 15 2011 jeffm@suse.com
- Update to 2.6.38.
- commit f2ec6ad
* Mon Mar 14 2011 jeffm@suse.com
- Linux: 2.6.38-rc8.
  - Eliminated 1 patch.
- commit 7da557d
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc7 and c/s 1072
- pv-ops blktap2.
- adjust xen build after addition of pv-ops' blktap2.
- blktap: Fix reference to freed struct request.
- cleanup to blkback and blktap.
- apply xen specific patch to the Chelsio ethernet drivers.
- Update Xen config files.
- commit 289ecca
* Fri Mar 11 2011 jbeulich@novell.com
- fix i386 unwind annotations.
- commit 02bd501
* Tue Mar  8 2011 jeffm@suse.de
- Update to 2.6.38-rc7.
  - Refresh patches.xen/xen-x86-no-lapic.
  - Refresh patches.xen/xen3-patch-2.6.19.
- commit 7eb9d30
* Mon Mar  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not abort build because of
  supported.conf inconsistency if %%supported_modules_check == 0.
- commit 88d5daa
* Wed Mar  2 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix a fatal oversight in
  yesterday's change.
- commit 098768b
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
- commit 87944ac
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
- commit ed81f8c
* Wed Feb 23 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unused code.
- commit dacbc44
* Tue Feb 22 2011 jeffm@suse.com
- Update to 2.6.38-rc6.
  - Eliminated 1 patch.
- commit 6cce7bb
* Tue Feb 22 2011 mmarek@suse.cz
- rpm/mkspec: Do not create kernel-syms.spec on vanilla-only branches
- commit eb17bba
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
- commit 5ef002b
* Fri Feb 18 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit 41c6654
* Thu Feb 17 2011 jeffm@suse.de
- Update to 2.6.38-rc5.
- commit 8344657
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  - disable CONFIG_DRM_VMWGFX (bnc#606458)
  - update sparc configs to at least be able to run "make oldconfig"
- commit da75bd9
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
  initial 2.6.37 merge.
- commit e493205
* Mon Feb 14 2011 mmarek@suse.cz
- Move spec file templates and helper scripts to a separate branch, to
  ease synchronizing these files among master, vanilla and linux-next.
- commit 411abb8
* Mon Feb 14 2011 mmarek@suse.cz
- Delete a couple of obsolete kabi and other scripts from misc/:
- Delete misc/checkmod.
- Delete misc/collect_ksyms.
- Delete misc/diff-the-xfs-cvs.
- Delete misc/ksyms.py.
- Delete misc/mangle-ifdef.py.
- Delete misc/obsolete-module-aliases.
- Delete misc/testmodule.
- commit edc6d32
* Mon Feb 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Delete misc/extract-modaliases, the code
  was merged into rpm's find-supplements script.
- Delete rpm/check-build.sh, not needed anymore.
- commit 0a157b1
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
  bnc#661429).
- commit 72bd3d0
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
  (bnc#661682).
- commit 1eb5eaa
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Set timestamp of sources to the commit
  timestamp, so that they are always older than generated files in
  /usr/src/linux-obj (bnc#669669).
- commit 8565452
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not run fdupes in /usr/src/linux-obj, to
  keep timestamps intact.
- commit 9ba5ff0
* Tue Feb  8 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove .gitignore files after applying patches
  (fix last change).
- commit 907f9cc
* Tue Feb  8 2011 jeffm@suse.com
- Updated to 2.6.38-rc4.
  - Eliminated 1 patch.
- commit c327e0a
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit 027481c
* Tue Feb  8 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc4 and c/s 1066.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 72cea6e
* Tue Feb  8 2011 jbeulich@novell.com
- Update config files.
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- Refresh and re-enable patches.suse/stack-unwind.
- commit 1fabeda
* Tue Feb  8 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate an
  upstream change.
- commit ae5bb3f
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/{kernel-source.spec.in,mkspec}: Sync with vanilla and linux-next
- commit c93cd6c
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove dead code.
- commit 99e8891
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-spec-macros: Fix the definition
  of %%release_major and rename it to %%release_num to better describe
  what it does. Add some comments to explain how the versioning works.
- commit 9a3bc94
* Fri Feb  4 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix sed regexp
- commit 608bae2
* Fri Feb  4 2011 jeffm@suse.com
- hfs: avoid crash in hfs_bnode_create (bnc#552250).
- commit d84296a
* Fri Feb  4 2011 jeffm@suse.com
- Updated to 2.6.38-rc3.
  - Eliminated 2 patches.
- commit b6b51ca
* Wed Feb  2 2011 tiwai@suse.de
- ALSA: hda - Fix memory leaks in conexant jack arrays
  (bnc#668929).
- commit 31971a4
* Mon Jan 31 2011 jslaby@suse.cz
- Refresh patches.rpmify/cloneconfig.diff.
  scripts/kconfig/conf accepts long parameters only for some time already
- commit 939410c
* Sun Jan 23 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 4bf0e68
* Sun Jan 23 2011 jeffm@suse.de
- winbond: needs <linux/delay.h> for msleep and friends.
- commit e394a2e
* Sun Jan 23 2011 jeffm@suse.de
- Refresh patches.arch/ia64-page-migration: Update for migrate_pages() API change.
- commit 40d2921
* Sun Jan 23 2011 jeffm@suse.de
- supported.conf: Added rc_core as a dependency.
- commit 8b2c1b9
* Sun Jan 23 2011 jeffm@suse.com
- Update config files.
  - CONFIG_EXPERT=n on all but ps3
  - Vanilla configs updated.
- commit b25e639
* Sun Jan 23 2011 jeffm@suse.com
- Revert "- Update config files: CONFIG_EXPERT=n except ps3"
  This reverts commit 3f2c93d6a0593b2cc0c40f5ffee426eef27cc400.
  This was a bad commit. I have no idea where all the changes came from.
- commit 459f3f1
* Sun Jan 23 2011 jeffm@suse.com
- Update config files: CONFIG_EXPERT=n except ps3
- commit 3f2c93d
* Sat Jan 22 2011 jeffm@suse.com
- Updated to 2.6.38-rc2.
  - Eliminated 1 patch.
- commit 90baa82
* Sat Jan 22 2011 jeffm@suse.com
- ata: Fix panics with ata_id (bnc#660464).
- commit fa7af15
* Sat Jan 22 2011 jeffm@suse.de
- Updated some Patch-mainline headers.
- commit 9122bf0
* Sat Jan 22 2011 jeffm@suse.de
- Update to 2.6.38-rc1.
  - Removed 12 patches.
  - Xen is disabled.
  - Quite a few patches need updating.
- commit 9163bb7
* Fri Jan 21 2011 trenn@suse.de
- perf: Do not export power_frequency, but power_start event
  (bnc#665153).
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- cpuidle: Rename X86 specific idle poll state from C0 to POLL
  (bnc#665153).
- perf timechart: Adjust perf timechart to the new power events
  (bnc#665153).
- Fix display of idle boxes (none).
- Fix huge and wronge C-state drawings due to uninitialized
  start/end timestamps (none).
- Update config files.
- doc/config-options.changes:
  CONFIG_EVENT_POWER_TRACING_DEPRECATED=y
- commit b308eff
* Wed Jan 19 2011 jbohac@suse.cz
-    revert: ipv6: don't flush routes when setting loopback down.
- commit de347ac
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Initialize the global lock spinlock as
  appropriate (bnc#637377).
- commit c4b8238
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Fix global lock acquisition (bnc#637377).
- commit 15cd726
* Mon Jan 17 2011 jeffm@suse.com
- mISDN: Add support for group membership check (bnc#564423).
- commit 3f46938
* Fri Jan 14 2011 mmarek@suse.cz
- Revert %%kernelrelease changes originally made on the vanilla branch,
  they break on master and must be done differently.
- commit b610327
* Thu Jan 13 2011 jkosina@suse.cz
- Input: introduce 'notimeout' blacklist for Dell Vostro V13
  (bnc#641105).
- commit cb76856
* Wed Jan 12 2011 jeffm@suse.com
- In-kernel dependencies for reiser4
  - Delete patches.suse/reiser4-exports.
  - Delete patches.suse/reiser4-set_page_dirty_notag.
- commit 1b97130
* Tue Jan 11 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29: Fix a regression.
- commit 6acb967
* Mon Jan 10 2011 jack@suse.cz
- novfs: NCP Fragments can be upto 64k in size (bnc#625965).
- commit afd7489
* Mon Jan 10 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37-final and c/s 1062.
- commit ef70146
* Mon Jan 10 2011 jeffm@suse.com
- Enabled AGP modules as parts of the static kernel on i386 (bnc#609607)
- commit 9446eb0
* Sat Jan  8 2011 jengelh@medozas.de
- config: run oldconfig on sparc64/default
- commit aa3e940
* Sat Jan  8 2011 jengelh@medozas.de
- config: update sparc64/net and throw out unworthy options
- commit 1aca53d
* Fri Jan  7 2011 mmarek@suse.cz
- Delete patches.suse/gfs2-ro-mounts-only.patch (obsolete and unused)
- commit 38ff246
* Fri Jan  7 2011 trenn@suse.de
- Some are mainline, some are/will be implemented differently:
- Delete patches.drivers/dynamic_debug_1.patch.
- Delete patches.drivers/dynamic_debug_2.patch.
- Delete patches.drivers/dynamic_debug_3.patch.
- Delete patches.drivers/dynamic_debug_4.patch.
- Delete patches.drivers/dynamic_debug_5.patch.
- Delete patches.drivers/dynamic_debug_6.patch.
- Delete patches.drivers/dynamic_debug_7.patch.
- commit 68dc5c8
* Fri Jan  7 2011 neilb@suse.de
- Remove old patch
- commit 7fc009b
* Thu Jan  6 2011 jeffm@suse.com
- reiserfs: Fix crash during umount (bnc#610598).
- commit 88f26ac
* Thu Jan  6 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Move the source tree if %%kernelrelease is
  different from the tarball version.
- commit 6be9ffe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.suse/export-sync_page_range (unused).
- commit d19ee6d
* Thu Jan  6 2011 jeffm@suse.com
- Delete patches.suse/supported-flag-sysfs: Merged with patches.suse/supported-flag
- commit 0f2e67b
* Thu Jan  6 2011 jeffm@suse.com
- Removed unused kdb patches.
  - Delete patches.suse/kdb-build-fixes.
  - Delete patches.suse/kdb-common.
  - Delete
    patches.suse/kdb-fix-assignment-from-incompatible-pointer-warnings.
  - Delete
    patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro.
  - Delete patches.suse/kdb-handle-nonexistance-keyboard-controller.
  - Delete patches.suse/kdb-ia64.
  - Delete patches.suse/kdb-usb-rework.
  - Delete patches.suse/kdb-vm-api-changes-for-2-6-34.
  - Delete patches.suse/kdb-x86.
  - Delete patches.suse/kdb-x86-build-fixes.
  - Delete patches.suse/kdb_dont_touch_i8042_early.patch.
  - Delete patches.suse/kdb_fix_ia64_build.patch.
  - Delete patches.xen/xen3-kdb-x86.
- commit c9e725d
* Thu Jan  6 2011 jeffm@suse.com
- rpm/kernel-source.spec.in: Remove the relocation of the source tree.
  It's expanded in-place.
- commit 8cde941
* Thu Jan  6 2011 jack@suse.cz
- Delete patches.suse/ext2-fsync-err as it is obsolete and unused.
- commit c8f4ebe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.fixes/kbuild-fix-generating-of-.symtypes-files.
  Fixed upstream in commit e26d6b8.
- commit 1b628e1
* Thu Jan  6 2011 mgalbraith@suse.de
- Replaced autogroup patch with what will appear in 2.6.38
- Replaced cgroup use after free fix wtih what will appear in 2.6.38
- Refresh
  patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Delete patches.fixes/sched-fix-autogroup-proc-interface-race.
- commit 81f018b
* Thu Jan  6 2011 jeffm@suse.com
- Update to 2.6.37-final.
- commit f4cd126
* Thu Dec 30 2010 jeffm@suse.com
- taskstats: Use better ifdef for alignment (bko#24272).
- commit 2948ffa
* Wed Dec 29 2010 jeffm@suse.com
- Update to 2.6.37-rc8.
  - Eliminated 1 patch.
- commit 42518e6
* Tue Dec 28 2010 mgalbraith@suse.de
- sched: fix autogroup /proc interface race.
- commit fd7019c
* Mon Dec 27 2010 jeffm@suse.com
- scripts/wd-functions.sh: Re-added support for finding tarball in $MIRROR.
- commit c8014fb
* Mon Dec 27 2010 jeffm@suse.com
- sched, cgroup: Use exit hook to avoid use-after-free crash.
- commit 59c0581
* Mon Dec 27 2010 jeffm@suse.com
- Update to 2.6.37-rc7.
  - Eliminated 9 patches.
- commit d38591c
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
  Backport to XEN.
- commit 92c0965
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "PCI: fix pci_bus_alloc_resource() hang, prefer positive
  decode" (bnc#655048).
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
- Revert "x86/PCI: allocate space from the end of a region,
  not the beginning" (bnc#655048).
- Revert "PCI: allocate bus resources from the top down"
  (bnc#655048).
- Revert "resources: support allocating space within a region
  from the top down" (bnc#655048).
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid low BIOS area when allocating address space
  (bnc#655048).
- x86: avoid E820 regions when allocating address space
  (bnc#655048).
- x86: avoid high BIOS area when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7bbbf27
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "- resources: add arch hook for preventing allocation in reserved"
  This reverts commit 7e253537787f4fb057e12a166356169c5adb9665. It was unintended to be pushed as the patches are obsoleted.
- commit 6f3bdf8
* Mon Dec 20 2010 jslaby@suse.cz
- Delete
  patches.fixes/res-0010-PCI-fix-pci_bus_alloc_resource-hang-prefer-positive-.patch.
  It's unreferenced and wrong.
- commit 9e6fc50
* Thu Dec 16 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Define %%kernelrelease
- commit 1d67b13
* Thu Dec 16 2010 jeffm@suse.com
- Linux: 2.6.37-rc6.
- Update config files.
- Refresh patches.suse/SoN-23-mm-swapfile.patch.
- Refresh patches.suse/SoN-26-nfs-swapper.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit 5650f90
* Mon Dec 13 2010 jbeulich@novell.com
- Update Xen config files (XEN_NETDEV_LOOPBACK=n).
- supported.conf: Update.
- commit d385dff
* Mon Dec 13 2010 tiwai@suse.de
- Refresh patches.suse/bootsplash-scaler: Fix crash when bootsplash animation is used (bnc#646908)
- commit c5eced1
* Fri Dec 10 2010 jslaby@suse.cz
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid BIOS area when allocating address space (bnc#655048).
- x86: avoid PNP resources when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7e25353
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen config files (CONFIG_XEN_COMPAT=0x040000).
- commit 5343e5f
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc5.
- commit bef1a0d
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- commit 149d22b
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:Factory
- commit bf19860
* Wed Dec  8 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Allow to build against any version of
  kernel-source
- commit 37bdc47
* Tue Dec  7 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Remove stringification
  (needed only with very old assemblers).
- commit 987c244
* Tue Dec  7 2010 jeffm@suse.com
- scripts/sequence-patch.sh: Added -vanilla suffix to the directory name when expanding vanilla tree.
- commit 77ad87b
* Tue Dec  7 2010 jeffm@suse.com
- Update vanilla config files.
- commit f55f81b
* Tue Dec  7 2010 jeffm@suse.com
- Update to 2.6.37-rc5.
- commit ca102d9
* Tue Dec  7 2010 jbeulich@novell.com
- patches.suse/novfs-fix-ioctl-usage: Fix compiler warnings.
- commit faf2142
* Mon Dec  6 2010 mgalbraith@suse.de
- Replace buggy per tty autogroup patch with final per session patch as
  integrated into tip.
- sched: Add 'autogroup' scheduling feature: automated per session task groups (bnc#657613).
- Delete patches.suse/sched-automated-per-tty-task-groups.
- commit 0db6b6b
* Mon Dec  6 2010 jbeulich@novell.com
- patches.rpmify/rpm-kernel-config, patches.rpmify/split-package,
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch,
  patches.suse/SoN-15-netvm-reserve.patch,
  patches.suse/SoN-27-nfs-swap_ops.patch,
  patches.suse/kconfig-automate-kernel-desktop,
  patches.suse/mm-tune-dirty-limits.patch,
  patches.suse/supported-flag-enterprise: Clean up Kconfig portions.
- commit 713650c
* Mon Dec  6 2010 jeffm@suse.com
- Fixed corrupted -rc4 patch.
- commit 9802d4e
* Mon Dec  6 2010 jeffm@suse.de
- Update to 2.6.37-rc4.
- commit d102b44
* Mon Nov 29 2010 jeffm@suse.com
- Merge 2.6.37-rc3-git6 with Xen.
- commit 7089cd5
* Mon Nov 29 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git6.
- commit 1294ef9
* Fri Nov 26 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc3-git1 and c/s 1055.
- xen/acpi: Add memory hotadd to pvops dom0 (bnc#651066).
- xen/acpi: Export host physical CPU information to dom0
  (bnc#651066).
- Xen: para-virtual watchdog driver.
- introduce {rd,wr}msr_safe_on_pcpu() and add/enable users.
- eliminate scalability issues from initrd handling.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit cf6d991
* Fri Nov 26 2010 trenn@suse.de
- PERF: Fix perf timechart C-state regression (none).
- commit ba2671d
* Wed Nov 24 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git1.
- commit 4ad245f
* Mon Nov 22 2010 jeffm@suse.com
- Update to 2.6.37-rc3.
  - Eliminated 1 patch.
- commit 12ac0ac
* Mon Nov 22 2010 jslaby@suse.cz
- Delete patches.fixes/make-note_interrupt-fast.diff.
- Delete patches.fixes/twl6030-fix-note_interrupt-call.
  __do_IRQ from ia64 lapic code is no longer called, because they use
  genirqs properly. So these patches don't make sense anymore. If we
  need something to do, then it's adding action_ret == IRQ_NONE test
  into handle_percpu_irq before jumping into note_interrupt.
- commit facd623
* Sun Nov 21 2010 jslaby@suse.cz
- PCI: fix offset check for sysfs mmapped files (bnc#655157).
- commit 2938f56
* Wed Nov 17 2010 jeffm@suse.com
- sched: automated per tty task groups.
  - Enabled in -desktop flavors for better interactivity.
- commit 2d5d397
* Tue Nov 16 2010 jeffm@suse.de
- doc/config-options.changes: Updated changes for 2.6.37-rc1 and -rc2.
- commit 0aca8b8
* Tue Nov 16 2010 jeffm@suse.com
- Update to 2.6.37-rc2.
- commit 1453a04
* Mon Nov 15 2010 jslaby@suse.cz
- PCI: fix pci_bus_alloc_resource() hang, prefer positive decode
  (bnc#651256).
- commit 4404c19
* Mon Nov 15 2010 jeffm@suse.com
- Update vanilla config files.
- commit 60b4a47
* Mon Nov 15 2010 jeffm@suse.com
- Update to 2.6.37-rc1-git11.
  - Eliminated 2 patches.
- commit 5959a67
* Mon Nov 15 2010 jeffm@suse.com
- supported.conf: Added missing dependencies.
- commit 0537c35
* Sat Nov 13 2010 jslaby@suse.cz
- TTY: restore tty_ldisc_wait_idle (bnc#642043).
- commit 84d87bf
* Fri Nov 12 2010 jeffm@suse.de
- Update to 2.6.37-rc1.
  - Eliminated 26 patches.
  - Xen is disabled.
- commit b9044e3
* Thu Nov 11 2010 gregkh@suse.de
- Update config files. (bnc#652954) increase the number of possible and
  default uarts for users with multi-port serial cards for the i386 and
  x86-64 default configs.
- commit 85c87e3
* Thu Nov 11 2010 jslaby@suse.cz
- rt2x00: Fix max TX power settings (bnc#584028).
- rt2x00: Fix channel configuration for RF3052 (bnc#584028).
- commit 60c0452
* Thu Nov 11 2010 jslaby@suse.cz
- resources: add a default alignf to simplify find_resource()
  (bnc#651256).
- resources: factor out resource_clip() to simplify
  find_resource() (bnc#651256).
- resources: ensure callback doesn't allocate outside available
  space (bnc#651256).
- resources: handle overflow when aligning start of available area
  (bnc#651256).
- resources: support allocating space within a region from the
  top down (bnc#651256).
- PCI: allocate bus resources from the top down (bnc#651256).
- x86/PCI: allocate space from the end of a region, not the
  beginning (bnc#651256).
- x86: update iomem_resource end based on CPU physical address
  capabilities (bnc#651256).
- x86: allocate space within a region top-down (bnc#651256).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 8c68ad1
* Tue Nov  9 2010 jack@suse.cz
- novfs: Fix for the issue of kernel dumps core on restart
  (bnc#641811).
- commit 76ba833
* Fri Oct 29 2010 jslaby@suse.cz
- net: Limit socket I/O iovec total length to INT_MAX
  (bnc#650128).
- commit 2ba74bb
* Fri Oct 29 2010 trenn@suse.de
- Update config files.
  Forgot to enable ACPI_EC_DEBUGFS on i386/pae
- commit 66b605b
* Wed Oct 27 2010 jslaby@suse.cz
- aha152x: enable PCMCIA on 64bit (bnc#630652).
- Update config files.
- commit a91d17c
* Wed Oct 27 2010 jslaby@suse.cz
- hpet: unmap unused I/O space (bnc#629908 bnc#629901).
- commit dad22c3
* Tue Oct 26 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_ACPI_EC_DEBUGFS=m on supported archs.
- commit 9035254
* Tue Oct 26 2010 jbeulich@novell.com
- Update Xen config files (restore options accidentally deleted
  by 1b1584fccbfdc42e6e8b35c3c207ca65feb0c7d5).
- commit f8e5000
* Mon Oct 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36 and c/s 1043.
- xen: netback: take net_schedule_list_lock when removing entry
  from net_schedule_list.
- Update Xen config files.
- commit b772cd8
* Mon Oct 25 2010 tiwai@suse.de
- ALSA: hda - Add workarounds for CT-IBG controllers (bnc#564324).
- ALSA: hda - Add some workarounds for Creative IBG (bnc#564324).
- ALSA: hda - Fix wrong SPDIF NID assignment for CA0110
  (bnc#564324).
- commit 2256eda
* Fri Oct 22 2010 jeffm@suse.de
- Update to 2.6.36-final.
- commit 1b1584f
* Fri Oct 22 2010 jbeulich@novell.com
- patches.arch/i386-unwind-annotations,
  patches.arch/x86_64-unwind-annotations: Update Patch-mainline tags.
- commit 6ee5ccb
* Thu Oct 21 2010 sjayaraman@suse.de
- SoN: fix null pointer dereference in swap_entry_free.
- SoN: fix mess up on swap with multi files from same nfs server.
- Refresh patches.xen/tmem.
- commit d068f12
* Mon Oct 18 2010 trenn@suse.de
- ACPI: Make Embedded Controller command timeout delay
  configurable (bnc#639261).
- commit 9ea38cf
* Fri Oct 15 2010 jslaby@suse.cz
- Update to 2.6.36-rc8.
- commit 0c0e67c
* Fri Oct 15 2010 jslaby@suse.cz
- Refresh patches.suse/SoN-22-netvm.patch.
  Fix lock imbalance in net core (caused errors with bridges). (bnc#637235)
- commit f7ca98f
* Tue Oct 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc7 and c/s 1042.
- Update tmem interface to v1.
- commit 03c1043
* Mon Oct 11 2010 mmarek@suse.cz
- Generate per-symbol provides again (fate#305945).
  11.4 will do incremental downloads of repository metadata
  (fate#309561), so there should be no problem with the update
  repository anymore.
- commit 4258cf2
* Mon Oct 11 2010 jbeulich@novell.com
- patches.apparmor/apparmor-compatibility-patch-for-v5-network-control:
  Remove .rej file from this patch.
- commit 8828ce5
* Fri Oct  8 2010 jeffm@suse.de
- Update to 2.6.36-rc7.
- commit 82673e4
* Tue Oct  5 2010 jbeulich@novell.com
- patches.drivers/dynamic_debug_4.patch: Fix build issues with
  !DYNAMIC_DEBUG and build warning.
- commit b08d2aa
* Tue Oct  5 2010 jeffm@suse.de
- Enable SECURITY_APPARMOR_COMPAT_24
- commit f9b83fc
* Tue Oct  5 2010 jeffm@suse.de
- AppArmor: Allow dfa backward compatibility with broken
  userspace.
- AppArmor: compatibility patch for v5 interface.
- AppArmor: compatibility patch for v5 network control.
- commit cb27981
* Mon Oct  4 2010 jeffm@suse.de
- Update to 2.6.36-rc6.
  - Eliminated 2 patches.
- commit 57ae577
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 one more time.
- commit d527087
* Fri Sep 24 2010 trenn@suse.de
- acpi: ec_sys: access user space with get_user()/put_user()
  (none).
- commit d028761
* Fri Sep 24 2010 trenn@suse.de
- kernel/module.c: Fix compiler warnings if debug is compiled in
  (none).
- PNP: Use dev_dbg instead of dev_printk(KERN_DEBUG.. if
  DYNAMIC_DEBUG is compiled in (none).
- PNP: Compile all pnp built-in stuff in one module namespace
  (none).
- Dynamic Debug: Introduce global fake module param module.ddebug
  - V4 (none).
- Dynamic Debug: Initialize dynamic debug earlier via
  arch_initcall (none).
- Dynamic Debug: Introduce ddebug_query= boot parameter (none).
- Dynamic Debug: Split out query string parsing/setup from
  proc_write (none).
- commit dcd5c68
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 again.
- commit 2fbc89f
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28.
- commit cba31c7
* Fri Sep 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc5 and c/s 1038.
- commit 7b86243
* Thu Sep 23 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kernel release strings like
  2.6.36-rc5-73-g57aebd7-vanilla.
- rpm/kernel-spec-macros: Cleanup.
- commit 0926a18
* Thu Sep 23 2010 jeffm@suse.de
- rose: Fix signedness issues wrt. digi count (CVE-2010-3310
  bnc#640721).
- commit bcdc88b
* Tue Sep 21 2010 jeffm@suse.de
- qla4xxx: add workaround for missing readq/writeq.
- commit 643f9cf
* Tue Sep 21 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: BuildRequire proper version of kernel-source
- commit beb33d1
* Tue Sep 21 2010 jeffm@suse.de
- Linux: 2.6.36-rc5.
  - Eliminated 6 patches (all security backports).
- commit d4603b4
* Mon Sep 20 2010 jeffm@suse.de
- Revert "- make SCSI and ATA drivers modules again. (bnc#564357)."
  This reverts commit 75e8e5eae2c1e8dd279370f2c7650835ee821deb.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
  This change only applies to enterprise releases and should have been
  reverted prior to the release of openSUSE 11.3.
- commit 7fc084f
* Mon Sep 20 2010 sjayaraman@suse.de
- Update patches.suse/SoN-05-reserve-slub.patch to accomodate an upstream
  change that uses kmem_cache flags instead of PageSlubDebug flag.
- commit 4ea582b
* Mon Sep 20 2010 jeffm@suse.de
- Set LSM_MMAP_MIN_ADDR=0 to allow tools like DOSemu to work properly. The
  default is still set to 64k.
- commit 0581892
* Sun Sep 19 2010 jeffm@suse.com
- Delete patches.suse/cgroup-disable-memory.patch: It is no longer needed. The performance hit that it caused has been eliminated.
- commit 1ec7da8
* Fri Sep 17 2010 jeffm@suse.de
- wext: fix potential private ioctl memory content leak
  (CVE-2010-2955 bnc#635413).
- commit 6df45c9
* Thu Sep 16 2010 jeffm@suse.de
- x86-64, compat: Test %%rax for the syscall number, not %%eax
  (CVE-2010-3301 bnc#639708).
- x86-64, compat: Retruncate rax after ia32 syscall entry tracing
  (CVE-2010-3301 bnc#639708).
- commit fb77404
* Thu Sep 16 2010 jeffm@suse.de
- compat: Make compat_alloc_user_space() incorporate the
  access_ok() (CVE-2010-3081 bnc#639709).
- commit 664a0ac
* Wed Sep 15 2010 jeffm@suse.com
- Remove reference to unused patch.
- commit a3abfe2
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/usb/hso.c: prevent reading uninitialized memory
  (CVE-2010-3298 bnc#639483).
- commit 35e70c8
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/cxgb3/cxgb3_main.c: prevent reading uninitialized
  stack memory (CVE-2010-3296 bnc#639481).
- commit a0634a9
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/eql.c: prevent reading uninitialized stack memory
  (CVE-2010-3297 bnc#639482).
- commit 2a7b160
* Wed Sep 15 2010 tiwai@suse.de
- Revert "patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171"
  This reverts commit c6a176c1df9ab4c69dd54ff3076bc92806eac8fd.
  It should have been applied to SLE11-SP1 branch.
- commit 05f07f3
* Tue Sep 14 2010 jslaby@suse.cz
- Update to Linux 2.6.36-rc4.
  - Obsoletes:
  - patches.fixes/bonding-jiffies2.patch.
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure.
  - patches.fixes/net-sched-fix-kernel-leak-in-act_police.
  - patches.rpmify/spectra-depends-on-moorestown.
- fix build on s390 as of 2.6.36-rc4.
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/reiser4-set_page_dirty_notag.
- Refresh patches.xen/pci-guestdev.
- Update config files.
- commit 6915057
* Mon Sep 13 2010 oneukum@suse.de
- patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171
- commit c6a176c
* Mon Sep 13 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Update patch-mainline.
- commit a1a8fdd
* Fri Sep  3 2010 jeffm@suse.de
- Always build in AGP on x86/x86_64 so KMS works on LiveCDs (bnc#609607).
- commit d9bfa1e
* Fri Sep  3 2010 jeffm@suse.com
- irda: Correctly clean up self->ias_obj on irda_bind() failure
  (CVE-2010-2954 bnc#636112).
- commit f04e61f
* Wed Sep  1 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc3 and c/s 1029.
- fix unwind annotations.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 6836619
* Wed Sep  1 2010 jbeulich@novell.com
- fix unwind annotations.
- commit 5aa6daf
* Tue Aug 31 2010 jeffm@suse.com
- net sched: fix kernel leak in act_police (CVE-2010-2942
  bnc#632309).
- commit 66e1d72
* Tue Aug 31 2010 jdelvare@suse.de
- fix jiffies overflow problems in bonding (bnc#613273).
- commit 28bd2e8
* Mon Aug 30 2010 jeffm@suse.de
- Refresh vanilla configs.
- commit 26a681e
* Mon Aug 30 2010 jeffm@suse.de
- Update to Linux: 2.6.36-rc3.
  - Eliminated 7 patches.
- commit d298d2d
* Sat Aug 28 2010 jslaby@suse.cz
- Delete
  patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch.
- Delete
  patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch.
- Delete
  patches.suse/rlim-0022-FS-proc-make-limits-writable.patch.
  This was just a workaround crap. In 2.6.36 we have a nice syscall
  instead. Sorry for commiting this to the merge-36 branch first. I
  didn't notice it was already merged here.
- commit 5449fcb
* Fri Aug 27 2010 jeffm@suse.com
- Disabled ACPI table override patches again. fsnotify was introduced into
  the truncate path and causes crashes.
- commit e18fc2c
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/supported-flag-enterprise: Fixed recovery on load failure.
- commit 8a06643
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/stack-unwind: Fixed recovery on load failure.
- commit 7f15b29
* Tue Aug 24 2010 jeffm@suse.com
- patches.arch/s390-message-catalog.diff: dev_info -> _dev_info
- commit ba20988
* Tue Aug 24 2010 jeffm@suse.de
- patches.suse/stack-unwind: Fix build on !SMP
- commit abd5493
* Tue Aug 24 2010 jeffm@suse.de
- s390: Fix prototype for execve.
- commit b448268
* Tue Aug 24 2010 jeffm@suse.de
- spectra: depend on X86_MRST.
- commit 1e3fb89
* Tue Aug 24 2010 jeffm@suse.de
- Delete patches.arch/ppc-vmcoreinfo.diff.
- commit ea39e14
* Tue Aug 24 2010 jeffm@suse.de
- caif: Use asm/unaligned.h.
- commit 92c07c2
* Tue Aug 24 2010 jeffm@suse.de
- Refresh patches.suse/SoN-20-netvm-tcp-deadlock.patch: Added missing
  fixup for sk_rmem_schedule in caif.
- commit a9ff761
* Tue Aug 24 2010 mmarek@suse.cz
- makefile: not need to regenerate kernel.release file when
  make kernelrelease.
- commit 81237a8
* Tue Aug 24 2010 jeffm@suse.com
- rpm/kernel-source.spec.in, scripts/tar-up.sh: Renamed config-options.changes
  to config-options.changes.txt in the exported package to avoid triggering
  a build service rule error.
- commit ff4889e
* Tue Aug 24 2010 jeffm@suse.com
- Revert "- Renamed doc/config-options.changes to doc/config-options.changes.txt to"
  This reverts commit 124ac26de4839f8181a5badedb231eedf5770a3e.
- commit 2932c62
* Tue Aug 24 2010 jeffm@suse.com
- Renamed doc/config-options.changes to doc/config-options.changes.txt to
  avoid triggering a build service rule error.
- commit 124ac26
* Mon Aug 23 2010 jeffm@suse.de
- supported.conf: Add iscsi_boot_sysfs
- commit 80e2ea9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Fixed typo with last fix.
- commit 22210d9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disable CONFIG_DEBUG_INFO. It's enabled
  dynamically in the spec file and now has follow-on options.
- commit d270759
* Mon Aug 23 2010 jeffm@suse.de
- patches.rpmify/spectra-drop-locked_ioctl-support: add <linux/smp_lock.h>
  to grab the BKL
- commit 1df02ec
* Mon Aug 23 2010 jeffm@suse.de
- Update config files: Disabled DEBUG_INFO_REDUCED.
- commit 393680a
* Mon Aug 23 2010 jeffm@suse.de
- Updated to 2.6.36-rc2.
  - Eliminated 2 patches.
- commit 52d47a0
* Wed Aug 18 2010 jeffm@suse.de
- Update to 2.6.36-rc1.
  - Eliminated 71 patches.
  - spectra: Drop ->locked_ioctl support.
  - spectra: Drop ->prepare_flush_fn support.
  - spectra: Remove duplicate GLOB_VERSION.
  - novfs: Fix ioctl usage.
  - novfs: use evict_inode.
  - Xen is disabled.
- commit 63642f6
* Mon Aug 16 2010 tiwai@suse.de
- ALSA: hda - Add quirk for Dell Vostro 1220 (bnc#631066).
- commit df12c34
* Fri Aug 13 2010 jeffm@suse.com
- README.BRANCH: Updated to reflect the permenent in-progress status.
- commit a2c882e
* Thu Aug 12 2010 gregkh@suse.de
- Update to 2.6.35.1
  - security fixes
  - bug fixes
  - obsoletes:
    patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch.
- commit a009fb4
* Thu Aug 12 2010 gregkh@suse.de
- Delete patches.kernel.org/patch-2.6.35-rc1.
- Delete patches.kernel.org/patch-2.6.35-rc1-rc2.
- Delete patches.kernel.org/patch-2.6.35-rc2-rc3.
- Delete patches.kernel.org/patch-2.6.35-rc3-rc4.
- Delete patches.kernel.org/patch-2.6.35-rc4-rc5.
- Delete patches.kernel.org/patch-2.6.35-rc5-rc6.
- commit 2e67843
* Thu Aug 12 2010 gregkh@suse.de
- Refresh patches.fixes/novfs-lindent.
  Someone needs to remember to actually test out their patches before
  adding them to the repo...
- commit 6569c56
* Thu Aug 12 2010 jeffm@suse.com
- doc/README.SUSE: Updated to describe the process used to add custom patches
- commit e5f4670
* Thu Aug 12 2010 jslaby@suse.cz
- patches.fixes/vmscan-fix-stalls.patch: vmscan: raise the bar
  to PAGEOUT_IO_SYNC stalls (bnc#625339).
- commit 1efea94
* Wed Aug 11 2010 jack@suse.cz
- novfs: Lindent novfs sources.
- commit 361594a
* Wed Aug 11 2010 neilb@suse.de
- Refresh
  patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch.
- Refresh patches.fixes/sunrpc-monotonic-expiry.
- Delete patches.fixes/nfs-write.c-bug-removal.patch.
  Update some patches for 2.6.35
- commit 15d7a62
* Wed Aug 11 2010 neilb@suse.de
- NFS: allow close-to-open cache semantics to apply to root of
  NFS filesystem (bnc#584720).
- commit deea101
* Tue Aug 10 2010 tiwai@suse.de
- ALSA: hda - patch_nvhdmi.c: Add missing codec IDs, unify names
  (bnc#627212).
- ALSA: hda - Add pin-fix for HP dc5750 (bnc#624118).
- commit 4844a71
* Mon Aug  9 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35 final and c/s 1025.
- create devices in /dev/xen when they are expected to be
  used there.
- xen/netback: Allow setting of large MTU before rings have
  connected.
- xen/netback: Always pull through PKT_PROT_LEN bytes into the
  linear part of an skb.
- pass trigger mode and polarity information to Xen for all
  interrupts.
- Update Xen config files.
- supported.conf: Add pci-iomul.ko.
- commit c642c1b
* Fri Aug  6 2010 jeffm@suse.de
- patches.xen/xen3-auto-xen-arch.diff: Update struct acpi_power_register
  usage from upstream commit 718be4aa.
- commit 4ce0b48
* Fri Aug  6 2010 jeffm@suse.de
- Update to 2.6.35-final and refresh patch set.
- commit a40327f
* Mon Aug  2 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Package log.sh in the source rpm
- commit 53246ff
* Fri Jul 23 2010 jack@suse.cz
- novfs: Fix error codes for getxattr for novfs (bnc#529535).
- commit 06b3243
* Fri Jul 23 2010 jeffm@suse.de
- Update to 2.6.35-rc6.
- commit 643df99
* Fri Jul 23 2010 jack@suse.cz
- novfs: code cleanup for one case of novfs return value
  (bnc#624606).
- commit 4875860
* Wed Jul 21 2010 jack@suse.cz
- Fixed patch headers of patches.fixes/novfs-xattr-memleak
- commit 65ab01f
* Wed Jul 21 2010 jack@suse.cz
- novfs: Fix a memory leak that causes an OOM condition
  (bnc#610828).
- commit 519d8a0
* Tue Jul 20 2010 jack@suse.cz
- novfs: backing device info initialization (bnc#623472).
- commit b576dae
* Tue Jul 20 2010 mmarek@suse.cz
- scripts/tar-up.sh: Generate the rpm changelog using gitlog2changes.
- Move kernel-source.changes.old to rpm/ (not included in the pachage
  though).
- commit 8ed2389
* Tue Jul 20 2010 jblunck@suse.de
- rpm/package-descriptions: Change summary/description for trace flavor (bnc#488692).
- commit da8e17e
* Mon Jul 19 2010 mmarek@suse.cz
- Move rpm changelog to kernel-source.changes.old
- commit 93036bd
* Thu Jul 15 2010 bphilips@suse.de
- X86_MRST: Disable moorsetown since it deselects SERIO_I8042
  - See 0b28bac5aef7bd1ab213723df031e61db9ff151a, fixed in -tip but we
    still don't want X86_MRST
* Wed Jul 14 2010 trenn@suse.de
- patches.arch/acpi_fix_fadt_32_bit_zero_length.patch: Only use
  32 bit addresses if they have a valid length (bug#581644).
* Wed Jul 14 2010 bphilips@suse.de
- Update -desktop config files to enable CGROUPS for systemd
* Wed Jul 14 2010 jeffm@suse.de
- Update to 2.6.35-rc5.
  - Eliminated 5 patches.
* Tue Jul 13 2010 jack@suse.de
- patches.fixes/novfs-overflow-fixes: novfs: security: Add buffer
  overflow, integer wraparound fixes (bnc#594362).
* Wed Jul  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc4.
* Wed Jul  7 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-2.6.35-api-changes: Updated for -debug flavor.
* Wed Jul  7 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Jul  7 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install config-option.changes
  This file documents the changes in the kernel configs.
* Wed Jul  7 2010 mmarek@suse.cz
- patches.rpmify/kbuild-setlocalversion-fix: kbuild: Fix path
  to scripts/setlocalversion.
* Tue Jul  6 2010 jeffm@suse.de
- Update to 2.6.35-rc4.
  - Eliminated 4 patches.
* Fri Jul  2 2010 jeffm@suse.de
- patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices:
  iwlwifi: fix TX power configuration on 3945 and 4965 devices
  (bnc#619440 bnc#610421).
* Fri Jul  2 2010 jbeulich@novell.com
- patches.suse/stack-unwind: Fix after upstream commit
  9e565292270a2d55524be38835104c564ac8f795.
* Fri Jul  2 2010 trenn@suse.de
- patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch:
  For some reason the macro used by dynamic debug breaks things
  (bnc#619416).
* Fri Jul  2 2010 trenn@suse.de
  Mainline goes another way (bug #476509).
  Also there is a problem with this patch, breaking dynamic debugging
  (bnc#619416) -> just remove it, there will show up something else
  mainline.
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Delete.
* Thu Jul  1 2010 jeffm@suse.de
- patches.suse/dm-raid45-api-update-remove-dm_put-after-dm_table_get_md:
  dm-raid45: API update: Remove dm_put after dm_table_get_md
  (bnc#615656).
* Thu Jul  1 2010 jdelvare@suse.de
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  Update references (bnc#610362).
* Thu Jul  1 2010 bphilips@suse.de
- patches.drivers/ixgbe-disable-tx-engine-before-disabling-tx-laser.patch:
  ixgbe: disable tx engine before disabling tx laser.
- patches.drivers/ixgbe-fix-panic-when-shutting-down-system-with-WoL-e.patch:
  ixgbe: fix panic when shutting down system with WoL enabled.
- patches.drivers/ixgbe-skip-non-IPv4-packets-in-ATR-filter.patch:
  ixgbe: skip non IPv4 packets in ATR filter.
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  e1000e: don't inadvertently re-set INTX_DISABLE.
* Wed Jun 30 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Delete.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Delete.
* Tue Jun 29 2010 nfbrown@suse.de
- patches.fixes/nfs_wb_page_deadlock.fix: NFS: Fix another
  nfs_wb_page() deadlock (bnc#612794).
* Mon Jun 28 2010 mmarek@suse.cz
- rpm/find-provides: Add base symsets to the main subpackage.
* Fri Jun 25 2010 jeffm@suse.de
- Update config files for sparc64/net to remove unnecessary options.
* Fri Jun 25 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Fri Jun 25 2010 jbeulich@novell.com
- patches.arch/kvm-split-paravirt-ops-by-functionality: Adjust
  Kconfig style to match upstream.
- patches.fixes/seccomp-disable-tsc-option: Adjust Kconfig style
  to match upstream.
- patches.suse/SoN-11-mm-reserve.patch: Fix compiler warning.
* Fri Jun 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc3.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Thu Jun 24 2010 agruen@suse.de
- Replace the nfs4acl patches by their successor patch queue,
  richacls (see http://www.suse.de/~agruen/richacl/).
- Update config files: CONFIG_EXT4_FS_RICHACL=y.
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files:
  ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only
  files (bnc#612457 CVE-2010-2066).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-writing-to-non-page-aligned-gfs2_quota-structures:
  GFS2: Fix writing to non-page aligned gfs2_quota structures
  (bnc#599957 CVE-2010-1436).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl:
  GFS2: Fix permissions checking for setflags ioctl() (bnc#608576
  CVE-2010-1641).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Wed Jun 23 2010 jeffm@suse.de
- btrfs fix rollup from v2.6.35:
- patches.fixes/btrfs-handle-err_ptr-from-posix_acl_from_xattr:
  Btrfs: handle ERR_PTR from posix_acl_from_xattr().
- patches.fixes/btrfs-avoid-bug-when-dropping-root-and-reference-in-same-transaction:
  Btrfs: avoid BUG when dropping root and reference in same
  transaction.
- patches.fixes/btrfs-prohibit-a-operation-of-changing-acl-s-mask-when-noacl-mount-option-used:
  Btrfs: prohibit a operation of changing acl's mask when noacl
  mount option used.
- patches.fixes/btrfs-should-add-a-permission-check-for-setfacl:
  Btrfs: should add a permission check for setfacl.
- patches.fixes/btrfs-btrfs_lookup_dir_item-can-return-err_ptr:
  Btrfs: btrfs_lookup_dir_item() can return ERR_PTR.
- patches.fixes/btrfs-btrfs_read_fs_root_no_name-returns-err_ptrs:
  Btrfs: btrfs_read_fs_root_no_name() returns ERR_PTRs.
- patches.fixes/btrfs-unwind-after-btrfs_start_transaction-errors:
  Btrfs: unwind after btrfs_start_transaction() errors.
- patches.fixes/btrfs-btrfs_iget-returns-err_ptr: Btrfs:
  btrfs_iget() returns ERR_PTR.
- patches.fixes/btrfs-handle-kzalloc-failure-in-open_ctree:
  Btrfs: handle kzalloc() failure in open_ctree().
- patches.fixes/btrfs-handle-error-returns-from-btrfs_lookup_dir_item:
  Btrfs: handle error returns from btrfs_lookup_dir_item().
- patches.fixes/btrfs-fix-bug_on-for-fs-converted-from-extn:
  Btrfs: Fix BUG_ON for fs converted from extN.
- patches.fixes/btrfs-fix-null-dereference-in-relocation-c:
  Btrfs: Fix null dereference in relocation.c.
- patches.fixes/btrfs-fix-remap_file_pages-error: Btrfs: fix
  remap_file_pages error.
- patches.fixes/btrfs-uninitialized-data-is-check_path_shared:
  Btrfs: uninitialized data is check_path_shared().
- patches.fixes/btrfs-fix-fallocate-regression: Btrfs: fix
  fallocate regression.
- patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs: Btrfs:
  fix loop device on top of btrfs.
- patches.fixes/btrfs-add-more-error-checking-to-btrfs_dirty_inode:
  Btrfs: add more error checking to btrfs_dirty_inode.
- patches.fixes/btrfs-allow-unaligned-dio: Btrfs: allow unaligned
  DIO.
- patches.fixes/btrfs-drop-verbose-enospc-printk: Btrfs: drop
  verbose enospc printk.
- patches.fixes/btrfs-fix-block-generation-verification-race:
  Btrfs: Fix block generation verification race.
- patches.fixes/btrfs-fix-preallocation-and-nodatacow-checks-in-o_direct:
  Btrfs: fix preallocation and nodatacow checks in O_DIRECT.
- patches.fixes/btrfs-avoid-enospc-errors-in-btrfs_dirty_inode:
  Btrfs: avoid ENOSPC errors in btrfs_dirty_inode.
- patches.fixes/btrfs-move-o_direct-space-reservation-to-btrfs_direct_io:
  Btrfs: move O_DIRECT space reservation to btrfs_direct_IO.
- patches.fixes/btrfs-rework-o_direct-enospc-handling: Btrfs:
  rework O_DIRECT enospc handling.
- patches.fixes/btrfs-use-async-helpers-for-dio-write-checksumming:
  Btrfs: use async helpers for DIO write checksumming.
- patches.fixes/btrfs-don-t-walk-around-with-task-state-task_running:
  Btrfs: don't walk around with task->state != TASK_RUNNING.
- patches.fixes/btrfs-do-aio_write-instead-of-write: Btrfs:
  do aio_write instead of write.
- patches.fixes/btrfs-add-basic-dio-read-write-support: Btrfs:
  add basic DIO read/write support.
- patches.fixes/direct-io-add-a-hook-for-the-fs-to-provide-its-own-submit_bio-function:
  direct-io: add a hook for the fs to provide its own submit_bio
  function.
- patches.fixes/btrfs-metadata-enospc-handling-for-balance:
  Btrfs: Metadata ENOSPC handling for balance.
- patches.fixes/btrfs-pre-allocate-space-for-data-relocation:
  Btrfs: Pre-allocate space for data relocation.
- patches.fixes/btrfs-metadata-enospc-handling-for-tree-log:
  Btrfs: Metadata ENOSPC handling for tree log.
- patches.fixes/btrfs-metadata-reservation-for-orphan-inodes:
  Btrfs: Metadata reservation for orphan inodes.
- patches.fixes/btrfs-introduce-global-metadata-reservation:
  Btrfs: Introduce global metadata reservation.
- patches.fixes/btrfs-update-metadata-reservation-for-delayed-allocation:
  Btrfs: Update metadata reservation for delayed allocation.
- patches.fixes/btrfs-integrate-metadata-reservation-with-start_transaction:
  Btrfs: Integrate metadata reservation with start_transaction.
- patches.fixes/btrfs-introduce-contexts-for-metadata-reservation:
  Btrfs: Introduce contexts for metadata reservation.
- patches.fixes/btrfs-kill-init_btrfs_i: Btrfs: Kill
  init_btrfs_i().
- patches.fixes/btrfs-shrink-delay-allocated-space-in-a-synchronized:
  Btrfs: Shrink delay allocated space in a synchronized.
- patches.fixes/btrfs-kill-allocate_wait-in-space_info: Btrfs:
  Kill allocate_wait in space_info.
- patches.fixes/btrfs-link-block-groups-of-different-raid-types:
  Btrfs: Link block groups of different raid types.
- patches.fixes/nilfs-fix-breakage-caused-by-barrier-flag-changes:
  nilfs: fix breakage caused by barrier flag changes.
- patches.fixes/blkdev-generalize-flags-for-blkdev_issue_fn-functions:
  blkdev: generalize flags for blkdev_issue_fn functions.
* Wed Jun 23 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Tue Jun 22 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-force_dma: ata_generic:
  implement ATA_GEN_* flags and force enable DMA on MBP 7,1
  (bko#15923).
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Tue Jun 22 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:11.3.
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Mon Jun 21 2010 jeffm@suse.de
- Resync v2.6.35 with master.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/acpi-generic-initramfs-table-override-support:
  Refresh.
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Refresh.
* Mon Jun 21 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require a mkinitrd that supports
  KMS (bnc#615680).
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap calls
  while loading initramfs files.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap of
  pages for initramfs loading.
* Fri Jun 18 2010 jbeulich@novell.com
- patches.xen/xen3-driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
- Refresh other Xen patches.
- Update Xen config files.
* Thu Jun 17 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-mcp89-mbp71:
  ahci,ata_generic: let ata_generic handle new MBP w/ MCP89
  (bko#15923).
* Wed Jun 16 2010 jeffm@suse.de
- Update to 2.6.35-rc3.
  - Eliminated 1 patch.
* Mon Jun 14 2010 jslaby@suse.de
- patches.fixes/pci-hotplug-cpqphp-fix-crash.patch: PCI:
  hotplug/cpqphp, fix NULL dereference (bnc#609338).
* Wed Jun  9 2010 jeffm@suse.de
- patches.rpmify/ceph-atomic_long-init-fix: ceph: fix atomic64_t
  initialization on ia64.
* Tue Jun  8 2010 jeffm@suse.de
- patches.trace/utrace-core: Workaround missing kref_set().
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/ppc64-xmon-dmesg-printing.patch: Refresh.
* Tue Jun  8 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: Refresh.
- patches.rpmify/wlags49-missing-strlen-include: wlags49_h2:
  build fix.
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Refresh.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Refresh.
* Tue Jun  8 2010 jeffm@suse.com
- supported.conf: Updated dependencies for 2.6.35
* Mon Jun  7 2010 jeffm@suse.com
- patches.kernel.org/revert-tty-fix-a-little-bug-in-scrup-vt-c:
  Revert "tty: fix a little bug in scrup, vt.c".
* Mon Jun  7 2010 jeffm@suse.com
- Update to 2.6.35-rc2.
* Thu Jun  3 2010 jeffm@suse.de
- Re-enable DSDT in initramfs code.
- patches.suse/acpi-don-t-preempt-until-the-system-is-up: acpi:
  don't preempt until the system is up.
* Wed Jun  2 2010 bphilips@suse.de
- patches.drivers/e1000e-entropy-source.patch: Reintroduce IRQF_SHARED
  to fix non-MSI case (bnc#610362).
* Wed Jun  2 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: More -rt fixes.
* Tue Jun  1 2010 jeffm@suse.com
- Update to 2.6.35-rc1.
  - Eliminated 13 patches.
  - Xen is disabled.
* Tue Jun  1 2010 bphilips@suse.de
- patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch:
  tg3: 5785 and 57780 asic revs not working (bnc#580780).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-module-subpackage: Change the kmp versioning to prefix
  the kernel version with "k" to avoid false version downgrades
  (bnc#609483).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: pcre-tools is not needed.
* Mon May 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix for -rt.
* Wed May 26 2010 gregkh@suse.de
- patches.drivers/driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
* Tue May 25 2010 jeffm@suse.de
- supported.conf: Added mperf, which powernow and acpi-cpufreq now
  depend on.
* Tue May 25 2010 jeffm@suse.com
- patches.arch/powernow-k8-add-core-performance-boost-support:
  powernow-k8: Add core performance boost support (bnc#602209).
- patches.arch/x86-cpu-add-amd-core-boosting-feature-flag-to-proc-cpuinfo:
  x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo.
- patches.arch/x86-cpufreq-add-aperf-mperf-support-for-amd-processors:
  x86, cpufreq: Add APERF/MPERF support for AMD processors
  (bnc#602209).
* Tue May 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34 final.
- Update Xen config files.
- patches.xen/xen3-acpi_processor_check_maxcpus.patch: Do not
  try to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Mon May 24 2010 jbenc@suse.cz
- patches.suse/b43-missing-firmware-info.patch: b43: Change
  firmware missing message to refer to openSUSE script.
* Sun May 23 2010 teheo@suse.de
- patches.drivers/pci-disable-msi-on-K8M800: pci: disable MSI
  on VIA K8M800 (bnc#599508).
* Sat May 22 2010 trenn@suse.de
- patches.xen/xen3-auto-common.diff: Refresh.
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
- patches.fixes/acpi_wmi_debug.patch: X86 platform wmi: Introduce
  debug param to log all WMI events (bnc#598059).
- patches.fixes/hp_wmi_fix_acpi_version_integer_size.patch:
  x86 platform drivers: hp-wmi fix buffer size depending on ACPI
  version (bnc#598059).
- patches.fixes/wmi_debug_pass_guid: X86 platform wmi: Also log
  GUID string when an event happens and debug is set (bnc#598059).
- patches.fixes/wmi_dump_wdg_data.patch: X86 platfrom wmi: Add
  debug facility to dump WMI data in a readable way (bnc#598059).
* Thu May 20 2010 jeffm@suse.com
- Disabled CONFIG_RT2800PCI (bnc#606243)
  - These devices are handled by the rt2860 staging driver.
* Mon May 17 2010 jeffm@suse.com
- patches.fixes/kvm-ioapic.patch: Refresh.
* Mon May 17 2010 jeffm@suse.com
- Update to 2.6.34-final.
* Wed May 12 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix preserving of old symsets.
* Wed May 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc7 and c/s 1017.
* Tue May 11 2010 jeffm@suse.com
- Update config files for vanilla.
* Tue May 11 2010 jeffm@suse.com
- Updated to 2.6.34-rc7.
  - Eliminated 3 patches.
* Sun May  2 2010 jeffm@suse.com
- Update to 2.6.34-rc6.
  - Eliminated 2 patches.
* Sun May  2 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-due-to-null-nameidata: Allow null nd
  (as nfs server uses) on create (bnc#593940).
* Fri Apr 30 2010 trenn@suse.de
- patches.fixes/acpi_ensure_spec_correct_address_space_length.patch:
  ACPI/x86/PCI: compute Address Space length rather than using
  _LEN (bnc#598641).
* Thu Apr 29 2010 jbeulich@novell.com
- Update -ec2 config files (X86_MSR=m again).
* Thu Apr 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc5-git8 and c/s 1016.
- Update Xen config files.
- patches.xen/xen-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/xen-fix_trace_power.patch: Rename to ...
- patches.xen/xen3-x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  ... this.
* Thu Apr 29 2010 knikanth@suse.de
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Refresh.
  Fix patch to call dm_table_get directly instead of calling
  dm_get_table unnecesarily.
* Thu Apr 29 2010 jeffm@suse.com
- Update to 2.6.34-rc5-git8.
  - Eliminated 1 patch.
* Wed Apr 28 2010 trenn@suse.de
- patches.xen/xen-fix_trace_power.patch: x86 cpufreq: Make
  trace_power_frequency cpufreq driver independent (none).
* Wed Apr 28 2010 mmarek@suse.cz
- Disable CONFIG_FIRMWARE_IN_KERNEL in all configs, we start udev
  early enough in the initrd.
* Wed Apr 28 2010 trenn@suse.de
- patches.fixes/acpi-cpufreq_fix_cpu_any_notification.patch:
  acpi-cpufreq: Fix CPU_ANY CPUFREQ_{PRE,POST}CHANGE notification
  (none).
- patches.trace/x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  x86 cpufreq: Make trace_power_frequency cpufreq driver
  independent (none).
* Wed Apr 28 2010 trenn@suse.de
- Update config files.
  Unify X86_MSR and X86_CPUID configs:
  - CONFIG_X86_CPUID=m
  - CONFIG_X86_MSR=y
  for all i386 and x86_64 flavors.
* Mon Apr 26 2010 jeffm@suse.com
- Disabled CONFIG_TUNE_CELL on ppc64 (bnc#599045)
* Mon Apr 26 2010 jeffm@suse.com
- Enabled CONFIG_FIREWIRE (bnc#586172)
  - CONFIG_IEEE1394 is still enabled but deprecated.
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp_wmi_add_media_key.patch: x86 platform drivers:
  hp-wmi Add media key 0x20e8 (bnc#598059).
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp-wmi_detect_keys.patch: x86 platform drivers:
  hp-wmi Reorder event id processing (bnc#598059).
- patches.fixes/hp_wmi_catch_unkown_event_key_codes.patch: x86
  platform drivers: hp-wmi Catch and log unkown event and key
  codes correctly (bnc#598059).
- patches.fixes/hp_wmi_use_prefix_string.patch: x86 platform
  drivers: hp-wmi Use consistent prefix string for messages
  (bnc#598059).
* Thu Apr 22 2010 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: Fix slab.h vs slab_def.h
  include ordering in kerntypes.c
* Thu Apr 22 2010 mmarek@suse.cz
- rpm/kernel-*.spec.in: Provide %%name = %%version-%%source_rel in
  all spec files (bnc#598453).
* Thu Apr 22 2010 tiwai@suse.de
- Update config files: Fix remaining CONFIG_LEDS_CLASS=m
* Thu Apr 22 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  Refresh.  Fix dependency with LED class.
- Update config files.
* Wed Apr 21 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  input: Add LED support to Synaptics device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/input-Add-support-of-Synaptics-Clickpad-device:
  input: Add support of Synaptics Clickpad device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/synaptics-hp-clickpad: Delete.
* Wed Apr 21 2010 jeffm@suse.com
- Update to  2.6.34-rc5.
  - Eliminated 1 patch.
* Mon Apr 19 2010 jack@suse.de
- patches.fixes/novfs-LFS-initialization: fs: novfs: Initialize
  super-block with standard macros.
- patches.fixes/novfs-return-ENOTEMPTY-when-deleting-nonempty-dir:
  fs: novfs: Return ENOTEMPTY when tyring to delete a non-empty
  folder (bnc#583964).
* Mon Apr 19 2010 jeffm@suse.de
- patches.fixes/x86-apbt-conditionally-register-cpu-hp-notifier-for-apbt:
  x86/apbt: conditionally register cpu hp notifier for apbt
  (bko#15786).
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, rpm/old-packages.conf:
  Obsolete kernel-vmi-base by kernel-pae-base (bnc#594271).
- commit a48fbdf
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/mkspec, rpm/old-packages.conf: Explicitly list ppc64 flavors that
  obsolete kernel-kdump.
- commit 0a4f75b
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/old-packages.conf: s390(x) provides/obsoletes not needed anymore.
- commit 0e039b7
* Thu Apr 15 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc4 and c/s 1011.
- patches.xen/xen-netfront-ethtool: netfront: ethtool -i does
  not return info about xennet driver (bnc#591179).
- patches.xen/xen-no-reboot-vector: eliminate REBOOT_VECTOR.
- patches.xen/xen-x86_64-kern_addr_valid: x86-64:
  kern_addr_valid() must not walk page tables mapping hypervisor
  space (bnc#591371).
- Update Xen config files.
- supported.conf: drivers/xen/evtchn.ko is supported.
* Thu Apr 15 2010 teheo@suse.de
- patches.fixes/block-blk_abort_request-lock-fix: libata/SCSI:
  fix locking around blk_abort_request() (bnc#585927).
* Wed Apr 14 2010 jeffm@suse.de
- Update to 2.6.34-rc4.
  - Eliminated 3 patches.
* Tue Apr 13 2010 mmarek@suse.cz
- Update vanilla config files.
* Tue Apr 13 2010 tiwai@suse.de
- patches.suse/bootsplash-console-fix: Fix rendering on linux
  console with bootsplash (bnc#595657,bnc#594209).
* Tue Apr 13 2010 agraf@suse.de
- Update config files to disable KVM on PPC also for ppc/ppc64.
* Tue Apr 13 2010 teheo@suse.de
- Update config files to disable CONFIG_DEBUG_BLOCK_EXT_DEVT which was
  enabled by 5246824c to ease testing userland handling of ext devt.
* Mon Apr 12 2010 jslaby@suse.de
- patches.fixes/hibernation-fix-s2disk.patch: PM / Hibernate:
  user.c, fix SNAPSHOT_SET_SWAP_AREA handling (bko#15728).
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-dentry-cache-limit.patch: novfs: Remove
  dcache count restricting code (bnc#576026).
* Mon Apr 12 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Refresh (bnc#588458).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: Fix issue on
  32-bit systems.
* Fri Apr  9 2010 knikanth@suse.de
- patches.fixes/loop-update-mtime.patch: loop: Update mtime when
  writing using aops (bnc#590738).
* Thu Apr  8 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv:
  reiserfs: Fix permissions on .reiserfs_priv (bnc#593906
  CVE-2010-1146).
* Thu Apr  8 2010 agraf@suse.de
- Update PPC config files to disable KVM on PPC. It's not ready yet.
  Please enable it again as soon as we hit 2.6.35.
* Wed Apr  7 2010 jengelh@medozas.de
- Add config/sparc64/net that is light on size. For netbooting,
  both the kernel and initrd must fit into 10MB.
* Wed Mar 31 2010 jeffm@suse.de
- Updated sparc64 config.
* Wed Mar 31 2010 jeffm@suse.de
- Update to 2.6.34-rc3.
* Wed Mar 31 2010 mmarek@suse.cz
- doc/README.SUSE: Update some obsolete information.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix path to kernel source.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/configtool.pl, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Add support for custom config options
  in config.addon.tar.bz2. This tarball is expected to have the
  same layout as config.tar.bz2 and the config options listed there
  take precedence over config.tar.bz2.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generate the chmod +x line automatically.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh:
  Generate the Source: lines from kernel-source.spec.in.
* Tue Mar 30 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: reiserfs:
  Remove 2 TB file size limit (bnc#592100).
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generated the NoSource and %%setup lines automatically from the
  preamble.
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Provide $pkg = %%version-%%source_rel
  in kernel-devel and kernel-source-vanilla.
* Mon Mar 29 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-locking-BUG-during-mount-failure:
  reiserfs: Fix locking BUG during mount failure (bnc#591807).
* Mon Mar 29 2010 jeffm@suse.de
- Disabled MAX63XX_WATCHDOG on s390.
* Mon Mar 29 2010 jeffm@suse.de
- Update to 2.6.34-rc2-git3.
  - Eliminated 1 patch.
  - Fixed ps3 config.
* Mon Mar 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc2 and c/s 1007.
- Update config files.
- config.conf: Re-enable Xen configs.
- patches.xen/xen-floppy: Xen: improve floppy behavior
  (bnc#584216).
- patches.xen/xen-vscsi-module-alias: allow pv scsi hba driver
  to be loaded automatically.
- patches.xen/xen-vusb-module-alias: allow pv usb hcd driver to
  be loaded automatically (bnc#584213).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.fixes/hid-fix-gyration-oops.patch: HID: fix oops in
  gyration_event() (bnc#589329).
* Thu Mar 25 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579).
* Thu Mar 25 2010 jeffm@suse.de
- patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len:
  powerpc: fix handling of strnlen with zero len (bnc#582681).
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/lpfc-add-raywire-id: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/linux-2.6.29-kms-after-sata.patch: Refresh.
* Tue Mar 23 2010 jeffm@suse.de
- patches.fixes/do_anonymous_page-race: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/libata-prefer-over-ide: Delete.
- patches.drivers/libata-ahci-aspire-3810t-noncq: Delete.
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: Delete.
- patches.suse/block-add-mangle-devt-switch: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/apm_setup_UP.diff: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: Delete.
- patches.arch/ppc-efika-mpc52xx-ac97.patch: Delete.
- patches.arch/ppc-efika-psc-console-autodetection.patch: Delete.
- patches.suse/suse-ppc32-mol-BIT: Delete.
- patches.suse/suse-ppc32-mol-get-property: Delete.
- patches.suse/suse-ppc32-mol-handle-mm-fault: Delete.
- patches.suse/suse-ppc32-mol-ioctl: Delete.
- patches.suse/suse-ppc32-mol-kbuild.patch: Delete.
- patches.suse/suse-ppc32-mol-semaphore: Delete.
- patches.suse/suse-ppc32-mol-sheep: Delete.
- patches.suse/suse-ppc32-mol.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/dlm-enable-debug.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/ds1682-build-fix: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/kvm-as-kmp: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-fix-incompatible-pointer-type-warning:
  xfs/dmapi: fix incompatible pointer type warning.
* Sun Mar 21 2010 jeffm@suse.de
- Updated to 2.6.34-rc2.
  - Eliminated 4 patches.
* Fri Mar 19 2010 jbohac@suse.cz
- set CONFIG_IPV6=y for all flavours (bnc#561611)
* Thu Mar 18 2010 jeffm@suse.de
- Refreshed patch series.
* Wed Mar 17 2010 jeffm@suse.de
- Updated to 2.6.34-rc1-git6.
  - Eliminated 8 patches.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove Obsoletes: for 10.3 KMPs.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Move Obsoletes: msi-wmi-kmp to the
  sle11-ga group and make the comment more explanatory.
* Tue Mar 16 2010 trenn@suse.de
- rpm/kernel-binary.spec.in:
  bnc#587578
* Thu Mar 11 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Thu Mar 11 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  Fix unintialized variable. Refresh.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/gpio/max730x, max7301 now
  depends on it.
* Wed Mar 10 2010 jeffm@suse.de
- Enabled CONFIG_DRM_RADEON_KMS; Matching KMS-enabled X.org has
  been committed to Factory.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: powerpc:
  kvm build failure workaround.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/i2c/i2c-smbus, i2c-parport
  now depends on it.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: the dwarfextract package has been
  dropped from Factory.
* Wed Mar 10 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Mar 10 2010 jdelvare@suse.de
- supported.conf: Add hwmon/ams back.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix symsets for non-split kernels.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add symsets.pl to the src.rpm.
* Wed Mar 10 2010 jeffm@suse.de
- Updated to 2.6.34-rc1.
  - Eliminated 36 patches.
  - Xen is disabled
  - Added new doc/config-options.changes to document configuration
    changes.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/old-packages.conf: Obsolete kernel-vmi by kernel-default.
- rpm/kernel-module-subpackage: Also obsolete vmi KMPs.
- commit bf55479
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package symsets in the -devel package.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides: Do not generate ksym(...) provides.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides, rpm/symsets.pl: Generate symsets again
  (bnc#582907).
* Fri Mar  5 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  xfs: Non-blocking inode locking in IO completion (bnc#568319).
* Fri Mar  5 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: split devel files and full source
  into two rpms, of which only the former is really required for
  KMP building
* Fri Mar  5 2010 jengelh@medozas.de
- add configs/sparc64/default
* Wed Mar  3 2010 tonyj@suse.de
- patches.trace/powerpc-rename-irq-tracing: should have been deleted by
  previous commit
* Wed Mar  3 2010 tonyj@suse.de
- remove perfmon2 patches
* Wed Mar  3 2010 tonyj@suse.de
- Remove lttng-instrumentation patches, they have been removed from
  SLE11SP1
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Tue Mar  2 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33 and c/s 1003.
- patches.xen/xen-clockevents: replace Xen's custom time handling
  with such using GENERIC_CLOCKEVENTS infrastructure.
- Update Xen config files.
* Tue Mar  2 2010 nfbrown@suse.de
- patches.fixes/sunrpc-monotonic-expiry: sunrpc: use monotonic
  time in expiry cache (bnc#578668).
* Thu Feb 25 2010 jeffm@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: Obsolete.
* Thu Feb 25 2010 mmarek@suse.cz
- Drop include of generated/autoconf.h in our patches, it's not
  needed since 2.6.15:
- patches.suse/novfs-client-module: Refresh.
- patches.suse/s390-Kerntypes.diff: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
* Thu Feb 25 2010 teheo@suse.de
- scripts/run_oldconfig.sh doesn't update ppc/vanilla for some reason.
  Do it manually.
* Thu Feb 25 2010 teheo@suse.de
- ppc explicitly sets CONFIG_LEDS_TRIGGER_IDE_DISK.  Run
  scripts/run_oldconfig.sh to fix configs up.
* Thu Feb 25 2010 teheo@suse.de
- Drop CONFIG_IDE from all configs.
* Thu Feb 25 2010 jeffm@suse.com
- patches.xen/xen3-patch-2.6.33-rc8-final: Build fix for the
  2.6.33-final update.
* Wed Feb 24 2010 jeffm@suse.de
- Updated to 2.6.33-final.
  - Eliminated 4 patches.
* Wed Feb 24 2010 jeffm@suse.de
- patches.rpmify/ftrace-fix-ftrace_event_call-alignment-for-use-with-gcc-4-5:
  ftrace: fix ftrace_event_call alignment for use with gcc 4.5
  (bnc#582222).
* Wed Feb 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc8 and c/s 997.
- patches.xen/xen-x86-time-per-cpu: fold per-CPU accounting data
  into a structure.
- patches.xen/xen-x86-xtime-lock: reduce contention on xtime_lock
  (bnc#569014, bnc#571041, bnc#571769, bnc#572146).
* Wed Feb 24 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: use macros in a few more places
* Tue Feb 23 2010 jack@suse.de
- patches.fixes/novfs-fix-inode-uid: novfs: Get proper UID when
  looking up inode (bnc#486997).
- patches.fixes/novfs-incorrect-filesize-fix: novfs: novfs
  reports incorrect file size (bnc#426536).
- patches.fixes/novfs-truncate-fix: novfs: Fixes corruption of
  OO documents on NSS Volumes (bnc#508259).
* Sat Feb 20 2010 jengelh@medozas.de
- use standard short options in tar commands
* Wed Feb 17 2010 nfbrown@suse.de
- patches.fixes/nfs-find-crash: Fix potential oops when running
  find on an NFS mount. (bnc#573107).
* Tue Feb 16 2010 jeffm@suse.com
- Set CONFIG_LSM_MMAP_MIN_ADDR=4096 to allow qemu to emulate
  other architectures properly (bnc#574654).
* Tue Feb 16 2010 jeffm@suse.com
- Update to 2.6.33-rc8.
  - Eliminated 1 patch.
* Mon Feb 15 2010 rgoldwyn@suse.de
- patches.fixes/novfs-err_ptr-fix.diff: Oops in novfs:unlink_local
  (bnc#569071).
* Fri Feb 12 2010 trenn@suse.de
- Update config files.
  Enable p4_clockmod for i386 desktop
  While this is broken by design it allows to remove clocking
  limits from the vendor on e.g. eeepc 701
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/taskstats-alignment: delayacct: align to 8 byte
  boundary on 64-bit systems (bnc#578065).
* Fri Feb 12 2010 trenn@suse.de
- patches.fixes/acpi_fix_no_critical_tp.patch: ACPI thermal:
  Don't invalidate thermal zone if critical trip point is bad
  (bnc#531547).
- patches.fixes/acpi_pci_hot_plug_sanity_checks.patch: ACPI:
  acpi_bus_{scan,bus,add}: return -ENODEV if no device was found
  (bnc#531547).
- patches.fixes/acpi_thermal_check_trip_points.patch: ACPI
  thermal: Check for thermal zone requirement (bnc#531547).
* Fri Feb 12 2010 jdelvare@suse.de
- supported.conf: saa7111 and saa7114 are gone.
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  kdb: fix kdb_cmds to include the arch common macro (bnc#578421).
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-handle-nonexistance-keyboard-controller: kdb:
  handle nonexistance keyboard controller (bnc#578051).
* Wed Feb 10 2010 gregkh@suse.de
- patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch: dvb:
  l64781.ko broken with gcc 4.5.
* Tue Feb  9 2010 jeffm@suse.com
- patches.apparmor/apparmor-check-for-network-in-interrupt-and-work-around:
  apparmor: check for network in interrupt and work around
  (bnc#492961, bln#350789).
* Tue Feb  9 2010 jeffm@suse.com
- Update to 2.6.33-rc7.
  - Eliminated 1 patch.
* Tue Feb  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-66-idt-hp-mute-led-fix-polarity:
  ALSA: hda - Fix default polarity of mute-LED GPIO on 92HD83x/88x
  codecs (bnc#578190).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-63-idt-hp-mute-led-detect:
  ALSA: hda - Detect HP mute-LED GPIO setup from GPIO counts
  (bnc#577927).
- patches.drivers/alsa-sp1-hda-64-idt-hp-mute-led-cleanup: ALSA:
  hda - Merge HP mute-LED status callback on both IDT 92HD7x
  and 8x codecs (bnc#577927).
- patches.drivers/alsa-sp1-hda-65-idt-hp-mute-led-cleanup2:
  ALSA: hda - Remove static gpio_led setup via model (bnc#577927).
* Fri Feb  5 2010 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: Delete from repo and series.conf.
  Back to 32bytes lvb length for clvm (bnc#573460).
* Fri Feb  5 2010 duwe@suse.de
- Update config files: Compile IBM_BSR into kernel, not as module.
  (ppc only, bnc#572381)
* Fri Feb  5 2010 duwe@suse.de
- patches.arch/ppc-pseries-ncpus-1: powerpc: Add static fields
  to ibm,client-architecture call (bnc#570909).
- patches.arch/ppc-pseries-ncpus-2: powerpc/pseries: Pass more
  accurate number of supported cores to firmware (bnc#570909).
* Fri Feb  5 2010 coly.li@suse.de
- disable patches.suse/64bytes_lvb_len.diff in series.conf
* Thu Feb  4 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: Remove the previous
  hack and set STRIP_KEEP_SYMTAB='*/vmlinux-*' instead to avoid
  stripping symbols from the ppc vmlinux image (bnc#572148).
* Thu Feb  4 2010 knikanth@suse.de
- patches.fixes/dm-stripe-zero-stripes: dm-stripe: return -EINVAL
  if stripe count is zero (bnc#576312).
* Thu Feb  4 2010 npiggin@suse.de
- Disable patches.suse/files-slab-rcu.patch.
* Thu Feb  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete iwlagn-2-6-27-kmp
  (bnc#559533).
* Thu Feb  4 2010 tiwai@suse.de
- supported.conf: mark snd-wss-lib unsupported
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-61-add-idt92hd88x-support2:
  ALSA: hda - Adding support for another IDT 92HD83XXX codec
  (bnc#569354).
* Wed Feb  3 2010 jbohac@suse.cz
- supported.conf: marked em_cmp supported (bnc#568130)
* Wed Feb  3 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: automatically install a matching
  - devel package if kernel-source is installed.
* Wed Feb  3 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc6 and c/s 989.
- patches.xen/xen-netback-generalize: Netback: Generalize
  static/global variables into 'struct xen_netbk'.
- patches.xen/xen-netback-kernel-threads: Use Kernel thread to
  replace the tasklet.
- patches.xen/xen-netback-multiple-tasklets: Netback:
  Multiple tasklets support.
* Tue Feb  2 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: the message about crashed kernel
  doesn't make sense any more with CONFIG_CRASH_DUMP enabled by
  default (bnc#575884).
* Sat Jan 30 2010 jeffm@suse.com
- Update to 2.6.33-rc6.
  - Eliminated 12 patches.
* Sat Jan 30 2010 jeffm@suse.com
- patches.rpmify/hugetlbfs-fix-section-mismatches: Removed __init
  from hugetlb_sysfs_add_hstate instead of adding it elsewhere.
* Sat Jan 30 2010 jslaby@suse.de
- patches.suse/kdb-common: Fix hid crash (bnc#570591)
* Fri Jan 29 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-60-add-idt92hd88x-support: ALSA:
  hda - Add support for IDT 92HD88 family codecs (bnc#569354).
* Fri Jan 29 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  Update patch-mainline tag.
* Fri Jan 29 2010 jbenc@suse.cz
- Update config files: fixed vanilla configs.
* Thu Jan 28 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-59-idt92hd83xxx-hp-mute-led: ALSA:
  hda - Add mute LED check for HP laptops with IDT 92HD83xxx codec
  (bnc#569354).
* Thu Jan 28 2010 jbeulich@novell.com
- patches.suse/supported-flag: Fix -ec2 build.
- patches.suse/supported-flag-enterprise: Refresh.
- patches.xen/xen3-patch-2.6.33-rc3: Fix ia64 build.
* Thu Jan 28 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc5 and c/s 987.
- config.conf: Re-enable Xen.
- Update config files.
* Thu Jan 28 2010 jbenc@suse.cz
- Update config files: enabled CONFIG_CFG80211_WEXT to keep backward
  user space compatibility and enabled few wireless drivers.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: Add support for an additional series file in
  patches.addon/series, this will be applied after the main series.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: put the patch loops from kernel-binary.spec.in
  and kernel-source.spec.in to one place.
* Wed Jan 27 2010 jeffm@suse.de
- Deleted 28 unused patches.
* Wed Jan 27 2010 jeffm@suse.com
- Update config files.
* Wed Jan 27 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  pci: fix nested spinlock hang in aer_inject (bnc#573578).
* Wed Jan 27 2010 mmarek@suse.cz
- Update config files: disable generic_serial users.
- patches.drivers/reenable-generic_serial: Delete.
- rpm/generic_serial-blacklist: Delete (bnc#569676).
* Wed Jan 27 2010 jengelh@medozas.de
- remove patches.suse/netfilter-ipv4options [bnc#490142]
* Wed Jan 27 2010 jeffm@suse.com
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: Refresh.
* Tue Jan 26 2010 knikanth@suse.de
- supported.conf: Fix misspelt dm-region-hash and mark it supported
  correctly (bnc#565962)
* Mon Jan 25 2010 gregkh@suse.de
- Update to 2.6.32.6
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/8250_pnp-wacom-add
  - patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch
  - patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch
  - patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch
* Mon Jan 25 2010 jeffm@suse.com
- supported.conf: Added sparse_keymap (eeepc_laptop depends on it)
* Mon Jan 25 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: slab -
  handle memoryless nodes V2a (bnc#436025, bnc#570492).
* Mon Jan 25 2010 jeffm@suse.com
- Updated to 2.6.33-rc5.
  - Eliminated 2 patches.
* Mon Jan 25 2010 trenn@suse.de
- Update config files.
- patches.arch/x86_mce_intel_decode_physical_address.patch: x86,
  mce: Xeon75xx specific interface to get corrected memory error
  information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  x86, mce: Xeon75xx specific interface to get corrected memory
  error information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
  (bnc#573380, fate#307738).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Mon Jan 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-57-cx5051-toshiba-quirk:
  ALSA: hda - Add support for Toshiba Satellite M300
  (bnc#492233,bnc#565904).
- patches.drivers/alsa-sp1-hda-58-cx5051-lenovo-mute-fix: ALSA:
  hda - Change headphone pin control with master volume on cx5051
  (bnc#573050).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_enable_tsc_sync_check_again.patch: x86:
  Reenable TSC sync check at boot, even with NONSTOP_TSC
  (bnc#573379).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch:
  x86: Set hotpluggable nodes in nodes_possible_map (bnc#567216).
- patches.arch/x86_node_hotplug_parse_srat_fix.patch: Delete.
* Mon Jan 25 2010 trenn@suse.de
- supported.conf:
  Add mce-inject and hwpoison-inject so that Intel can easier test
  this. As these are debug drivers, they might get reverted from
  support.conf again if kernel-extra package gets fixed for SLES,
  only seem to exist for SLED because "NCC is not yet working for SP1".
  (bnc#572552).
* Sat Jan 23 2010 bphilips@suse.de
- patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch: tg3:
  updates from f4188d to ba5b0bf (bnc#573237).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-irq-check-move_in_progress-before-freeing-the-vector-mapping.patch:
  x86, irq: Check move_in_progress before freeing the vector
  mapping (bnc#558247).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch:
  x86, apic: use logical flat for systems with <= 8 logical cpus
  (bnc#567510).
- patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch:
  x86: Revert "apic: Use logical flat on intel with <= 8 logical
  cpus" (bnc#567510).
* Sat Jan 23 2010 gregkh@suse.de
- Update to 2.6.32.5:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-54-alc861-capture-fix
  - patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard
  - patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
  - patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch
* Fri Jan 22 2010 tonyj@suse.de
- Update config files: drop UTRACE from default s390 configs
  as per communication from Ihno.
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch:
  x86, msr/cpuid: Register enough minors for the MSR and CPUID
  drivers (bnc#572720).
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch:
  SCSI: enclosure: fix oops while iterating enclosure_status array
  (bnc#572818).
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  Delete.
* Fri Jan 22 2010 duwe@suse.de
- Update config files.
- patches.arch/ppc-extended_h_cede-update-to-mainline: Incremental
  patch set to sync H_CEDE with actual mainline (bnc#550447,
  FATE#307059).
* Fri Jan 22 2010 trenn@suse.de
- Update config files.
  Add DMAR to -trace flavor -> get in sync with -default
* Fri Jan 22 2010 hare@suse.de
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Re-save PCI state after EEH recovery (bnc#570233).
* Fri Jan 22 2010 jjolly@suse.de
- patches.arch/s390-06-01-zfcp-introduce-bsg-timeout-callback.patch:
  zfcp: introduce BSG timeout callback (BNC#572659).
- patches.arch/s390-06-02-zfcp-set-hw-timeout-requested-by-bsg.patch:
  zfcp: set HW timeout requested by BSG request (BNC#572659).
* Fri Jan 22 2010 bphilips@suse.de
- patches.drivers/netxen-8f9b3f-to-c651a8.patch: netxen: 8f9b3f
  to c651a8 (bnc#572832).
* Fri Jan 22 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh to
  newest version of patch.
* Thu Jan 21 2010 astarikovskiy@suse.de
- supported.conf: added power_meter driver (FATE #306959).
* Thu Jan 21 2010 tonyj@suse.de
- config.conf: add -trace flavor for s390* at Ihno's request
- Add more tracers to existing ppc64 trace config at IBM request
  Both related to FATE# 307051.
- patches.trace/ftrace-framepointer.diff: Delete.
* Thu Jan 21 2010 hare@suse.de
- patches.fixes/scsi-fc-class-allow-LLD-bsg-timeout:
  scsi_transport_fc: Allow LLD to reset FC BSG timeout
  (bnc#572658).
* Thu Jan 21 2010 jbeulich@novell.com
- patches.xen/xen-privcmd-mmap-batch-clear: privcmd: mmapbatch-v2
  fixes.
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5-update: lpfc update to 8.3.5
  (bnc#572427).
- patches.drivers/lpfc-8.3.5.3-update: lpfc driver update to
  8.3.5.3 (bnc#572427).
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh. More updates and
  clean-up by Egbert (bnc#570082)
* Wed Jan 20 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
* Wed Jan 20 2010 jslaby@suse.de
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
  (change firmwares in makefile)
* Wed Jan 20 2010 jslaby@suse.de
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: Refresh.
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch: Refresh.
* Wed Jan 20 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.4 and c/s 984.
- Update Xen config files.
* Wed Jan 20 2010 bphilips@suse.de
- patches.drivers/bnx2i-backport-from-v2.6.32-to-45ca38e.patch:
  bnx2i: Backport from v2.6.32 to 45ca38e (bnc#564640).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  bnx2x: backports v2.6.32 to af901ca (bnc#564638).
- patches.drivers/cnic-backport-from-v2.6.32-4e9c4f.patch: cnic:
  backport from v2.6.32-4e9c4f (bnc#564640).
* Wed Jan 20 2010 gregkh@suse.de
- Update config files.  2.6.32.4 changed one of them.
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fixed the text area
  calculation, and added the upscaling (bnc#570082).
* Tue Jan 19 2010 jeffm@suse.com
- Updated to 2.6.33-rc4-git7.
  - Eliminated 4 patches.
* Tue Jan 19 2010 gregkh@suse.de
- Patch refresh for fuzz due to upstream -stable additions.
* Tue Jan 19 2010 gregkh@suse.de
- Update to 2.6.32.4
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y
  - patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix
  - patches.fixes/audit_untag_chunk.patch
  - patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch
  - patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1
* Tue Jan 19 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix: ALSA: hda -
  Fix parsing pin node 0x21 on ALC259 (bnc#571879).
- patches.drivers/alsa-sp1-hda-56-realtek-eapd-fix: ALSA: hda -
  Turn on EAPD only if available for Realtek codecs (bnc#571879).
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fix the hang-up with
  resolution changes (bnc#570082)
* Tue Jan 19 2010 jkosina@suse.cz
- supported.conf: added aesni-intel (bnc#566618 FATE#304209).
* Tue Jan 19 2010 jkosina@suse.cz
- Update config files: set CONFIG_CRYPTO_HMAC=y to avoid
  regression from SLE11 (bnc#571501).
* Tue Jan 19 2010 jack@suse.de
- patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch:
  reiserfs: truncate blocks not used by a write (bnc#483375).
* Mon Jan 18 2010 jeffm@suse.de
- patches.suse/smtnice-disable: Delete (obsolete).
* Mon Jan 18 2010 jeffm@suse.com
- Disabled custom ACPI table loading from initramfs again.
* Mon Jan 18 2010 jeffm@suse.com
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Mon Jan 18 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix.patch:
  x86/mm/srat_64.c: nodes_parsed should include all nodes detected
  by ACPI (bnc#567140).
* Mon Jan 18 2010 hare@suse.de
- patches.fixes/aic79xx-null-scb-in-nonpkt-busfree: aic79xx: check
  for non-NULL scb in ahd_handle_nonpkt_busfree (bnc#542568).
* Mon Jan 18 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh to fix 60 second delay. (bnc#568271)
* Sat Jan 16 2010 tonyj@suse.de
- patches.fixes/audit_untag_chunk.patch: fix braindamage in
  audit_tree.c untag_chunk() (bnc#556282).
* Sat Jan 16 2010 rjw@suse.de
- patches.xen/xen-x86-rename-display_cacheinfo-to-cpu_detect_cache_sizes.patch:
  x86: Rename display_cacheinfo() to cpu_detect_cache_sizes().
* Fri Jan 15 2010 gregkh@suse.de
- Update config files.
- patches.drivers/vmw_pvscsi-scsi-driver-for-vmware-s-virtual-hba.patch:
  vmw_pvscsi: SCSI driver for VMware's virtual HBA.
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard:
  HID: add device IDs for new model of Apple Wireless Keyboard
  (bnc#568231).
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 trenn@suse.de
- patches.suse/kdb_dont_touch_i8042_early.patch: Avoid early
  hang when i8042 controller is missing (bnc#528811).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/remount-no-shrink-dcache: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/smtnice-disable: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 mfasheh@suse.com
- patches.fixes/Ocfs2-Let-ocfs2-support-fiemap-for-symlink-and-fast-.patch:
  Ocfs2: Let ocfs2 support fiemap for symlink and fast symlink..
- patches.fixes/Ocfs2-Should-ocfs2-support-fiemap-for-S_IFDIR-inode.patch:
  Ocfs2: Should ocfs2 support fiemap for S_IFDIR inode?.
- patches.fixes/ocfs-stop-using-do_sync_mapping_range.patch:
  ocfs: stop using do_sync_mapping_range.
- patches.fixes/ocfs2-Add-reflinked-file-s-inode-to-inode-hash-earil.patch:
  ocfs2: Add reflinked file's inode to inode hash eariler..
- patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch:
  ocfs2: Find proper end cpos for a leaf refcount block..
- patches.fixes/ocfs2-Set-i_nlink-properly-during-reflink.patch:
  ocfs2: Set i_nlink properly during reflink..
- patches.fixes/ocfs2-always-include-acl-support.patch: ocfs2:
  Always include ACL support.
- patches.fixes/ocfs2-cluster-Make-fence-method-configurable-v2.patch:
  ocfs2/cluster: Make fence method configurable - v2.
- patches.fixes/ocfs2-devel-remove-redundant-OCFS2_MOUNT_POSIX_ACL-c.patch:
  ocfs2-devel: remove redundant OCFS2_MOUNT_POSIX_ACL check
  in ocfs2_get_acl_nolock().
- patches.fixes/ocfs2-explicit-declare-uninitialized-var-in-user_clu.patch:
  ocfs2: explicit declare uninitialized var in
  user_cluster_connect().
- patches.fixes/ocfs2-make-acl-use-the-default.patch: ocfs2:
  Make acl use the default.
- patches.fixes/ocfs2-refcounttree.c-cleanup.patch: ocfs2:
  refcounttree.c cleanup..
- patches.fixes/ocfs2-replace-u8-by-__u8-in-ocfs2_fs.h.patch:
  ocfs2: replace u8 by __u8 in ocfs2_fs.h.
- patches.fixes/ocfs2-return-EAGAIN-instead-of-EAGAIN-in-dlm.patch:
  ocfs2: return -EAGAIN instead of EAGAIN in dlm.
- patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch: ocfs2:
  Set MS_POSIXACL on remount.
- patches.fixes/ocfs2-trivial-Use-le16_to_cpu-for-a-disk-value-in-xa.patch:
  ocfs2/trivial: Use le16_to_cpu for a disk value in xattr.c.
- patches.fixes/ocfs2-trivial-Use-proper-mask-for-2-places-in-hearbe.patch:
  ocfs2/trivial: Use proper mask for 2 places in hearbeat.c.
- patches.suse/fiemap-Add-new-extent-flag-FIEMAP_EXTENT_SHARED.patch:
  fiemap: Add new extent flag FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-Use-FIEMAP_EXTENT_SHARED.patch: ocfs2:
  Use FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch:
  x86: Limit number of per cpu TSC sync messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Limit-the-number-of-processor-bootup-messages.patch:
  x86: Limit the number of processor bootup messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-CPU-cache-size-output-for-non-Intel-too.patch:
  x86: Remove CPU cache size output for non-Intel too (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-enabling-x2apic-message-for-every-CPU.patch:
  x86: Remove enabling x2apic message for every CPU (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-the-CPU-cache-size-printks.patch: x86:
  Remove the CPU cache size printk's (bnc#564618, FATE#306952).
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  x86, cpu: mv display_cacheinfo -> cpu_detect_cache_sizes
  (bnc#564618, FATE#306952).
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  x86: ucode-amd: Load ucode-patches once and not separately of
  each CPU (bnc#564618, FATE#306952).
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch:
  sched: Limit the number of scheduler debug messages (bnc#564618,
  FATE#306952).
- patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch:
  timers, init: Limit the number of per cpu calibration bootup
  messages (bnc#564618, FATE#306952).
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/add-initramfs-file_read_write: Build fix.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-enterprise: Refresh.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-sysfs: Properly report proprietary modules
* Thu Jan 14 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: initramfs: add
  initramfs_{read,write} (bnc#568120).
- Re-enabled custom ACPI table loading from initramfs.
* Thu Jan 14 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_CPU_FREQ_DEBUG as requested by HP.
  This one adds conditional printks which can be enabled via:
  cpufreq.debug=7
* Thu Jan 14 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-54-alc861-capture-fix: ALSA: hda -
  Fix missing capture mixer for ALC861/660 codecs (bnc#567340).
* Thu Jan 14 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: really fix ppc
  symbol provides.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/UV-Expose-irq_desc-node-in-proc.patch: Expose the
  irq_desc node as /proc/irq/*/node. (bnc#566745, fate#306952).
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch:
  dmfe/tulip: Let dmfe handle DM910x except for SPARC on-board
  chips (bnc#537016).
* Wed Jan 13 2010 jkosina@suse.cz
- patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch:
  crypto: testmgr - Fix complain about lack test for internal
  used algorithm (bnc#568278 FATE#306883).
* Wed Jan 13 2010 jeffm@suse.com
- Update to 2.6.33-rc4.
  - Eliminated patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
* Wed Jan 13 2010 mmarek@suse.cz
- patches.suse/bootsplash-keep-multiple-data: Keep multiple
  splash screens for KMS (bnc#570082).
- patches.suse/bootsplash-scaler: Add bootsplash image scaler
  (bnc#570082).
* Wed Jan 13 2010 mmarek@suse.de
- rpm/kernel-binary.spec.in, rpm/find-provides: extract exported
  symbols from /boot/vmlinux before the image is stripped (affects
  ppc).
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/twl6030-fix-note_interrupt-call: Rename to patches.fixes/twl6030-fix-note_interrupt-call
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/autoconf-h-fix-locations: autoconf.h: Fix
  locations.
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: Renamed to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  Delete.
* Tue Jan 12 2010 jeffm@suse.com
- Update config files.
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: rename to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 rjw@suse.de
- needs_update: Remove some patches that we've got through the
  upstream.
* Tue Jan 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix: ALSA:
  hda - Fix ALC861-VD capture source mixer (bnc#568305).
* Tue Jan 12 2010 jeffm@suse.com
- Update to 2.6.33-rc3-git5.
* Tue Jan 12 2010 trenn@suse.de
- patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch:
  nohz: Prevent clocksource wrapping during idle (bnc#569238).
* Tue Jan 12 2010 jack@suse.de
- patches.suse/readahead-request-tunables.patch: Update readahead
  and max_sectors tunables (bnc#548529).
* Tue Jan 12 2010 jkosina@suse.cz
- patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch:
  iTCO_wdt: Add support for Intel Ibex Peak (bnc#557081
  FATE#308591).
* Tue Jan 12 2010 tonyj@suse.de
- needs_update: remove LTT/trace patches (assigned to jbl), all had
  already been taken care of by my fwd port to 2.6.32
* Tue Jan 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Fixup compilation error.
* Tue Jan 12 2010 rjw@suse.de
- patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch:
  PCI: Always set prefetchable base/limit upper32 registers
  (bnc#569003).
* Mon Jan 11 2010 jeffm@suse.com
- Merged patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu into
  patches.arch/kvm-split-paravirt-ops-by-functionality
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/kmsg-fix-parameter-limitations to
  patches.arch/kmsg-fix-parameter-limitations
* Mon Jan 11 2010 jeffm@suse.com
- patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu:
  x86_64/ksyms: Make the native_load_gs_index export depend
  on CONFIG_PARAVIRT_CPU.
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/rt2870-fix-section-mismatches to
  patches.rpmify/rt2860-fix-section-mismatches
* Mon Jan 11 2010 jeffm@suse.de
- Updated to 2.6.33-rc3-git3.
  - Eliminated 392 patches.
  - Xen is disabled.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Update qla4xxx driver for SLES11 SP1 (bnc#556572,FATE#307128).
* Mon Jan 11 2010 jblunck@suse.de
- needs_update: Removed some patches.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-update: Update bfa driver to
  version 2.1.2.1 (bnc#561881).
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/fcoe-libfc-adds-enable-di: adds enable/disable
  for fcoe interface (bnc#562046).
- patches.fixes/fcoe-use-lld-s-wwpn-and-w: Use LLD's WWPN and
  WWNN for lport if LLD supports ndo_fcoe_get_wwn (bnc#562046).
- patches.fixes/libfc-reduce-hold-time-on: reduce hold time on
  SCSI host lock (bnc#562046).
- patches.fixes/libfc-remote-port-gets-st: remote port gets
  stuck in restart state without really restarting (bnc#562046).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: LSI mptsas2 driver
  update to 03.100.03.00 (bnc#566013).
* Mon Jan 11 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-nx-user-mappings: Delete (bnc#568741).
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/qla4xxx-lun-reset-fix: Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-ibm-174x: scsi_dh_rdac: Add
  two new IBM devices (bnc# 556159).
* Sat Jan  9 2010 jslaby@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Refresh.
- patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch:
  resource: move kernel function inside __KERNEL__ (FATE#305733).
- patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits (FATE#305733).
- patches.suse/rlim-0004-IA64-use-helpers-for-rlimits.patch:
  [IA64] use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  infiniband: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  FS: proc, switch limits reading to fops (FATE#305733).
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable (FATE#305733).
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Delete.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Delete.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Delete.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Delete.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Delete.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Delete.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Delete.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Delete.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Delete.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Delete.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Delete.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Delete.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Delete.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Delete.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
  Sync with upstream. Drop limits syscalls altogether.
* Sat Jan  9 2010 jkosina@suse.cz
- patches.apparmor/apparmor.diff: Delete, as it is unused after
  splitup into smaller patches.
* Fri Jan  8 2010 sjayaraman@suse.de
- patches.suse/SoN-23-mm-swapfile.patch: Fix up the enum declaration
  to avoid conflict due to a upstream change.
* Fri Jan  8 2010 jkosina@suse.cz
- patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch:
  quota: fix reserved space management for ordinary fs.
* Fri Jan  8 2010 gregkh@suse.de
- patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch:
  Staging: hv: fix smp problems in the hyperv core code.
* Fri Jan  8 2010 jeffm@suse.de
- Disable set,getprlimit compat syscalls on xen.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled custom ACPI table loading from initramfs until
  the scheduling while atomic issues are worked out.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled set,getprlimit syscalls until the syscall numbers
  have been officially reserved.
* Fri Jan  8 2010 jeffm@suse.com
- patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y:
  module: handle ppc64 relocating kcrctabs when
  CONFIG_RELOCATABLE=y (bnc#566243).
* Thu Jan  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.3 and c/s 974.
- Update EC2 config files.
- patches.xen/xen3-x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.xen/xen3-x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.xen/xen3-x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  Delete.
- patches.xen/xen-scsifront-block-timeout-update: Delete.
- patches.xen/xen3-x86-fix-nodac: Delete.
* Thu Jan  7 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  e1000: enhance frame fragment detection (bnc#567376,
  CVE-2009-4536).
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  e1000e: enhance frame fragment detection (bnc#567376,
  CVE-2009-4538).
* Thu Jan  7 2010 gregkh@suse.de
- Update to 2.6.32.3
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-04-03-dasd-diag-ro.patch
  - patches.drivers/alsa-sp1-hda-50-alc88x-missing-capsrc_nids
  - patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host
  - patches.fixes/scsi-ipr-fix-eeh-recovery
* Wed Jan  6 2010 rjw@suse.de
- patches.arch/x86-Force-irq-complete-move-during-cpu-offline.patch:
  x86: Force irq complete move during cpu offline (bnc#558247).
- patches.arch/x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.arch/x86-Remove-move_cleanup_count-from-irq_cfg.patch:
  x86: Remove move_cleanup_count from irq_cfg (bnc#558247).
- patches.arch/x86-Remove-unnecessary-mdelay-from-cpu_disable_common.patch:
  x86: Remove unnecessary mdelay() from cpu_disable_common()   .
- patches.arch/x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.arch/x86-Use-EOI-register-in-io-apic-on-intel-platforms.patch:
  x86: Use EOI register in io-apic on intel platforms
  (bnc#558247).
- patches.arch/x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.arch/x86-io-apic-Move-the-effort-of-clearing-remoteIRR-explicitly-before-migrating-the-irq.patch:
  x86, io-apic: Move the effort of clearing remoteIRR explicitly
  before migrating the irq (bnc#558247).
- patches.arch/x86-ioapic-Document-another-case-when-level-irq-is-seen-as-an-edge.patch:
  x86, ioapic: Document another case when level irq is seen as
  an edge (bnc#558247).
- patches.arch/x86-ioapic-Fix-the-EOI-register-detection-mechanism.patch:
  x86, ioapic: Fix the EOI register detection mechanism
  (bnc#558247).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch: PCI:
  AER: fix aer inject result in kernel oops (bnc#566619).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch:
  PCIe AER: reject aer inject if hardware mask error reporting
  (bnc#566621).
* Wed Jan  6 2010 gregkh@suse.de
- patches.xen/xen3-patch-2.6.29: Refresh due to conflicts from i915
  changes.  Ick, the xen code sucks rocks, it shouldn't be touching
  stuff here at all.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
- patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch:
  drm/i915: add i915_lp_ring_sync helper (bnc#568447).
- patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch:
  drm/i915: fix get_core_clock_speed for G33 class desktop chips
  (bnc#568447).
- patches.drivers/drm-i915-fully-switch-off-overlay-when-not-in-use.patch:
  drm/i915: fully switch off overlay when not in use (bnc#568447).
- patches.drivers/drm-i915-implement-drmmode-overlay-support-v4.patch:
  drm/i915: implement drmmode overlay support v4 (bnc#568447).
- patches.drivers/drm-i915-implement-fastpath-for-overlay-flip-waiting.patch:
  drm/i915: implement fastpath for overlay flip waiting
  (bnc#568447).
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
* Tue Jan  5 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  drm/i915: Add ACPI OpRegion support for Ironlake (bnc#568436).
* Tue Jan  5 2010 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Update to newer version
* Wed Dec 30 2009 nfbrown@suse.de
- patches.fixes/nfs-fix-NFS4ERR_FILE_OPEN-handling:
  NFS4ERR_FILE_OPEN handling in Linux/NFS (bnc#526819).
* Mon Dec 28 2009 jeffm@suse.com
- patches.fixes/dmar-fix-oops-with-no-dmar-table: dmar: Fix oops
  with no DMAR table (bnc#548108).
* Sun Dec 27 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-52-hdmi-sticky-stream-tag: ALSA:
  hda - HDMI sticky stream tag support (FATE#306783).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/xpc_first_contact_when_active.patch: X86: UV
  - xpc_make_first_contact hang due to not accepting ACTIVE
  state. (bnc#562288, fate#306952).
- patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch: x86: UV - XPC
  NULL deref when mesq becomes empty. (bnc#562288, fate#306952).
- patches.arch/xpc_introduce_xp_socket.patch: x86: UV - XPC
  needs to provide an abstraction for uv_gpa. (bnc#562288,
  fate #306952).
- patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch:
  UV - pass nasid instead of nid to gru_create_message_queue
  (bnc#562288, fate#306952).
- patches.arch/xpc_recv_msg_slots_wrap.patch: X86: UV - XPC
  receive message reuse triggers invalid BUG_ON(). (bnc#562288,
  fate#306952).
- patches.arch/xpc_uv_bios_changes.patch: x86: UV - Update XPC
  to handle updated BIOS interface. (bnc#562288, fate#306952).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561989_gru_rollup.patch: SGI GRU Updates
  (bnc#561989, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: powerpc: use min_t in
  copy_oldmem_page.
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561946_uv_irq_affinity.patch: x86: SGI UV: Fix
  irq affinity for hub based interrupts (bnc#561946, fate#306952).
- patches.arch/bug-561946_uv_move_ioapic.patch: x86, apic: Move
  SGI UV functionality out of generic IO-APIC code (bnc#561946,
  fate#306952).
- patches.arch/bug-561946_uv_use_rtc.patch: x86: UV RTC: Always
  enable RTC clocksource (bnc#561946, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly:
  fix SBA IOMMU to handle allocation failure properly
  (bnc#545367).
* Tue Dec 22 2009 jeffm@suse.com
- Enabled CONFIG_CRASH_DUMP on ppc/ppc64 (bnc#566243).
* Tue Dec 22 2009 jeffm@suse.com
- patches.fixes/scsi-ipr-fix-eeh-recovery: ipr: fix EEH recovery
  (bnc#566613).
* Sun Dec 20 2009 trenn@suse.de
- Update config files.
- patches.drivers/cpufreq_ondemand_limit_fix.patch: cpufreq:
  Fix ondemand to not request targets outside policy limits
  (fate#306746).
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver.patch:
  x86,cpufreq: Processor Clocking Control (PCC) driver
  (fate#306746).
- supported.conf:
* Sun Dec 20 2009 rjw@suse.de
- patches.arch/bug-561939_uv_bios_call_hwperf_updated.patch:
  x86, uv: Add serial number parameter to uv_bios_get_sn_info()
  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: Delete.
* Sat Dec 19 2009 jeffm@suse.com
- patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly:
  scsi_debug: scale virtual_gb with sector_size properly
  (bnc#535939).
* Sat Dec 19 2009 gregkh@suse.de
- patches.xen/xen3-fixup-xen: Refresh.  Fix up build error from
  .32.2 import
* Sat Dec 19 2009 gregkh@suse.de
- Update to 2.6.32.2
  - lots of security fixes
  - loads of bugfixes
  - other goodness
  - obsoletes:
  - patches.arch/bug-561939_bau_data_config.patch
  - patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch
  - patches.arch/s390-04-01-clear-high-regs.patch
  - patches.arch/s390-kvm-prefix.patch
  - patches.arch/s390-kvm-psw.patch
  - patches.arch/x86-fix-nodac
  - patches.arch/x86_mce_nfs-mig2
  - patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero
  - patches.fixes/uart-txen-race.patch
* Fri Dec 18 2009 jeffm@suse.com
- Update config files: CONFIG_STRICT_DEVMEM=n. It was enabled
  mistakenly in commit 3df90f9e and affects using tools like
  crash with a live system.
* Fri Dec 18 2009 gregkh@suse.de
- Update config files.
  CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT = n (bnc#565607)
* Fri Dec 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-{24..51}-*: 2.6.33-rc1 backport
  fixes for HDMI and new Realtek codecs (FATE#306783)
- Refresh Patch-mainline tags in patches.drivers/alsa-*
* Fri Dec 18 2009 jjolly@suse.de
- patches.arch/s390-05-01-netiucv-tx-bytes.patch: netiucv:
  displayed TX bytes value much too high (BNC#565612).
- patches.arch/s390-05-02-cmm-suspend.patch: cmm: free pages on
  hibernate. (BNC#565612).
- patches.arch/s390-05-03-iucv-suspend.patch: iucv: add work_queue
  cleanup for suspend (BNC#565612).
- patches.arch/s390-05-04-zfcp-work-queue.patch: zfcp: Assign
  scheduled work to driver queue (BNC#565612).
- patches.arch/s390-05-05-zfcp-fail-commands.patch: zfcp: Don't
  fail SCSI commands when transitioning to blocked fc_rport
  (BNC#565612,LTC#58541).
- patches.arch/s390-05-06-zfcp-adisc.patch: zfcp: Improve ELS
  ADISC handling (BNC#565612).
- patches.arch/s390-05-07-zfcp-fsf-errors.patch: zfcp: Update
  FSF error reporting (BNC#565612).
- patches.arch/s390-05-08-zfcp-block.diff: zfcp: Block SCSI EH
  thread for rport state BLOCKED (BNC#565612).
- patches.arch/s390-05-09-ctcm-suspend-wait.diff: ctcm: suspend
  has to wait for outstanding I/O (BNC#565612).
- patches.arch/s390-05-10-rework-tso.diff: qeth: rework TSO
  functions (BNC#565612).
- patches.arch/s390-05-11-atomic-volatile.patch: kernel: improve
  code generated by atomic operations. (BNC#565612).
- patches.arch/s390-05-12-tape-remove-fn.patch: tape: incomplete
  device removal (BNC#565612).
- patches.arch/s390-05-13-qeth-blkt-defaults.patch: qeth:
  set default BLKT settings dependend on OSA hw level
  (BNC#565612,LTC#58654).
- patches.arch/s390-05-14-dasd-dasd-enable-prefix.patch: dasd:
  enable prefix independent of pav support (BNC#565612).
- patches.arch/s390-05-15-dasd-s390dbf-strings.patch: dasd:
  remove strings from s390dbf (BNC#565612).
- patches.arch/s390-05-16-dasd-wait-lcu-setup.patch: dasd:
  let device initialization wait for LCU setup (BNC#565612).
* Fri Dec 18 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix generating /boot/Kerntypes* for
  s390/vanilla.
* Fri Dec 18 2009 nfbrown@suse.de
- patches.fixes/md-start_ro-fix: md: fix small irregularity with
  start_ro module parameter (bnc#565219).
* Fri Dec 18 2009 rjw@suse.de
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  XEN: Fix compilation after renaming of generic_irqs.
* Fri Dec 18 2009 rjw@suse.de
- patches.arch/bug-561946_rename_generic_int.patch: x86: UV RTC:
  Rename generic_interrupt to x86_platform_ipi (bnc#561946,
  fate#306952).
* Thu Dec 17 2009 mmarek@suse.cz
- patches.suse/s390-Kerntypes.diff: S390: Generate Kerntypes file.
- rpm/kernel-binary.spec.in: install /boot/Kerntypes-$version.
* Thu Dec 17 2009 jeffm@suse.com
- patches.fixes/powerpc-fix-cpu-name-in-show-cpuinfo: powerpc:
  fix cpu name in show-cpuinfo (bnc#565267).
* Thu Dec 17 2009 hare@suse.de
- patches.fixes/fc-transport-remove-BUG_ON: scsi_transport_fc:
  remove invalid BUG_ON (bnc#564479).
- patches.fixes/lpfc-ia64-hang: lpfc: fix hang on SGI ia64
  platform (bnc#564479).
- patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host:
  qla2xxx: dpc thread can execute before scsi host has been added
  (bnc#564479).
- patches.suse/fc-transport-allow-dev_loss_tmo-disable: Remove
  capping from dev_loss_tmo (bnc#492469).
* Wed Dec 16 2009 gregkh@suse.de
- Update config files.
  - fix up CONFIG_IPV6 option that was built into the kernel
    incorrectly (bnc#564357)
* Wed Dec 16 2009 jeffm@suse.com
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  acpi: Fix build when CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS is
  not defined.
* Wed Dec 16 2009 jbeulich@novell.com
- Update Xen patches to c/s 960.
- Update Xen EC2 config files.
- patches.xen/xen3-bug-561933_uv_pat_is_gru_range.patch: x86:
  UV SGI: Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.fixes/aggressive-zone-reclaim.patch: be more aggressive
  with zone reclaims (bnc#476525).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.suse/x86-mark_rodata_rw.patch: Refresh.
* Wed Dec 16 2009 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Dec 15 2009 jeffm@suse.com
- patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero:
  firewire: ohci: handle receive packets with a data length of
  zero (bnc#564712 CVE-2009-4138).
* Tue Dec 15 2009 mmarek@suse.cz
- rpm/config.sh: set OBS_PROJECT and IBS_PROJECT variables for
  osc_wrapper.
* Tue Dec 15 2009 knikanth@suse.de
- supported.conf: Mark dm-log-userspace as supported (fate#307380).
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  Fix the build failure due to previous commit.
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  sched: Fix missing sched tunable recalculation on cpu add/remove
  (bnc#560317).
- patches.fixes/sched-make-tunable-scaling-configurable: sched:
  Make tunable scaling style configurable (bnc#560317).
- patches.fixes/sched-sysctl-for-normalized-tunables:  sched:
  Update normalized values on user updates via proc (bnc#560317).
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - fix up USB options that were built into the kernel incorrectly
    (bnc#564357)
* Mon Dec 14 2009 jjolly@suse.de
- patches.arch/s390-04-01-clear-high-regs.patch: kernel:
  clear high-order bits after switching to 64-bit mode
  (BNC#563999,LTC#58088).
- patches.arch/s390-04-02-zcrypt-hrtimer.patch: zcrypt: Do not
  simultaneously schedule hrtimer (BNC#563999,LTC#58222).
- patches.arch/s390-04-03-dasd-diag-ro.patch: dasd: support DIAG
  access for read-only devices (BNC#563999,LTC#57147).
- patches.arch/s390-04-04-mm-fault-fix.patch: kernel: performance
  counter fix and page fault optimization (BNC#563999).
- patches.arch/s390-04-05-sclp-dump-indicator.patch: kernel:
  fix dump indicator (BNC#563999).
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: dasd:
  move diag kmsg to generic dasd kmsg (BNC#563999).
- patches.arch/s390-04-07-cio-fix-double-free.patch: cio: double
  free under memory pressure (BNC#563999).
- patches.arch/s390-04-08-cio-fix-dev-stall.patch: cio: device
  recovery stalls after multiple hardware events (BNC#563999).
- patches.arch/s390-04-09-cio-recover-hw-changes.patch: cio:
  device recovery fails after concurrent hardware changes
  (BNC#563999).
- patches.arch/s390-04-10-cio-fix-onoffline-failure.patch: cio:
  setting a device online or offline fails for unknown reasons
  (BNC#563999).
- patches.arch/s390-04-11-cio-error-reporting.patch: cio:
  incorrect device state after device recognition and recovery
  (BNC#563999).
- patches.arch/s390-04-12-cio-avoid-panic.patch: cio: kernel
  panic after unexpected interrupt (BNC#563999).
- patches.arch/s390-04-13-cio-internal-io.patch: cio:
  initialization of I/O devices fails (BNC#563999).
- patches.arch/s390-04-14-cio-allow-offline.patch: cio: not
  operational devices cannot be deactivated (BNC#563999).
- patches.arch/s390-04-15-cio-split-pgid.patch: cio: erratic
  DASD I/O behavior (BNC#563999).
- patches.arch/s390-04-16-cio-path-verification.patch: cio:
  DASD cannot be set online (BNC#563999).
- patches.arch/s390-04-17-cio-steal-lock.patch: cio: DASD steal
  lock task hangs (BNC#563999).
- patches.arch/s390-04-18-cio-fix-memleak-chk-dev.patch: cio:
  memory leaks when checking unusable devices (BNC#563999).
- patches.arch/s390-04-19-cio-fix-deact-dev-panic.patch: cio:
  deactivated devices can cause use after free panic (BNC#563999).
* Mon Dec 14 2009 rjw@suse.de
- patches.arch/bug-561933_uv_pat_is_gru_range.patch: x86: UV SGI:
  Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.arch/bug-561939_bau_data_config.patch: x86: SGI UV
  BAU initialization (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: x86: UV
  hardware performance counter and topology access  (bnc#561939,
  fate#306952).
- patches.arch/bug-561939_uv_gpa_is_mmr_space.patch: x86: UV -
  Introduce uv_gpa_is_mmr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_gpa_to_soc_phys_ram.patch:
  x86: UV - Introduce a means to translate from gpa ->
  socket_paddr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_ipi_macro.patch: x86: UV: Introduce
  uv_hub_ipi_value (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_mmap_low.patch: x86: SGI UV: Map
  low MMR ranges (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_cleanup.patch: x86: UV RTC:
  Clean up error handling (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_fixes.patch: x86: UV RTC:
  Fix early expiry handling  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_setup_evt.patch: x86: UV RTC:
  Add clocksource only boot option (bnc#561939, fate#306952).
- patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch:
  x86: Fix duplicated UV BAU interrupt vector (bnc#564471).
* Mon Dec 14 2009 gregkh@suse.de
- Refresh patches to be clean of fuzz
* Mon Dec 14 2009 gregkh@suse.de
- Update to 2.6.32.1
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext
  - patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects
* Mon Dec 14 2009 jjolly@suse.de
- patches.drivers/dcb-data-center-bridging-ops-s: dcb: data
  center bridging ops should be r/o (BNC#562046).
- patches.drivers/drivers-net-request_irq-remove: drivers/net:
  request_irq - Remove unnecessary leading & from second arg
  (BNC#562046).
- patches.drivers/ethtool-add-direct-attach-supp: ethtool: Add
  Direct Attach support to connector port reporting (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-al: ixgbe: Add
  support for 82599 alternative WWNN/WWPN prefix (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-ba: ixgbe: add
  support for 82599 based Express Module X520-P2 (BNC#562046).
- patches.drivers/ixgbe-add-support-for-netdev_o: ixgbe: Add
  support for netdev_ops.ndo_fcoe_get_wwn to 82599 (BNC#562046).
- patches.drivers/ixgbe-change-default-ring-size: ixgbe: change
  default ring size (BNC#562046).
- patches.drivers/ixgbe-disable-flow-control-for: ixgbe: Disable
  Flow Control for certain devices (BNC#562046).
- patches.drivers/ixgbe-display-currently-attach: ixgbe: Display
  currently attached PHY through ethtool (BNC#562046).
- patches.drivers/ixgbe-fix-erroneous-display-of: ixgbe: Fix
  erroneous display of stats by ethtool -S (BNC#562046).
- patches.drivers/ixgbe-fix-kr-to-kx-fail-over-f: ixgbe: Fix KR
  to KX fail over for Mezzanine cards (BNC#562046).
- patches.drivers/ixgbe-fix-receive-address-regi: ixgbe:
  Fix Receive Address Register (RAR) cleaning and accounting
  (BNC#562046).
- patches.drivers/ixgbe-flush-the-lsc-mask-chang: ixgbe: Flush
  the LSC mask change to prevent repeated interrupts (BNC#562046).
- patches.drivers/ixgbe-handle-parameters-for-tx: ixgbe: handle
  parameters for tx and rx EITR, no div0 (BNC#562046).
- patches.drivers/ixgbe-links2-is-not-a-valid-re: ixgbe: LINKS2
  is not a valid register for 82598 (BNC#562046).
- patches.drivers/ixgbe-make-queue-pairs-on-sing: ixgbe: Make
  queue pairs on single MSI-X interrupts (BNC#562046).
- patches.drivers/ixgbe-modify-82599-hwrsc-stati: ixgbe: Modify
  82599 HWRSC statistics counters (BNC#562046).
- patches.drivers/ixgbe-only-set-clear-vfe-in-ix: ixgbe: Only
  set/clear VFE in ixgbe_set_rx_mode (BNC#562046).
- patches.drivers/ixgbe-performance-tweaks: ixgbe: performance
  tweaks (BNC#562046).
- patches.drivers/ixgbe-r_idx-not-used-in-ixgbe_: ixgbe: r_idx
  not used in ixgbe_msix_clean_rx() (BNC#562046).
- patches.drivers/ixgbe-select-fcoe-tx-queue-in-: ixgbe: select
  FCoE Tx queue in ndo_select_queue (BNC#562046).
- patches.drivers/ixgbe-use-eiam-to-automask-msi: ixgbe: use
  EIAM to automask MSI-X (BNC#562046).
- patches.drivers/ixgbe-use-known-user-priority-: ixgbe: use
  known user priority for FCoE when DCB is enabled (BNC#562046).
- patches.drivers/ixgbe-use-rx-buffer-length-fro: ixgbe: Use rx
  buffer length from rx ring for configuring rscctl (BNC#562046).
- patches.drivers/ixgbe-use-the-instance-of-net_: ixgbe: Use
  the instance of net_device_stats from net_device. (BNC#562046).
- patches.drivers/net-add-ndo_fcoe_get_wwn-to-ne: net: Add
  ndo_fcoe_get_wwn to net_device_ops (BNC#562046).
- patches.drivers/net-add-netdev_alloc_skb_ip_al: net: Add
  netdev_alloc_skb_ip_align() helper (BNC#562046).
- patches.drivers/net-use-netdev_alloc_skb_ip_al: net: Use
  netdev_alloc_skb_ip_align() (BNC#562046).
- patches.drivers/vlan-add-support-to-netdev_ops: vlan:
  Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device
  (BNC#562046).
- patches.fixes/fcoe-allow-scsi-fcp-to-be: fcoe: allow SCSI-FCP
  to be processed directly in softirq context (BNC#562046).
- patches.fixes/fcoe-libfc-add-get_lesb-t: fcoe, libfc: add
  get_lesb() to allow LLD to fill the link error status block
  (LESB) (BNC#562046).
- patches.fixes/libfc-add-fc-bb-5-lesb-co: libfc: add FC-BB-5
  LESB counters to fcoe_dev_stats (BNC#562046).
- patches.fixes/libfc-add-fcoe_fc_els_les: libfc: add
  fcoe_fc_els_lesb to fc_fcoe.h for FC-BB-5 LESB definitions
  (BNC#562046).
- patches.fixes/libfc-add-support-of-rece: libfc: add support
  of receiving ELS_RLS (BNC#562046).
- patches.fixes/libfc-add-target-reset-fl: libfc: Add target
  reset flag to FCP header file (BNC#562046).
- patches.fixes/libfc-fix-payload-size-pa: libfc: fix payload size
  passed to fc_frame_alloc() in fc_lport_els_request (BNC#562046).
- patches.fixes/libfcoe-add-checking-disa: libfcoe: add checking
  disable flag in FIP_FKA_ADV (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip-: libfcoe: add tracking
  FIP Missing Discovery Advertisement count (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip--0: libfcoe: add tracking
  FIP Virtual Link Failure count (BNC#562046).
* Mon Dec 14 2009 mmarek@suse.cz
- rpm/kabi.pl: Do not print harmless kabi changes by default.
* Mon Dec 14 2009 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Revert sched
  latency defaults and turn FAIR_SLEEPERS off (bnc#557307).
* Mon Dec 14 2009 jkosina@suse.cz
- patches.fixes/uart-txen-race.patch: Serial: Do not read IIR in
  serial8250_start_tx when UART_BUG_TXEN (bnc#479304 bnc#509066).
* Sun Dec 13 2009 rjw@suse.de
- patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch: sched:
  Fix isolcpus boot option (bnc#562290, fate#306952).
* Fri Dec 11 2009 mmarek@suse.cz
- patches.suse/supported-flag: Fix -Wmissing-prototypes warnings
  in modpost.c.
* Fri Dec 11 2009 mmarek@suse.cz
- patches.rpmify/modpost-segfault: modpost: fix segfault with
  short symbol names.
* Fri Dec 11 2009 jeffm@suse.com
- Moved kernel-docs into the git repo. It is now built automatically
  with the matching kernel sources.
* Fri Dec 11 2009 trenn@suse.de
- patches.suse/kdb_fix_ia64_build.patch: Fix ia64 - Export
  kdb_usb_kbds (none).
* Fri Dec 11 2009 trenn@suse.de
  Jeff updated kdb, try without this ugly workaround.
  If it still does not work, I have something better...
- patches.suse/kdb_x86_fix_hang.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Dec 11 2009 trenn@suse.de
  Updated MCE/MCA patches from Andi -> delete the old ones:
- patches.arch/x86_mce_hwpoison-action_result-valid-pfn.patch:
  HWPOISON: return ENXIO on invalid page number (fate#307738).
- patches.arch/x86_mce_hwpoison-is-free-page.patch: HWPOISON:
  detect free buddy pages explicitly (fate#307738).
- patches.arch/x86_mce_hwpoison-no-double-ref.patch: HWPOISON:
  avoid grabbing the page count multiple times during madvise
  injection (fate#307738).
- patches.arch/x86_mce_madvise-locking: HWPOISON: Use
  get_user_page_fast in hwpoison madvise (fate#307738).
- patches.arch/x86_mce_nfs-mig2: NFS: Fix nfs_migrate_page()
  (fate#307738).
- patches.arch/x86_mce_offline-inject: HWPOISON: Add a madvise()
  injector for soft page offlining (fate#307738).
- patches.arch/x86_mce_page-offline: HWPOISON: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_ref-to-flags: HWPOISON: Turn ref argument
  into flags argument (fate#307738).
- patches.arch/x86_mce_shake-page: HWPOISON: Be more aggressive
  at freeing non LRU caches (fate#307738).
- patches.arch/x86_mce_undef-lru: HWPOISON: Undefine short-hand
  macros after use to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_lru_cleanup.patch: Delete.
- patches.arch/x86_mce_page_offlining.patch: Delete.
- patches.arch/x86_mce_page_offlining_test_ability.patch: Delete.
- patches.arch/x86_mce_test_page.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
- needs_update: Merge or delete remaining patches.
- patches.fixes/scsi-dh-emc-mode-select-10-size: DM-MPIO fails
  to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.fixes/scsi-dh-emc-rw-mismatch: Server crashes when
  path failures occur against EMC storage (bnc#474482).
- patches.fixes/scsi-dh-rdac-add-stk: STK arrays missing from
  rdac devicehandler (bnc#503855).
- patches.fixes/scsi-retry-alua-transition-in-progress: I/O
  errors for ALUA state transitions (bnc#491289).
- patches.suse/dm-mpath-no-activate-for-offlined-paths: DM-MPIO
  fails to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.suse/dm-mpath-no-partitions-feature: Disable partitions
  scan for multipathed devices (bnc#402922,bnc#514767).
* Fri Dec 11 2009 tiwai@suse.de
- Update config files: set back to CONFIG_SOUND=m
* Fri Dec 11 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-23-hp-mute-led-gpio-fixes:
  ALSA: hda - Fix LED GPIO setup for HP laptops with IDT codecs
  (bnc#547357,bnc#523487).
* Fri Dec 11 2009 jeffm@suse.de
- patches.suse/kdb-usb-rework: Fix ia64.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files: Enable USB_SERIAL_DEBUG.
* Fri Dec 11 2009 jeffm@suse.com
- patches.suse/kdb-usb-rework: kdb: Cleanup KDB_USB.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files.
  - Disabled USB_TEST and USB_LIBUSUAL.
* Thu Dec 10 2009 jeffm@suse.com
- Update config files. Re-enable missing options:
  - CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
  - CONFIG_VIDEO_GO7007=m (and related options)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  Refresh to fix fuzz
* Thu Dec 10 2009 jeffm@suse.com
- Updated KDB to v4.4-2.6.32-3 and re-enabled USB keyboard support.
* Thu Dec 10 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: Fix vmlinux stripping on power
  (bnc#559547)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0000-Use-the-instance-of-net_device_stats-from-net.patch:
  netxen: Use the instance of net_device_stats from
  net_device. (bnc#560003, fate#307134).
- patches.drivers/netxen-0001-remove-sub-64-bit-mem-accesses.patch:
  netxen: remove sub 64-bit mem accesses (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0002-add-access-to-on-chip-memory-for-tools.patch:
  netxen: add access to on chip memory for tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0003-annotate-register-windowing-code.patch:
  netxen: annotate register windowing code (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0004-separate-register-and-memory-access-lock.patch:
  netxen: separate register and memory access lock (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0005-add-sysfs-entries-for-diag-tools.patch:
  netxen: add sysfs entries for diag tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0006-defines-for-next-revision.patch:
  netxen: defines for next revision (bnc#560003, fate#307134).
- patches.drivers/netxen-0007-128-memory-controller-support.patch:
  netxen: 128 memory controller support (bnc#560003, fate#307134).
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  netxen: reset sequence changes (bnc#560003, fate#307134).
- patches.drivers/netxen-0009-onchip-memory-access-change.patch:
  netxen: onchip memory access change (bnc#560003, fate#307134).
- patches.drivers/netxen-0010-fix-error-codes-in-for-tools-access.patch:
  netxen: fix error codes in for tools access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0011-sysfs-control-for-auto-firmware-recovery.patch:
  netxen: sysfs control for auto firmware recovery (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0012-update-version-to-4.0.62.patch:
  netxen; update version to 4.0.62 (bnc#560003, fate#307134).
- patches.drivers/netxen-0013-fix-builds-for-SYSFS-n-or-MODULES-n.patch:
  netxen: fix builds for SYSFS=n or MODULES=n (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  netxen: support for new firmware file format (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0015-refactor-indirect-register-access.patch:
  netxen: refactor indirect register access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0016-add-PCI-IDs-for-new-chip.patch:
  netxen: add PCI IDs for new chip (bnc#560003, fate#307134).
- patches.drivers/netxen-0017-update-module-info.patch: netxen:
  update module info (bnc#560003, fate#307134).
- patches.drivers/netxen-0018-module-firmware-hints.patch:
  netxen: module firmware hints (bnc#560003, fate#307134).
- patches.drivers/netxen-0019-update-version-to-4.0.65.patch:
  netxen: update version to 4.0.65 (bnc#560003, fate#307134).
- patches.drivers/netxen-0020-remove-PCI-IDs-of-CNA-device.patch:
  netxen: remove PCI IDs of CNA device (bnc#560003, fate#307134).
- patches.drivers/netxen-0021-fix-debug-tools-access-for-NX2031.patch:
  netxen : fix debug tools access for NX2031 (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0022-fix-failure-cases-for-fw-hang-recovery.patch:
  netxen: fix failure cases for fw hang recovery (bnc#560003,
  fate#307134).
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/qlge-0001-Use-the-instance-of-net_device_stats-from-net_.patch:
  qlge: Use the instance of net_device_stats from
  net_device. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch:
  qlge: Remove explicit setting of PCI Dev CTL reg. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  qlge: Set PCIE max read request size. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch:
  qlge: Add handler for DCBX firmware event. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0005-Store-firmware-revision-as-early-as-possible.patch:
  qlge: Store firmware revision as early as possible. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0006-Remove-inline-math-for-small-rx-buf-mapping.patch:
  qlge: Remove inline math for small rx buf mapping. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0007-Get-rid-of-firmware-handler-debug-code.patch:
  qlge: Get rid of firmware handler debug code. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch:
  qlge: Don't fail open when port is not initialized. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0009-Add-CBFC-pause-frame-counters-to-ethtool-stats.patch:
  qlge: Add CBFC pause frame counters to ethtool
  stats. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0010-Size-RX-buffers-based-on-MTU.patch:
  qlge: Size RX buffers based on MTU. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0011-Add-ethtool-get-set-pause-parameter.patch:
  qlge: Add ethtool get/set pause parameter. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0012-Add-ethtool-blink-function.patch:
  qlge: Add ethtool blink function. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0013-Add-ethtool-wake-on-LAN-function.patch:
  qlge: Add ethtool wake on LAN function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0014-Add-ethtool-register-dump-function.patch:
  qlge: Add ethtool register dump function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0015-Add-ethtool-self-test.patch: qlge:
  Add ethtool self-test. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0016-Change-naming-on-vlan-API.patch:
  qlge: Change naming on vlan API. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0017-Fix-indentations.patch: qlge: Fix
  indentations. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0018-Add-firmware-driver-sub-command-support.patch:
  qlge: Add firmware/driver sub-command support. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0019-Clean-up-netdev-stats-usage.patch:
  qlge: Clean up netdev->stats usage. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0020-Do-not-change-frame-routing-during-suspend.patch:
  qlge: Do not change frame routing during suspend. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0021-Add-asic-reset-to-open-call.patch:
  qlge: Add asic reset to open call. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0022-Clean-up-module-parameter-name.patch:
  qlge: Clean up module parameter name. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0023-Change-version-to-v1.00.00.23.00.00-01.patch:
  qlge: Change version to v1.00.00.23.00.00-01. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch: qlge:
  Bonding fix for mode 6. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  qlge: Add performance change for non-split headers. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: qlge:
  Add firmware core dump. (bnc#560420, FATE#307130).
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete more merged fixes.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete merged driver fixes.
- patches.drivers/megaraid-mbox-fix-SG_IO: megaraid_mbox: Oops
  on SG_IO (bnc#475619).
* Thu Dec 10 2009 duwe@suse.de
- Disable PHYP_DUMP for all PPC flavours, per bnc#541302.
* Thu Dec 10 2009 jbenc@suse.cz
- patches.suse/novfs-fix-debug-message.patch: novfs: fix debug
  message.
* Thu Dec 10 2009 hare@suse.de
- patches.fixes/tehuti-firmware-name: Tehuti network driver
  references wrong firmware (bnc#562092).
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: fix section mismatch due to
  previous checkin
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: export audit logging
  symbols.
* Wed Dec  9 2009 jbohac@suse.cz
- Update config files: added CONFIG_IP_NF_MATCH_IPV4OPTIONS
  to ppc64/trace
* Wed Dec  9 2009 jeffm@suse.com
- patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext:
  ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT (bnc#561018
  CVE-2009-4131).
* Wed Dec  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Fix a potentially serious mis-merge
  in swiotlb code.
* Wed Dec  9 2009 jjolly@suse.de
- patches.fixes/nohz-delay-from-tip.diff: nohz: Introduce
  arch_needs_cpu.
- patches.fixes/reuse-ktime-from-tip.diff: nohz: Reuse ktime in
  sub-functions of tick_check_idle..
- series.conf: Moved s390 patchs to proper place
* Wed Dec  9 2009 npiggin@suse.de
- patches.fixes/ipc-ns-fix-memory-leak-idr.patch: ipc: ns fix
  memory leak (bnc#518767).
- patches.fixes/ipc-remove-unreachable-code-in-semc.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-add-a-per-semaphore-pending-list.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-if-semops-fail.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-semop-operations.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-sops-when-semval-is-zero.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-optimise-undo-list-search.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-preempt-improve.patch:  (bnc#518767).
- patches.fixes/ipc-semc-sem-use-list-operations.patch:
  (bnc#518767).
* Wed Dec  9 2009 bphilips@suse.de
- needs_update: patches moved upstream or obsoleted by upstream
* Tue Dec  8 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: Update to what will
  hopefully be in 2.6.33.
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin: Delete.
* Tue Dec  8 2009 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: netfilter ipv4options
  match from patch-o-matic-ng (bnc#131728 - FATE#182).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-devzero-optimisation.patch: mm: /dev/zero
  optimisation (bnc#430738).
* Tue Dec  8 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-22-alc888-exclude-unusable-adcs:
  ALSA: hda - Exclude unusable ADCs for ALC88x (bnc#561235).
* Tue Dec  8 2009 mmarek@suse.cz
- patches.drivers/reenable-generic_serial: Revert "tty: Mark
  generic_serial users as BROKEN".
- Update config files: enable RIO and SX.
- rpm/generic_serial-blacklist: blacklist generic_serial users from
  automatic loading (bnc#551348).
* Tue Dec  8 2009 rgoldwyn@suse.de
- needs_update: patches merged upstream
- novfs patches to be handled by novfs team
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-vmalloc-fail-dump-stack.patch: mm: improve
  vmalloc reporting (bnc#511079).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update: most of mine are merged. apparmor patch sent to Andreas.
* Tue Dec  8 2009 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: use 64byte lvb len.(bnc#515645)
* Tue Dec  8 2009 agraf@suse.de
- patches.arch/s390-kvm-prefix.patch: KVM: s390: Fix prefix
  register checking in arch/s390/kvm/sigp.c (FATE#306513).
- patches.arch/s390-kvm-psw.patch: KVM: s390: Make psw available
  on all exits, not just a subset (FATE#306513).
* Mon Dec  7 2009 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add support of
  clickpad mode to synaptics mouse driver (bnc#547370).
* Mon Dec  7 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32 final and c/s 958.
- patches.xen/xen-dcdbas: force proper address translation
  in DCDBAS.
- patches.xen&xen-vmalloc_32: guarantee 32-bit
  (bus-)addressability of vmalloc_32() output (bnc#548010,
  bnc#552492).
- patches.xen/xen-x86_64-nx-user-mappings: set NX bit in kernel
  version of top level user mode page table entries.
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls (FATE#305733).
- patches.xen/xen3-x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829, bnc#482220).
- patches.xen/xen3-x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829, bnc#482220).
- Update EC2 config files (disable CAN_DEV and UIO).
* Mon Dec  7 2009 jbeulich@novell.com
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch,
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  Fix build warnings.
* Mon Dec  7 2009 hare@suse.de
- patches.drivers/lpfc-add-raywire-id: Add missing PCI-ID to lpfc.
* Sat Dec  5 2009 tonyj@suse.de
- config.conf: add trace flavor for ppc64 (fate# 307051)
- Update config files.
* Fri Dec  4 2009 jeffm@suse.com
- Split apparmor.diff out into separate patches to align more
  closely with the upstream AppArmor 2.4 repo.
- patches.apparmor/apparmor-fix-cap-audit_caching-preemption-disabling:
  AppArmor: Fix cap audit_caching preemption disabling.
- patches.apparmor/apparmor-fix-change_profile-failing-lpn401931:
  AppArmor: Fix change_profile failing lpn401931.
- patches.apparmor/apparmor-fix-change_profile-failure: AppArmor:
  Fix change_profile failure.
- patches.apparmor/apparmor-fix-determination-of-forced-audit-messages:
  AppArmor: Fix determination of forced AUDIT messages..
- patches.apparmor/apparmor-fix-failure-to-audit-change_hat-correctly:
  AppArmor: fix failure to audit change_hat correctly.
- patches.apparmor/apparmor-fix-file-auditing-when-quiet-is-used:
  AppArmor: Fix file auditing when quiet is used.
- patches.apparmor/apparmor-fix-leak-when-profile-transition-table-fails-unpack:
  AppArmor: Fix leak when profile transition table fails unpack.
- patches.apparmor/apparmor-fix-mediation-of-created-paths-that-look-like-deleted-paths:
  AppArmor: Fix mediation of created paths that look like
  "deleted" paths.
- patches.apparmor/apparmor-fix-oops-after-profile-removal:
  AppArmor: Fix oops after profile removal.
- patches.apparmor/apparmor-fix-oops-when-auditing-the-addition-of-profile-namespace:
  AppArmor: Fix oops when auditing the addition of profile
  namespace.
- patches.apparmor/apparmor-fix-oops-when-in-apparmor_bprm_set_creds:
  AppArmor: Fix Oops when in apparmor_bprm_set_creds.
- patches.apparmor/apparmor-fix-profile-namespace-removal:
  AppArmor: Fix profile namespace removal..
- patches.apparmor/apparmor-fix-refcounting-bug-causing-leak-of-creds-and-oops:
  AppArmor: Fix refcounting bug causing leak of creds and oops.
- patches.apparmor/apparmor-fully-close-race-condition-for-deleted-paths:
  AppArmor: Fully close race condition for deleted paths.
- patches.apparmor/apparmor-missing-unlock: AppArmor: Add missing
  unlock to next_profile.
- patches.apparmor/apparmor-policy-load-and-replacement-can-fail-to-alloc-mem:
  AppArmor: Policy load and replacement can fail to alloc mem.
- patches.apparmor/apparmor-fix-security_ops-task_setrlimit-api-use:
  AppArmor: Fix security_ops->task_setrlimit API use.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
- patches.suse/revert-usb-remove-phidget-drivers-from-kernel-tree.patch:
  Revert "USB: remove phidget drivers from kernel tree.".
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-message-catalog.diff: Updated patch
  (bnc#549193,FATE#306999,LTC#57210).
* Fri Dec  4 2009 mmarek@suse.cz
- supported.conf: Update wireless drivers.
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-03-qeth-hs-traffic-analyzer.patch: qeth:
  HiperSockets Network Traffic Analyzer (bnc#560674).
* Fri Dec  4 2009 hare@suse.de
- patches.drivers/qla2xxx-8.03.01-k7-update: qla2xxx driver
  update to 8.03.01-k7 (bnc#560415).
* Fri Dec  4 2009 mmarek@suse.cz
- rpm/package-descriptions: Add description for kernel-vmi.
* Fri Dec  4 2009 trenn@suse.de
- patches.arch/x86_mce_lru_cleanup.patch: HWPOISON: Undefine lru
  define after table to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_page_offlining.patch: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_page_offlining_test_ability.patch:
  HWPOISON: Add a madvise() injector for soft page offlining
  (fate#307738).
- patches.arch/x86_mce_test_page.patch: Expose Test pageflagA
  and set pageflagB primitive (fate#307738).
* Fri Dec  4 2009 mmarek@suse.cz
- Add the vmi flavor again.
* Fri Dec  4 2009 sjayaraman@suse.de
- patches.suse/SoN-18-netvm-skbuff-reserve.patch: add emergeny flag
  inside kmemcheck boundaries.
- patches.xen/xen3-auto-common.diff: Refresh.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 and i386 vanilla (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for i386 (bnc#560402)
* Thu Dec  3 2009 jeffm@suse.com
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch:
  Delete. (bnc#560043)
* Thu Dec  3 2009 jeffm@suse.com
- Cleanup config files.
* Thu Dec  3 2009 bphilips@suse.de
- patches.drivers/tg3_libphy_workaround: Delete. We have all of the 57780
  phylib and tg3 changes due to 2.6.32 bump.
* Thu Dec  3 2009 duwe@suse.de
- back out cpuidle feature that is still unconsistent.
* Thu Dec  3 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  Fix the "fixed" feature patch set from IBM.
* Thu Dec  3 2009 mfasheh@suse.com
- Update config files.
- patches.suse/gfs2-ro-mounts-only.patch: gfs2: allow spectator
  mounts for migration to ocfs2 (FATE#307584).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for 2.6.32 (again).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for cpuidle.
* Thu Dec  3 2009 tiwai@suse.de
- patches.drivers/8250_pnp-wacom-add: serial/8250_pnp.c: add
  new Wacom devices (bnc#544763).
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  one lonely hunk already seems to be in 2.6.32 final
* Thu Dec  3 2009 duwe@suse.de
- bnc#552860 / FATE#307104: kernel idle low power, take 2:
- patches.suse/cpuidle-cleanup: Refresh.
- patches.suse/cpuidle-cleanup-x86: Refresh.
- patches.suse/cpuidle-eliminate-ppcmdpowersave1: Refresh.
* Thu Dec  3 2009 jeffm@suse.com
- Updated to 2.6.32-final.
  - 2 patches eliminated.
* Thu Dec  3 2009 hare@suse.de
- Update config files: Enable Hibernation for zSeries.
* Thu Dec  3 2009 mmarek@suse.cz
- Update config files: Disable CONFIG_MFD_PCF50633, the chip is
  unlikely to be used on architectures we support.
* Thu Dec  3 2009 mmarek@suse.cz
- rpm/split-modules: Print which supported modules need unsupported
  modules.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: support lis3lv02d, hp_accel needs it.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: hp_accel is supported (FATE #306448).
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: remove wm831x drivers, we no longer ship them.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable all new hwmon drivers on ppc
  (default and vanilla) for consistency.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Add wm831x, needed by drivers/input/misc/wm831x-on.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Fix up after commit bfea0bd.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable WM831x and WM8350 support entirely,
  as recommended by the drivers author. These devices are only
  found on embedded devices such as music players or mobile phones.
* Thu Dec  3 2009 hare@suse.de
- supported.conf: Mark pmcraid and igbvf as supported;
  OSD drivers as unsupported.
* Thu Dec  3 2009 jdelvare@suse.de
- Restore link from config/s390/vanilla to config/s390x/vanilla.
* Thu Dec  3 2009 jbeulich@novell.com
- supported.conf: Update Xen drivers.
* Thu Dec  3 2009 tonyj@suse.de
- needs_update: readd
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch
  patches.suse/perfmon2-remove_syscalls.patch
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: woh dluoc I tegrof ot esolc eht fi
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: If this is a Moblin-based box, don't run yast-bootloader
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: stop shipping wm831x-hwmon, wm8350-hwmon,
  i2c-simtec and i2c-designware.
- supported.conf: remove i2c-simtec.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Add all new hwmon and i2c/busses drivers. The
  former unsupported, the latter supported.
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_VOODOO3.
- supported.conf: drop i2c-voodoo3, superseded by tdfxfb.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Drop hwmon and i2c/chips drivers which have been
  obsoleted.
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete perfmon-kmp.
* Wed Dec  2 2009 mmarek@suse.cz
- supported.conf: Add perfmon, hid and input modules.
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: Fix vanilla configs
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: disabled CONFIG_SND_SOC* in ppc configs.
* Wed Dec  2 2009 tiwai@suse.de
- Updated the sound section of supported.conf
* Wed Dec  2 2009 gregkh@suse.de
- Update config files. disable USB OTG drivers that should not
  have been enabled.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: remove some usb drivers that were deleted or renamed.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: update usb driver section
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/check-supported-list: Skip modules in Documentation and
  drivers/staging.
* Wed Dec  2 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-remote-DoS.patch: mac80211: fix
  remote DoS (bnc#558267).
* Tue Dec  1 2009 tiwai@suse.de
- Forward-port 11.2 patches:
  patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix: ALSA: hda -
    Add a position_fix quirk for MSI Wind U115.
  patches.drivers/alsa-sp1-hda-19-cx5047-test-mode-fix: ALSA:
    hda - Fix Cxt5047 test mode (bnc#559062).
  patches.drivers/alsa-sp1-hda-20-fsc-amilo-pi1505-fix: ALSA:
    hda - Add a pin-fix for FSC Amilo Pi1505 (bnc#557403).
  patches.drivers/alsa-sp1-hda-21-hp-dv3-position-fix-quirk:
    ALSA: hda - Add position_fix quirk for HP dv3 (bnc#555935).
* Mon Nov 30 2009 jeffm@suse.com
- patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io:
  megaraid_sas: Fix permissions on poll_mode_io (bnc#557180
  CVE-2009-3939).
* Mon Nov 30 2009 jeffm@suse.com
- patches.arch/x86-64-add-comment-for-rodata-large-page-retainment:
  x86-64: add comment for RODATA large page retainment
  (bnc#558249).
- patches.arch/x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.arch/x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop libata patches which are already included in
  2.6.31 vanilla.
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop patches which are already included in 2.6.31
  vanilla.
* Mon Nov 30 2009 teheo@suse.de
  Forward port two x86 patches from SLE11.
- needs_update:
- patches.arch/x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829).
- patches.arch/x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829).
* Mon Nov 30 2009 agraf@suse.de
- Update config files: Enable KSM (FATE#306513)
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: acpi dock patch was hmacht's, not mine
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: sysfs debugging crash patch is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: jeffm merged novfs patches into the main novfs patch.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: qualcomm modem driver is upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: squashfs is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: via driver bugfixes never went upstream, and people
  are complaining about them, so they were dropped.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove staging driver entries, they are all upstream.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove hv driver entries, those are upstream now.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove xen patches with my name on it.  Just because
  I refreshed the patch, doesn't mean I own it or even like the
  thing :)
* Sat Nov 28 2009 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix build errors in -trace
  and ppc64 flavors.
* Fri Nov 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Abort if supported modules depend on
  unsupported ones.
* Fri Nov 27 2009 mmarek@suse.cz
- supported.conf: mark cnic as supported (needed by bnx2i).
* Fri Nov 27 2009 jbenc@suse.cz
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch: API
  fix: X86: sysctl to allow panic on IOCK NMI error (bnc#427979).
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Nov 27 2009 jbohac@suse.cz
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
* Fri Nov 27 2009 trenn@suse.de
- needs_update:
  One I still have to send upstream, but it's nicer error output
  only, SP1 is fine in respect to removing all these, thanks.
* Fri Nov 27 2009 hare@suse.de
- Update config files: Compile in efivars module for
  x86_64 (FATE#306931).
* Fri Nov 27 2009 sjayaraman@suse.de
- needs_update:	sjayaraman's patches are either upstream already or
  rebased to SP1.
* Fri Nov 27 2009 sjayaraman@suse.de
- Update config files: NFS_SWAP=y.
* Fri Nov 27 2009 sjayaraman@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh and fix
  a build failure with fuzz factor 0.
* Fri Nov 27 2009 sjayaraman@suse.de
- Rebase Swap-over-NFS(SoN) patches:
- patches.xen/tmem: Refresh to accomodate changes due to SoN patches.
- patches.xen/xen3-auto-common.diff: Refresh to accomodate changes
  due to SoN patches.
* Fri Nov 27 2009 knikanth@suse.de
- needs_update: Verify knikanth's patches in SLE11 but not in SP1
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Release
  md->map_lock before set_disk_ro  (bnc#556899 bnc#479784).
* Fri Nov 27 2009 nfbrown@suse.de
- Restore following patches from SLES11 that are still needed for
  SLES11-SP1
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  sunrpc/cache: allow thread to block while waiting for cache
  update. (bnc#498708).
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  sunrpc/cache: retry cache lookups that return -ETIMEDOUT
  (bnc#498708).
- patches.fixes/nfsd-07-nfsd-idmap-drop-special-request-deferal-in-favour-of.patch:
  nfsd/idmap: drop special request deferal in favour of improved
  default. (bnc#498708).
- patches.fixes/nfsd-09-fix-kabi: Fix kabi breakage in previous
  nfsd patch series (bnc#498708).
* Thu Nov 26 2009 coly.li@suse.de
- needs_update: remove patches item of coly.li, lmb and mfasheh.
- patches.fixes/dlm-enable-debug.patch: update the patch from SLES11
  to SLES11 SP1 tree.
* Thu Nov 26 2009 jslaby@suse.cz
- patches.fixes/make-note_interrupt-fast.diff: Fix performance
  regression on large IA64 systems (bnc #469589).
* Thu Nov 26 2009 mmarek@suse.cz
- rpm/old-packages.conf: obsolete kernel-kdump on ppc.
- config.conf: delete kdump configs.
- config/ppc/kdump: Delete.
- config/ppc64/kdump: Delete.
* Thu Nov 26 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-Export_memory_sysdev_class:
  Refresh. Fix "typo", memory_sysdev_class should be exported
  only to GPL'ed modules.
* Thu Nov 26 2009 hare@suse.de
  Fixup patches for series2git:
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 duwe@suse.de
- config.conf: disable build of ppc kdump flavours
  (FATE#304346)
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/libata-missing-_SDD-is-not-an-error:
  libata-acpi: missing _SDD is not an error (bnc#551942).
* Thu Nov 26 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-spurious-delba-handling.patch:
  mac80211: fix spurious delBA handling (bnc#558267,
  CVE-2009-4026, CVE-2009-4027).
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/sky2-add-register-definitions: sky2: add
  register definitions for new chips (bnc#544760).
- patches.drivers/sky2-88E8059-support: sky2: 88E8059 support
  (bnc#544760).
- patches.drivers/sky2-optima-tcp-offload-fix: net: Fix Yukon-2
  Optima TCP offload setup (bnc#544760).
- patches.drivers/sky2-optima-fix-pci-cfg: net: Add missing
  TST_CFG_WRITE bits around sky2_pci_write (bnc#544760).
* Thu Nov 26 2009 nfbrown@suse.de
- Update config files.
  disable CONFIG_MULTICOE_RAID456 as it is not yet stable.
  Enable CONFIG_ASYNC_TX_DMA for FATE#306368
* Thu Nov 26 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Nov 26 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: Delete.
  it never went upstream, so we should drop it as well.
* Wed Nov 25 2009 tonyj@suse.de
- patches.trace/lttng-*: update for 2.6.32
- patches.trace/lttng-instrumentation-timer.patch: Delete.
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Wed Nov 25 2009 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: detect oprofile counters
  reserved by bios (FATE#307426).
* Wed Nov 25 2009 jeffm@suse.com
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  netfilter: Remove pointless CONFIG_NF_CT_ACCT warning
  (bnc#552033 (and others)).
* Tue Nov 24 2009 hare@suse.de
- Update config files.
- patches.drivers/mpt-fusion-4.22.00.00-update: Update MPT Fusion
  driver to 4.22.00.00-suse (bnc#556587).
- patches.drivers/mpt-fusion-4.16.00.00-update: Delete.
* Tue Nov 24 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-17-fix-mute-LED-sync-idt92h383xxx:
  ALSA: hda - Fix mute-LED sync on HP laptops with IDT92HD83xxx
  codecs (bnc#547357).
* Tue Nov 24 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-*: Increase power savings
  by allowing the core to sleep.
  (FATE##307059, bnc#550447)
* Tue Nov 24 2009 sjayaraman@suse.de
- patches.suse/kconfig-automate-kernel-desktop: automate a few config
  options for kernel-desktop (FATE#305694).
* Tue Nov 24 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Update
  references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Update references (bnc#556135, FATE#306453).
* Mon Nov 23 2009 jeffm@suse.com
- Enabled:
  patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch: crypto:
  Add ghash algorithm test before provide to users (FATE#306883,
  bnc#554578).
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "ghash - put proper .data section in place" fix
* Mon Nov 23 2009 sjayaraman@suse.de
- Update config files.
  - Add new options KERNEL_DESKTOP and DEFAULT_VM_DIRTY_RATIO.
  - Enable KERNEL_DESKTOP for only desktop flavor.
* Mon Nov 23 2009 sjayaraman@suse.de
- patches.suse/mm-tune-dirty-limits.patch: mm: Make default
  VM dirty ratio configurable to suit different workloads
  (bnc#552883).
* Fri Nov 20 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in, rpm/mkspec: build kernel-syms only for
  supported architectures.
* Fri Nov 20 2009 jeffm@suse.com
- Enabled B43_PHY_LP=y for PHY support on certain b43 chips.
* Fri Nov 20 2009 mmarek@suse.cz
- patches.suse/export-sync_page_range: Revert "vfs: Remove
  generic_osync_inode() and sync_page_range{_nolock}()"
  (bnc#557231).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Fix a bad-pointer warning.
* Fri Nov 20 2009 agruen@suse.de
- rpm/macros.kernel-source: Add kernel_module_package_moddir()
  macro for cross-distro compatibility (FATE 305225).
* Fri Nov 20 2009 jslaby@suse.cz
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Update
  references (FATE#305733).
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Update references (FATE#305733).
* Fri Nov 20 2009 jslaby@suse.cz
- Add writable resource limits support
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  SECURITY: selinux, fix update_rlimit_cpu parameter.
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  IA64: use helpers for rlimits.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  misc: use helpers for rlimits.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  core: rename setrlimit to do_setrlimit.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  core: implement getprlimit and setprlimit syscalls.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  unistd: add __NR_[get|set]prlimit syscall numbers.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  COMPAT: add get/put_compat_rlimit.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 hare@suse.de
- patches.drivers/megaraid-04.12-update: megaraid: Update
  megaraid_sas to version 04.12 (FATE#307125).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/bnx2-entropy-source.patch: bnx2: entropy source
  (FATE#307517).
- patches.drivers/e1000-entropy-source.patch: Enable e1000 as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/e1000e-entropy-source.patch: Enable e1000e as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/igb-entropy-source.patch: Enable igb as entropy
  source (disabled by default) (FATE#307517).
- patches.drivers/ixgbe-entropy-source.patch: Enable ixgbe as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/tg3-entropy-source.patch: tg3: entropy source
  (FATE#307517).
* Fri Nov 20 2009 hare@suse.de
- patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects:
  scsi_lib_dma: fix bug with dma maps on nested scsi objects
  (bnc#556595).
- patches.fixes/scsi-introduce-helper-function-for-blocking-eh:
  scsi_transport_fc: Introduce helper function for blocking
  scsi_eh (bnc#556595).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Delete.
* Fri Nov 20 2009 hare@suse.de
  Whitespace cleanup for series2git:
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/aacraid-24701-update: Refresh.
- patches.suse/crasher-26.diff: Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-ia64: Refresh.
- patches.suse/kdb-x86: Refresh.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch:
  igb: add support for 82576NS SerDes adapter (FATE#306856).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  Fix for !CONFIG_SCSI (in -ec2).
* Fri Nov 20 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: ocfs2:
  allocation reservations (bnc#501563 FATE#307247).
* Fri Nov 20 2009 jjolly@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86-self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
- patches.suse/self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
* Fri Nov 20 2009 jeffm@suse.com
- Update to 2.6.32-rc8.
  - Eliminated 1 patch.
* Fri Nov 20 2009 jeffm@suse.de
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  enclosure: fix oops while iterating enclosure_status array
  (bnc#540997).
* Thu Nov 19 2009 tonyj@suse.de
- Update config files.
- patches.suse/perfmon2.patch: perfmon2 (FATE#303968).
- patches.suse/perfmon2_ioctl.patch: switch to ioctl interface
  for perfmon2.
- patches.suse/perfmon2_noutrace.patch: remove UTRACE code
  from perfmon2.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Nov 19 2009 jjolly@suse.de
- Update config files.
- patches.arch/s390-message-catalog.diff: Kernel message
  catalog. (bnc#549193,LTC#57210,FATE#306999).
- rpm/kernel-binary.spec.in:
* Thu Nov 19 2009 jbohac@suse.cz
- patches.suse/add-queue_depth-ramp-up-code.patch: add queue_depth
  ramp up code (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-a-separate-scsi-transport-template-for-npiv-vports.patch:
  fcoe: add a separate scsi transport template for NPIV vports
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-check-to-fail-gracefully-in-bonding-mode.patch:
  fcoe: add check to fail gracefully in bonding mode (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-call-ndo_fcoe_enable-disable-to-turn-fcoe-feature-on-off-in-lld.patch:
  fcoe: Call ndo_fcoe_enable/disable to turn FCoE feature on/off
  in LLD (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-checking-san-mac-address.patch: fcoe: Fix
  checking san mac address (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch:
  fcoe: Fix getting san mac for VLAN interface (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-fix-setting-lport-s-wwnn-wwpn-to-use-san-mac-address.patch:
  fcoe: Fix setting lport's WWNN/WWPN to use san mac address
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-using-vlan-id-in-creating-lport-s-wwwn-wwpn.patch:
  fcoe: Fix using VLAN ID in creating lport's WWWN/WWPN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-formatting-cleanups-and-commenting.patch:
  fcoe: Formatting cleanups and commenting (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-increase-fcoe_max_lun-to-0xffff-65535.patch:
  fcoe: Increase FCOE_MAX_LUN to 0xFFFF (65535) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch:
  fcoe: initialize return value in fcoe_destroy (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch:
  fcoe, libfc: fix an libfc issue with queue ramp down in libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-use-single-frame-allocation-api.patch:
  fcoe, libfc: use single frame allocation API (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-npiv-vport-create-destroy.patch: fcoe: NPIV
  vport create/destroy (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-remove-extra-function-decalrations.patch:
  fcoe: remove extra function decalrations (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch:
  fcoe: remove redundant checking of netdev->netdev_ops
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-use-netif_f_fcoe_mtu-flag-to-set-up-max-frame-size-lport-mfs.patch:
  fcoe: Use NETIF_F_FCOE_MTU flag to set up max frame size
  (lport->mfs) (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-vport-symbolic-name-support.patch: fcoe: vport
  symbolic name support (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-host-number-to-lport-link-up-down-messages.patch:
  libfc: add host number to lport link up/down
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-libfc-fc_libfc-ch-for-libfc-internal-routines.patch:
  libfc: Add libfc/fc_libfc.[ch] for libfc internal routines
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-queue_depth-ramp-up.patch: libfc:
  add queue_depth ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-routine-to-copy-data-from-a-buffer-to-a-sg-list.patch:
  libfc: Add routine to copy data from a buffer to a SG list
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-set_fid-function-to-libfc-template.patch:
  libfc: add set_fid function to libfc template (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-add-some-generic-npiv-support-routines-to-libfc.patch:
  libfc: add some generic NPIV support routines to libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-can_queue-ramp-up.patch: libfc: adds
  can_queue ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-missing-exch-release-for-accepted-rrq.patch:
  libfc: adds missing exch release for accepted RRQ (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-changes-to-libfc_host_alloc-to-consolidate-initialization-with-allocation.patch:
  libfc: changes to libfc_host_alloc to consolidate initialization
  with allocation (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-request-functions.patch:
  libfc: combine name server registration request functions
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-response-handlers.patch:
  libfc: combine name server registration response handlers
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-convert-to-scsi_track_queue_full.patch:
  libfc: convert to scsi_track_queue_full (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-do-not-use-did_no_connect-for-pkt-alloc-failures.patch:
  libfc: do not use DID_NO_CONNECT for pkt alloc
  failures. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch:
  libfc: don't WARN_ON in lport_timeout for RESET state
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-export-fc-headers.patch: libfc: Export FC
  headers (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-add-fc-passthrough-support.patch: libfc,
  fcoe: Add FC passthrough support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fcoe-don-t-export_symbols-unnecessarily.patch:
  libfc, fcoe: Don't EXPORT_SYMBOLS unnecessarily (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-fixes-for-highmem-skb-linearize-panics.patch:
  libfc, fcoe: fixes for highmem skb linearize panics
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-increase-els-and-ct-timeouts.patch:
  libfc fcoe: increase ELS and CT timeouts (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-an-issue-of-pending-exch-es-after-i-f-destroyed-or-rmmod-fcoe.patch:
  libfc: fix an issue of pending exch/es after i/f destroyed or
  rmmod fcoe (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch: libfc: fix
  ddp in fc_fcp for 0 xid (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-fc_els_resp_type-to-correct-display-of-ct-responses.patch:
  libfc: fix fc_els_resp_type to correct display of CT responses
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch:
  libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in
  fc_fcp_send_data (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch:
  libfc: fix free of fc_rport_priv with timer pending
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch:
  libfc: fix memory corruption caused by double frees and bad
  error handling (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-rnn_id-smashing-skb-payload.patch: libfc:
  fix RNN_ID smashing skb payload (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fix-symbolic-name-registrations-smashing-skb-data.patch:
  libfc: fix symbolic name registrations smashing skb data
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch:
  libfc: fix typo in retry check on received PRLI (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch:
  libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-formatting-cleanups-across-libfc.patch:
  libfc: Formatting cleanups across libfc (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-libfcoe-fdisc-els-for-npiv.patch: libfc,
  libfcoe: FDISC ELS for NPIV (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-lport-fix-minor-documentation-errors.patch:
  libfc: lport: fix minor documentation errors (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-move-libfc_init-and-libfc_exit-to-fc_libfc-c.patch:
  libfc: Move libfc_init and libfc_exit to fc_libfc.c
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-move-non-common-routines-and-prototypes-out-of-libfc-h.patch:
  libfc: Move non-common routines and prototypes out of libfc.h
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-reduce-can_queue-for-all-fcp-frame-allocation-failures.patch:
  libfc: reduce can_queue for all FCP frame allocation failures
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-register-fc4-features-with-the-fc-switch.patch:
  libfc: register FC4 features with the FC switch (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-node-name-rsnn_nn.patch:
  libfc: Register Symbolic Node Name (RSNN_NN) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-port-name-rspn_id.patch:
  libfc: Register Symbolic Port Name (RSPN_ID) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-remove-fc_fcp_complete.patch: libfc: Remove
  fc_fcp_complete (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-remove-unused-fc_lport-pointer-from-fc_fcp_pkt_abort.patch:
  libfc: Remove unused fc_lport pointer from fc_fcp_pkt_abort
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-initializing-fc_cpu_order-and-fc_cpu_mask-per-lport.patch:
  libfc: removes initializing fc_cpu_order and fc_cpu_mask per
  lport (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-unused-disc_work-and-ex_list.patch:
  libfc: removes unused disc_work and ex_list (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-rnn_id-may-be-required-before-rsnn_nn-with-some-switches.patch:
  libfc: RNN_ID may be required before RSNN_NN with some switches
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-rpn_id-is-obsolete-and-unnecessary.patch:
  libfc: RPN_ID is obsolete and unnecessary (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-vport-link-handling-and-fc_vport-state-managment.patch:
  libfc: vport link handling and fc_vport state managment
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-allow-fip-to-be-disabled-by-the-driver.patch:
  libfcoe: Allow FIP to be disabled by the driver (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-do-not-pad-fip-keep-alive-to-full-frame-size.patch:
  libfcoe: Do not pad FIP keep-alive to full frame size
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-don-t-send-els-in-fip-mode-if-no-fcf-selected.patch:
  libfcoe: don't send ELS in FIP mode if no FCF selected
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fcoe-libfcoe-npiv-support.patch:
  libfcoe, fcoe: libfcoe NPIV support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfcoe-fcoe-simplify-receive-flogi-response.patch:
  libfcoe: fcoe: simplify receive FLOGI response (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-allow-fip-receive-to-be-called-from-irq.patch:
  libfcoe: fip: allow FIP receive to be called from
  IRQ. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-should-report-link-to-libfc-whether-selected-or-not.patch:
  libfcoe: FIP should report link to libfc whether selected or
  not (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-use-scsi-host-number-to-identify-debug-messages.patch:
  libfcoe: fip: use SCSI host number to identify debug
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-formatting-and-comment-cleanups.patch:
  libfcoe: formatting and comment cleanups (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  modify change_queue_depth to take in reason why it is being
  called (fate#306857, fate#306859, bnc#551175).
- patches.suse/scsi-error-have-scsi-ml-call-change_queue_depth-to-handle-queue_full.patch:
  scsi error: have scsi-ml call change_queue_depth to handle
  QUEUE_FULL (fate#306857, fate#306859, bnc#551175).
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fixup patch to apply.
* Thu Nov 19 2009 hare@suse.de
  Port patches from SLES11:
- patches.fixes/scsi-dh-queuedata-accessors: Kernel bug triggered
  in multipath (bnc#486001).
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-detach-existing-hardware-handler:
  multipath: detach existing hardware handler if none was
  specified.
- patches.suse/dm-mpath-requeue-for-stopped-queue: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  multipath: Evaluate request result and sense code
  (FATE#303695,bnc#433920,bnc#442001).
* Thu Nov 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Kill support for kernel-$flavor
  symbols, we need a unified kernel-source for all flavors.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/bnx2i-use-common-iscsi-suspend-queue: bnx2i:
  use common iscsi suspend queue (FATE#307215).
- patches.fixes/iscsi-class-modify-handling-of-replacement-time:
  iscsi class: modify handling of replacement timeout
  (FATE#307215).
- patches.fixes/iser-set-tgt-and-lu-reset-timeout: iser: set
  tgt and lu reset timeout (FATE#307215).
- patches.fixes/libiscsi-add-warm-target-reset-tmf-support:
  libiscsi: add warm target reset tmf support (FATE#307215).
- patches.fixes/libiscsi-check-tmf-state-before-sending-pdu:
  libiscsi: Check TMF state before sending PDU (FATE#307215).
- patches.fixes/libiscsi-fix-login-text-checks-in-pdu-inject:
  libiscsi: fix login/text checks in pdu injection code
  (FATE#307215).
- patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl:
  add scsi target reset support to scsi ioctl.
- patches.fixes/scsi-devinfo-update-hitachi-entries: scsi_devinfo:
  update Hitachi entries (v2).
- patches.fixes/scsi-fc-class-failfast-bsg-requests: [SCSI]
  fc class: fail fast bsg requests.
- patches.drivers/cxgb3i: Delete.
- patches.drivers/cxgb3i-fixed-offload-array-size: Delete.
- patches.fixes/disable-lro-per-default: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/scsi_dh-always-attach-sysfs: scsi_dh: create
  sysfs file, dh_state for all SCSI disk devices.
- patches.fixes/scsi_dh-change-activate-interface: scsi_dh: Change
  the scsidh_activate interface to be asynchronous (bnc#556144).
- patches.fixes/scsi_dh-make-alua-handler-asynchronous: scsi_dh:
  Make alua hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-hp_sw-handler-asynchronous: scsi_dh:
  Make hp hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-rdac-handler-asynchronous: scsi_dh:
  Make rdac hardware handler's activate() async (bnc#556144).
* Thu Nov 19 2009 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Delete.
- patches.drivers/qla4xxx-sles11-update: Delete.
* Thu Nov 19 2009 hare@suse.de
- Update config files.
- patches.drivers/hpsa: hpsa: New driver SCSI driver for HP
  Smart Array (FATE#307153,bnc#555855).
- supported.conf: Mark hpsa as supported.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-01-qeth-isolation.patch: qeth: Exploit QDIO
  Data Connection Isolation (bnc#555199,LTC#57826,FATE#307015).
- patches.arch/s390-02-01-cex3-init-msg.patch:
  zcrypt: initialize ap_messages for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-02-cex3-special-command.patch:
  zcrypt: special command support for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-03-cex3-device.patch: zcrypt: add support
  for cex3 device types (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-04-cex3-use-def.patch: zcrypt: use
  definitions for cex3 (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-05-zcrypt-speed-cex2c.patch:
  zcrypt: adjust speed rating between cex2 and pcixcc
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-06-zcrypt-speed-cex3.patch:
  zcrypt: adjust speed rating of cex3 adapters
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch: Delete.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch:
  qeth: Exploit QDIO Data Connection Isolation
  (bnc#555199,LTC#57826,FATE#307015).
* Wed Nov 18 2009 jeffm@suse.com
- scripts/sequence-patch.sh: Add automatic generation of supported
  modules list.
* Wed Nov 18 2009 jeffm@suse.com
- Update config files: Enable CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/acpi-generic-initramfs-table-override-support:
  ACPI: generic initramfs table override support (bnc#533555).
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  init: move populate_rootfs back to start_kernel (bnc#533555).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "crypto: ghash-intel - Hard-code pshufb" fix
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default:
  hung_task_timeout: configurable default (bnc#552820).
  - Default to runtime-disabled on all flavors except debug.
* Wed Nov 18 2009 agraf@suse.de
- patches.fixes/kvm-ioapic.patch: Ignore apic polarity
  (bnc#556564).
- patches.fixes/kvm-macos.patch: Implement some missing intercepts
  so osx doesn't blow up (bnc#556564).
* Wed Nov 18 2009 hare@suse.de
- supported.conf: mark missing 10Gb drivers as supported
  (bnc#555793)
* Wed Nov 18 2009 hare@suse.de
- patches.drivers/aacraid-24701-update: Problems with aacraid
  (bnc#524242,FATE#307437).
* Wed Nov 18 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.apparmor/apparmor.diff: Refresh.
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Refresh.
- patches.suse/bootsplash: Refresh.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- patches.suse/silent-stack-overflow-2.patch: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
* Wed Nov 18 2009 agraf@suse.de
- Update config files to enable pv-ops for KVM clock. (bnc#556135)
* Wed Nov 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler: ALSA:
  hda - select IbexPeak handler for Calpella (FATE#306783).
- patches.drivers/alsa-sp1-hda-02-vectorize-get_empty_pcm_device:
  ALSA: hda - vectorize get_empty_pcm_device() (FATE#306783).
- patches.drivers/alsa-sp1-hda-03-allow-up-to-4-HDMI: ALSA:
  hda - allow up to 4 HDMI devices (FATE#306783).
- patches.drivers/alsa-sp1-hda-04-convert-intelhdmi-global-references:
  ALSA: hda - convert intelhdmi global references to local
  parameters (FATE#306783).
- patches.drivers/alsa-sp1-hda-05-remove-intelhdmi-dependency-on-multiout:
  ALSA: hda - remove intelhdmi dependency on multiout
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-06-use-pcm-prepare-callbacks-for-intelhdmi:
  ALSA: hda - use pcm prepare/cleanup callbacks for intelhdmi
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-07-reorder-intelhemi-prepare-callbacks:
  ALSA: hda - reorder intelhdmi prepare/cleanup callbacks
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-08-vectorize-intelhdmi: ALSA:
  hda - vectorize intelhdmi (FATE#306783).
- patches.drivers/alsa-sp1-hda-09-get-intelhtemi-max-channels:
  ALSA: hda - get intelhdmi max channels from widget caps
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-10-auto-parse-intelhdmi-cvt-pin:
  ALSA: hda - auto parse intelhdmi cvt/pin configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-11-remove-static-intelhdmi-config:
  ALSA: hda - remove static intelhdmi configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-12-reset-pins-idt-codec-free:
  ALSA: hda - Reset pins of IDT/STAC codecs at free (bnc#544779).
- patches.drivers/alsa-sp1-hda-13-add-reboot-notifier: ALSA:
  hda - Add reboot notifier to each codec (bnc#544779).
- patches.drivers/alsa-sp1-hda-14-add-missing-export: ALSA: hda -
  Add missing export for snd_hda_bus_reboot_notify (bnc#544779).
- patches.drivers/alsa-sp1-hda-15-fix-build-warning: ALSA: hda -
  Add a proper ifdef to a debug code (FATE#306783).
- patches.drivers/alsa-sp1-hda-16-stac-dual-headphones-fix:
  ALSA: hda - Fix detection of dual headphones (bnc#556532).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  crypto: ghash - Add PCLMULQDQ accelerated implementation
  (FATE#306883, bnc#554578).
- Update config files: set CRYPTO_GHASH_CLMUL_NI_INTEL=m
- patches.xen/xen3-patch-2.6.28: Refresh to apply cleanly
* Wed Nov 18 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Only export selected pv-ops feature structs (bnc#556135).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Replace kvm io delay pv-ops with linux magic (bnc#556135).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Split
  paravirt ops by functionality (bnc#556135).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Split the KVM pv-ops support by feature (bnc#556135).
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Nov 18 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: Delete.
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Also enable CONFIG_DMAR (fate#306796) for vanilla flavors
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Do the same for i386
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Enabling CONFIG_DMAR (fate#306796), introduces these changes:
    +CONFIG_HAVE_INTEL_TXT=y
  - # CONFIG_DMAR is not set
    +CONFIG_DMAR=y
    +# CONFIG_DMAR_DEFAULT_ON is not set
    +CONFIG_DMAR_FLOPPY_WA=y
    +# CONFIG_INTEL_TXT is not set
  Done for x86_64 for now only.
* Mon Nov 16 2009 jkosina@suse.de
- patches.fixes/hid-fixup-ncr-quirk.patch: HID: fixup quirk for
  NCR devices (bnc#548807).
* Fri Nov 13 2009 mmarek@suse.cz
- rpm/*.spec.in, rpm/kernel-module-subpackage: add
  Provides: multiversion(kernel) to binary kernel packages,
  kernel-source, kernel-syms and all KMPs so that zypp can be
  configured to keep multiple versions of these packages
  (fate#305311).
* Fri Nov 13 2009 npiggin@suse.de
- Disable LGUEST on x86 32. It doesn't build properly without PARAVIRT.
* Wed Nov 11 2009 jack@suse.cz
- patches.fixes/zisofs-large-pagesize-read.patch: zisofs:
  Implement reading of compressed files when PAGE_CACHE_SIZE >
  compress block size (bnc#540349).
* Wed Nov 11 2009 npiggin@suse.de
- Update config files.
* Wed Nov 11 2009 npiggin@suse.de
- Disable PARAVIRT_GUEST on x86 32 and 64.
* Tue Nov 10 2009 teheo@suse.de
- patches.drivers/libata-ahci-aspire-3810t-noncq: ahci: disable
  NCQ on Aspire 3810t (bnc#522790).
* Tue Nov 10 2009 npiggin@suse.de
- Update config files.
* Tue Nov 10 2009 npiggin@suse.de
- Update config files. Disable CONFIG_CC_STACKPROTECTOR on all
  x86 kernels except debug. Overhead is prohibitive.
* Mon Nov  9 2009 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: SLAB_DESTROY_BY_RCU for
  file slab.
* Mon Nov  9 2009 npiggin@suse.de
- Update config files. Vanilla doesn't have unwinder, trace selects
  options which select frame pointers.
* Mon Nov  9 2009 npiggin@suse.de
- Disable FRAME_POINTER on i386 and x86-64, all kernels. Unwind info
  should provide all this functionality.
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-honour-server-preferred-io-size: NFS: Honour
  server-preferred io sizes (bnc#550648).
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-slot-table-alloc: Don't fail allocations
  for the slot table when mounting an NFS filesystem (bnc#519820).
* Fri Nov  6 2009 trenn@suse.de
- patches.arch/x86_amd_fix_erratum_63.patch: x86/amd-iommu:
  Workaround for erratum 63 (bnc#548274).
* Fri Nov  6 2009 jeffm@suse.de
- Disabled PARAVIRT_GUEST on ia64/trace and ia64/vanilla.
* Fri Nov  6 2009 trenn@suse.de
- patches.suse/kdb_x86_fix_hang.patch: X86 KDB: Reduce timeout
  for blinking LEDs (bnc#528811).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix last change.
* Fri Nov  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc6 and c/s 941.
- Update Xen config files.
- supported.conf: Add domctl.
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add the /lib/modules/.../{source,devel}
  symlinks to the -devel package (bnc#548728).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kvm-kmp.
* Thu Nov  5 2009 jeffm@suse.com
- Update to 2.6.32-rc6.
  - 2 patches eliminated
  - NR_CPUS=4096 on ia64/vanilla again
* Thu Nov  5 2009 jeffm@suse.com
- Performance: Disabled CONFIG_PARAVIRT on all flavors.
* Thu Nov  5 2009 mmarek@suse.cz
- Delete unused 2.6.31.y patches.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: add libfcoe and fix typo.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: update so that supported modules don't require
  unsupported ones by adding following modules: async_pq
  async_raid6_recov ath blkback_pagemap crypto_hash drm_kms_helper
  fddi fscache lib80211 libfcoe libipw libiscsi_tcp llc md_mod mdio
  mfd_core nf_defrag_ipv4 p8022 psnap raid6_pq tr ttm ucb1400_core
  v4l2_compat_ioctl32.
* Thu Nov  5 2009 mmarek@suse.cz
- config.conf: remove kernel-ps3-devel (does not exist) and
  kernel-debug-devel (not needed most of the time) from
  kernel-syms.
* Thu Nov  5 2009 hare@suse.de
- Update config files: Set CONFIG_HZ to 100 for zSeries
  (bnc#552564).
* Thu Nov  5 2009 hare@suse.de
- Update config files: Increase MAX_RAW_DEVS to 4096 on
  zSeries (bnc#552565).
* Wed Nov  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete stray text.
* Tue Nov  3 2009 mmarek@suse.cz
- config.conf: remove the ec2 flavor from kernel-syms, most KMPs
  don't make any sense on ec2
  (http://lists.opensuse.org/opensuse-kernel/2009-11/msg00001.html).
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete also brocade-bfa-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: add split-modules to the src.rpm.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete enic-kmp and fnic-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kmps by their full name, not
  just the foo-kmp virtual dependency (bnc#472410).
* Thu Oct 29 2009 tonyj@suse.de
- Update ppc/ps3 config for CONFIG_UTRACE
* Thu Oct 29 2009 tonyj@suse.de
- patches.trace/utrace-core: Update for SP1 (FATE# 304321)
* Wed Oct 28 2009 nfbrown@suse.de
- patches.fixes/nfsd-acl.patch: nfsd: Fix sort_pacl in
  fs/nfsd/nf4acl.c to actually sort groups (bnc#549748).
* Wed Oct 28 2009 jdelvare@suse.de
- Update config files:
  CONFIG_NTFS_FS=n
  We handle NTFS through FUSE these days.
* Tue Oct 27 2009 jbohac@suse.cz
- Update config files:
  CONFIG_NETLABEL=y
  CONFIG_SECURITY_NETWORK_XFRM=y
  (fate#307284)
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix compilation failure for configs with CONFIG_SMP=n and
  CONFIG_FAR_GROUP_SCHED=y
* Tue Oct 27 2009 jbeulich@novell.com
- Update config files (MINIX_FS=m globally, NTFS_FS off for -ec2).
- supported.conf: Add fs/minix.
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/percpu-allow-pcpu_alloc-to-be-called-with-IRQs-off:
  percpu: allow pcpu_alloc() to be called with IRQs off
  (bnc#548119).
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  Update to newer version which is going to be merged upstream.
* Fri Oct 23 2009 jeffm@suse.com
- Update to 2.6.32-rc5-git3.
* Fri Oct 23 2009 mmarek@suse.cz
- Update config files: set NR_CPUS back to 2048 for ia64/vanilla
  until there is a fix in mainline.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix for !CONFIG_SMP.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Cleanup and make boot splash work with KMS (bnc#544645).
* Thu Oct 22 2009 jeffm@suse.com
- Re-enabled NR_CPUS=4096 on ia64.
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  sched: move rq_weight data array out of .percpu (bnc#548119).
* Tue Oct 20 2009 jbeulich@novell.com
- Update x86-64 Xen config file (NR_CPUS=512).
- Refresh a few Xen patches.
- rpm/kernel-binary.spec.in: Handle -ec2 flavor.
- rpm/package-descriptions: Describe -ec2 flavor.
- rpm/post.sh: Handle -ec2 flavor.
* Tue Oct 20 2009 jbeulich@novell.com
- patches.fixes/use-totalram_pages: Delete.
* Tue Oct 20 2009 jbeulich@novell.com
- config.conf: Add -ec2 configs (fate#305273)
- Add ec2 config files.
- patches.xen/xen-unpriv-build: No need to build certain bits
  when building non-privileged kernel.
- supported.conf: Add fs/nls/nls_base.
* Mon Oct 19 2009 jeffm@suse.com
- Temporarily reduce NR_CPUS to 2048 on ia64 to avoid build
  failures (bnc#548119)
* Mon Oct 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: [s390x] ignore errors from
  dwarfextract for now.
* Fri Oct 16 2009 jeffm@suse.com
- Update config files.
* Fri Oct 16 2009 jeffm@suse.com
- Update to 2.6.32-rc5.
* Fri Oct 16 2009 mmarek@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: ia64/sn: fix
  percpu warnings.
* Fri Oct 16 2009 mmarek@suse.de
- Update config files: disable MTD_GPIO_ADDR, VME_CA91CX42 and
  VME_TSI148 on ia64 to fix build.
* Fri Oct 16 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32-rc4: Fix AGP for PowerPC.
* Fri Oct 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc4 and c/s 938.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Tue Oct 13 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: Added missing sites.
* Mon Oct 12 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: staging: Complete
  sched.h removal from interrupt.h.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/ptrace_may_access-fix: apparmor:
  ptrace_may_access -> ptrace_access_check.
* Mon Oct 12 2009 jeffm@suse.de
- Update config files.
* Mon Oct 12 2009 jeffm@suse.de
- Updated to 2.6.32-rc4.
  - Eliminated 4 patches.
  - Refreshed context.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: Refresh and enable.
* Fri Oct  9 2009 jeffm@suse.de
- Cleanup unused patches:
  - patches.fixes/iwl3945-fix-rfkill.patch: Delete.
  - patches.fixes/iwlagn-fix-rfkill.patch: Delete.
  - patches.suse/kdb-serial-8250: Delete.
  - patches.suse/kdb-sysctl-context: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.fixes/scsi-add-tgps-setting: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.suse/kbuild-icecream-workaround: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/mm-avoid-bad-page-on-lru: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- Update vanilla config files.
* Fri Oct  9 2009 jeffm@suse.de
- Update to 2.6.32-rc3.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/tsi148-dependency: vme/tsi148: Depend on VIRT_TO_BUS
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-x86-build-fixes: kdb: Use $srctree not $TOPDIR
  in Makefile.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-prepare_multicast: winbond: implement
  prepare_multicast and fix API usage.
- patches.rpmify/winbond_beacon_timers: winbond: use
  bss_conf->beacon_int instead of conf->beacon_int.
- patches.rpmify/winbond-build-fixes: Delete.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/rtl8192e-build-fixes: rtl8192e: Add #include
  <linux/vmalloc.h>.
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-build-fixes: kdb: Build fixes.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/iio-s390-build-fix: iio: Don't build on s390.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-build-fixes: winbond: API fix.
* Thu Oct  8 2009 jeffm@suse.de
- Update vanilla config files.
* Thu Oct  8 2009 jeffm@suse.de
- Update config files.
* Thu Oct  8 2009 jeffm@suse.de
- Updated to 2.6.32-rc1 (AKA 2.6.32-rc2).
  - Eliminated 28 patches.
  - 14 patches need further review.
  - Xen and AppArmor are currently disabled.
  - USB support in KDB is disabled.
* Wed Oct  7 2009 gregkh@suse.de
- patches.kernel.org/patch-2.6.31.2-3: Linux 2.6.31.3.
  - major tty bugfix
* Wed Oct  7 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc268-automic-fix: ALSA: hda -
  Fix yet another auto-mic bug in ALC268 (bnc#544899).
* Wed Oct  7 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Fix the regression,
  "iostat reports wrong service time and utilization", introduced
  by this patch  (bnc#544926).
* Tue Oct  6 2009 gregkh@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Delete.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
  - both of these were not being used anyway.
* Tue Oct  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.2.
* Tue Oct  6 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc660vd-asus-a7k-fix: ALSA: hda -
  Add a workaround for ASUS A7K (bnc#494309).
* Mon Oct  5 2009 gregkh@suse.de
- refresh patch fuzz due to 2.6.31.2 import.
* Mon Oct  5 2009 gregkh@suse.de
- Update to Linux 2.6.31.2:
  - bugfixes, lots of them.
  - security fixes
* Mon Oct  5 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc861-toshiba-fix: ALSA: hda -
  Fix invalid initializations for ALC861 auto mode (bnc#544161).
* Fri Oct  2 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: Delete.
  The code never got upstream and looks incorrect.
* Fri Oct  2 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi-04-fix-surround-side-mute: ALSA:
  ctxfi: Swapped SURROUND-SIDE mute.
- patches.drivers/alsa-hda-2.6.32-rc1-toshiba-fix: ALSA: hda -
  Added quirk to enable sound on Toshiba NB200.
- patches.drivers/alsa-hda-2.6.32-rc2: ALSA: backport 2.6.32-rc2
  fixes for HD-audio.
* Thu Oct  1 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.1 and c/s 934.
* Thu Oct  1 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete quickcam-kmp (bnc#543361).
* Wed Sep 30 2009 gregkh@suse.de
- Update to 2.6.31.1
  - lots of bugfixes
  - security fixes
* Wed Sep 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete the sle11 ocfs2-kmp.
* Tue Sep 29 2009 trenn@suse.de
- Disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
  with +trenn (bnc#542767)
* Wed Sep 23 2009 teheo@suse.de
- Update config files.  Build pci-stub driver into the kernel so that
  built in pci drivers can be blocked from attaching to devices.
* Tue Sep 22 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: when building against Linus'
  kernels (2.6.x), append a .0 to the kernel version embedded in
  the KMP version, to ensure that such KMP is older than a KMP
  built against a subsequent stable kernel (2.6.x.y, y > 0).
* Mon Sep 21 2009 jeffm@suse.de
- Update config files.
* Mon Sep 21 2009 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Ported to
  2.6.31 (bnc#533555).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: do not remove the bootloader entry if the kernel
  version didn't change (bnc#533766).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: remove dead code.
* Fri Sep 18 2009 jeffm@suse.de
- patches.fixes/reiserfs-replay-honor-ro: reiserfs: Properly
  honor read-only devices (bnc#441062).
* Thu Sep 17 2009 jeffm@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86-64) (bnc#503038).
* Thu Sep 17 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-rc1: ALSA HD-audio backport
  from 2.6.32-rc1.
* Wed Sep 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31 final.
* Tue Sep 15 2009 teheo@suse.de
  Backport attach inhibition for builtin pci drivers from 2.6.32-rc.
- patches.drivers/pci-separate-out-pci_add_dynid: pci: separate
  out pci_add_dynid().
- patches.drivers/pci_stub-add-ids-parameter: pci-stub: add
  pci_stub.ids parameter.
* Tue Sep 15 2009 teheo@suse.de
  Backport patches from 2.6.32-rc to ease ossp testing.
- Update config files - SOUND_OSS_CORE_PRECLAIM is set to N.
- patches.drivers/implement-register_chrdev: chrdev: implement
  __register_chrdev().
- patches.drivers/sound-make-oss-device-number-claiming-optional:
  sound: make OSS device number claiming optional and schedule
  its removal.
- patches.drivers/sound-request-char-major-aliases-for-oss-devices:
  sound: request char-major-* module aliases for missing OSS
  devices.
* Mon Sep 14 2009 sdietrich@suse.de
- patches.suse/novfs-client-module: Update header todo list with
  locking nits (semaphore used as mutex / completion)
* Mon Sep 14 2009 jeffm@suse.com
- Revert back to CONFIG_M586TSC from CONFIG_M686 for default flavor
  (bnc#538849)
* Fri Sep 11 2009 jbeulich@novell.com
- patches.suse/crasher-26.diff: Add capability to also trigger a
  kernel warning.
* Fri Sep 11 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Seperate read
  and write statistics of in_flight requests (fate#306525).
* Thu Sep 10 2009 gregkh@suse.de
- patch fuzz removal now that 2.6.31 is the base.
* Thu Sep 10 2009 gregkh@suse.de
- Update config files.
    CONFIG_MOUSE_PS2_ELANTECH=y
    CONFIG_MOUSE_PS2_TOUCHKIT=y
    (bnc#525607)
* Thu Sep 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh: fix misc realtek
  issues, add another Nvidia HDMI device id
* Thu Sep 10 2009 jeffm@suse.de
- Updated to 2.6.31-final.
* Tue Sep  8 2009 gregkh@suse.de
- refresh patches for fuzz due to upstream changes
* Tue Sep  8 2009 gregkh@suse.de
- Update to 2.6.31-rc9
  - obsoletes:
  - patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708
  - patches.drivers/alsa-hda-fix-02-mbp31-hp-fix
* Tue Sep  8 2009 knikanth@suse.de
- patches.fixes/scsi_dh-Provide-set_params-interface-in-emc-device-handler.patch:
  scsi_dh: Provide set_params interface in emc device handler
  (bnc#521607).
- patches.fixes/scsi_dh-Use-scsi_dh_set_params-in-multipath.patch:
  scsi_dh: Use scsi_dh_set_params() in multipath. (bnc#521607).
- patches.fixes/scsi_dh-add-the-interface-scsi_dh_set_params.patch:
  scsi_dh: add the interface scsi_dh_set_params() (bnc#521607).
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: delete obsolete macro.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: require minimum versions of
  module-init-tools and perl-Bootloader, the %%post script is no
  longer compatible with ancient versions.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.31, the
  previous <= 2.6.30-1 didn't catch some cases obviously
  (bnc#533766).
* Fri Sep  4 2009 jeffm@suse.de
- Enabled CONFIG_SCSI_DEBUG=m (bnc#535923).
* Fri Sep  4 2009 mmarek@suse.cz
- kabi/severities, rpm/kabi.pl, rpm/kernel-binary.spec.in,
- rpm/kernel-source.spec.in: Use a simple script to check kabi by
  comparing Module.symvers files (similar to the old SLES9 one).
- rpm/built-in-where: Delete.
- rpm/symsets.pl: Delete.
- kabi/commonsyms: Delete.
- kabi/usedsyms: Delete.
* Fri Sep  4 2009 mmarek@suse.cz
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin:
  kbuild: rebuild fix for Makefile.modbuiltin.
* Thu Sep  3 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  Delete, it was wrong.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen config files.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc8 and c/s 931.
- patches.fixes/use-totalram_pages: use totalram_pages in favor
  of num_physpages for sizing boot time allocations (bnc#509753).
- patches.xen/xen-x86-per-cpu-vcpu-info: x86: use per-cpu storage
  for shared vcpu_info structure.
* Wed Sep  2 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh; merged fixes for
  IDT92HD73* codecs
* Tue Sep  1 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: Update to latest git.
* Tue Sep  1 2009 jeffm@suse.com
- patches.arch/add_support_for_hpet_msi_intr_remap.patch:
  intr-remap: generic support for remapping HPET MSIs
  (bnc#532758).
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  x86: arch specific support for remapping HPET MSIs (bnc#532758).
* Tue Sep  1 2009 mmarek@suse.cz
- rpm/package-descriptions: fix description of the x86_64
  kernel-desktop package (bnc#535457).
* Mon Aug 31 2009 jeffm@suse.com
- Update to 2.6.31-rc8.
  - Eliminated 1 patch.
* Mon Aug 31 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708:
  ALSA: hda - Add missing mux check for VT1708 (bnc#534904).
- patches.drivers/alsa-hda-fix-02-mbp31-hp-fix: ALSA: hda -
  Fix MacBookPro 3,1/4,1 quirk with ALC889A.
- patches.drivers/alsa-hda-2.6.32-pre: Refresh.
* Wed Aug 26 2009 tiwai@suse.de
- patches.drivers/alsa-hda-[0-9]*: Delete, fold into a single patch
  patches.drivers/alsa-hda-2.6.32-pre
* Tue Aug 25 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Delete.
* Tue Aug 25 2009 jbeulich@novell.com
- scripts/run_oldconfig.sh: Consistently use $prefix.
* Mon Aug 24 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.30-1
  (bnc#530752).
* Mon Aug 24 2009 jeffm@suse.com
- Update to 2.6.31-rc7.
  - Eliminated 3 patches.
* Mon Aug 24 2009 jeffm@suse.com
- Update config files: Enable CONFIG_PROC_EVENTS.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh: Do not call /sbin/module_upgrade, the rename
  happened before SLES10.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/module-renames: Delete, we don't need to care about modules
  renamed before SLES10. Also, current mkinitrd gets the list of
  storage drivers based on pci ids.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: drop support for SLE10, the package
  can't be installed on SLE10 as is, so why not make it more
  adventurous.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove product(openSUSE) supplements
  from the -extra subpackage which doesn't exist on openSUSE
  anymore.
* Thu Aug 20 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-0*: Backport from 2.6.31-rc fixes
  (to be merged)
- patches.drivers/alsa-hda-32-Reword-auto-probe-messages: Refresh.
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Thu Aug 20 2009 jbeulich@novell.com
- Update config files (modularize crypto again).
- supported.conf: Add resulting modules as supported.
* Wed Aug 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc6 and c/s 928.
* Tue Aug 18 2009 tiwai@suse.de
- patches.drivers/alsa-hda-48-alc268-oops-fix: ALSA: hda -
  Fix invalid capture mixers with some ALC268 models.
* Tue Aug 18 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  USB: storage: increase the bcd range in Sony's bad device
  table. (bnc#466554).
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: Change the range from
  0-255 to 0-7 to make it easier for HAL to handle the device without a
  need for custom scripts.
* Mon Aug 17 2009 jeffm@suse.com
- Updated to 2.6.31-rc6.
* Sun Aug 16 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: added N120 support
  and some other devices that were integrated into the driver from
  upstream.
* Sun Aug 16 2009 coly.li@suse.de
- supported.conf:
  set kernel/fs/dlm/dlm as unsupported, since fs/dlm is provided
  separately in the ocfs2 KMP package
* Sat Aug 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-47-idt92hd8x-fix: ALSA: hda - Fix /
  clean up IDT92HD83xxx codec parser (bnc#531533).
* Sat Aug 15 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Samsung
  backlight driver (bnc#527533, bnc#531297).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add some hints how to set the %%jobs
  macro (bnc#530535).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/modversions: for overriden functions, keep the keyword in
  - -pack.
* Thu Aug 13 2009 jeffm@suse.com
- Updated to 2.6.31-rc5-git9.
  - Eliminated 7 patches.
* Thu Aug 13 2009 tiwai@suse.de
- patches.drivers/alsa-hda-42-hp-more-quirk: ALSA: hda - Add
  quirks for some HP laptops (bnc#527284).
- patches.drivers/alsa-hda-4[35]-*: Improve Realtek codec mic
  support
- patches.drivers/alsa-hda-46-stac-lo-detect-fix: ALSA: hda -
  Enable line-out detection only with speakers (bnc#520975).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/split-modules, rpm/kernel-binary.spec.in: add the base files
  also to the main package. That way, kernel-$flavor-base is not
  needed in normal setups (fate#307154).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/find-provides: no rpm provides for drivers/staging. It's
  higly unlikely that any KMP would require them and they just
  take up space in the rpm metadata.
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-41-msi-white-list: ALSA: hda - Add
  a white-list for MSI option (bnc#529971).
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-39-dont-override-ADC-definitions:
  ALSA: hda - Don't override ADC definitions for ALC codecs
  (bnc#529467).
- patches.drivers/alsa-hda-40-auto-mic-support-for-realtek:
  ALSA: hda - Add auto-mic support for Realtek codecs.
* Tue Aug 11 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: do not rename kernel-source.rpmlintrc
  for the -rt variant.
* Mon Aug 10 2009 mmarek@suse.cz
- patches.rpmify/staging-rtl8192su-fix-build-error.patch: move to
  patches.rpmify to fix vanilla ppc builds.
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-38-fix-ALC269-vmaster: ALSA: hda -
  Add missing vmaster initialization for ALC269 (bnc#527361).
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Fri Aug  7 2009 jeffm@suse.com
- patches.fixes/recordmcount-fixup: recordmcount: Fixup wrong
  update_funcs() call.
* Fri Aug  7 2009 tiwai@suse.de
- patches.drivers/alsa-soc-fsl-build-fixes: ASoC: Add missing
  DRV_NAME definitions for fsl/* drivers (to fix PPC builds)
* Fri Aug  7 2009 tiwai@suse.de
- patches.arch/wmi-Fix-kernel-panic-when-stack-protection-enabled:
  wmi: Fix kernel panic when stack protection
  enabled. (bnc#529177).
- supported.conf: Update HD-audio modules
* Fri Aug  7 2009 mmarek@suse.cz
- make config/s390/vanilla a symlink again.
* Fri Aug  7 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: do not manually extract vmlinux
  debuginfo on ppc(64), rpm does it itself.
* Thu Aug  6 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Added kernel-spec-macros to Sources.
* Thu Aug  6 2009 jeffm@suse.de
- patches.suse/linux-2.6.29-even-faster-kms.patch: Disabled. It
  doesn't wake up the display on certain hardware.
* Wed Aug  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not split the -extra subpackage on
  openSUSE (bnc#528097).
* Wed Aug  5 2009 jeffm@suse.de
- Updated to 2.6.31-rc5-git3.
  - Eliminated 4 patches.
* Wed Aug  5 2009 gregkh@suse.de
- kernel-source.changes: remove old (pre 2008) messages, and move 2008
  to kernel-source.changes.old.  No need to spam email addresses that
  are no longer with the company for failed kernel builds.
* Wed Aug  5 2009 gregkh@suse.de
- patches.drivers/staging-rtl8192su-fix-build-error.patch:
  Staging: rtl8192su: fix build error.
* Wed Aug  5 2009 jeffm@suse.de
- patches.suse/supported-flag-enterprise: Make the supported
  flag configurable at build time (bnc#528097).
* Wed Aug  5 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910 for vanilla builds
* Tue Aug  4 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910
* Tue Aug  4 2009 jeffm@suse.de
- patches.rpmify/ttm-pgprot-fixes: ttm: Use pgprot_val for
  comparing pgprot_t.
* Tue Aug  4 2009 tiwai@suse.de
- patches.drivers/alsa-hda-3[0-8]*: ALSA HD-audio updates
- Update config files: enable CONFIG_SND_HDA_CIRRUS=y
* Mon Aug  3 2009 jeffm@suse.de
- Update config files: CONFIG_FRAME_WARN=2048 on all arches, fixes
  ppc build failures.
* Mon Aug  3 2009 jeffm@suse.de
- patches.xen/xen3-patch-2.6.31-rc4-rc5: Fixup pgtable port
* Mon Aug  3 2009 jeffm@suse.de
- Updated to 2.6.31-rc5.
  - Eliminated 11 patches.
* Mon Aug  3 2009 coly.li@suse.de
- Update config files to enable CONFIG_DLM_DEBUG.
* Fri Jul 31 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc4 and c/s 916.
- patches.xen/xen3-driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Delete.
- patches.xen/xen3-panic-on-io-nmi.diff: Delete.
- config.conf: Re-enable Xen.
- Update config files.
* Wed Jul 29 2009 tiwai@suse.de
- Update config files: revert to CONFIG_SND=m and enabled again
  CONFIG_SND_DEBUG=y
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_PRISM2_USB on ia64 and ppc.
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_FB_UDL on ia64.
* Tue Jul 28 2009 jbeulich@novell.com
- config.conf: Remove duplicate i386/desktop entry.
* Tue Jul 28 2009 tiwai@suse.de
- patches.drivers/alsa-hda-29-Add-quirk-for-Dell-Studio-1555:
  ALSA: hda - Add quirk for Dell Studio 1555 (bnc#525244).
* Mon Jul 27 2009 tiwai@suse.de
- patches.drivers/alsa-pcm-*: ALSA PCM fixes
- Fix/enhancement patches backported from ALSA tree
  * patches.drivers/alsa-core-Add-new-TLV-types-for-dBwith-min-max:
    ALSA: Add new TLV types for dBwith min/max (for usb).
  * patches.drivers/alsa-ctxfi-*: SB X-Fi support (FATE#306935).
  * patches.drivers/alsa-hda-*: More HD-audio fixes
  * patches.drivers/alsa-ice-*: ICE17xx fixes
  * patches.drivers/alsa-midi-*: MIDI fixes
  * patches.drivers/alsa-usb-*: USB-audio/MIDI fixes
- Remove obsoleted patches: patches.drivers/alsa-ad1984a-hp-quirks,
  patches.drivers/alsa-ca0106-capture-bufsize-fix,
  patches.drivers/alsa-ctxfi
- Update config files.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, scripts/tar-up.sh: really drop
  config-subst from the package.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: manually create a -devel-debuginfo
  subpackage with vmlinux.debug to fix build with new rpm. This
  works for ix86 and x86_64, other archs might need further fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: more ia64 fixes
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Sat Jul 25 2009 jeffm@suse.de
- config.conf: Re-enabled trace flavor.
* Fri Jul 24 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on i386 and x86_64
  across all flavors.
* Fri Jul 24 2009 jeffm@suse.de
- Update to 2.6.31-rc4.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: cleanup %%cpu_arch_flavor definition,
  make %%symbols a variable and only use it for selecting patches.
  Also drop the RT symbol as there are not rt patches currently.
* Thu Jul 23 2009 mmarek@suse.cz
- Change the s390(x) config layout so that each arch has its own
  subdirectory, as it is done for other archs. s390/vanilla is a
  symlink to s390x/vanilla.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/kernel-spec-macros: move some common
  macros to kernel-spec-macros.
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-bufsize-fix: ALSA: ca0106 -
  Fix the max capture buffer size (bnc#521890).
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi: Add SoundBlaster X-Fi support
  (FATE#306935).
- Update config files.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  Delete.
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  Delete.
- patches.drivers/cpufreq_change_load_calculation_2.patch: Delete.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  Delete.
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  Delete.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  Delete.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Delete.
- patches.arch/thinkpad_fingers_off_backlight_igd.patch: Delete.
* Tue Jul 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove double-slash from include2/asm
  symlink.
* Tue Jul 21 2009 mmarek@suse.cz
- config.conf, rpm/mkspec: exclude trace, kdump and ia64/debug from
  the kernel-syms package. These flavor are often excluded in KMPs,
  so excluding them from kernel-syms reduces useless build
  dependencies. KMPs can buildrequire kernel-$flavor-devel
  explicitely if desired.
* Tue Jul 21 2009 mmarek@suse.cz
  Delete obsolete apparmor patches.
- patches.apparmor/add-path_permission.diff: Delete.
- patches.apparmor/add-security_path_permission: Delete.
- patches.apparmor/apparmor-2.6.25.diff: Delete.
- patches.apparmor/apparmor-audit.diff: Delete.
- patches.apparmor/apparmor-intree.diff: Delete.
- patches.apparmor/apparmor-lsm.diff: Delete.
- patches.apparmor/apparmor-main.diff: Delete.
- patches.apparmor/apparmor-misc.diff: Delete.
- patches.apparmor/apparmor-module_interface.diff: Delete.
- patches.apparmor/apparmor-network.diff: Delete.
- patches.apparmor/apparmor-path_permission: Delete.
- patches.apparmor/apparmor-ptrace-2.6.27.diff: Delete.
- patches.apparmor/apparmor-rlimits.diff: Delete.
- patches.apparmor/d_namespace_path.diff: Delete.
- patches.apparmor/d_namespace_path_oops_fix.diff: Delete.
- patches.apparmor/do_path_lookup-nameidata.diff: Delete.
- patches.apparmor/export-security_inode_permission-for-aufs:
  Delete.
- patches.apparmor/file-handle-ops.diff: Delete.
- patches.apparmor/fix-complain.diff: Delete.
- patches.apparmor/fix-vfs_rmdir.diff: Delete.
- patches.apparmor/fork-tracking.diff: Delete.
- patches.apparmor/fsetattr-reintro-ATTR_FILE.diff: Delete.
- patches.apparmor/fsetattr-restore-ia_file.diff: Delete.
- patches.apparmor/fsetattr.diff: Delete.
- patches.apparmor/remove_suid.diff: Delete.
- patches.apparmor/security-create.diff: Delete.
- patches.apparmor/security-getxattr.diff: Delete.
- patches.apparmor/security-link.diff: Delete.
- patches.apparmor/security-listxattr.diff: Delete.
- patches.apparmor/security-mkdir.diff: Delete.
- patches.apparmor/security-mknod.diff: Delete.
- patches.apparmor/security-readlink.diff: Delete.
- patches.apparmor/security-removexattr.diff: Delete.
- patches.apparmor/security-rename.diff: Delete.
- patches.apparmor/security-rmdir.diff: Delete.
- patches.apparmor/security-setattr.diff: Delete.
- patches.apparmor/security-setxattr.diff: Delete.
- patches.apparmor/security-symlink.diff: Delete.
- patches.apparmor/security-unlink.diff: Delete.
- patches.apparmor/security-xattr-file.diff: Delete.
- patches.apparmor/sysctl-pathname.diff: Delete.
- patches.apparmor/unambiguous-__d_path.diff: Delete.
- patches.apparmor/vfs-getxattr.diff: Delete.
- patches.apparmor/vfs-link.diff: Delete.
- patches.apparmor/vfs-listxattr.diff: Delete.
- patches.apparmor/vfs-mkdir.diff: Delete.
- patches.apparmor/vfs-mknod.diff: Delete.
- patches.apparmor/vfs-notify_change.diff: Delete.
- patches.apparmor/vfs-removexattr.diff: Delete.
- patches.apparmor/vfs-rename.diff: Delete.
- patches.apparmor/vfs-rmdir.diff: Delete.
- patches.apparmor/vfs-setxattr.diff: Delete.
- patches.apparmor/vfs-symlink.diff: Delete.
- patches.apparmor/vfs-unlink.diff: Delete.
* Tue Jul 21 2009 npiggin@suse.de
- Update config files for bnc#522686 -- set
  CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR=65536.
* Mon Jul 20 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on all flavors
  (FATE#305694)
* Mon Jul 20 2009 jeffm@suse.de
- Update config files.
* Mon Jul 20 2009 jeffm@suse.com
- Update to 2.6.30.2
  - lots of security and bug fixes
  - Obsoleted patches.fixes/firmware-memmap-64bit.diff
* Mon Jul 20 2009 mmarek@suse.cz
- rpm/split-modules: set LC_COLLATE=C
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64 (FATE#305694)
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Fri Jul 17 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: simplify the add_dirs_to_filelist
  function and make it less chatty in build logs.
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: ia64 build fix
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/security-default-lsm: security: Define default
  LSM (bnc#442668).
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.rpmify/sgi-hotplug-fixup: hotplug: fix sgi-hotplug
  attribute handling.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: drop the config-subst script, use
  scripts/config instead.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix debugsource generation.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/split-modules: fix last change.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/split-modules: fix for module names with underscores or
  dashes.
* Wed Jul 15 2009 jeffm@suse.de
- Update to 2.6.31-rc3.
  - Eliminated 2 patches.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: annotate in which products the
  obsoleted kmps were last used, remove "ralink-rt2860-kmp" which
  I couldn't find anywhere.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete btusb-kmp (bnc#514375).
* Tue Jul 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/split-modules: move generating of
  the base / main / unsupported module lists to a separate script.
  Avoids 6k modinfo calls and fixes module dependencies
  (bnc#512179).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix include2/asm symlink (bnc#509680).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of function symbols.
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of unknown symbols.
* Tue Jul  7 2009 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Delete the leftover debugging patches for e1000e EEPROM corruption
  that are not needed anymore.
* Tue Jul  7 2009 aj@suse.de
- README.BRANCH: Update, kotd will become 11.2 eventually.
* Mon Jul  6 2009 jeffm@suse.com
- Update to 2.6.31-rc2.
* Fri Jul  3 2009 jeffm@suse.com
- Update to 2.6.31-rc1-git10.
  - Eliminated 28 patches.
  - Xen is disabled.
* Fri Jul  3 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: kbuild: generate
  modules.builtin.
- rpm/kernel-binary.spec.in: package modules.builtin for use by
  modprobe / mkinitrd.
* Fri Jul  3 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: simplify
  the patch applying loops to reduce noise in build logs.
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: chmod +x find-provides
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not "annotate" the packaged
  Modules.symvers
- patches.suse/modpost-filter-out-built-in-depends: Delete.
* Tue Jun 30 2009 jbeulich@novell.com
- patches.arch/ia64-page-migration: Fix compiler warning.
* Mon Jun 29 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/symvers* files back to
  - base, these are needed during KMP installation.
* Mon Jun 29 2009 mmarek@suse.cz
- patches.fixes/kbuild-fix-generating-of-.symtypes-files: kbuild:
  fix generating of *.symtypes files.
- patches.suse/genksyms-add-override-flag.diff: Refresh.
- rpm/kernel-binary.spec.in: create the *.symref files in the build
  directory
* Fri Jun 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add Provides: kernel-{base,extra} to
  the subpackages (bnc#516827).
* Wed Jun 24 2009 gregkh@suse.de
- Update config files.
  revert the ACPI and thermal config changes:
    config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=m
  CONFIG_ACPI_BATTERY=m
  CONFIG_ACPI_BUTTON=m
  CONFIG_ACPI_VIDEO=m
  CONFIG_ACPI_FAN=m
  CONFIG_ACPI_PROCESSOR=m
  CONFIG_ACPI_THERMAL=m
  CONFIG_ACPI_CONTAINER=m
  CONFIG_X86_ACPI_CPUFREQ=m
  CONFIG_THERMAL=m
* Wed Jun 24 2009 gregkh@suse.de
- patches.suse/ec_merge_irq_and_poll_modes.patch: Delete.
- patches.suse/linux-2.6.29-retry-root-mount.patch: Delete.
* Wed Jun 24 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30 and c/s 908.
- Update Xen config files.
- patches.xen/tmem: Transcendent memory ("tmem") for Linux.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=y
  CONFIG_ACPI_BATTERY=y
  CONFIG_ACPI_BUTTON=y
  CONFIG_ACPI_VIDEO=y
  CONFIG_ACPI_FAN=y
  CONFIG_ACPI_PROCESSOR=y
  CONFIG_ACPI_THERMAL=y
  CONFIG_ACPI_CONTAINER=y
  CONFIG_X86_ACPI_CPUFREQ=y
  CONFIG_THERMAL=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_SND_TIMER=y
  CONFIG_SND_PCM=y
  CONFIG_SND_SEQUENCER=y
  CONFIG_SND_MIXER_OSS=y
  CONFIG_SND_PCM_OSS=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  fix up config mistake in x86-64/default made in last commit.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_VIDEO_OUTPUT_CONTROL=y
  CONFIG_SOUND=y
  CONFIG_SND=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_I2C=y
  CONFIG_HWMON=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_IPV6=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_HID=y
  CONFIG_USB_STORAGE=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ATA_PIIX=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_USB_EHCI_HCD=Y
  CONFIG_USB_OHCI_HCD=Y
  CONFIG_USB_UHCI_HCD=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_CFG80211=Y
  CONFIG_LIB80211=Y
  CONFIG_MAC80211=Y
  CONFIG_ATH5K=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_X86_MSR=Y
  CONFIG_X86_CPUID=Y
* Fri Jun 19 2009 gregkh@suse.de
- comment out broken acpi patch for the moment.
* Fri Jun 19 2009 gregkh@suse.de
- move the "preload" branch into master to get 2.6.30 working
  for Moblin.
- Update config files.
- patches.drivers/alsa-ad1984a-hp-quirks: ALSA: update HP
  quirks for Zenith & co (bnc#472789, bnc#479617, bnc#502425,
  bnc#503101).
- patches.suse/driver-core-add-nodename-callbacks.patch: Driver
  Core: add nodename callbacks.
- patches.suse/driver-core-aoe-add-nodename-for-aoe-devices.patch:
  Driver Core: aoe: add nodename for aoe devices.
- patches.suse/driver-core-block-add-nodename-support-for-block-drivers.patch:
  Driver Core: block: add nodename support for block drivers..
- patches.suse/driver-core-bsg-add-nodename-for-bsg-driver.patch:
  Driver Core: bsg: add nodename for bsg driver.
- patches.suse/driver-core-devtmpfs-driver-core-maintained-dev-tmpfs.patch:
  Driver Core: devtmpfs - kernel-maintained tmpfs-based /dev.
- patches.suse/driver-core-drm-add-nodename-for-drm-devices.patch:
  Driver Core: drm: add nodename for drm devices.
- patches.suse/driver-core-dvb-add-nodename-for-dvb-drivers.patch:
  Driver Core: dvb: add nodename for dvb drivers.
- patches.suse/driver-core-input-add-nodename-for-input-drivers.patch:
  Driver Core: input: add nodename for input drivers.
- patches.suse/driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Driver Core: misc: add nodename support for misc devices..
- patches.suse/driver-core-raw-add-nodename-for-raw-devices.patch:
  Driver Core: raw: add nodename for raw devices.
- patches.suse/driver-core-sound-add-nodename-for-sound-drivers.patch:
  Driver Core: sound: add nodename for sound drivers.
- patches.suse/driver-core-usb-add-nodename-support-for-usb-drivers.patch:
  Driver Core: usb: add nodename support for usb drivers..
- patches.suse/driver-core-x86-add-nodename-for-cpuid-and-msr-drivers.patch:
  Driver Core: x86: add nodename for cpuid and msr drivers..
- patches.suse/ec_merge_irq_and_poll_modes.patch: ACPI: EC:
  Merge IRQ and POLL modes.
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: fastboot:
  remove "wait for all devices before mounting root" delay.
- patches.suse/linux-2.6.29-enable-async-by-default.patch:
  enable async_enabled by default.
- patches.suse/linux-2.6.29-even-faster-kms.patch: speed up kms
  even more.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval.
- patches.suse/linux-2.6.29-kms-after-sata.patch: make kms happen
  after sata.
- patches.suse/linux-2.6.29-retry-root-mount.patch: fastboot:
  retry mounting the root fs if we can't find init.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Silence
  acer wmi driver on non-acer machines.
- patches.suse/linux-2.6.29-touchkit.patch: some new touch screen
  device ids
  .
- patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch:
  uvcvideo: ignore hue control for 5986:0241 (bnc#499152).
- patches.suse/devtmpfs.patch: Delete.
* Fri Jun 12 2009 greg@suse.de
- scripts/sequence-patch.sh: fix bug in ketchup usage
* Wed Jun 10 2009 jeffm@suse.com
- Update to 2.6.30-final.
* Wed Jun 10 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30-rc8 and c/s 898.
- Update Xen config files.
- patches.xen/pci-reserve: linux/pci: reserve io/memory space
  for bridge.
- patches.xen/xen-x86-exports: Delete.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: update copyright header and
  change indentation to what autobuild enforces on checkin. No
  functional change.
* Tue Jun  9 2009 jbeulich@novell.com
- patches.suse/stack-unwind-add-declaration.patch: Fold into ...
- patches.suse/stack-unwind: ... this one.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/vmlinux-*.gz to -devel
  again.
- rpm/find-provides: don't generate the ksym() provides ourself,
  let rpm do it. Add a workaround for vmlinux-*.gz in -devel.
* Mon Jun  8 2009 jeffm@suse.com
- patches.suse/reiser4-set_page_dirty_notag: mm: Add
  set_page_dirty_notag() helper for reiser4.
* Fri Jun  5 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: add Enhances: kernel-$flavor to
  kmps (bnc#502092).
* Thu Jun  4 2009 jeffm@suse.de
- Update to 2.6.30-rc8.
* Thu Jun  4 2009 sdietrich@suse.de
- supported.conf: remove duplicate kernel/drivers/md/dm-log
* Thu Jun  4 2009 teheo@suse.de
  Conver ide major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Mon Jun  1 2009 jeffm@suse.de
- Update to 2.6.30-rc7-git4.
* Fri May 29 2009 teheo@suse.de
  Rename mangle_minor to mangle_devt and also cover sd major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Fri May 29 2009 teheo@suse.de
- Update config files to enable DEBUG_BLOCK_EXT_DEVT on all configs
  except for vanilla and ppc/ps3.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_minor parameter (fate#305584).
* Thu May 28 2009 jdelvare@suse.de
- patches.fixes/scsi-scan-blist-update: Add BLIST_REPORTLUN2 to
  EMC SYMMETRIX (bnc#185164, bnc#191648, bnc#505578).
* Wed May 27 2009 jeffm@suse.com
- Update to 2.6.30-rc7-git2.
* Wed May 27 2009 gregkh@suse.de
- patches.drivers/ath1e-add-new-device-id-for-asus-hardware.patch:
  ath1e: add new device id for asus hardware.
* Tue May 26 2009 mmarek@suse.cz
- rpm/mkspec: when using a custom release number, create a
  get_release_number.sh script for autobuild.
* Tue May 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround for bnc#507084: strip
  binaries in /usr/src/linux-obj/*/*/scripts.
* Tue May 26 2009 jdelvare@suse.de
- patches.drivers/r8169-allow-true-forced-mode-setting.patch:
  r8169: allow true forced mode setting (bnc#467518).
* Mon May 25 2009 mmarek@suse.cz
- switch i386 flavors back to -default (non-pae) and -pae for
  milestone2
* Sun May 24 2009 mmarek@suse.cz
- rpm/find-provides: fix for kernel-kdump.
* Sat May 23 2009 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in, rpm/symsets.pl:
  workaround to fix provides of built-in symbols: move vmlinux*.gz
  back to -base and extract the provides from it.
* Fri May 22 2009 teheo@suse.de
- patches.arch/i586-unwind-quick-fix: i586-relocs: ignore NONE
  relocation.
* Fri May 22 2009 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh, rpm/mkspec, scripts/tar-up.sh: avoid
  unpacking the patches tarballs in compute-PATCHVERSION.sh.
* Fri May 22 2009 mmarek@suse.cz
- rpm/mkspec: add --release option to set a custom release string.
- scripts/tar-up.sh: revive -rs option.
* Wed May 20 2009 mmarek@suse.cz
- patches.arch/acpi_thermal_passive_blacklist.patch,
  patches.suse/devtmpfs.patch: fix patches to apply with git-apply.
* Tue May 19 2009 sdietrich@suse.de
- patches.suse/stack-unwind-add-declaration.patch: Fix compile
  error when CONFIG_STACK_UNWIND is not set.
* Tue May 19 2009 jblunck@suse.de
- patches.rpmify/arm-arch_include_asm-fix.diff: ARM: move
  mach-types.h to arch/include/asm.
* Tue May 19 2009 jeffm@suse.com
- Set CONFIG_FRAMEBUFFER_CONSOLE=y
* Tue May 19 2009 jeffm@suse.com
- Restored CONFIG_BOOTSPLASH=y and CONFIG_FB_VESA=y on
  x86/x86_64 (bnc#504608)
* Tue May 19 2009 jbeulich@novell.com
- patches.xen/sfc-endianness: fix building with gcc 4.4.
* Tue May 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30/rc6-git3 and c/s 873.
* Mon May 18 2009 jeffm@suse.com
- Updated to 2.6.30-rc6-git3.
  - Eliminated 4 patches.
* Fri May 15 2009 jeffm@suse.de
- doc/README.SUSE: Updated to reflect building in an external
  directory so as not to contaminate /usr/src/linux
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix path in
  /usr/src/linux-obj/.../Makefile.
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: provide kernel-$flavor-devel =
  %%version-%%source_rel in the -devel packages (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also fix kernel-$flavor-devel requires
  (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/mkspec: fix kernel-syms requires (bnc#503280).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/dup2-retval-fix: dup2: Fix return value with
  oldfd == newfd and invalid fd (bnc#498042).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-fixup: reiserfs: clean up ifdefs.
- patches.fixes/reiserfs-xattr-root-fixup: reiserfs: deal with
  NULL xattr root w/ xattrs disabled.
- patches.fixes/reiserfs-xattrs-disabled-perms: reiserfs: fixup
  perms when xattrs are disabled.
- patches.fixes/reiserfs-expose-privroot: reiserfs: allow exposing
  privroot w/ xattrs enabled.
* Mon May 11 2009 jeffm@suse.de
- Updated to 2.6.30-rc5-git1.
  - Eliminated 4 patches.
* Wed May  6 2009 gregkh@suse.de
- Update config files. update vanilla configs so that the build works.
* Wed May  6 2009 gregkh@suse.de
- Update config files.
- patches.suse/devtmpfs.patch: driver-core: devtmpfs - driver-core
  maintained /dev tmpfs.
* Tue May  5 2009 jeffm@suse.com
- Update config files.
* Tue May  5 2009 jeffm@suse.com
- Update to 2.6.30-rc4-git1.
- patches.rpmify/fix-unexpected-non-allocable-warnings-with-suse-gcc:
  kbuild, modpost: fix "unexpected non-allocatable" warning with
  SUSE gcc.
* Tue May  5 2009 jbeulich@novell.com
- patches.fixes/iwl3945-build: iwl3945: fix ia64/ppc build.
* Tue May  5 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.30-rc4: Fix ia64 build.
* Tue May  5 2009 jbeulich@novell.com
- patches.suse/stack-unwind: Also initialize PT_GS() on 32-bit.
- patches.arch/x86_64-unwind-annotations: Refresh.
* Tue May  5 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc4 and c/s 867.
- Update i386 and x86_64 config files.
- config.conf: Re-enable Xen.
* Tue May  5 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: kbuild: add workaround
  for icecream bug (bnc#495786).
* Fri May  1 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
* Fri May  1 2009 jeffm@suse.com
- Update to 2.6.30-rc4.
  - Eliminated 2 patches.
* Fri May  1 2009 jeffm@suse.com
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
- patches.kernel.org/patch-2.6.30-rc3-rc4:
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch: Delete.
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: Delete.
* Thu Apr 30 2009 mmarek@suse.cz
- scripts/submit-to-bs: tentative script to submit a new kernel to
  openSUSE:Factory
* Tue Apr 28 2009 npiggin@suse.de
- patches.apparmor/unambiguous-__d_path.diff: Put a reminder in here
  to fix the lock order problem when the patch is updated to HEAD.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: Fix prepending EXTRAVERSION,
  rename the variable back to @RELEASE_PREFIX@.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: prepend the EXTRAVERSION to
  the rpm release string (note that this won't have any effect in
  the openSUSE:* projects).
* Fri Apr 24 2009 gregkh@suse.de
- Update config files.
  - build rtc_cmos driver into the kernel for i386 and x86-64 default
    kernels.  This should automatically take care of the rtc/system time
    syncing so we don't need to do it in a boot script and should speed
    up booting time a lot.
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change CONFIG_ATA=y and CONFIG_SATA_AHCI=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_EXT2_FS=y and CONFIG_EXT3_FS=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_SCSI=y and CONFIG_BLK_DEV_SD=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to use CONFIG_USB=y
* Thu Apr 23 2009 jeffm@suse.de
- Added legacy config.
* Thu Apr 23 2009 jeffm@suse.de
- Temporarily disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
* Thu Apr 23 2009 jeffm@suse.de
- Moved i386 kernel-default to kernel-legacy.
- Moved i386 kernel-pae config to kernel-default.
- Disabled CONFIG_ISA in i386 kernel-default to improve boot speed.
* Thu Apr 23 2009 jeffm@suse.de
- Update to 2.6.30-rc3.
* Thu Apr 23 2009 jeffm@suse.de
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: x86:
  hpet: fix periodic mode programming on AMD 81xx.
- patches.fixes/hpet-boot-fix: Delete.
* Mon Apr 20 2009 jeffm@suse.de
- patches.fixes/hpet-boot-fix: hpet: fix "IO-APIC + timer doesn't work!"
* Mon Apr 20 2009 jeffm@suse.de
- Update to 2.6.30-rc2-git6.
* Wed Apr 15 2009 jeffm@suse.de
- Update to 2.6.30-rc2.
  - trace and xen flavors disabled.
  - CONFIG_OTUS disabled on ppc.
  - request-based multipath could use some testing.
  - Eliminated 96 patches.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/devel-post.sh, rpm/kernel-binary.spec.in: Created i586 symlink
  for i386.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added /usr/src/linux-obj to -devel
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use xargs -r to fix case when no
  modules are supported.
* Fri Apr 10 2009 jeffm@suse.com
- Moved linux-obj symlink handling to kernel-$flavor-devel.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/package-descriptions: Add comment.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh: Rename the timestamp
  file to source-timestamp instead, so that autobuild does not add
  the timestamp verbatim.
* Thu Apr  9 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29 final and c/s 854.
- patches.xen/sfc-external-sram: enable access to Falcon's
  external SRAM (bnc#489105).
- patches.xen/sfc-sync-headers: sync Solarflare accelerator
  headers (bnc#489105).
- Update Xen config files.
* Wed Apr  8 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Fix last change: do not add the
  timestamp if it is already added verbatim (by prepare_spec during
  checkin)
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Add source timestamp to package
  descriptions.
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: add descriptions to
  generated spec files.
- rpm/package-descriptions: descriptions of binary packages.
* Mon Apr  6 2009 jeffm@suse.com
- Enabled STAGING on !x86 and disabled COMEDI.
* Mon Apr  6 2009 jeffm@suse.com
- patches.rpmify/split-package: Enable
* Mon Apr  6 2009 jeffm@suse.com
- Update config files: Fixed i386-vanilla.
* Mon Apr  6 2009 jeffm@suse.com
- patches.fixes/xfs-export-debug: xfs: export assertion handler.
* Mon Apr  6 2009 jeffm@suse.com
- Switch from SPARSEMEM to DISCONTIGMEM on i386.
* Sun Apr  5 2009 jeffm@suse.com
- scripts/tar-up_and_run_mbuild.sh: Added pae to the important
  specfiles list.
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Fix missing ia64-debug.
* Fri Apr  3 2009 jeffm@suse.com
- patches.xen/sfc-resource-driver: Fix uninitialized var warning.
* Fri Apr  3 2009 jeffm@suse.com
- Drop NR_CPUS back to 128 on i386.
* Fri Apr  3 2009 jeffm@suse.com
- rpm/kernel-binary.spec.in: Added CONFIG_SPLIT_PACKAGE.
* Fri Apr  3 2009 jeffm@suse.de
- Update config files: Enabled STAGING drivers on -vanilla.
* Fri Apr  3 2009 jblunck@suse.de
- patches.rpmify/rpm-kernel-config: Rediff.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: chmod +x mkspec arch-symbols
  compute-PATCHVERSION.sh
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Enabled STAGING drivers.
* Fri Apr  3 2009 jeffm@suse.com
- Sync up kernel configs for x86/x86_64 flavors.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: do not package the binary
  spec files anymore.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/modversions: keep the override keyword in --pack.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh: remove
  @TOLERATE_UNKNOWN_NEW_CONFIG_OPTIONS@ expansion, check for a file
  named TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS in sourcedir instead.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: set LC_ALL=C in rpm -q call
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add @FLAVOR@ again to avoid %%%%(...)
  expansion
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/mkspec: new script to generate spec files from *.spec.in
  templates
- rpm/compute-PATCHVERSION.sh, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in: add to the
  source rpm
- scripts/tar-up.sh: just tar up patches directories and call
  mkspec
* Tue Mar 31 2009 mmarek@suse.cz
- rpm/kernel-dummy.spec.in: Delete.
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
* Tue Mar 31 2009 mmarek@suse.cz
- config.conf, rpm/old-packages.conf, scripts/arch-symbols,
  scripts/run_oldconfig.sh, scripts/tar-up.sh: drop the arch
  symbols completely, only map the various ix86 archs to i386.
* Tue Mar 31 2009 mmarek@suse.cz
- doc/README.SUSE: allow_unsupported_modules needs to be set before
  installing the kernel (bnc#484664).
* Tue Mar 31 2009 jeffm@suse.de
- Add %%changelog to spec files
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Clean up %%build_$flavor macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in: Create kernel-source-vanilla
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-syms.spec.in, scripts/tar-up.sh: Depend on kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Create a %%using_buildservice macro
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/sequence-patch.sh, scripts/tar-up.sh:
  kernel-{binary,source}: Remove arch guards
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.SUSE, rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: Move development files from kernel-source to
  kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove $CONFIG_MODULES
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove duplicate CONFIG_DEBUG_INFO=y
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Use macros for cpu_arch
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in:
  kernel-{source,binary}: Use path-related rpm macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,  rpm/kernel-source.spec.in:
  Use a %%kernelrelease macro.
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in, rpm/source-post.sh, scripts/tar-up.sh:
  Use %%variant instead of $variant
* Tue Mar 31 2009 jeffm@suse.de
- kernel-source: Kill old obsoletes
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh:
  Use %%var instead of @VAR@ except where necessary
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Sort by flavor, not architecture
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Stop the architecture %%else madness
* Tue Mar 31 2009 jeffm@suse.de
- kernel-binary: Stop the architecture %%else madness
* Mon Mar 30 2009 jeffm@suse.de
- Removed -RT guards and a dead patch.
* Mon Mar 30 2009 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: Delete.
* Mon Mar 30 2009 jeffm@suse.de
- patches.suse/reiserfs-inode-init: Delete.
* Thu Mar 26 2009 mmarek@suse.cz
- rpm/config.sh: introduce rpm/config.sh, defining SRCVERSION and
  VARIANT variables.
* Tue Mar 24 2009 jeffm@suse.de
- Update to 2.6.29-final.
  - Eliminated 4 patches.
* Fri Mar 20 2009 jbeulich@novell.com
- Update Xen config files.
- Update Xen patches to 2.6.29-rc8 and c/s 821.
* Wed Mar 18 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, scripts/tar-up.sh: don't add "<RELEASE>"
  to the release, breaks plain rpmbuild.
* Tue Mar 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't generate symsets
- rpm/kernel-syms.spec.in: don't package symsets
- rpm/find-provides: disable symset provides
- rpm/macros.kernel-source: don't check for /boot/symsets*
  (fate#305945)
* Tue Mar 17 2009 knikanth@suse.de
- patches.fixes/loop-barriers: Delete.
- patches.fixes/loop-barriers2: Delete.
  Remove non-mainline patches to loop driver making it honour
  O_SYNC, sync requests and barriers. (bnc#485089), (bnc#471249)
* Mon Mar 16 2009 bphilips@suse.de
- README: add rough guide to updating KABI
* Fri Mar 13 2009 jeffm@suse.com
- Update to 2.6.29-rc8.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.fixes/fix-nf_conntrack_slp,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: fix build warnings.
* Thu Mar 12 2009 jbeulich@novell.com
- Update Xen patches addressing several issues in initial commit
- Update Xen config files (re-enable oprofile, disable novfs).
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind annotations
  in entry_64-xen.S.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: fix unwind annotations in
  entry_64.S.
* Thu Mar 12 2009 rgoldwyn@suse.de
- patches.suse/novfs-creds-change-2.6.29: Changing credential
  according to new task_struct.
* Wed Mar 11 2009 jblunck@suse.de
- rpm/kernel-binary.spec.in: Use split_packages only if supported.conf
  is not empty.
* Mon Mar  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: renamed modprobe config to
  /etc/modprobe.d/50-module-renames.conf (required by new
  module-init-tools).
* Mon Mar  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29-rc4: fix ia64 build.
* Mon Mar  9 2009 jbeulich@novell.com
- Update Xen config files (get tracing options back in sync with
  default).
* Fri Mar  6 2009 jeffm@suse.de
- Update config files: Enable CONFIG_FRAME_POINTER on Xen.
* Fri Mar  6 2009 jeffm@suse.de
- config.conf: Enabled Xen for building.
* Fri Mar  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc7.
* Fri Mar  6 2009 jbenc@suse.cz
- Update config files: enabled wireless debugging in -debug flavors.
* Fri Mar  6 2009 mmarek@suse.cz
- rpm/get_release_number.sh.in, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in,
  scripts/tar-up.sh, doc/README.SUSE: finally drop kernel-dummy
- rpm/prepare-build.sh: Delete.
* Wed Mar  4 2009 jeffm@suse.com
- Update to 2.6.29-rc7.
  - Eliminated 1 patch.
* Wed Mar  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround a bash bug (bnc#481817)
  in kernel-vanilla.spec.
* Tue Mar  3 2009 jeffm@suse.com
- patches.suse/export-security_inode_permission: Export
  security_inode_permission for aufs.
* Thu Feb 26 2009 jeffm@suse.com
- scripts/tar-up.sh: Add -u to update existing spec files.
* Thu Feb 26 2009 sven@suse.de
- rpm/kernel-binary.spec.in: Fix sub-package install-time conflict.
* Wed Feb 25 2009 mmarek@suse.cz
- scripts/tar-up.sh: create tarballs that don't change
  unnecessarily: set owner/group to nobody/nobody, mtime to time of
  the latest commit and sort the input files.
* Tue Feb 24 2009 jeffm@suse.com
- Update to 2.6.29-rc6-git1.
* Sat Feb 21 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: also check if the package versions match
  (bnc#478462)
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix 32-bit arch_unwind_init_running().
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix patch fuzz.
* Fri Feb 20 2009 jbeulich@novell.com
- misc/xen-port-patches.py: Adjust fro new x86 header placement.
- patches.arch/x86_64-unwind-annotations: fix unwind annotations
  (bnc#472783).
- patches.suse/stack-unwind: Properlz hook up unwinder again.
* Fri Feb 20 2009 jeffm@suse.de
- patches.suse/kdb-common: Build fix with -I directive.
* Fri Feb 20 2009 jeffm@suse.de
- Update config files.
* Fri Feb 20 2009 jeffm@suse.de
- Update to 2.6.29-rc5-git3.
  - Eliminated 1 patch.
* Thu Feb 19 2009 mmarek@suse.cz
- rpm/symsets.pl: allow passing only Module.symvers and no modules
* Wed Feb 18 2009 olh@suse.de
- disable ppc601 support, disable unused framebuffer drivers
* Wed Feb 18 2009 olh@suse.de
- disable kdump on ppc32
* Mon Feb 16 2009 jeffm@suse.com
- Update config files.
* Sat Feb 14 2009 jeffm@suse.de
- Update to 2.6.29-rc5.
* Fri Feb 13 2009 jeffm@suse.de
- Update to 2.6.29-rc4-git7.
  - Eliminated 2 patches.
* Mon Feb  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: spin_is_contended
  Kconfig fixes.
* Mon Feb  9 2009 jeffm@suse.de
- Updated to 2.6.29-rc4.
  - Eliminated 3 patches.
* Fri Feb  6 2009 jeffm@suse.com
- patches.fixes/fix-warning-while-mapping-0-1MB-range-with-dev-mem:
  x86, pat: fix warn_on_once() while mapping 0-1MB range.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: fix
  last change: don't pass -e to weak-modules2.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: pass
  down shell options like -x to weak-modules2 to make debugging
  with rpm -ivv easier.
* Tue Feb  3 2009 jeffm@suse.de
- patches.fixes/fix-nf_conntrack_slp: make nf_conntrack_slp
  actually work (bnc#470963).
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/tar-up.sh: fix branch name in KOTD packages.
* Tue Feb  3 2009 olh@suse.de
- config.conf: readde -debug flavor for ppc64
* Tue Feb  3 2009 olh@suse.de
- patches.fixes/scsi-ibmvfc_prli_initiator_fix.patch:
  Better handle other FC initiators (bnc#471217 - LTC51238)
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/wd-functions.sh: display master as "master", not "HEAD"
  or "".
* Mon Feb  2 2009 jeffm@suse.de
- patches.fixes/ath9k-fix-led_device_naming.diff: ath9k: fix
  led naming.
- patches.fixes/b43legacy-fix-led_device_naming.diff: b43legacy:
  fix led naming.
- patches.fixes/iwlwifi-fix-iwl-3945_led_device_naming.diff:
  iwlwifi: another led naming fix.
- patches.fixes/iwlwifi-fix-iwl-led_device_naming.diff: iwlwifi:
  fix led naming   .
- patches.fixes/rt2x00-fix-led_device_naming.diff: rt2x00:
  fix led naming.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3-git3.
  - Eliminated 6 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3.
  - AppArmor is disabled.
  - Xen is disabled.
  - Eliminated 745 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Enabled patches.suse/reiserfs_warning-reentrant
* Mon Feb  2 2009 rw@suse.de
- patches.fixes/xpc-pass-physical,
  patches.kabi/xpc-pass-physical:
  kABI: restore upstream patch, add ABI cover-up. (bnc#458811)
* Mon Feb  2 2009 olh@suse.de
- patches.fixes/serial-jsm-enable_ms.patch:
  Add enable_ms to jsm driver (bnc#471224 - LTC51066)
* Mon Feb  2 2009 olh@suse.de
- patches.arch/ppc-optimize-sync.patch:
  Optimise smp_{r,w}mb and mutex (bnc#471222 - LTC51356)
* Sat Jan 31 2009 gregkh@suse.de
- refresh patches for fuzz due to 2.6.27.14-rc1 import.
* Sat Jan 31 2009 gregkh@suse.de
- patches.kabi/abi-fix-add-epoll_devs-back-to-struct-user_struct.patch:
  ABI fix: add epoll_devs back to struct user_struct.
* Sat Jan 31 2009 gregkh@suse.de
- Update to 2.6.27.14-rc1
  - lots of security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.drivers/alsa-virtuoso-no-eeprom-overwrite
  - patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch
  - patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch
  - patches.fixes/sysfs-fix-problems-with-binary-files.patch
  - patches.fixes/xpc-fix-NULL-deref
  - patches.fixes/xpc-write-barrier
* Fri Jan 30 2009 olh@suse.de
- patches.arch/ppc-pseries-migration_hang_fix.patch:
  Fix partition migration hang under load (bnc#470563 - LTC51153)
* Fri Jan 30 2009 olh@suse.de
- disable CONFIG_DEBUG_STACKOVERFLOW and CONFIG_DEBUG_STACK_USAGE
  on ppc/ppc64
* Fri Jan 30 2009 teheo@suse.de
- patches.drivers/libata-fix-EH-device-failure-handling: libata:
  fix EH device failure handling (bnc#470845).
* Thu Jan 29 2009 jjolly@suse.de
- patches.arch/s390-08-08-add_qdio_utilization.patch: zfcp:
  queue_full is lacking the entry for qdio utilization
  (bnc#466462).
* Thu Jan 29 2009 gregkh@suse.de
- add ability to debug kernel using USB debug connector.
- Update config files.
- patches.suse/usb-move-ehci-reg-def.patch: usb: move ehci
  reg def.
- patches.suse/x86-usb-debug-port-early-console-v4.patch: x86:
  usb debug port early console, v4.
* Thu Jan 29 2009 mmarek@suse.cz
- patches.kabi/abi-fix-add-s_syncing-back-to-struct-super_block.patch
  patches.kabi/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch
  patches.kabi/export-iwl_rx_allocate
  patches.kabi/sched-kabi-compat-hack.patch: Introduce
  patches.kabi/ for patches that only work around kabi issues and
  can be safely dropped at the next SP.
* Wed Jan 28 2009 agruen@suse.de
- patches.xen/xen-x86-mark_rodata_rw.patch: Add missing pageattr.c
  changes to pageattr-xen.c (bnc#439348).
* Wed Jan 28 2009 agruen@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
- patches.xen/xen-x86-mark_rodata_rw.patch: xen specific part
  (bnc#439348).
* Wed Jan 28 2009 mmarek@suse.cz
- config/s390/s390: the -man package still fails for s390, disable
  it
* Wed Jan 28 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix build of the -man subpackage on
  31bit s390
* Wed Jan 28 2009 mmarek@suse.cz
- fix kernel-default.ppc64 reference symsets
* Wed Jan 28 2009 jslaby@suse.cz
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
  [cpu_mask_to_apicid bigsmp fix]
* Wed Jan 28 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-module_alias.patch:
  map scsi proc_name to module name (bnc#459933 - LTC50724)
* Tue Jan 27 2009 jeffm@suse.de
- Update config files: Disable ftrace in -debug on ppc64
* Tue Jan 27 2009 jeffm@suse.de
- config.conf: Added -debug flavor for ppc64.
* Tue Jan 27 2009 bwalle@suse.de
- patches.drivers/libfc-set-the-release-function.diff:
  Whitespace change.
* Tue Jan 27 2009 hare@suse.de
- patches.drivers/libfc-fix-read-IO-data-integrity: libfc:
  IO data integrity issue when a IO data frame lost (bnc#469536).
* Tue Jan 27 2009 jbeulich@novell.com
- re-enable patches.xen/xen3-e1000e_Export_set_memory_ro-rw.
* Tue Jan 27 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  include prototype for PFN_UP() (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls.
  readded to avoid kabi change
* Mon Jan 26 2009 jeffm@suse.de
- config.conf: Added kernel-vmi to i386.
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  use PFN_UP() for end_pfn (bnc#462546 - LTC50009)
* Mon Jan 26 2009 mmarek@suse.cz
- kabi: import FCoE changes
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: disable
  wrong debug message again.
* Mon Jan 26 2009 rw@suse.de
- patches.fixes/taskstats-alignment:
  IA64: fill 'struct taskstats' on stack and 'memcpy' result to skb.
  (bnc#448410)
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix calculation of reserve_size (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/disable-lro-per-default: Disable LRO per default
  in igb and ixgbe. (bnc#467519)
* Mon Jan 26 2009 jbeulich@novell.com
- Just comment out patches.xen/xen3-e1000e_* (to address build error)
  until disposition of their originals is known.
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/sctp_do_not_use_stale_copy_of_sk: Do not use
  stale copy of sk. (bnc#440104)
* Mon Jan 26 2009 jblunck@suse.de
  Renamed some patches so they get included in vanilla builds.
- patches.rpmify/firmware-path: Renamed.
- patches.rpmify/no-include-asm: Renamed.
- patches.suse/md-raid-metadata-PAGE_SIZE.patch: Renamed.
* Mon Jan 26 2009 olh@suse.de
- patches.suse/led_classdev.sysfs-name.patch: use correct name
  for /sys/devices/virtual/leds/ entries (bnc#468350)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Delete.
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_ioremap_sanity_check: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Remove not mainline e1000e patches which were added to help with
  the e1000e NVM corruption - root issue is fixed
* Mon Jan 26 2009 kkeil@suse.de
- patches.drivers/tg3_libphy_workaround: tg3 libphy workaround.
  (bnc#468725)
* Mon Jan 26 2009 hare@suse.de
- supported.conf: Correct spelling for dm-least-pending
  path checker.
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-check-info-before-access: Kernel Oops
  during path failover (bnc#458393).
* Sun Jan 25 2009 gregkh@suse.de
- refresh patch fuzz now that 2.6.27.13 is in tree
* Sun Jan 25 2009 gregkh@suse.de
- Update to final version of 2.6.27.13
* Sat Jan 24 2009 gregkh@suse.de
- dynamic debugging fixes backported from upstream:
- patches.drivers/driver-core-add-newlines-to-debugging-enabled-disabled-messages.patch:
  driver core: add newlines to debugging enabled/disabled
  messages.
- patches.drivers/driver-core-fix-dynamic_debug-cmd-line-parameter.patch:
  Driver core: fix 'dynamic_debug' cmd line parameter.
- patches.drivers/driver-core-fix-using-ret-variable-in-unregister_dynamic_debug_module.patch:
  driver core: fix using 'ret' variable in
  unregister_dynamic_debug_module.
* Sat Jan 24 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch:
  (fix return of an unitialized value (bnc#469017)
* Sat Jan 24 2009 mmarek@suse.cz
- update kabi files: ignore changes in struct pcie_link_state as
  it is an internal structure only.
* Sat Jan 24 2009 mmarek@suse.cz
- patches.suse/genksyms-add-override-flag.diff: genksyms: add
  - -override flag.
- rpm/kernel-binary.spec.in: set KBUILD_OVERRIDE=1
* Sat Jan 24 2009 ghaskins@suse.de
- patches.fixes/sched-kabi-compat-hack.patch: sched: leave
  RT_GROUP_SCHED structure components intact to preserve kABI.
  broke kabi with fix for 456542
* Sat Jan 24 2009 trenn@suse.de
- patches.fixes/cpufreq_export_latency.patch: CPUFREQ: Introduce
  /sys/devices/system/cpu/cpu*/cpufreq/cpuinfo_transition_latency
  (bnc#464461).
- patches.fixes/cpufreq_ondemand_adjust_sampling_rate_limit.patch:
  CPUFREQ: ondemand/conservative: sanitize sampling_rate
  restrictions (bnc#464461).
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
- patches.fixes/x86_cpufreq_powernow-k8_acpi_latency_values.patch:
  X86 powernow-k8 cpufreq: Get transition latency from acpi _PSS
  object (bnc#464461).
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/xfs-dmapi-fixes: xfs/dmapi: fix crash on mount
  (bnc#458027).
* Fri Jan 23 2009 ghaskins@suse.de
- Update config files: Disable RT_GROUP_SCHED (bnc#456542).
  The RT_GROUP_SCHED feature is experimental and clearly broken, so
  lets turn it off for now.
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/hpilo-open-close-fix: hpilo open/close fix
  (bnc#466517).
* Fri Jan 23 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: Handle I/O
  on stopped queues correctly (bnc#458393).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.suse/mnt-want-write-speedup.patch,
  patches.suse/mnt_clone_write.patch: modified not to break kABI,
  enabled (bnc#436953).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.fixes/iwlagn-fix-rfkill.patch: iwlagn: fix hw-rfkill
  while the interface is down (bnc#446158).
* Fri Jan 23 2009 mmarek@suse.cz
- kabi/severities: temporarily enable changes in FcOE modules.
* Fri Jan 23 2009 hare@suse.de
- patches.arch/s390-08-06-personality.patch: kernel: setting 32
  bit personality doesn't work (bnc#466462).
- patches.arch/s390-08-07-compat_wrappers.patch: kernel:
  Add missing wrapper functions for 31 bit compat
  syscalls. (bnc#466462,LTC#51229).
- patches.fixes/block-leave-the-request-timeout-timer-running:
  Delete obsolete patch.
* Fri Jan 23 2009 bwalle@suse.de
- patches.drivers/fcoe-change-fcoe_sw-sg_tablesi.diff: change
  fcoe_sw sg_tablesize to SG_ALL (bnc #459142).
- patches.drivers/fcoe-check-return-for-fc_set_m.diff: check
  return for fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-fix-frame-length-validati.diff: fix frame
  length validation in the early receive path (bnc #459142).
- patches.drivers/fcoe-fix-incorrect-use-of-struct-module.diff:
  fcoe: fix incorrect use of struct module (bnc #468051).
- patches.drivers/fcoe-improved-load-balancing-i.diff: improved
  load balancing in rx path (bnc #459142).
- patches.drivers/fcoe-logoff-of-the-fabric-when.diff: Logoff
  of the fabric when destroying interface (bnc #459142).
- patches.drivers/fcoe-remove-warn_on-in-fc_set.diff: remove
  WARN_ON in fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-user_mfs-is-never-used.diff: user_mfs is
  never used (bnc #459142).
- patches.drivers/libfc-add-fc_disc-c-locking-co.diff: Add
  fc_disc.c locking comment block (bnc #459142).
- patches.drivers/libfc-ensure-correct-device_pu.diff: libfc:
  Ensure correct device_put/get usage (round 2).
- patches.drivers/libfc-fix-rport-recursive-lock.diff: libfc:
  Fix rport recursive lock on rport mutex (bnc #459142).
- patches.drivers/libfc-handle-rrq-exch-timeout.diff: libfc:
  handle RRQ exch timeout (bnc #465596).
- patches.drivers/libfc-improve-fc_lport-c-locki.diff: Improve
  fc_lport.c locking comment block (bnc #459142).
- patches.drivers/libfc-improve-fc_rport-c-locki.diff: Improve
  fc_rport.c locking comment block (459142).
- patches.drivers/libfc-make-fc_disc-inline-with.diff: make
  fc_disc inline with the fc_lport structure (bnc #459142).
- patches.drivers/libfc-make-rscn-parsing-more-r.diff: make RSCN
  parsing more robust (bnc #459142).
- patches.drivers/libfc-make-sure-we-access-the.diff: make sure
  we access the CRC safely (bnc #459142).
- patches.drivers/libfc-pass-lport-in-exch_mgr_r.diff: libfc:
  Pass lport in exch_mgr_reset (bnc #465596).
- patches.drivers/libfc-remove-debug-print-state.diff: libfc:
  Remove debug print statement, too verbose (bnc #459142).
- patches.drivers/libfc-set-the-release-function.diff: Set
  the release function for the rport's kobject (round 2)
  (bnc #459142).
- patches.drivers/libfc-updated-comment-for-orde.diff: updated
  comment for order of em and ex locks (bnc #459142).
- patches.drivers/libfc-updated-libfc-fcoe-modul.diff: updated
  libfc fcoe module ver to 1.0.6 (bnc #459142).
- patches.drivers/libfc-use-an-operations-struct.diff: use an
  operations structure for rport callbacks (bnc #459142).
- patches.drivers/libfc-when-rport-goes-away-re.diff: libfc:
  when rport goes away (re-plogi), clean up exchanges to/from
  rport (bnc #465596).
- patches.drivers/libfc_locking.diff: libfc, fcoe: fixed locking
  issues with lport->lp_mutex around lport->link_status (bnc
  [#468053]).
- patches.drivers/libfc_rport.diff: libfc: rport retry on LS_RJT
  from certain ELS (bnc #468054).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/qla2xxx-check-fc-rport-validity:
  qla2xxx: added check for fcport is valid in
  qla2x00_terminate_rport_io(). (bnc#467624).
* Fri Jan 23 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-t1616-quirk: ALSA: hda -
  Add quirk for Gateway T1616 laptop (bnc#467597).
- patches.drivers/alsa-hda-hp-dv4-quirk: ALSA: hda - Add model
  entry for HP dv4.
- patches.drivers/alsa-hda-intel-d945-ref-quirk: ALSA: hda -
  Add model=ref for Intel board with STAC9221 (bnc#406529).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: block: Rediff
- patches.fixes/block-use-round_jiffies_up: Block: use
  round_jiffies_up() (bnc#464155).
- Add missing patches to series.conf:
  patches.fixes/round-jiffies-up
  patches.fixes/block-use-round_jiffies_up
  patches.fixes/block-fix-blk_start_queueing
  patches.fixes/suppress-buffer-IO-errors
  patches.fixes/block-optimizations-in-blk_rq_timed_out_timer
  patches.fixes/block-add-comment-in-blk_rq_timed_out
* Fri Jan 23 2009 olh@suse.de
- update patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  handle also drivers/scsi/ibmvscsi/ibmvfc.c
* Fri Jan 23 2009 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-on-ipv6-mount: cifs: make sure we
  allocate enough storage for socket address (467691).
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch:
  ABI fix: add WB_SYNC_HOLD enum writeback_sync_modes.
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-s_syncing-back-to-struct-super_block.patch:
  ABI fix: add s_syncing back to struct super_block.
* Fri Jan 23 2009 gregkh@suse.de
- update to 2.6.27.13-rc1:
  - security updates
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-fix_hugepage_check.patch
  - patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back
  - patches.drivers/alsa-hda-samsung-q45-quirk
  - patches.fixes/security-introduce-missing-kfree.patch
  - patches.fixes/xpc-fix-heartbeat
- Update config files.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/e1000-fix-shared-emc.patch: e1000: fix bug
  with shared interrupt during reset (bnc#396687)
* Thu Jan 22 2009 tonyj@suse.de
- patches.fixes/revert-bgcolor-line-feed-93f78da4.patch: Revert
  "vt: fix background color on line feed" (bnc#418613).
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/iwlwifi-fix-rs_get_rate-oops.patch: iwlwifi:
  fix rs_get_rate WARN_ON() (bnc#456002).
- Reordered wireless patches to group together patches touching the same
  driver.
* Thu Jan 22 2009 bphilips@suse.de
- patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch:
  disable catas_reset by default to avoid problems with EEH
  (bnc#456389).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  fixed kABI breakage. (bnc#458811)
* Thu Jan 22 2009 bwalle@suse.de
- scripts/tar-up_and_run_mbuild.sh: s390 (the 31 bit variant) is
  not an important spec file.
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: fixed kABI
  breakage, reenabled.
* Thu Jan 22 2009 mmarek@suse.cz
- rpm/modversions: eat the "override" keyword before parsing the
  symbol definition.
* Thu Jan 22 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  Correct VIO bus/device CMO accounting problems (bnc#468304 - LTC51205)
* Thu Jan 22 2009 olh@suse.de
- patches.suse/of_platform_driver.module-owner.patch:
  add missing module symlink to /sys/bus/*/driver/*
  in struct of_platform_driver.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix - new version from Intel  (bnc#465923)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
  (fix compilation on i386 and add hpet64 to kernel-parameters.txt)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  sgi-xpc: need to pass the physical address, not virtual. (bnc#458811)
- patches.fixes/xpc-fix-heartbeat:
  sgi-xpc: eliminate false detection of no heartbeat. (bnc#464545)
* Thu Jan 22 2009 jkosina@suse.de
- patches.fixes/input-add-nomux-dell-vostro-1510.patch: Input:
  add Dell Vostro 1510 to nomux list (bnc#404881).
* Thu Jan 22 2009 jblunck@suse.de
- scripts/compute-PATCHVERSION.sh: Fix SRCVERSION parsing (bnc#465113).
* Thu Jan 22 2009 tiwai@suse.de
- patches.drivers/alsa-hda-add-volume-offset: ALSA: hda - Add
  extra volume offset to standard volume amp macros (bnc#466428).
- patches.drivers/alsa-hda-stac-reduce-volume-scale: ALSA: hda -
  Halve too large volume scales for STAC/IDT codecs (bnc#466428).
* Thu Jan 22 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.12-update: Update lpfc from 8.2.8.11
  to 8.2.8.12 (bnc#467713).
* Thu Jan 22 2009 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: fix missing jl arg
* Wed Jan 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete duplicate error message in the
  kabi checks
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/remove_kernel_physical_mapping_init_from_init:
  move kernel_physical_mapping_init to __meminit (bnc#467474).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: disabled, as it changes
  kABI.
* Wed Jan 21 2009 gregkh@suse.de
- patches.fixes/security-introduce-missing-kfree.patch: security:
  introduce missing kfree (bnc#467322).
- patches.fixes/sysfs-fix-problems-with-binary-files.patch:
  sysfs: fix problems with binary files.
* Wed Jan 21 2009 rw@suse.de
- patches.arch/ia64-page-migration.fix:
  fix deadlock caused by cpe_migrate.ko and mark it supported.
  (bnc#464676)
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/sn-irq-affinity: sn2: preserve irq affinity set
  in PROM (bnc#457679).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/uv_zalias_support: uv: Support for non-nasid 0
  systems (bnc#458869).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/xpc-fix-NULL-deref: sgi-xpc: Remove NULL pointer
  dereference. (bnc#466563).
- patches.fixes/xpc-write-barrier: sgi-xpc: ensure flags are
  updated before bte_copy (bnc#466563).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/ipw2200-workaround-firmware-restarts-when-scanning.patch:
  ipw2200: fix scanning while associated (bnc#459067).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/iwl3945-fix-rfkill.patch: iwl3945: report
  killswitch changes even if the interface is down (bnc#446013).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: mac80211:
  add direct probe before association (bnc#461889).
* Wed Jan 21 2009 hare@suse.de
- patches.drivers/mptsas-discover-all-devices: mptsas driver
  fails to discover devices (bnc#459932).
* Wed Jan 21 2009 jbeulich@novell.com
- Update Xen patches to 2.6.27.12.
- patches.xen/764-netback-foreign-pages.patch: netback: handle
  non-netback foreign pages.
- patches.xen/769-evtchn-CPU-offline.patch: evtchn: Fix CPU offlining
  to switch all affected ports belonging to a particular /dev/evcthn
  user.
- patches.xen/gso-size-check.patch: gso: Ensure that the packet
  is long enough.
- patches.xen/xen-S3-MSI: fix Dom0 resume from S3 when MSI is
  in use (bnc#435596).
- patches.xen/xen3-e1000e_ioremap_sanity_check: ioremap sanity
  check to catch mapping requests exceeding the BAR sizes
  (bnc#425480).
- patches.xen/xen3-x86-fix-kmap-contig.patch: x86: contiguous
  kmap fix (bnc#449812).
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  implement correct model matching
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/dm-mpath-tracking-nr-bytes:
  lpp_end_io gets nr_bytes as third arg
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  match all JSxx/QSxx models based on the first 4 chars in 'model'
* Wed Jan 21 2009 olh@suse.de
- update patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  Fix MSI after kexec (bnc#467633)
* Tue Jan 20 2009 gregkh@suse.de
- clean up patch fuzz after 2.6.27.12 inclusion.
* Tue Jan 20 2009 gregkh@suse.de
- Update to the real 2.6.27.12
* Tue Jan 20 2009 jeffm@suse.de
- patches.suse/reiserfs_warning-reentrant: reiserfs: eliminate
  reiserfs_warning from uniqueness functions; Fixes deadlock.
* Tue Jan 20 2009 olh@suse.de
- patches.drivers/cxgb3-ser.patch:
  reset the adapter on fatal error (bnc#466062 - LTC51042)
* Tue Jan 20 2009 jjolly@suse.de
- patches.arch/s390-08-03-iucv-cpu-hotremove.diff: iucv: failing
  cpu hot remove for inactive iucv (bnc#466462,LTC#51104).
- patches.arch/s390-08-04-compat-sigaltstack.diff:
  kernel: 31 bit compat sigaltstack syscall fails with
  - EFAULT. (bnc#466462,LTC#50888).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch:
  af_iucv: System hang if recvmsg() is used with MSG_PEEK
  (bnc#466462,LTC#51136).
* Tue Jan 20 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Only accept
  non-existing paths when adding failed paths (bnc#467579)
* Tue Jan 20 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: set CONFIG_DEBUG_INFO=y in the
  packaged .configs if builfing debug packages (bnc#460887)
* Mon Jan 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: set %%tolerate_kabi_changes to 6
* Mon Jan 19 2009 mmarek@suse.cz
- patches.suse/export-iwl_rx_allocate: reintroduce
  EXPORT_SYMBOL(iwl_rx_allocate).
* Mon Jan 19 2009 mmarek@suse.cz
- import SLE11 RC2 reference kabi
* Mon Jan 19 2009 hare@suse.de
- patches.drivers/mpt-return-all-sense-data: MPT Fusion doesn't
  return all sense data (bnc#466179).
* Sat Jan 17 2009 gregkh@suse.de
- Update to 2.6.27.12-rc2
* Fri Jan 16 2009 od@suse.de
- patches.arch/x86-call-boot-IRQ-quirks-at-end-of-device-init-and-during-resume.patch:
  call boot IRQ quirks at end of device init and during resume.
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch:
  update to upstream variant of this patch:
  - integrate an older quirk to make IO-APIC mode work on AMD
    8131 rev. A0 and B0
  - fix boot IRQ disabling logic for AMD 813x
  - remove unneeded code for AMD SB700S
* Fri Jan 16 2009 jbeulich@novell.com
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Fri Jan 16 2009 olh@suse.de
- enable mptsas in kdump kernel to allow crashdump on QS2x blades
* Fri Jan 16 2009 tiwai@suse.de
  Fix STAC925x patch again
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  (yet more) STAC925x issues (bnc#460478).
* Fri Jan 16 2009 jjolly@suse.de
- patches.arch/s390-08-01-cio-fix-mp-mode.diff: cio: fix
  subchannel multipath mode setup (bnc#466462,LTC#51047).
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: zfcp: fix
  memory alignment for GPN_FT requests. (bnc#466462).
* Thu Jan 15 2009 gregkh@suse.de
- Update config files for vanilla kernel versions due to new config
  option added in 2.6.27.12-rc1.
* Thu Jan 15 2009 gregkh@suse.de
- Update to 2.6.27.12-rc1:
  - security fixes
  - fixes CVE-2009-0029
  - bug fixes all over the place.
  - obsoletes the following patches:
  - patches.arch/ppc-cmm_no_kdump.patch
  - patches.drivers/alsa-caiaq-midi-oops-fix
  - patches.drivers/alsa-hda-hp-6730b-quirk
  - patches.drivers/ibmvfc-host_init_delay.patch
  - patches.drivers/ibmvfc-improve_sync_events.patch
  - patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch
  - patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch
  - patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch
  - patches.fixes/mm-lockless-pagecache-barrier.patch
  - patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch
  - patches.fixes/uv-remove-erroneous-BAU-init
- Update config files.
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-virtuoso-no-eeprom-overwrite: sound:
  virtuoso: do not overwrite EEPROM on Xonar D2/D2X (bnc#462365).
* Thu Jan 15 2009 bwalle@suse.de
- patches.suse/s390-System.map.diff:
  Strip L2^B symbols (bnc #456682).
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-fix: ALSA: patch_sigmatel:
  Add missing Gateway entries and autodetection (bnc#460478).
- patches.drivers/alsa-hda-gateway-fix2: ALSA: hda - More fixes
  on Gateway entries (bnc#460478).
- patches.drivers/alsa-hda-hp-dv5-mic-fix: ALSA: hda - Fix HP
  dv5 mic input (bnc#462913).
- patches.drivers/alsa-hda-hp-dv5-quirk: ALSA: hda - Add quirk
  for another HP dv5 (bnc#462913).
- patches.drivers/alsa-hda-idt92hd83-fix-typo: ALSA: hda -
  Fix a typo.
- patches.drivers/alsa-hda-samsung-q45-quirk: ALSA: hda - Add
  automatic model setting for Samsung Q45.
- patches.drivers/alsa-hda-seek-for-codec-id: ALSA: hda - Add
  a new function to seek for a codec ID (bnc#460478).
- patches.drivers/alsa-hda-sigmatel-no-hp-reset: ALSA: hda -
  Don't reset HP pinctl in patch_sigmatel.c (bnc#460478).
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  missing initialization of NID 0x0e for STAC925x (bnc#460478).
* Thu Jan 15 2009 olh@suse.de
- patches.arch/ppc-fix_hugepage_check.patch:
  is_hugepage_only_range() must account for both 4kB and 64kB
  slices (bnc#466229 - LTC51063)
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disabled PARAVIRT on vanilla and LGUEST.
* Wed Jan 14 2009 jeffm@suse.de
- Enabled patches.suse/unlock_page-speedup.patch
* Wed Jan 14 2009 rjw@suse.de
- patches.fixes/PCI-PM-Split-PCI-Express-port-suspend-resume.patch:
  PCI PM: Split PCI Express port suspend-resume (bnc#455926).
- patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch:
  PCI: Suspend and resume PCI Express ports with interrupts
  disabled (bnc#455926).
- patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch:
  PCI: handle PCI state saving with interrupts disabled
  (bnc#455926).
- patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch:
  PCI: Rework default handling of suspend and resume (bnc#455926).
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disable PARAVIRT.
* Wed Jan 14 2009 gregkh@suse.de
- refresh patches for fuzz due to update to 2.6.27.11
* Wed Jan 14 2009 gregkh@suse.de
- Update to final version of 2.6.27.11
* Wed Jan 14 2009 kkeil@suse.de
- patches.drivers/ixgbe-dcb-setstate.patch: Bugfix for ixgbe
  and kernel DCB netlink code. (bnc#458194)
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix. (bnc#465923)
- Update config files.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: Delete.
  It came out that this is an already fixed BIOS bug. The quirk
  is not needed anymore.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_fix_double_slash_root_prefix_handling.patch:
  In AcpiNsGetInternalNameLength, skip the redundant backslash
  of RootPrefix (http://bugzilla.kernel.org/show_bug.cgi?id=11541
  http://www.acpica.org/bugzilla/show_bug.cgi?id=739).
- patches.fixes/acpi_video_always_update_sys.patch: video: always
  update the brightness when poking "brightness" (bnc#450149).
- patches.fixes/acpi_video_handle_reversed_brightness_info.patch:
  ACPI: video: Fix reversed brightness behavior on ThinkPad SL
  series (bnc#450149).
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/sched-fix-__load_balance_iterator-for-cfs-with-on.patch:
  fix __load_balance_iterator() for cfs with only one task
  (bnc#457594 - LTC50544)
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/xfs-redirty-ENOSPC.patch: Re-dirty pages on
  ENOSPC when converting delayed allocations (bnc#433112 - LTC48749)
* Wed Jan 14 2009 npiggin@suse.de
- Added guarded patches:
- patches.suse/mnt-want-write-speedup.patch: fs: mnt_want_write
  speedup (bnc#436953).
- patches.suse/mnt_clone_write.patch: fs: introduce
  mnt_clone_write (bnc#436953).
- patches.suse/unlock_page-speedup.patch: mm: unlock_page speedup
  (bnc#436953).
* Wed Jan 14 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: add Via
  chrome9 drm support.
* Wed Jan 14 2009 gregkh@suse.de
- patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch:
  pata_via.c: Support VX855 and future chips whose IDE controller
  use 0x0571..
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Modify patch
  after suggestions from James Bottomley (bnc#465346).
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Restart
  scsi_device_lookup_by_target() (bnc#465346).
* Tue Jan 13 2009 olh@suse.de
- update patches.drivers/cxgb3-Allocate-multiqueues-at-init-time:
  Allow multiqueue setting in MSI-X mode only (bnc#464351 - LTC50966)
* Tue Jan 13 2009 olh@suse.de
- patches.drivers/cxgb3i-mainline.patch: fixes bug in tag release
  and sync-up cxgb3i with mainline state (bnc#464508 - LTC50816)
* Tue Jan 13 2009 gregkh@suse.de
- Update to 2.6.27.11-rc1:
  - lots of minor fixes
  - obsoletes:
  - patches.fixes/md-bitmap-read-do-not-overflow
  - patches.suse/scsi-scsi_transport_srp-shost_data.patch
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: add kernel/drivers/acpi/acpi_memhotplug as supported
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh: handle arch
  symlinks like i586 -> i386 in /usr/src/linux-obj.
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: updated staging and other drivers
* Mon Jan 12 2009 kkeil@suse.de
- patches.drivers/r8169-Tx-performance-tweak-helper: r8169:
  Tx performance tweak helper.
- patches.drivers/r8169-add-8168-8101-registers-description:
  r8169: add 8168/8101 registers description.
- patches.drivers/r8169-add-hw-start-helpers-for-the-8168-and-the-8101:
  r8169: add hw start helpers for the 8168 and the 8101.
- patches.drivers/r8169-additional-8101-and-8102-support: r8169:
  additional 8101 and 8102 support.
- patches.drivers/r8169-use-pci_find_capability-for-the-PCI-E-features:
  r8169: use pci_find_capability for the PCI-E features.
  (bnc#448168)
* Mon Jan 12 2009 dgollub@suse.de
- scripts/tar-up_and_run_mbuild.sh: use $BUILD_DIR instead of fixed
  "kernel-source" string, to stay in sync with with differet kernel
  variants.
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/source-pre.sh:
  replace the /usr/src/linux-obj symlink with a directory containing
  per-flavor symlinks instead. This allows us to install kernel-source /
  syms and kernel-source-rt / syms-rt in parallel and still find
  everything below /usr/src/linux-obj/.
- rpm/kernel-binary.spec.in: for -rt, install into
    /usr/src/linux-$version-rt-obj.
- rpm/kernel-syms.spec.in: fix kernel-source requires for -rt.
* Sun Jan 11 2009 jkosina@suse.de
- patches.drivers/input-usbtouchscreen-hw-calibration.patch:
  Input: usbtouchscreen - allow reporting calibrated data
  (bnc#444814).
* Fri Jan  9 2009 mmarek@suse.cz
- patches.suse/file-capabilities-add-file_caps-switch.diff:
  fix parsing of the file_caps commandline option (bnc#264075)
* Fri Jan  9 2009 trenn@suse.de
- patches.arch/x86_fix_llc_shared_map__cpu_llc_id_anomolies.patch:
  x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
  (bnc#464329).
* Fri Jan  9 2009 olh@suse.de
- patches.arch/ppc-cmm_no_kdump.patch:
  Disable Collaborative Memory Manager for kdump (bnc#460552 - LTC50789)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/cgroup-disable-memory.patch: memcg: disable the
  memory controller by default.
- patches.suse/add-enable_cgroup-parameter.patch: Delete.
- patches.suse/disable-cgroups.patch: Delete.
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch
  fix compile errors
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/ath5k-ignore-calibration-return-value.patch:
  ath5k: ignore the return value of
  ath5k_hw_noise_floor_calibration (bnc#446541).
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/cgroups-suppress-cloning-warning.patch: cgroups:
  suppress bogus warning messages (bnc#460961).
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch: Add quirk for
  the graphics adapter in some JSxx (bnc#461002 - LTC50817)
* Fri Jan  9 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: ACPI: Do not
  derive IRQ from parent bridge/device via boot param/dmi list
  (bnc#437211).
- patches.suse/acpi_osi_sle11_ident.patch: Provide possibility
  for vendors to fix BIOS issues for SLE11 only (none).
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/blk-request-based-multipath-update: Rediff.
- patches.fixes/scsi-refactor-busy-processing: refactor
  sdev/starget/shost busy checking; break out from
  blk-request-based-multipath-update.
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.11-update: Update lpfc from 8.2.8.10
  to 8.2.8.11 (bnc#464662).
- patches.fixes/scsi-call-unprep_request-under-lock: scsi_lib:
  only call scsi_unprep_request() under queue lock (bnc#464155).
- patches.fixes/scsi-fix-hang-in-starved-list-processing: Fix
  hang in starved list processing (bnc#464155).
* Fri Jan  9 2009 kkeil@suse.de
- patches.drivers/bnx2-Add-PCI-ID-for-5716S: bnx2: Add PCI ID
  for 5716S
- patches.drivers/bnx2-Fix-bug-in-bnx2_free_rx_mem_: bnx2:
  Fix bug in bnx2_free_rx_mem() (bnc#464130)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/disable-cgroups.patch: Disable all cgroups
  (bnc#436025).
* Fri Jan  9 2009 hare@suse.de
- Backporting block layer fixes (bnc#464155):
  * patches.fixes/block-add-comment-in-blk_rq_timed_out: add
    comment in blk_rq_timed_out() about why next can not be 0
  * patches.fixes/block-fix-blk_start_queueing: block: Fix
    blk_start_queueing() to not kick a stopped queue.
  * patches.fixes/block-leave-the-request-timeout-timer-running:
    block: leave the request timeout timer running even on an
    empty list.
  * patches.fixes/block-optimizations-in-blk_rq_timed_out_timer:
    block: optimizations in blk_rq_timed_out_timer().
  * patches.fixes/block-suppress-buffer-IO-errors: block: Supress
    Buffer I/O errors when SCSI REQ_QUIET flag set.
  * patches.fixes/block-use-round_jiffies_up: Block: use
    round_jiffies_up().
  * patches.fixes/round-jiffies-up: Add round_jiffies_up and
    related routines.
* Fri Jan  9 2009 jbeulich@novell.com
- patches.xen/xen3-acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
* Fri Jan  9 2009 hare@suse.de
- patches.fixes/scsi_dh-retry-on-UNIT_ATTENTION: scsi_dh_rdac
  does not retry MODE SENSE on UNIT ATTENTION (bnc#464155).
- patches.suse/scsi-check-removed-device-for-offline: Only check
  for SDEV_OFFLINE and SDEV_DEL, not SDEV_CANCEL.
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/add-enable_cgroup-parameter.patch: Add
  cgroup_enable parameter (bnc#436025).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aer-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe AER _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aspm-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe ASPM _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-remove-obsolete-_osc-capability-support-functions.patch:
  ACPI/PCI: remove obsolete _OSC capability support functions
  (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-call-_osc-support-during-root-bridge-discovery.patch:
  ACPI/PCI: call _OSC support during root bridge discovery
  (bnc#438941).
- patches.drivers/acpi-pci-change-pci_osc_control_set-to-query-control-bits-first.patch:
  ACPI/PCI: Change pci_osc_control_set() to query control bits
  first (bnc#438941).
- patches.drivers/acpi-pci-fix-possible-race-condition-on-_osc-evaluation.patch:
  ACPI/PCI: Fix possible race condition on _OSC evaluation
  (bnc#438941).
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
- patches.drivers/acpi-pci-pci-extended-config-_osc-support-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI extended config _OSC support called when root
  bridge added (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/bnx2x-version-update.patch: bnx2x: Version
  Update (bnc#439679).
* Thu Jan  8 2009 jjolly@suse.de
- patches.arch/s390-07-01-zfcp-port-failed-message.diff: zfcp:
  Remove message for failed port (bnc#464466).
- patches.arch/s390-07-02-zfcp-unchained-fsf.diff: zfcp: Add
  support for unchained FSF requests (bnc#464466).
- patches.arch/s390-07-03-topology-fix.diff: kernel: fix cpu
  topology support (bnc#464466).
- patches.arch/s390-07-04-dasd-failfast.patch: dasd: Add
  'failfast' device feature. (bnc#464466,LTC#43066).
* Thu Jan  8 2009 tiwai@suse.de
- patches.drivers/alsa-caiaq-midi-oops-fix: ALSA: caiaq - Fix
  Oops with MIDI.
* Thu Jan  8 2009 knikanth@suse.de
- patches.fixes/dm-avoid-put-table-dm_any_congested: dm: avoid
  destroying table in dm_any_congested (bnc#457205).
- patches.fixes/dm-table-ref-count: dm table: rework reference
  counting (bnc#457205).
- patches.fixes/dm-unbind-drop-ref: dm table: drop reference at
  unbind (bnc#457205).
* Thu Jan  8 2009 olh@suse.de
- update kdump config, disable some unused drivers
* Thu Jan  8 2009 olh@suse.de
- refresh config files, no functional changes
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  use separate table for module alias (bnc#435215 - LTC48564)
* Thu Jan  8 2009 tiwai@suse.de
  Backport fixes for HD-audio from the upstream:
- patches.drivers/alsa-hda-ad1882-id-typo-fix: ALSA: hda -
  Fix typos for AD1882 codecs.
- patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back: ALSA:
  hda - make laptop-eapd model back for AD1986A.
- patches.drivers/alsa-hda-hp2230s-quirk: ALSA: hda - Add quirk
  for HP 2230s (bnc#461660).
- patches.drivers/alsa-hda-sigmatel-add-missing-terminators:
  ALSA: hda - Add missing terminators in patch_sigmatel.c.
* Thu Jan  8 2009 bwalle@suse.de
- Update config files: Enable CONFIG_EHEA=m (and CONFIG_IBMEBUS=y)
  for ppc/kdump and ppc64/kdump (bnc #459119).
* Thu Jan  8 2009 jblunck@suse.de
- Make kernel-source.changes incremental again
* Thu Jan  8 2009 olh@suse.de
- supported.conf: rename dm-leastpending-path to dm-leastpending
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  add alias entry for portN properties (bnc#435215 - LTC48564)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-abort-response.patch:
  Fixup command response translation (bnc#459383 - LTC50695)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-improve_sync_events.patch:
  Improve async event handling (bnc#460567 - LTC50778)
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: via: Unichrome
  DRM bugfixes.
* Thu Jan  8 2009 coly.li@suse.de
- Move patch from patches.suse/dlm-fix-shutdown-cleanup.patch to
  patches.fixes/dlm-fix-shutdown-cleanup.patch
* Thu Jan  8 2009 coly.li@suse.de
- Fixes a regression from commit
  0f8e0d9a317406612700426fad3efab0b7bbc467,
  "dlm: allow multiple lockspace creates".
* Wed Jan  7 2009 olh@suse.de
- patches.arch/ppc-pseries-cpu-migrate.patch: Update
  default_server during migrate_irqs_away (bnc#460566 - LTC50723)
* Wed Jan  7 2009 jack@suse.cz
- patches.suse/mm-increase-dirty-limits.patch: Increase limits
  for starting writeback of dirty data (bnc#449662).
* Wed Jan  7 2009 ghaskins@suse.de
- Update config files (part of bnc#448412).
* Wed Jan  7 2009 ghaskins@suse.de
- patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch:
  configure HAVE_UNSTABLE_SCHED_CLOCK for SGI_SN systems (bnc#448412).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.10-update: Emulex 8.2.8.10 driver
  patches for SLE11 (bnc#460775).
* Wed Jan  7 2009 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Update Patch-mainline
  header. Patch is not refreshed as it breaks kabi (FATE#304489).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/cciss-driver-panic-on-volume-delete: cciss
  driver may panic if a logical volume is deleted (bnc#459553).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC to avoid deadlocks
  (bnc#461747).
* Wed Jan  7 2009 hare@suse.de
- patches.fixes/fc_transport-devloss-callback-restore: FC devloss
  callback not called when devloss timer fires (bnc#463289).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/dm-mpath-leastpending-path-update: Update
  least-pending-IO dynamic load balancer (bnc#444199).
- patches.suse/dm-mpath-queue-length-load-balancing: Rediff.
- patches.suse/dm-mpath-service-time-load-balancing: Rediff.
- patches.suse/dm-mpath-tracking-nr-bytes: Rediff.
- patches.suse/dm-mpath-leastpending-path: Delete.
* Tue Jan  6 2009 jeffm@suse.de
- patches.fixes/uv-remove-erroneous-BAU-init: UV: remove erroneous
  BAU initialization (bnc#463313).
* Tue Jan  6 2009 jjolly@suse.de
- patches.arch/s390-06-01-qeth-ext-src-mac-addr.patch: qeth:
  exploit source MAC address for inbound layer3 packets
  (bnc#458339).
- patches.arch/s390-06-02-qeth-layercrash.patch: qeth: avoid
  crash in case of layer mismatch for VSWITCH (bnc#458339).
- patches.arch/s390-06-03-dasd_sim_sense_condition.patch: Fix
  unsolicited SIM sense condition. (bnc#458339).
- patches.arch/s390-06-04-qdio_ssqd_memcpy.patch: qdio: fix
  broken memcpy (bnc#458339).
- patches.arch/s390-06-05-qdio_s390dbf.patch: qdio: rework
  s390dbf usage  (bnc#458339).
- patches.arch/s390-06-06-qdio_inbound_ack.patch: qdio: rework
  inbound buffer acknowledgement (bnc#458339).
- patches.arch/s390-06-07-cio-attach_detach.patch: cio: Crashes
  when repeatetly attaching/detaching devices. (bnc#458339).
* Tue Jan  6 2009 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: Jan's comments for
  contiguous kmap fix (bnc#449812).
* Tue Jan  6 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: update.
* Mon Jan  5 2009 mmarek@suse.cz
- patches.suse/modpost-filter-out-built-in-depends: modpost:
  filter out "built-in" depends (bnc#450085).
- patches.drivers/0002-Staging-add-TAINT_CRAP-flag-to-drivers-staging-modu.patch:
  refresh.
* Mon Jan  5 2009 npiggin@suse.de
- Fix ps3 config.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: mm lockless
  pagecache barrier fix.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch:
  fs symlink write_begin allocation context fix.
* Mon Jan  5 2009 npiggin@suse.de
- Update config files.
* Mon Jan  5 2009 npiggin@suse.de
- patches.suse/cgroup-freezer.patch: cgroup freezer update (bnc#417294,
  fate#304191, fate#201036).
* Wed Dec 31 2008 npiggin@suse.de
- patches.fixes/s390-lru_add_drain_all.patch: mm: remove UP
  version of lru_add_drain_all() (bnc#458380).
* Wed Dec 31 2008 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Mon Dec 29 2008 jeffm@suse.de
- patches.arch/thinkpad_acpi-hotkey-notify-fix: thinkpad_acpi:
  Fix oops with incompatible backlight interface.
* Mon Dec 22 2008 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix bootmem reservation on uninitialized node (bunc#457029 - LTC50483)
* Mon Dec 22 2008 olh@suse.de
- patches.fixes/scsi-ibmvscsi-can_queue_fix.patch: Make
  max_requests module parameter more accurate (bnc#458499 - LTC50637)
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-dv7-quirk: ALSA: hda - Add quirk
  for another HP dv7 (bnc#461108).
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: More fixes (bnc#447624).
* Fri Dec 19 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Print more info.
* Fri Dec 19 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-no-44khz: ALSA: disable
  44.1kHz capture on CA0106 (bnc#447624).
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-92hd73x-desktop-fixes: ALSA: Fix
  plaback problems on Intel desktops with IDT codecs.
* Fri Dec 19 2008 jbeulich@novell.com
- patches.arch/x86_sgi-uv-scir.patch,
  patches.suse/e1000e_ioremap_sanity_check,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: eliminate build warnings.
* Fri Dec 19 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rt2870-wireless-driver.patch:
  Staging: add rt2870 wireless driver.
* Fri Dec 19 2008 nfbrown@suse.de
- patches.fixes/md-bitmap-read-do-not-overflow: md: Don't read
  past end of bitmap when reading bitmap. (bnc#459557).
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Fixed ordering.
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: Delete.
* Thu Dec 18 2008 gregkh@suse.de
- Updated to final 2.6.27.10 release
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Use apic=bigsmp on specific xseries machines (bnc#440497).
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86_restrict_pci_early_quirks_to_root_bridges.patch:
  Only scan the root bus in early PCI quirks. (bnc#57886).
* Thu Dec 18 2008 jbeulich@novell.com
- patches.xen/746-pirq-status-page.patch: Merge in c/s 751.
- patches.xen/761-highpte.patch: blktap, gntdev: fix highpte handling.
- patches.xen/762-xencons-hvc.patch: add hvc compatibility mode to xencons.
- patches.xen/xen3-patch-2.6.27.7-8: Linux 2.6.27.8.
- patches.xen/xen3-patch-2.6.27.8-9: Linux 2.6.27.9.
- patches.xen/xen-x86-exports: export a few more symbols
  (bnc#458222).
- patches.xen/xen3-perfmon2_remove_syscalls.patch: Rename to ...
- patches.xen/xen3-perfmon2-remove_syscalls.patch: ... this.
* Thu Dec 18 2008 nfbrown@suse.de
- patches.fixes/md-disable-recovery-on-faulty-degraded-array:
  Disable recovery when degraded RAID1 array appears to be
  faulty. (bnc#447835).
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/symsets.pl: fix uninitialized variable
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - add genksyms reference files so that genksyms can explain why
    did checksums change
* Wed Dec 17 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Delete.  It
  oopses badly and is not needed for the HP2133 hardware, as
  it has switched to Intel chipsets.
* Wed Dec 17 2008 gregkh@suse.de
- Upate to 2.6.27.10-rc1, fixing lots of problems.
  - obsoletes:
  - patches.drivers/libata-update-ST-FLUSH-blacklist
  - patches.fixes/iwlwifi_fix_oops.patch
  - patches.fixes/v4l-dvb-avoid-writing-outside-array
* Tue Dec 16 2008 jeffm@suse.de
- patches.suse/reiserfs-barrier-default: Make reiserfs default
  to barrier=flush.
* Tue Dec 16 2008 mmarek@suse.cz
- addded symtypes-* files to the RC1 reference kabi
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/ext3-mark-super-uptodate: ext3: always mark
  super uptodate before dirty (bnc#457043).
* Tue Dec 16 2008 hare@suse.de
- patches.fixes/blk-dont-invoke-request_fn-on-stopped-queue:
  block: only call ->request_fn when the queue is not stopped
  (bnc#457041).
- patches.fixes/blk-get-extra-reference-before-unmap: block:
  hold extra reference to bio in blk_rq_map_user_iov().
- patches.fixes/blk-move-unplug_work-init: block: move
  q->unplug_work initialization.
- patches.fixes/blk-set-segment-boundary-mask: block: fix setting
  of max_segment_size and seg_boundary mask.
- patches.fixes/dm-mpath-send-activate-to-every-path: Handle
  multiple paths in a path group properly during pg_init.
- patches.fixes/scsi_dh-add-lsi-ids-to-rdac: Adding LSI vendor
  and product IDs to RDAC device handler.
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037,bnc#458393).
- patches.suse/scsi-check-removed-device-for-offline: Check if
  device is removed in scsi_device_online() (bnc#456747).
* Tue Dec 16 2008 hare@suse.de
- Enable 3270 console (bnc#457039)
* Tue Dec 16 2008 rjw@suse.de
- Update config files.
- patches.suse/mm-do-not-disable-memory-hotplug-when-hibernation-is-enabled.patch:
  mm: Do not disable memory hotplug when hibernation is enabled
  (bnc#438914).
* Mon Dec 15 2008 jeffm@suse.de
- patches.fixes/iwlwifi_fix_oops.patch: iwlwifi: clean key table
  in iwl_clear_stations_table function (bnc#457062).
* Mon Dec 15 2008 jjolly@suse.de
- patches.drivers/cxgb3i_ddp.patch: cxgb3i - added pdu size
  check and fixed ddp page setup (bnc#449519).
* Mon Dec 15 2008 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-04-update: qla4xxx
  driver SLES 11 Beta6 update (bnc#458186).
* Mon Dec 15 2008 oneukum@suse.de
- patches.suse/usb_correct_config_ti_04b3_4543.diff: fix
  ti_usb_3410_5052 driver for device 04b3:4543 (bnc#395775).
* Sun Dec 14 2008 gregkh@suse.de
- Update to 2.6.27.9
  - obsoleted:
  - patches.fixes/applicom-fix-unchecked-ioctl-range
  - patches.fixes/watchdog-ib700wdt-buffer-underflow
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: reiserfs:
  ensure nonzero transaction (bnc#447406).
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Update to print accurate refcount.
* Fri Dec 12 2008 jblunck@suse.de
- .gitignore: Ignore backup files.
* Fri Dec 12 2008 hare@suse.de
- patches.fixes/scsi-check-host-lookup-failure: Correct
  scsi_host_lookup return value (bnc#456532).
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch: hso: rfkill type should
  be WWAN (bnc#458625).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch:
  fix hso rfkillswitch type to WWAN (bnc#458625)
* Fri Dec 12 2008 mmarek@suse.cz
- import SLE11 RC1 reference kabi
* Fri Dec 12 2008 gregkh@suse.de
- refresh patches to apply cleanly due to 2.6.27.9-rc addition.
* Fri Dec 12 2008 gregkh@suse.de
- remove patches that were obsoleted by 2.6.27.9-rc2
  - patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch
  - patches.arch/x86-hpet-use-WARN_ON_ONCE
  - patches.drivers/alsa-hda-acer-quirk
  - patches.drivers/alsa-hda-alc888-medion-add
  - patches.drivers/alsa-hda-dell-studio-15-quirk
  - patches.drivers/alsa-hda-dell-studio-1535-quirk
  - patches.drivers/alsa-hda-hp-6730s-quirk
  - patches.drivers/alsa-hda-hp-elitebook-8530p-quirk
  - patches.drivers/alsa-hda-hp-mobile-fix
  - patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch
  - patches.drivers/cell_edac.patch
  - patches.fixes/acpi-set-SCI_EN-on-MacBook.patch
  - patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch
  - patches.fixes/block-enforce-minimum-SG_IO-timeout
  - patches.fixes/cxgb3-remove-duplicate-tests-in-lro
  - patches.fixes/cxgb3_fix_race_in_EEH
  - patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch
  - patches.fixes/pci_aspm_check_endless_loop_safe.patch
  - patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch
  - patches.fixes/x86-arch_add_memory-remove-debug
  - patches.fixes/x86-memory-hotplug-off-by-one
* Fri Dec 12 2008 gregkh@suse.de
- update to 2.6.27.9-rc2:
  - lots of bugfixes
  - some security updates
* Thu Dec 11 2008 gregkh@suse.de
- intermediate commit as part of adding 2.6.27.9-rc1 to the tree.
* Thu Dec 11 2008 hare@suse.de
- Compile in zfcpdump module for S/390 (bnc#446367).
* Thu Dec 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: one more fix to make kabi checks work
* Thu Dec 11 2008 teheo@suse.de
- patches.drivers/libata-update-ST-FLUSH-blacklist: libata:
  fix Seagate NCQ+FLUSH blacklist (bnc#458192).
* Wed Dec 10 2008 nfbrown@suse.de
- patches.suse/SoN-fix-sync: Cope with racy nature of sync_page
  in swap_sync_page (441793).
* Wed Dec 10 2008 jjolly@suse.de
- patches.arch/s390-05-09-cleanup-of-portopen-requests.patch:
  zfcp: fix erp timeout cleanup for port open requests
  (bnc#450096).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/watchdog-ib700wdt-buffer-underflow: ib700wdt.c -
  fix buffer_underflow bug (bnc#457898).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/applicom-fix-unchecked-ioctl-range: applicom: Fix
  an unchecked user ioctl range and an error return (bnc#457897).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/block-enforce-minimum-SG_IO-timeout: Enforce a
  minimum SG_IO timeout (bnc#457896).
* Wed Dec 10 2008 mmarek@suse.cz
- rpm/find-provides: don't fail if a subpackage doesn't contain
  any modules (such as the -man subpackage on s390x)
* Wed Dec 10 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-6730b-quirk: ALSA: hda - Add quirk
  for HP6730B laptop (bnc#457909).
- patches.drivers/alsa-hda-hp-6730s-quirk: ALSA: hda - Add
  another HP model (6730s) for AD1884A.
- patches.drivers/alsa-hda-hp-elitebook-8530p-quirk: ALSA: hda -
  Make the HP EliteBook 8530p use AD1884A model laptop.
* Wed Dec 10 2008 olh@suse.de
- patches.drivers/ibmvfc-add_sync.patch:
  Fix errors due to inconsistent command data (bnc#456654 - LTC50451)
- patches.drivers/ibmvfc-host_init_delay.patch:
  Delay NPIV login retry and add retries (bnc#456654 - LTC50451)
* Wed Dec 10 2008 teheo@suse.de
- patches.drivers/libata-pata_hpt366-fix-cable-detection:
  pata_hpt366: fix cable detection, (bnc#362159).
- patches.drivers/libata-pata_hpt366-fix-clock-detection:
  pata_hpt366: fix clock detection (bnc#362159).
- patches.drivers/libata-pata_hpt366-no-ATAPI-DMA: pata_hpt366:
  no ATAPI DMA (bnc#362159).
- patches.drivers/libata-pata_hpt366-reimplement-mode-programming:
  pata_hpt366: reimplement mode programming (bnc#362159).
* Tue Dec  9 2008 agruen@suse.de
- supported.conf: Mark xfs_dmapi as supported (bnc#457668).
* Tue Dec  9 2008 jeffm@suse.de
- patches.fixes/x86-arch_add_memory-remove-debug: x86: remove
  debug code from arch_add_memory() (bnc#457526).
- patches.fixes/x86-memory-hotplug-off-by-one: x86, memory
  hotplug: remove wrong -1 in calling init_memory_mapping()
  (bnc#457526).
* Tue Dec  9 2008 agruen@suse.de
- rpm/{kernel-module-subpackage,macros.kernel-source}: Remove
  a leftover hardcoded dependency on the kernel-source package so
  that KMPs can alternatively be built against a kernel other
  than (kernel-source + kernel-syms), such as (kernel-source-rt +
  kernel-syms-rt).
* Tue Dec  9 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop_safe.patch: PCIe:
  ASPM: Break out of endless loop waiting for PCI config bits
  to switch (bnc#449799).
* Tue Dec  9 2008 mmarek@suse.cz
- rpm/symsets.pl:
  - add --required-modules option to tell which modules this
    subpackage requires via dependencies. This is needed to
    preserve symsets when modules move from one subpackage to
    another.
  - add POD help and --help option.
- rpm/kernel-binary.spec.in: make use of --required-modules
* Tue Dec  9 2008 nfbrown@suse.de
- patches.fixes/xfs-barrier-fix.patch: Fix propagation of
  EOPNOTSUPP when barriers are not supported. (bnc#438608).
* Mon Dec  8 2008 rjw@suse.de
- patches.fixes/tg3-fix-default-wol.patch: net (tg3): Fix failure
  to enable WoL by default when possible (bnc#447371).
* Mon Dec  8 2008 olh@suse.de
- patches.arch/ppc-valid-hugepage-size-hugetlb_get_unmapped_area.patch:
  Check for valid hugepage size in hugetlb_get_unmapped_area
  (bnc#456433 - LTC50170).
* Mon Dec  8 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop.patch: Delete.
* Mon Dec  8 2008 rw@suse.de
- patches.drivers/sgi-xp-no-uv:
  SGI SN: Eliminate dependency of the XP/XPC drivers on GRU. (bnc#442442)
* Mon Dec  8 2008 rw@suse.de
- Update config files for ia64:
  Disable PERMIT_BSP_REMOVE.  (bnc#386714)
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in: figure out what
  subpackage is being processed in find-provides and just print
  the symsets computed in the spec.
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: use flavor-rpmarch to match boards on powerpc
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: skip empty KMPs with a warning in
  the kmp %%%%postun
* Mon Dec  8 2008 jjohansen@suse.de
- Update config files.
- patches.apparmor/fix-complain.diff: fix enforcement of deny
  rules in complain mode (bnc#426159).
- patches.apparmor/fix-security-param.diff: fix recognition of
  security= boot parameter (bnc#442668).
- patches.apparmor/fork-tracking.diff: fix log messages to enable
  tools profile learning (bnc#447564).
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: update board detection to use rpmarch instead flavor
* Mon Dec  8 2008 hare@suse.de
- patches.fixes/block-integrity-update: Block integrity update
  (FATE#304345).
- patches.suse/dm-block-integrity: Block integrity support for
  DM and MD (FATE#304345).
- patches.suse/dm-mpath-add-start-io: dm-mpath: add a path
  selector interface (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-queue-length-load-balancing: dm-mpath: add
  queue-length dynamic load balancer (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-service-time-load-balancing:
  dm-mpath: add service-time oriented dynamic load balancer
  (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-tracking-nr-bytes: dm-mpath:
  interface change for service-time dynamic load balancer
  (FATE#303862,FATE#302108).
- supported.conf: Update to correctly reference dynamic load
  balancer modules (bnc#444199)
* Mon Dec  8 2008 tonyj@suse.de
- patches.suse/perfmon2-add_ioctl_interface.patch: switch to
  ioctl interface for perfmon2.
- patches.suse/perfmon2-fix_disabled.patch: fix initializion of
  perfmon disabled.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribyute.
- patches.suse/perfmon2-remove_syscalls.patch: drop additional
  perfmon2 syscalls.
- patches.xen/xen3-perfmon2_remove_syscalls.patch: drop additional
  perfmon2 syscalls.
* Sat Dec  6 2008 trenn@suse.de
- patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch:
  ACPI: EC: Don't degrade to poll mode at storm
  automatically. (bnc#446142).
- patches.fixes/pci_aspm_check_endless_loop.patch: PCIE Break
  out of endless loop waiting for PCI config bits to switch
  (bnc#449799).
* Sat Dec  6 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Sat Dec  6 2008 gregkh@suse.de
- Update to final 2.6.27.8 release
  - contains 2 changes from 2.6.27.8-rc1
* Fri Dec  5 2008 jbeulich@novell.com
- patches.xen/xen-configurable-guest-devices: fix a typo.
* Fri Dec  5 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  move crq_queue_create at the end of initialization (bnc#455929).
* Fri Dec  5 2008 hare@suse.de
- patches.drivers/open-fcoe-fnic-patches: Open-FCoE bugfixes
  for fnic.
- patches.drivers/open-fcoe-rc1-update: Update open-FCoE with
  latest patches from Intel (bnc#438954).
* Fri Dec  5 2008 jbeulich@novell.com
- Update Xen x86-64 config (2k guest devices, 1k outstanding transmits
  in netback).
* Fri Dec  5 2008 hare@suse.de
- patches.arch/s390-zfcp-synchronize-scsi-register: No udev
  events for zfcp online / offline (bnc#443667).
- patches.fixes/scsi-remove-scmd-timeout: Fix block timeout
  residue problems (bnc#447249,bnc#441335).
- patches.fixes/scsi-eh_stu-timeout: Delete obsolet patch.
* Fri Dec  5 2008 bphilips@suse.de
- patches.fixes/saa7134-fix-resource-map-sanity-check-conflict.patch:
  saa7134: fix resource map sanity check conflict (bnc#446733).
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rtl8187se-driver.patch: Staging:
  add rtl8187se driver.  Needed for MSI Wind and other netbooks.
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-serverengines-benet-10gb-ethernet-driver.patch:
  Staging: Add ServerEngines benet 10Gb ethernet driver.
* Fri Dec  5 2008 gregkh@suse.de
- update the wlan-ng driver to the latest upstream version, making
  it much more useful (it actually works now...)
* Fri Dec  5 2008 nfbrown@suse.de
- patches.fixes/sunrpc-module-refcount-fix: Add a reference to
  sunrpc in svc_addsock (443379).  This avoid a bug where
  refcount on sunrpc can go zero or negative.
* Thu Dec  4 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: reiserfs: print more
  information when an empty journal list is encountered
  (bnc#447406 bnc#399966).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch:
  ATM: duplicate listen() on socket corrupts the vcc table
  (CVE-2008-5079).
* Thu Dec  4 2008 jack@suse.cz
- Update config files.
* Thu Dec  4 2008 jack@suse.cz
  XFS update on request from SGI:
- patches.apparmor/vfs-notify_change.diff: Add a vfsmount
  parameter to notify_change(). (refreshed)
- patches.suse/xfs-account-for-allocated-blocks-when-expanding-directories:
  Account for allocated blocks when expanding directories
  (bnc#450658).
- patches.suse/xfs-check-for-valid-transaction-headers-in-recovery:
  XFS: Check for valid transaction headers in recovery
  (bnc#450658).
- patches.suse/xfs-dmapi-enable: VFS changes to support DMAPI
  (bnc#450658).
- patches.suse/xfs-dmapi-src: DMAPI Source  (bnc#450658).
- patches.suse/xfs-dmapi-xfs-enable: DMAPI support for xfs
  (bnc#450658).
- patches.suse/xfs-handle-memory-allocation-failures-during-log-initialisation:
  handle memory allocation failures during log initialisation
  (bnc#450658).
- patches.suse/xfs-nfsd-dmapi-aware: Make NFSD DMAPI aware
  (74107, 173874, bnc#450658).
- patches.suse/xfs-wait-for-all-IO-on-truncate-to-zero: Wait
  for all I/O on truncate to zero file size (bnc#450658).
- patches.suse/xfs-dmapi-2.6.27: Delete.
- patches.suse/xfs-dmapi-xfs-2.6.27: Delete.
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch:
  Don't reset affinity for secondary MPIC on boot (bnc#456408 - LTC50397).
* Thu Dec  4 2008 jjolly@suse.de
- Update config files.
- patches.arch/s390-05-04-fix_rport_status_check.patch: zfcp:
  fix remote port status check (bnc#450096).
- patches.arch/s390-05-05-stp-etr-stop-machine.patch: stp/etr:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-06-stp-etr-mutex.patch: stp/etr: serialize
  work. (bnc#450096).
- patches.arch/s390-05-07-generic-ipi.patch: kernel:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-08-topology.patch: kernel: disable cpu
  topology support by default (bnc#450096,LTC#50392).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-cell-gdb-watchpoints.patch:
  Fix GDB watchpoints on Cell (bnc#456405 - LTC50396).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-syscall-xer.so.1.patch: Fix system calls on
  Cell entered with XER.SO=1 (bnc#456406 - LTC50395).
* Thu Dec  4 2008 hare@suse.de
- patches.suse/genhd-disk-ro-uevents: Send uevents for
  write_protect changes (bnc#440959).
* Thu Dec  4 2008 mmarek@suse.cz
- supported.conf: mark kernel/net/ipv4/ipvs/ip_vs/* and
  kernel/net/ipv4/netfilter/ipt_CLUSTERIP as unsupported,
  a supported variant will be provided in a separate KMP
  (bnc#455959)
* Thu Dec  4 2008 schwab@suse.de
- Set CONFIG_IA64_CPE_MIGRATE=m.
* Thu Dec  4 2008 jbeulich@novell.com
- supported.conf: Mark pciback as support, sfc_resource, sfc_netback,
  and sfc_netutil as externally supported, add sfc_netfront, and mark
  xenscsi and xen-scsibk as unsupported.
* Thu Dec  4 2008 mszeredi@suse.de
- patches.suse/SoN-fix-uninitialized-variable.patch: Fix use of
  uninitialized variable in cache_grow() (bnc#444597).
* Thu Dec  4 2008 hare@suse.de
- patches.fixes/scsi-eh_stu-timeout: make scsi_eh_try_stu use
  block timeout (bnc#447249,bnc#441335).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/jbd2-create-proc-entry-fix.patch: Delete. It's not needed
  anymore now that 2.6.27.8-rc1 has a similar fix.
* Wed Dec  3 2008 gregkh@suse.de
- Update to 2.6.27.8-rc1:
  - lots of bugfixes
  - some security fixes as well.
  - obsoletes lots of existing patches:
  - patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
  - patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  - patches.drivers/libata-fix-ata_tf_read_block-overflow
  - patches.drivers/libata-fix-ata_tf_to_lba48-overflow
  - patches.drivers/libata-seagate-firmware-bug
  - patches.drivers/parport-serial-array-overflow-fix
  - patches.fixes/af_unix-soft-lockup-fix.patch
  - patches.fixes/cifs-add-cifs_sock_list
  - patches.fixes/cifs-cleanup-cifs_mount
  - patches.fixes/cifs-cleanup-proto-handling
  - patches.fixes/cifs-disable-sess-sharing
  - patches.fixes/cifs-fix-build-breakage
  - patches.fixes/cifs-fix-data-corruption
  - patches.fixes/cifs-fix-dead-tcon-check
  - patches.fixes/cifs-fix-oops-on-failed-mount
  - patches.fixes/cifs-fix-reconnection-flags
  - patches.fixes/cifs-fix-smb-send2
  - patches.fixes/cifs-fix-writepages
  - patches.fixes/cifs-reinstate-sess-sharing-sans-races
  - patches.fixes/cifs-reinstate-treecon-sharing
  - patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors
  - patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully
  - patches.fixes/ext4_fix_whitespace_checkpatch_issues
  - patches.fixes/ext4_update-flex-bg-counters-when-resizing
  - patches.fixes/fix-inotify-watch-removal-umount-races
  - patches.fixes/hpwdt-execute-page.diff
  - patches.fixes/hpwdt-kdump.diff
  - patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch
  - patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch
* Wed Dec  3 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.19: Fix a kernel warning during shutdown.
- patches.xen/xen3-patch-2.6.27,
  patches.xen/xen-netback-notify-multi,
  patches.xen/xen-virq-per-cpu-irq: Refresh.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch: change
  init order to fill in shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC for
  skb allocation.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  add debug for Scsi_Host->shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- supported.conf: mark dm-leastpending-path as supported
  (bnc#444199)
* Wed Dec  3 2008 teheo@suse.de
  Patch updated to remove strcmp() on NULL strings.
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Wed Dec  3 2008 jbeulich@novell.com
- Update Xen patches to c/s 728 (plus several indivual ones)
- patches.xen/735-balloon-exit.patch: remove sysfs files during balloon
  module exit.
- patches.xen/737-kexec-free.patch: kexec: Don't pass
  limit_pages_to_max_mfn() regions to xen_destroy_contiguous_region().
- patches.xen/740-blkback-resource-leak.patch: blkback, blktap: Fix
  potential resource leak.
- patches.xen/746-pirq-status-page.patch: use shared page indicating
  the need for an EOI notification
- patches.xen/747-x86-undo-mfn-limit.patch: revert the effect of
  xen_limit_pages_to_max_mfn()
- patches.xen/748-x86-ioapic-cleanup.patch: cleanup IO-APIC code
- patches.xen/panic-on-io-nmi-xen.diff: Rename to ...
- patches.xen/xen3-panic-on-io-nmi.diff: ... this.
- patches.xen/uv-sysfs-no-xen.diff: Replace by ...
- patches.xen/xen3-uv_setup_irq.diff: ... this.
- patches.xen/xen3-x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
- patches.xen/xen-fb-bad-irq: Delete.
* Wed Dec  3 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.9-update: Update Emulex lpfc driver
  to 8.2.8.9 (bnc#420767).
* Wed Dec  3 2008 knikanth@suse.de
- patches.suse/cfq-ioc-race: Exiting queue and task might race
  to free cic (bnc#444346).
* Wed Dec  3 2008 sjayaraman@suse.de
- patches.fixes/cifs-reinstate-sess-sharing-sans-races: Adjust as it
  didn't apply cleanly.
* Wed Dec  3 2008 sjayaraman@suse.de
- Fix data corruption issues (411655).
  patches.fixes/cifs-fix-data-corruption
  patches.fixes/cifs-fix-smb-send2
- Fix multiple oopses, memory corruption due to mount/umount races
  (https://bugzilla.samba.org/show_bug.cgi?id=5720).
  patches.fixes/cifs-add-cifs_sock_list
  patches.fixes/cifs-cleanup-cifs_mount
  patches.fixes/cifs-cleanup-proto-handling
  patches.fixes/cifs-disable-sess-sharing
  patches.fixes/cifs-fix-build-breakage
  patches.fixes/cifs-fix-dead-tcon-check
  patches.fixes/cifs-fix-oops-on-failed-mount
  patches.fixes/cifs-fix-reconnection-flags
  patches.fixes/cifs-fix-writepages
  patches.fixes/cifs-reinstate-sess-sharing-sans-races
  patches.fixes/cifs-reinstate-treecon-sharing
* Tue Dec  2 2008 jeffm@suse.de
- scripts/git-create-branch: Helper script to create a new
  branch.
* Tue Dec  2 2008 mmarek@suse.cz
- rpm/get_release_number.sh.in, scripts/tar-up.sh: append first
  eight digits of the commit id to the release string. This makes
  it easier to match rpm release numbers with commits.
* Tue Dec  2 2008 mszeredi@suse.de
- patches.fixes/af_unix-soft-lockup-fix.patch: net: Fix soft
  lockups/OOM issues w/ unix garbage collector (bnc#449739
  CVE-2008-5300).
* Tue Dec  2 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01.02.11.0-k9-update: qla2xxx:
  additional fixes/updates for SLES11 (bnc#450197).
- patches.fixes/scsi-fixup-failfast-definitions: fc_transport:
  fix old bug on bitflag definitions (bnc#447814).
* Tue Dec  2 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff
- patches.suse/novfs-merge-changes.diff: Modified to revert
  some changes in novfs_set_map_drive()
- patches.suse/novfs-clear-mappeddrives.patch: Unlink mapped
  drives on exit (bnc#449451).
* Tue Dec  2 2008 mmarek@suse.cz
- supported.conf: mark ocfs2 as unsupported, a supported variant
  will be provided in a separate KMP (bnc#449824)
* Tue Dec  2 2008 olh@suse.de
- patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch:
  update error message (bnc#448301 - LTC50134)
* Tue Dec  2 2008 hare@suse.de
- Update config files for S/390: Disable FCoE and sync
  default and s390.
- supported.conf: Mark KVM as supported.
* Tue Dec  2 2008 jjolly@suse.de
- ...and added the patches to the series.conf (bnc#450096)
* Tue Dec  2 2008 jjolly@suse.de
- patches.arch/s390-05-01-zfcp-message-linebreak.patch: zfcp:
  Wrong placement of linebreak in message (bnc#450096).
- patches.arch/s390-05-02-zfcp-invalid-non-null-return.patch:
  zfcp: invalid return value on failing fsf_req creation
  (bnc#450096).
- patches.arch/s390-05-03-zfcp-wka-port.patch: zfcp: Fix opening
  of wka ports (bnc#450096).
* Mon Dec  1 2008 kkeil@suse.de
- patches.drivers/cxgb3-Add-1G-fiber-support: cxgb3: Add 1G
  fiber support.
- patches.drivers/cxgb3-Allocate-multiqueues-at-init-time: cxgb3:
  Allocate multiqueues at init time.
- patches.drivers/cxgb3-More-flexible-support-for-PHY-interrupts:
  cxgb3: More flexible support for PHY interrupts..
- patches.drivers/cxgb3-Support-for-Aeluros-2005-PHY: cxgb3:
  Support for Aeluros 2005 PHY.
- patches.drivers/cxgb3-allow-for-PHY-reset-status: cxgb3:
  allow for PHY reset status.
- patches.drivers/cxgb3-commnonize-LASI-phy-code: cxgb3:
  commnonize LASI phy code.
- patches.drivers/cxgb3-eeprom-read-fixes.patch:
  cxgb3 - eeprom read fixes.
- patches.drivers/cxgb3-enable-lro-through-ethtool: cxgb3 -
  enable lro control through ethtool.
- patches.drivers/cxgb3-simplify-port-type-struct-and-usage:
  cxgb3: simplify port type struct and usage.
- patches.drivers/cxgb3-update-driver-version: cxgb3: update
  driver version. (bnc#446739)
* Mon Dec  1 2008 mmarek@suse.cz
- rpm/macros.kernel-source: one more fix to the flavor selection
  code (for some reason %%* contained a newline)
* Mon Dec  1 2008 trenn@suse.de
- patches.arch/acpi_x2APIC_madt_enhancements.patch: ACPICA:
  x2APIC support: changes for MADT and SRAT ACPI tables (fate
  303948 and fate 303984).
- patches.fixes/acpi_check_for_invalid_handle.patch: ACPICA:
  Add check for invalid handle in acpi_get_object_info
  (http://www.acpica.org/bugzilla/show_bug.cgi?id=474).
- patches.fixes/acpi_dereference_object_if_possible.patch:
  ACPICA: Add function to dereference returned reference objects
  (http://bugzilla.kernel.org/show_bug.cgi?id=11105).
- patches.fixes/acpi_do_not_load_acpi_cpufreq_acpioff.patch:
  ACPI: don't load acpi_cpufreq if acpi=off (no reference).
* Mon Dec  1 2008 trenn@suse.de
- patches.fixes/acpi_copy_tables_fix_suspend.patch: ACPICA:
  Copy dynamically loaded tables to local buffer (bnc#410726).
* Sat Nov 29 2008 nfbrown@suse.de
- patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch:
  SUNRPC: Fix autobind on cloned rpc clients.
  Importantly, this removes a 'BUG_ON' that fires. (450083).
* Sat Nov 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Sat Nov 29 2008 bwalle@suse.de
- UV updates from SGI (bnc#442455, #442455).
  o patches.fixes/ia64_uv_partition_id.diff:
    Add partition id, coherence id, and region size to UV
  o patches.fixes/ia64_uv_watchlist.diff:
    Add UV watchlist suppor
  o patches.fixes/null_irq_desc_name.diff:
    genirq: NULL struct irq_desc's member 'name' in
    dynamic_irq_cleanup()
  o patches.fixes/uv-bios_call_memprotect.diff:
    Add UV bios call to change memory protections
  o patches.fixes/uv-bios_call_partition.diff:
    x86: Add UV partition call
  o patches.fixes/uv-bios_call_reserve_page.diff:
    Add UV bios call to get the address of the reserved page
  o patches.fixes/uv-bios_call_watchlist.diff:
    Add UV bios calls to allocate and free watchlists
  o patches.fixes/uv-bios_common.diff:
    x86: Add UV bios call infrastructure
  o patches.fixes/uv-efi_bios.diff:
    x86: Add UV EFI table entry
  o patches.fixes/uv-sn_region_size.diff:
    Use consistent names for region size and conherence id on x86
    and ia64
  o patches.fixes/uv-sysfs.diff:
    x86: Add UV sysfs entries
  o patches.fixes/uv-xp-change_memprotect.diff:
    Define xp_expand_memprotect() and xp_restrict_memprotect()
  o patches.fixes/uv-xpc-get_sn_info.diff:
    Define xp_partition_id and xp_region_size
  o patches.fixes/uv-xpc_create_gru_mq_uv.diff:
    Add the code to create the activate and notify gru message
    queues
  o patches.fixes/uv-xpc_get_part_rsvd_page.diff:
    Add support for getting the address of a partition's reserved
    page
  o patches.fixes/uv_setup_irq.diff:
    x86, UV: add uv_setup_irq() and uv_teardown_irq() functions, v3
- Refresh Xen patches
  o patches.xen/xen3-auto-arch-x86.diff
  o patches.xen/xen3-patch-2.6.19
- patches.xen/xen-x86-no-lapic: Add uv_irq.o
- patches.xen/uv-sysfs-no-xen.diff:
  Don't build UV sysfs support on Xen.
* Fri Nov 28 2008 trenn@suse.de
- patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch:
  powernow-k8: ignore out-of-range PstateStatus value (no
  bug avail).
* Fri Nov 28 2008 sassmann@suse.de
- Update config files.
  activate ALTIVEC in ps3 config
* Fri Nov 28 2008 hare@suse.de
- patches.drivers/open-fcoe-beta4-update: rediff.
- patches.drivers/open-fcoe-beta6-update: Incremental Open-FCoE
  for Beta6 (bnc#438954).
* Fri Nov 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sony-vaio-vgn-sr19xn-quirk: ALSA:
  hda - Add quirk for Sony VAIO VGN-SR19XN (bnc#450080).
* Fri Nov 28 2008 olh@suse.de
- rpm/kernel-binary.spec.in: move Module.symvers creation into
  CONFIG_MODULES section, a static kernel exports nothing
* Fri Nov 28 2008 olh@suse.de
- rpm/post*.sh: kernel-vanilla has now vmlinux-vanilla symlink
* Fri Nov 28 2008 teheo@suse.de
  Block layer timer bug fixed.  Multipath patch update is just patch
  refresh.
- patches.drivers/block-internal-dequeue-shouldnt-start-timer:
  block: internal dequeue shouldn't start timer (bnc#449880).
- patches.drivers/blk-request-based-multipath-update: Block layer
  fixes for request-based multipathing (References: FATE#302108).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix no-op macro args
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix compile on ppc32
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: always create a dummy initrd because
  mkinitrd is called unconditionally
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: kernel-ps3 needs a suffix
* Thu Nov 27 2008 olh@suse.de
- remove last traces of kernel-um handling
* Thu Nov 27 2008 hare@suse.de
- patches.fixes/qla2xxx-disable-automatic-queue-tracking: qla2xxx:
  Conditionally disable queue_full tracking (bnc#449386).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: no sysrq on Cell QS21/QS22
  serial console (bnc#422987,bnc#96313 - LTC47675/LTC16841).
* Thu Nov 27 2008 olh@suse.de
- patches.arch/ppc-memoryless-nodes.patch: fix booting with
  memoryless nodes (443280 - LTC49675)
* Thu Nov 27 2008 teheo@suse.de
- patches.drivers/libata-seagate-firmware-bug: libata: blacklist
  Seagate drives which time out FLUSH_CACHE when used with NCQ
  (bnc#449531).
* Wed Nov 26 2008 agruen@suse.de
- rpm/macros.kernel-source: Fix the kernel flavor selection logic
  for the %%kernel_module_package macro.
* Wed Nov 26 2008 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: move to
  correct place in series.conf and rediff
- patches.drivers/cciss-newids.patch: Delete.
* Wed Nov 26 2008 hare@suse.de
- patches.drivers/cciss-newids.patch: Support for newcciss
  controller (bnc#448416).
- patches.fixes/blk-leave-sync-timer-running: block: leave
  request timeout timer running on an empty list (bnc#447249).
* Tue Nov 25 2008 mszeredi@suse.de
- patches.fixes/slab-alloc_slabmgmt-fix.patch: slab: remove
  GFP_THISNODE clearing from alloc_slabmgmt() (bnc#444597).
* Tue Nov 25 2008 sjayaraman@suse.de
- patches.suse/SoN-11-mm-page_alloc-emerg.patch: Fix accidental side-effect
  that this patch introduced by reverting patches.fixes/oom-warning
  (bnc #444597).
* Tue Nov 25 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-dell-92hd73xx-models: ALSA: hda -
  Check model for Dell 92HD73xx laptops (bnc#446025).
- patches.drivers/alsa-hda-dell-studio-1535-quirk: ALSA: hda -
  mark Dell studio 1535 quirk (bnc#446025).
- patches.drivers/alsa-hda-spdif-bits-cache-fix: ALSA: hda -
  Fix caching of SPDIF status bits.
- patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch: ALSA:
  hda - No 'Headphone as Line-out' swich without line-outs
  (bnc#446025).
- patches.drivers/alsa-hda-stac-yet-more-fixes: ALSA: hda -
  Fix AFG power management on IDT 92HD* codecs (bnc#446025).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/fix-inotify-watch-removal-umount-races: Fix
  inotify watch removal/umount races (bnc#446973 CVE-2008-5182).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/uv-redundant-creation-of-proc-dir: UV: redundant
  creation of sgi_uv (bnc#444799).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid45 depends on a few more modules
  (bnc#440208, bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Switch from a no_file_caps command line switch to file_caps={0,1}
  for enabling/disabling file capabilities, and make file_caps=0
  the default: we cannot get the no_file_caps option added to the
  kernel command line anymore (perl-Bootloader, bnc#418366).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid4-5 was renamed to dm-raid45 (bnc#440208,
  bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Update config files: switch from CONFIG_PREEMPT_VOLUNTARY to
  CONFIG_PREEMPT_NONE.
* Mon Nov 24 2008 ghaskins@suse.de
- patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch:
  sched: fix a bug in sched domain degenerate (bnc#442464).
* Mon Nov 24 2008 mmarek@suse.cz
- doc/README.SUSE: document that setting allow_unsupported_modules
  to 1 in /etc/modprobe.d/unsupported-modules is required to make
  self-compiled kernels work.
* Mon Nov 24 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff: Sync with latest upstream
  submission.
* Sun Nov 23 2008 trenn@suse.de
- patches.arch/x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
* Sat Nov 22 2008 olh@suse.de
- enable CONFIG_CGROUP_NS on ia64, s390 and powerpc (bnc#447507 - LTC50053)
* Sat Nov 22 2008 rjw@suse.de
- patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch:
  fix boot panic caused by offline CPUs (bnc#440386).
* Fri Nov 21 2008 agruen@suse.de
- config/x86_64/maxcpus: Delete.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: s/CVS/GIT/
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: fix module names in export lists
  (kernel/irq/built-in was printed as irq/built-in)
* Fri Nov 21 2008 agruen@suse.de
- Update x86_64/{debug,default,trace,vanilla} config files:
  increase NR_CPUS to 512.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: Replace the bash and awk scripts around symsets
  and kabi checking with a single script that generates symsets,
  reuses symsets from older kernels and checks for kabi changes for
  each of the split packages (kabi checking and symset reuse
  require a set of reference files, which does not exist yet)
- rpm/list-exported-symbols: Delete.
- rpm/split-into-symsets: Delete.
- scripts/kabi-checks: Delete.
- kabi/severities: table of kabi change severities
- rpm/built-in-where, rpm/find-provides,
  rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: update to use symsets.pl
* Fri Nov 21 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: include additional fixes from
  Intel (bnc#442411)
* Fri Nov 21 2008 kkeil@suse.de
- patches.fixes/igb_ethtool.patch: add missing ethtool hooks
  (bnc#435551)
* Fri Nov 21 2008 jjolly@suse.de
- patches.arch/s390-04-08-cio-ungroup-race-fix.patch:
  cio: ccwgroup online vs. ungroup race condition
  (bnc#445100,LTC#50092).
- patches.arch/s390-04-09-zfcp-host-busy-count-fix.patch: zfcp:
  prevent double decrement on host_busy counter (bnc#445100).
* Fri Nov 21 2008 agruen@suse.de
- rpm/macros.kernel-source:
  + Rename the -s option to -t in the %%kernel_module_package macro
    for improved cross-distro compatibility.
  + Define %%kernel_module_package_release as 1 for feature tests.
  + Define %%kernel_module_package_buildreqs for use by KMPs: that
    way, KMPs can either use this macro for compatibility, or
    they can substitute other packages for special cases.
* Fri Nov 21 2008 hare@suse.de
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3i-fixed-offload-array-size: cxgb3i -
  fixed offload wr array size (bnc#447409).
- patches.fixes/dm-table-switch-to-readonly: dm multipath devices
  are not getting created for readonly devices (bnc#382705).
- patches.suse/dm-mpath-null-pgs: Allow zero paths for multipath
  priority groups (bnc#372684).
- patches.suse/scsi-netlink-ml: Netlink interface for SCSI
  sense codes (FATE#303789).
* Fri Nov 21 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff: Fix oops in
  set_map_drive (bnc#446824, bnc#444469).
* Fri Nov 21 2008 jbeulich@novell.com
- patches.xen/xen3-x86-vmware-tsc-03-detect-from-hypervisor:
  Fix Xen pv driver build.
* Fri Nov 21 2008 olh@suse.de
- patches.arch/ppc-spufs-01-use-inc_nlink.patch: use inc_nlink
- patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
- patches.arch/ppc-spufs-03-sputrace-Only-enable-logging-on-open.patch
- patches.arch/ppc-spufs-04-sputrace-Don-t-block-until-the-read.patch
- patches.arch/ppc-spufs-05-Use-state_mutex-for-switch_log-lockin.patch
- patches.arch/ppc-spufs-06-Don-t-require-full-buffer-in-switch_l.patch
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch
- patches.arch/ppc-spufs-08-Use-kmalloc-rather-than-kzalloc-for-s.patch
- patches.arch/ppc-spufs-09-Improve-search-of-node-for-contexts-w.patch
- patches.arch/ppc-spufs-10-Explain-conditional-decrement-of-aff_.patch
- patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  update spufs to current mainline state (bnc#447133 - LTC50070)
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/parport-serial-array-overflow-fix: Fix array
  overflow in parport_serial.c (bnc#447067).
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-15-quirk: ALSA: hda -
  Add a quirk for Dell Studio 15 (bnc#446025).
- patches.drivers/alsa-hda-stac-dell-m4-3-quirk: ALSA: hda:
  Add STAC_DELL_M4_3 quirk (bnc#446025).
* Fri Nov 21 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap. Try again.
* Fri Nov 21 2008 gregkh@suse.de
- Refresh patches to apply cleanly after 2.6.27.7 update.
* Fri Nov 21 2008 gregkh@suse.de
- Update to 2.6.27.7
  - lots of bugfixes and security updates.
  - obsoletes:
  - patches.arch/s390-04-05-topology-lock.diff
  - patches.drivers/bnx2x-zero-PMF
  - patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch
  - patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch
  - patches.fixes/sony_laptop_fix_suspend.patch
  - patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch
  - patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch
  - patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
* Fri Nov 21 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: ata_piix:
  detect and clear spurious IRQs (bnc#445872).
* Fri Nov 21 2008 npiggin@suse.de
- patches.fixes/mm-madvise-fix.patch: mm: madvise correct return
  code (bnc#352998).
* Thu Nov 20 2008 jack@suse.cz
- patches.suse/ocfs2-Change-quotafile-names.patch: ocfs2: Change
  file names of local quota files to be consistent (fate#302681).
- patches.suse/ocfs2-Fix-hang-in-quota-recovery-code.patch:
  ocfs2: Fix hang in quota recovery code (fate#302681).
- patches.suse/ocfs2-Fix-oops-when-one-quotatype-enabled: ocfs2:
  Fix oops when only usrquota or grpquota feature is enabled
  (fate#302681).
* Thu Nov 20 2008 garloff@suse.de
- patches.suse/panic-on-io-nmi.diff
  patches.xen/panic-on-io-nmi-xen.diff:
  New kernel sysctl panic-on-io-nmi, which is set will cause a
  kernel panic on receiving an IOCK NMI (bnc#427979).
* Thu Nov 20 2008 jjolly@suse.de
- patches.arch/s390-04-06-cio-sac-update.diff: cio: update sac
  values (bnc#445100).
- patches.arch/s390-04-07-als.patch: kernel: Add processor type
  march=z10 and a processor type safety check. (bnc#445100).
* Thu Nov 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-gpio-switch-fix: ALSA: hda:
  STAC_DELL_M6 EAPD (bnc#446025).
* Thu Nov 20 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.6 and c/s 724.
- Update Xen config files.
- patches.xen/xen-fb-bad-irq: xenfb: don't use irq before it
  gets set up (bnc#445659).
- patches.xen/xen-netback-notify-multi: netback: use multicall
  for send multiple notifications.
- patches.xen/xen-netback-nr-irqs: netback: reduce overhead of
  IRQ recording.
* Thu Nov 20 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: removed (no SR-IOV) (bnc#440614)
* Thu Nov 20 2008 olh@suse.de
- disable patches.arch/ppc-efika-bestcomm-ata-dma.patch
  crashes the sound driver
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: excluded vanilla build from creating
  the man package
* Thu Nov 20 2008 hare@suse.de
- patches.drivers/ibmvfc-async-events-oops: ibmvfc oops while
  processing async events (bnc#445541).
- patches.drivers/mpt-fusion-4.16.00.00-update: MPT fusion driver
  update to 4.16.00.00 (bnc#425660).
- patches.fixes/dm-mpath-NULL-pgpath-in-activate_path: Do not
  call activate_path() if pgpath is NULL (bnc#442676).
- patches.fixes/scsi-dh-rdac-initialize-passive-path: Initialize
  path state to be passive when path is not owned (bnc#442676).
- patches.suse/dm-mpath-leastpending-path: Dynamic load balancing
  policy for device mapper multipath (bnc#444199).
* Thu Nov 20 2008 olh@suse.de
- patches.fixes/bug-437171_1_sched_clock_lock.patch: sched: only
  update rq->clock while holding rq->lock (437171 - LTC47404).
- patches.fixes/bug-437171_2_sched_delta_weight.patch: sched:
  revert back to per-rq vruntime (437171 - LTC47404).
- patches.fixes/bug-437171_3_rework_wakeup_preemption.patch:
  sched: rework wakeup preemption (437171 - LTC47404).
- patches.fixes/bug-437171_4_sched_reinstate_vruntime_wakeup.patch:
  sched: re-instate vruntime based wakeup preemption (437171 -
  LTC47404).
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  Fixed debug build, added dependent config option.
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  - > unified i386/x86_64 debug kernels:
  - added CONFIG_NO_HZ=y to i386-debug
  - added CONFIG_DEBUG_INFO to x86_64-debug
  Differ method to receive processor_id depending whether the processor
  got declared as a regular ACPI device or as a processor object:
- patches.arch/acpi_behave_uniquely_based_on_processor_declaration.patch:
  ACPI: Behave uniquely based on processor declaration definition
  type (bnc#440062).
- patches.arch/acpi_disambiguate_processor_declaration_type.patch:
  ACPI: Disambiguate processor declaration type (bnc#440062).
- patches.arch/acpi_processor_cleanups.patch: ACPI: 80 column
  adherence and spelling fix (no functional change) (bnc#440062).
- patches.xen/xen3-auto-common.diff: xen3 common.
  Fix missing bit for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
- patches.fixes/sony_laptop_fix_suspend.patch: sony-laptop:
  Ignore missing _DIS method on pic device (bnc#446487).
* Thu Nov 20 2008 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Do not detach hardware
  handler when removing multipath maps (bnc#435688).
- patches.fixes/scsi-dh-alua-send-stpg: Always send STPG for
  explicit tgps mode.
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: Added kernel man package for s390x
* Thu Nov 20 2008 olh@suse.de
- patches.arch/ppc-of-irq-map.patch: fix IRQ assignment if
  interrupts property is missing (bnc#446610 - LTC50006)
* Thu Nov 20 2008 rjw@suse.de
- patches.fixes/acpi-set-SCI_EN-on-MacBook.patch: ACPI suspend:
  Blacklist boxes that require us to set SCI_EN directly on resume
  (bnc#444786).
* Wed Nov 19 2008 tiwai@suse.de
- patches.arch/x86-hpet-pre-read: x86: workaround for mccreary
  HPET read problem (bnc#433746).
* Wed Nov 19 2008 trenn@suse.de
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
  - > Fix typo, must not invert logic at this point
* Wed Nov 19 2008 kkeil@suse.de
- patches.drivers/e1000e_add_ECC: e1000e: enable ECC (bnc#445829)
* Wed Nov 19 2008 mmarek@suse.cz
- scripts/tar-up.sh: record the git branch name in the spec files
  (no branch name means master)
* Wed Nov 19 2008 jkosina@suse.de
- patches.drivers/elousb.patch: fix values of maximum X and Y
  coordinates so that they are compliant with the values that
  the device contains in its descriptor (bnc#442865)
* Wed Nov 19 2008 goldwyn@suse.de
- patches.suse/novfs-merge-changes.diff: Merge changes left out
  during code pull (bnc#445000).
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-multinode.patch: Add support for
  multiple BSR nodes in the device tree. (bnc#443665 - LTC49817)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-cmm-pagecounter.patch:
  Update page in counter for CMM (bnc#445540 - LTC49942)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-4k.patch: Unable to Use Small
  BSR register on Power LPAR (bnc#443673 - LTC49749)
* Wed Nov 19 2008 jjolly@suse.de
- config/s390/s390: Update config files: added CONFIG_UTRACE=y and
  CONFIG_HAVE_ARCH_TRACEHOOK=y
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/ehca-fix-possible-nullpointer-access-v2.patch:
  ehca: fix a possible nullpointer access (bnc#441966).
* Wed Nov 19 2008 jjolly@suse.de
- patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  powerpc/cell/axon-msi: retry on missing interrupt (bnc#445964).
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/0001-IB-ehca-Fix-problem-with-max-number-of-QPs-and-CQs.patch:
  Fix problem with max number of QPs and CQs (bnc#441619).
* Tue Nov 18 2008 bwalle@suse.de
- Disable CONFIG_STRICT_DEVMEM for i386 and x86_64 (bnc#443852).
* Tue Nov 18 2008 jjolly@suse.de
- Update config files.
- patches.trace/s390-syscall-get-nr.diff: fix syscall_get_nr..
- patches.trace/s390-utrace-enablement.patch: Backport s390
  kernel components required for utrace enablement.
* Tue Nov 18 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: on s390(x) call dwarfextract to create the
  Kerntypes file for use with old lcrash debuggers.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-92hd71bxx-gpio-fix: ALSA:
  hda - Fix GPIO initialization in patch_stac92hd71bxx()
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-gpio-unsol-resume-fix:
  ALSA: hda - Fix resume of GPIO unsol event for STAC/IDT
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-hp-pavilion-quirks: ALSA: hda -
  Add quirks for HP Pavilion DV models (bnc#445321,bnc#445161).
* Tue Nov 18 2008 tiwai@suse.de
- patches.arch/x86-hpet-use-WARN_ON_ONCE: x86: HPET: convert
  WARN_ON to WARN_ON_ONCE (bnc#433746).
* Tue Nov 18 2008 sdietrich@suse.de
  RT development has moved to slert-devel branch.
- Remove RT patches from master branch.
  (itemized RT patch list suppressed)
* Tue Nov 18 2008 olh@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: use ATA DMA (bnc#445856)
* Tue Nov 18 2008 olh@suse.de
- config/ppc/ppc64: reenable 64k PAGE_SIZE to keep the config
  flavor on ppc and ppc64 in sync
  the last change had also no bug number to fix the possible bug
  in the Xserver.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-acer-dmic: ALSA: hda - Split
  ALC268 acer model (bnc#420048).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-04-01-qdio_prevent_double_shutdown.patch:
  qdio: prevent double qdio shutdown in case of I/O
  errors. (bnc#445100).
- patches.arch/s390-04-02-qdio-osa-port-count.patch: qdio:
  fix qeth port count detection. (bnc#445100).
- patches.arch/s390-04-03-kmsg.patch: kmsg: do not change pr_xyz
  messages without KMSG_COMPONENT (bnc#445100).
- patches.arch/s390-04-04-dasd_fatal_error_log_sense.patch:
  dasd: log sense for fatal errors. (bnc#445100).
- patches.arch/s390-04-05-topology-lock.diff: kernel: Fix locking
  in cpu topology code. (bnc#445100).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-personality-mask.patch: fix s390x_newuname.
* Tue Nov 18 2008 gregkh@suse.de
- patches.drivers/staging-rt2860-enable-wpa_supplicant-support.patch:
  Staging: rt2860: enable WPA_SUPPLICANT support (bnc#437959).
* Mon Nov 17 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.7-update: Update lpfc to 8.2.8.7
  (bnc#420767).
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Update
  qla4xxx to 5.01.00-k8_sles11-03     (bnc#444884).
- patches.fixes/dm-mpath-reattach-dh: Reattach device handler
  for multipath devices (bnc#435688).
- patches.fixes/scsi-add-tgps-setting: Add TGPS setting to
  scsi devices.
- patches.fixes/scsi-dh-alua-retry-UA: Retry ALUA device handler
  initialization on Unit Attention.
* Mon Nov 17 2008 jeffm@suse.de
- patches.fixes/v4l-dvb-avoid-writing-outside-array: V4L/DVB
  (9621): Avoid writing outside shadow.bytes array (bnc#445569).
* Mon Nov 17 2008 fseidel@suse.de
- patches.fixes/ipw2200-send-noassoc.patch: ipw2200: fix oops
  in ipw_tx_skb (bnc#397390).
* Sat Nov 15 2008 rjw@suse.com
- patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch:
  x86: Hibernate: Fix breakage on x86_32 with CONFIG_NUMA set
  (bnc#439126).
* Sat Nov 15 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-hp-m4-check-fix: ALSA:
  hda - Check model type instead of SSID in patch_92hd71bxx()
  (bnc#444349).
- patches.drivers/alsa-hda-sigmatel-vref-event-fix: ALSA: hda:
  STAC_VREF_EVENT value change (bnc#444349).
* Sat Nov 15 2008 gregkh@suse.de
- patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch:
  memory hotplug: fix page_zone() calculation in
  test_pages_isolated() (bnc#445163).
* Fri Nov 14 2008 gregkh@suse.de
- patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch:
  Input: ALPS - add signature for DualPoint found in Dell Latitude
  E6500 (bnc#436719).
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/hpwdt-execute-page.diff:
  [WATCHDOG] [hpwdt] Set the mapped BIOS address space as
  executable (bnc#430680).
* Fri Nov 14 2008 tiwai@suse.de
- patches.arch/x86-vmware-tsc-01-add-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-02-add-X86_FEATURE_HYPERVISOR,
  patches.arch/x86-vmware-tsc-03-detect-from-hypervisor,
  patches.arch/x86-vmware-tsc-04-use-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-05-skip-tsc-clocksource,
  patches.arch/x86-vmware-tsc-06-fix-vmware_get_tsc,
  patches.arch/x86-vmware-tsc-07-DMI-product-serial-key,
  patches.xen/xen-x86-vmware-tsc-fix:
    VMware tsc clocksource workaround (bnc#441338).
* Fri Nov 14 2008 tiwai@suse.de
- Fixed a typo in definition of X86_FEATURE_XTOPOLOGY (bnc#443293)
  in patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4
* Fri Nov 14 2008 agruen@suse.de
- Update CONFIG_X86_RESERVE_LOW_64K in config/x86_64/maxcpus as
  well.
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff:
  rename to patches.suse/mem_cgroup_stat-dynamic-alloc, and update
  to newer version.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/kdump-x86-sparsemem.diff: x86, kdump: fix invalid
  access on i386 sparsemem (bnc#440525).
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  Refresh.
* Thu Nov 13 2008 gregkh@suse.de
- patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch:
  iwlagn: avoid sleep in softirq context (bnc#444382).
* Thu Nov 13 2008 philips@suse.de
- patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch:
  cdc-acm.c: fix recursive lock in acm_start_wb error path.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K for i386 and x86-64 vanilla
  configs.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K on i386 and x86-64 to fix some
  suspend/resume issues (option added in 2.6.27.6)
* Thu Nov 13 2008 gregkh@suse.de
- refresh patches so that everything applies cleanly.
* Thu Nov 13 2008 gregkh@suse.de
- Update to 2.6.27.6:
  - fixes some security issues
  - lots of bugfixes
  - obsoletes:
  - patches.arch/acpi-dock-avoid-check-_STA-method.patch:
  - patches.arch/ppc-gigantic-page-fix2.patch:
  - patches.arch/ppc-gigantic-page-fix3.patch:
  - patches.drivers/alsa-hda-dell-eq-option:
  - patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  - patches.drivers/cciss-fix-sysfs-symlink.patch:
  - patches.drivers/libata-fix-last_reset-timestamp-handling:
  - patches.kernel.org/md-raid10-recovoery-fix.path:
* Thu Nov 13 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: package modules.order (bnc#441384)
* Thu Nov 13 2008 agruen@suse.de
- config.conf: Add x86_64/maxcpus as the 4096-cpu configuration
  and switch back to at most 128 cpus in the other configs. This
  avoids wasting memory on all but the most extreme x86_64
  systems.
- rpm/kernel-binary.spec.in: define a kernel-$flavor symbol to
  allow per-flavor patches. (Use this for testing only!)
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff: Add
  this patch conditionally for x86_64/maxcpus for now pending
  test results from bnc#425240.
* Thu Nov 13 2008 tiwai@suse.de
- patches.drivers/alsa-hda-beep-dig-switch: ALSA: hda - Add
  digital beep playback switch for STAC/IDT codecs (#444572).
- patches.drivers/alsa-hda-beep-null-check-fix: ALSA: hda -
  Missing NULL check in hda_beep.c.
* Thu Nov 13 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: fix to
  make it work with iSCSI (bnc#444234)
* Thu Nov 13 2008 olh@suse.de
- mark some powerpc device drivers as supported to move them out of
  kernel-extra, otherwise installation-images will not pick them up
- ps3vram, mtd, mtdblock, mtd_blkdevs (bnc#444220)
- PowerMac, Efika and Pegasos2 storage and network drivers
* Wed Nov 12 2008 bwalle@suse.de
- patches.fixes/firmware-memmap-64bit.diff: Always use 64 bit
  addresses for the firmware memory map.
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-powermac-ibook-g4-mic-fix: ALSA: powermac -
  Rename mic-analog loopback mixer element (bnc#444194).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-detect-fix: ALSA: hda -
  Fix IDT/STAC multiple HP detection (bnc#443267).
* Wed Nov 12 2008 agruen@suse.de
- patches.suse/module-ref-dynamic-alloc: fall back to vmalloc if
  kmalloc fails (bnc#425240).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac9200-missing-mux-capture: ALSA:
  hda - Add missing analog-mux mixer creation for STAC9200
  (bnc#443738).
- patches.drivers/alsa-hda-stac92xx-mic-pin-fix: ALSA: hda -
  Fix input pin initialization for STAC/IDT codecs (bnc#443738).
* Tue Nov 11 2008 philips@suse.de
- rpm/kernel-binary.spec.in: remove Recommends: kerneloops, opt-in will
  be implemented in the 11.2 installer
* Tue Nov 11 2008 jeffm@suse.de
- patches.fixes/reiserfs-error-buffer-locking: reiserfs: add
  locking around error buffer.
- patches.fixes/reiserfs-varargs-fix: reiserfs: prepare_error_buf
  wrongly consumes va_arg.
* Tue Nov 11 2008 tiwai@suse.de
- patches.suse/module-ref-dynamic-alloc: Allocate module.ref
  array dynamically (bnc#425240).
- Update config files: back to NR_CPUS=4096
* Tue Nov 11 2008 jblunck@suse.de
- Update config files: Set NR_CPUS on x86_64 back to 128 again for
  now: with NR_CPUS=4096, the size of eack .ko file increases by
  496 KiB because of the static struct module in
  .gnu.linkonce.this_module.
* Tue Nov 11 2008 schwab@suse.de
- patches.arch/ppc-select: Fix wrong error code from ppc32 select.
* Tue Nov 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also encode the architecture into the
  packageand supplements.
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-fix-ata_tf_read_block-overflow: libata:
  Avoid overflow in ata_tf_read_block() when tf->hba_lbal > 127
  (bnc#443661).
- patches.drivers/libata-fix-ata_tf_to_lba48-overflow: libata:
  Avoid overflow in ata_tf_to_lba48() when tf->hba_lbal > 127
  (bnc#443661).
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-pata_sch-slave-poss: pata_sch: slave
  devices (bnc#443657).
* Mon Nov 10 2008 schwab@suse.de
- config/ppc/ppc64: Disable 64k pages to work around X server bug.
* Mon Nov 10 2008 olh@suse.de
- rpm/kernel-binary.spec.in: fix variable assignment in last change
* Mon Nov 10 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: encode the architecture into
  subpackage dependencies (bnc#440961)
* Mon Nov 10 2008 olh@suse.de
- handle arch differences for cpu and kbuild correctly
* Mon Nov 10 2008 schwab@suse.de
- patches.arch/ia64-page-migration. patches.arch/mm-avoid-bad-page-on-lru:
  migrade pages off of pages with correctable errors.
* Mon Nov 10 2008 mmarek@suse.cz
- scripts/tar-up.sh: do not generate kernel-source-rt.spec and
  kernel-syms-rt.spec if RT is not enabled.
* Mon Nov 10 2008 sdietrich@suse.de
- config.conf: Suppress RT configurations.
* Sun Nov  9 2008 jeffm@suse.de
- config.conf: Removed previous workaround.
- rpm/kernel-binary.spec.in: Remove @FLAVOR@ from %%symbols.
* Sat Nov  8 2008 jeffm@suse.de
- config.conf: Workaround for kernel-ppc64 on head-ppc.
* Sat Nov  8 2008 gregkh@suse.de
- Update to the "real" 2.6.27.5.  No code changes from what we had
  in our tree previously, with the exception for the version number
  change.
* Fri Nov  7 2008 bwalle@suse.de
- patches.fixes/kdb-read-CR.diff:
  Support '\n' in KDB (bnc#442808).
* Fri Nov  7 2008 gregkh@suse.de
- disable perfmon support in the -trace kernels as it doesn't build
  properly.
* Fri Nov  7 2008 schwab@suse.de
- patches.arch/compat-sys-swapcontext: Fix msr check in sys_swapcontext.
* Fri Nov  7 2008 hare@suse.de
- patches.drivers/ixgbe-add-bcna-support: DCB: Add BCNA support
  to ixgbe.
- patches.drivers/open-fcoe-beta3-update: Open-FCoE update for
  Beta3 (bnc#438954).
- patches.drivers/open-fcoe-beta4-update: Open-FCoE: Update for
  Beta4 (bnc#438954).
- patches.drivers/open-fcoe-beta5-update: Open-FCoE: Update for
  Beta5 (bnc#438954).
- patches.fixes/dcb-fix-setpfcstate: Fix setpfcstate (bnc#438954).
- patches.fixes/dcb-setting-pg-will-cause-tx-hang: DCB: setting
  pg will cause tx unit hangs (bnc#438954).
- patches.fixes/multiq-requeue-should-rewind-current_band:
  multiq: requeue should rewind the current_band (bnc#438954).
- patches.fixes/scsi-dh-rdac-retry-mode-select: Retry mode select
  in RDAC device handler (bnc#441337).
- patches.fixes/scsi-dh-rdac-set-default-ownership: scsi_dh_rdac:
  make sure the ownership is set correctly (bnc#441337).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Update patch
  to check for ->bus instead of ->type (bnc#431294).
* Fri Nov  7 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-probe-fix: ALSA: hda -
  Fix probe errors on Dell Studio Desktop (bnc#440907).
- patches.drivers/alsa-hda-hp-3013-master-fix: ALSA: hda -
  Fix ALC260 hp3013 master switch (bnc#441068).
* Fri Nov  7 2008 jjolly@suse.de
- patches.arch/s390-03-07-qeth_hsi_mcl_string.patch:
  qeth: pre z9 systems return HiperSocket version string
  different. (bnc#440610,LTC#49052).
- patches.arch/s390-03-08-zfcp-abort-race.patch: zfcp: eliminate
  race between validation and locking. (bnc#440610).
- patches.arch/s390-03-09-zfcp-oops-during-target-scan.patch:
  zfcp: prevent SCSI target scan for vanished rport
  (bnc#440610,LTC#49373).
* Fri Nov  7 2008 olh@suse.de
- Update config files for RT
* Fri Nov  7 2008 olh@suse.de
- build a kernel-default in dist ppc64, its identical to kernel-ppc64
  otherwise unused
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-source.spec.in: map ppc/ppc64 to powerpc
* Fri Nov  7 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: VF enabled igb driver (fate#305004)
* Fri Nov  7 2008 olh@suse.de
- stop building kernel-default and kernel-ps3 in dist ppc64,
  they are openSuSE only packages
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: extracting debuginfo from vdso fails
  on powerpc, disable vdso_install for the time being
* Fri Nov  7 2008 jbeulich@novell.com
- patches.xen/xen3-intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
* Fri Nov  7 2008 olh@suse.de
- rpm/post.sh: reject legacy iSeries again
* Fri Nov  7 2008 olh@suse.de
- build a 32bit and a 64bit vanilla kernel on powerpc
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: no vdso in vanilla and ps3 kernel
* Fri Nov  7 2008 gregkh@suse.de
- patches.kernel.org/net-fix-recursive-descent-in-__scm_destroy.patch:
  net: Fix recursive descent in __scm_destroy()..
* Fri Nov  7 2008 olh@suse.de
- remove patches.arch/ppc64-rpanote-relocate-firmware.patch
  older firmware versions can handle relocation properly (bnc#427960)
* Fri Nov  7 2008 jjolly@suse.de
- patches.drivers/cxgb3-get_drvinfo-deadlock.patch: RDMA/cxgb3:
  deadlock in iw_cxgb3 can cause hang when configuring
  interface. (bnc#430998).
* Fri Nov  7 2008 gregkh@suse.de
- patches.suse/perfmon2.patch: perfmon2 (bnc#430298).
* Fri Nov  7 2008 nfbrown@suse.de
- patches.fixes/nfs-write.c-bug-removal.patch: Revert "NFS:
  Allow redirtying of a completed unstable write." (442267).
  It causes a BUG().
* Fri Nov  7 2008 nfbrown@suse.de
- patches.kernel.org/md-raid10-recovoery-fix.path: md: fix bug
  in raid10 recovery..
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped..:  Removed much of this patch as it turned out
  to be both buggy and unnecessary (the ioctl can be done from
  mdadm).
* Thu Nov  6 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: ixgbe driver update to add
  Longcove (SFP+) NIC support for FCoE needs (bnc#442411)
* Thu Nov  6 2008 gregkh@suse.de
- enable CONFIG_X86_SUMMIT, CONFIG_X86_ES7000, and CONFIG_X86_BIGSMP
  for the i386 default kernel, so that the installer can actually
  boot on "modern" multiprocessor i386 boxes (bnc#428247)
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install only on x86 and ppc.
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install to install the
  vdso shared objects for debugging.
* Thu Nov  6 2008 jjolly@suse.de
- patches.drivers/intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
- patches.drivers/intel-ibex-peak-device-support.patch: i2c-i801:
  Add support for Intel Ibex Peak (bnc#415383).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: Fixed patch for build
- patches.arch/s390-03-04-qdio_multicast_performance.patch: dasd:
  fix  message flood for unsolicited interrupts (bnc#440610).
- patches.arch/s390-03-05-dasd-block-uevent.patch: dasd: DASD
  uevents are not sent correctly (bnc#440610,LTC#49429).
- patches.arch/s390-03-06-zfcp-hexdump.patch: zfcp: fix hexdump
  data in s390dbf traces (bnc#440610).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: kernel: Fix
  initialization of stp. (bnc#440610,LTC#49639).
- patches.arch/s390-03-02-setup_memory.patch: kernel: Fix range
  for add_active_range() in setup_memory() (bnc#440610,LTC#49639).
- patches.arch/s390-03-03-dasd_unsolicited_interrupt.patch:
  dasd: fix  message flood for unsolicited interrupts
  (bnc#440610,LTC#49639).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-02-10-zfcp-scan-online.patch: wait for port
  scan when setting FCP device online (bnc#434333).
* Thu Nov  6 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.4 and c/s 718.
- Update Xen config files.
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch: Include
  pv-ops-Xen changes here
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: Delete.
- patches.xen/xen-configurable-guest-devices: allow number of
  guest devices to be configurable.
- patches.xen/xen-cpufreq-report: make /proc/cpuinfo track
  CPU speed.
- patches.xen/xen-ipi-per-cpu-irq: fold IPIs onto a single
  IRQ each.
- patches.xen/xen-rtl2860-build: Rename to ...
- patches.xen/xen-rt2860-build: ... this.
- patches.xen/xen-sysdev-suspend: use base kernel suspend/resume
  infrastructure.
- patches.xen/xen-virq-per-cpu-irq: fold per-CPU VIRQs onto a
  single IRQ each.
- patches.xen/xen-x86-mmu-batching: Delete.
- patches.xen/xen3-patch-2.6.27.3-4: Linux 2.6.27.4.
- patches.xen/xen3-x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.xen/xen3-x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.xen/xen3-x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
* Thu Nov  6 2008 sassmann@suse.de
- patches.arch/ppc-ps3-introduce-ps3_gpu_mutex.patch: required for
  new ps3vram patch
- patches.arch/ppc-ps3-ps3vram-mtd.patch: updated ps3vram patch
  that works with firmware 2.50 (bnc#442227)
* Thu Nov  6 2008 olh@suse.de
- remove unneeded BuildRequires for dtc
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: Feature removed
  (bnc#417299)
* Thu Nov  6 2008 gregkh@suse.de
- patches.suse/file-capabilities-add-no_file_caps-switch.patch:
  file capabilities: add no_file_caps switch (v4).
  add the patch back into the tree.
* Wed Nov  5 2008 jblunck@suse.de
- patches.suse/coredump_filter-add-elfhdr-default.patch: Dump
  elf headers to core per default.
* Wed Nov  5 2008 teheo@suse.de
  Fix !CONFIG_DMI case.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
* Wed Nov  5 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: update patch
  to skip all devices with no dma_parms (bnc#431294)
* Wed Nov  5 2008 agruen@suse.de
- rpm/kernel-module-subpackage: Remove the obsolete kernel-$flavor
  dependency (bnc#440961).
* Wed Nov  5 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Removed and replaced with
  v3 of the patch from IBM (bnc#417300)
- patches.arch/s390-01-05-kmsg-v3.patch: Kernel message catalog
  infrastucture and message generation (bnc#417300).
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Patch edited to allow new kmsg patch
* Wed Nov  5 2008 agruen@suse.de
- Update config files: set CONFIG_MODULE_FORCE_LOAD=y to allow
  ignoring ABI mismatches. (This is still unsafe to do!)
* Wed Nov  5 2008 tiwai@suse.de
  Backport fixes from 2.6.28-rc.
- patches.drivers/alsa-hda-acer-quirk: ALSA: hda - Add a quirk
  for another Acer Aspire (1025:0090) (bnc#426935).
- patches.drivers/alsa-hda-alc888-medion-add: ALSA: hda - Add
  a quirk for MEDION MD96630 (bnc#412548).
- patches.drivers/alsa-hda-dell-eq-option: ALSA: hda: make a
  STAC_DELL_EQ option.
- patches.drivers/alsa-hda-proc-gpio-fix: ALSA: hda - Limit the
  number of GPIOs show in proc.
* Wed Nov  5 2008 gregkh@suse.de
- refresh -rt patches to remove fuzz.
* Wed Nov  5 2008 teheo@suse.de
  Backport two more device specific workarounds from 2.6.28-rc.
- patches.drivers/libata-add-and-use-HORKAGE_ATAPI_MOD16_DMA:
  libata: implement ATA_HORKAGE_ATAPI_MOD16_DMA and apply it.
- patches.drivers/libata-whitelist-good-bridges: libata: add
  whitelist for devices with known good pata-sata bridges.
* Wed Nov  5 2008 gregkh@suse.de
- refresh patches to remove fuzz
* Wed Nov  5 2008 teheo@suse.de
  Backport double spin off workaround.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
- patches.drivers/libata-ahci-blacklist-double-spin-off: SATA
  AHCI: Blacklist system that spins off disks during ACPI power
  off (bnc#441721).
- patches.drivers/libata-ata_piix-blacklist-double-spin-off:
  SATA PIIX: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/libata-implement-NO_SPINDOWN: SATA: Blacklisting
  of systems that spin off disks during ACPI power off (rev. 2)
  (bnc#441721).
- patches.drivers/libata-sata_sil-blacklist-double-spin-off:
  SATA Sil: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/power-introduce-system_entering_hibernation:
  Hibernation: Introduce system_entering_hibernation (bnc#441721).
* Wed Nov  5 2008 gregkh@suse.de
- fix rt tree that was broken by 2.6.27.5-rc1
* Wed Nov  5 2008 olh@suse.de
- update patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix booting on ppc32 (bnc#439491 - LTC48584)
* Wed Nov  5 2008 teheo@suse.de
  Backport sata_via fixes from 2.6.28-rc.
- patches.drivers/libata-sata_via-fix-support-for-5287: sata_via:
  fix support for 5287 (bnc#441718).
- patches.drivers/libata-sata_via-load-DEVICE-register-when-CTL-changes:
  sata_via: load DEVICE register when CTL changes (bnc#441718).
- patches.drivers/libata-sata_via-restore-vt-_prepare_host-error-handling:
  sata_via: restore vt*_prepare_host error handling (bnc#441718).
* Wed Nov  5 2008 teheo@suse.de
  Backport laptop table and pci device ID table entries from 2.6.28-rc.
- patches.drivers/libata-ata_piix-add-Hercules-EC-900-mini-to-laptop-tbl:
  ata_piix: add Hercules EC-900 mini-notebook to ich_laptop
  short cable list.
- patches.drivers/libata-ata_piix-add-intel-ibex-pci-ids:
  ata_piix: IDE Mode SATA patch for Intel Ibex Peak DeviceIDs.
* Wed Nov  5 2008 teheo@suse.de
  Backport slave_link from 2.6.28-rc to fix ata_piix probing problem.
- patches.drivers/libata-ata_piix-use-slave_link: ata_piix:
  drop merged SCR access and use slave_link instead (bnc#441420).
- patches.drivers/libata-eh-fix-slave-link-EH-action-mask-handling:
  libata-eh: fix slave link EH action mask handling (bnc#441420).
- patches.drivers/libata-implement-slave_link: libata: implement
  slave_link (bnc#441420).
- patches.drivers/libata-make-SCR-access-ops-per-link: libata:
  make SCR access ops per-link (bnc#441420).
- patches.drivers/libata-misc-updates-to-prepare-for-slave-link:
  libata: misc updates to prepare for slave link (bnc#441420).
- patches.drivers/libata-reimplement-link-iterator: libata:
  reimplement link iterator (bnc#441420).
- patches.drivers/libata-set-device-class-to-NONE-if-phys_offline:
  libata: set device class to NONE if phys_offline (bnc#441420).
- patches.drivers/libata-transfer-EHI-control-flags-to-slave-ehc.i:
  libata: transfer EHI control flags to slave ehc.i (bnc#441420).
* Wed Nov  5 2008 gregkh@suse.de
- Update to 2.6.27.5-rc1:
  - fixes lots of things, including a few CVE entries
  - obsoletes, and caused to be deleted:
  - patches.arch/ppc-pseries_16g-numa.patch
  - patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  - patches.arch/ppc-pseries_mem-limit-16g.patch
  - patches.arch/s390-02-02-smp-sysdev.patch
  - patches.drivers/alsa-hda-reboot-notifier
  - patches.drivers/libata-sata_nv-hardreset-fix
  - patches.fixes/acpi-clear-wake-status.patch
  - patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch
  - patches.suse/file-capabilities-add-no_file_caps-switch.diff
  - patches.suse/file-capabilities-turn-on-by-default.diff
- Update config files.
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/bnx2-Add-bnx2_shutdown_chip: bnx2: Add
  bnx2_shutdown_chip()
- patches.drivers/bnx2-check-running.patch: Check netif_running
  in most ethtool operations    (bnc#440052)
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/ixgbe-copper_pond.patch: ixgbe: add device
  support for 82598AT (copper 10GbE) adapters (bnc#441471)
* Tue Nov  4 2008 tonyj@suse.de
- patches.rt/fork_init_nrcpus.patch: Fix oops in fork_init.
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix typo
* Tue Nov  4 2008 rw@suse.de
- patches.drivers/bnx2x-zero-PMF:
  bnx2x: Removing the PMF indication when unloading.  (bnc#439679)
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: make also -base and -extra x86
  subpackages not installable on x86_64
* Tue Nov  4 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-3-v2.patch: (kernel):FCP -
  Performance Data colletion & analysis patch update (bnc#417243).
- patches.arch/s390-01-04-fcpperf-3.patch: Removed for update
* Tue Nov  4 2008 miklos@szeredi.hu
- patches.apparmor/d_namespace_path_oops_fix.diff: fix oops in
  d_namespace_path (bnc#433504).
* Tue Nov  4 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: scsi_lib_dma.c :
  fix bug w/ dma on virtual fc ports (bnc#431294).
* Tue Nov  4 2008 sdietrich@suse.de
- Update RT config files: Enable CONFIG_NO_HZ on i386/rt_debug.
  - Refresh config files.
* Tue Nov  4 2008 teheo@suse.de
- patches.drivers/libata-fix-last_reset-timestamp-handling:
  libata: fix last_reset timestamp handling (bnc#441340).
* Tue Nov  4 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01-k9-update: Update qla2xxx to
  8.02.01-k9 (bnc#439208).
* Tue Nov  4 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Compile fix.
* Mon Nov  3 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy-fixes: ALSA: emu10k1 -
  Add more invert_shared_spdif flag to Audigy models (bnc#440862).
- patches.drivers/alsa-hda-alc269-fsc-amilo: ALSA: hda - Add
  ALC269 fujitsu model (bnc#440626).
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Update dmraid45.
* Mon Nov  3 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Fix dm table
  ref count (FATE#304489).
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach (bnc#440980).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach.
* Mon Nov  3 2008 olh@suse.de
- add patches.arch/ppc-clock_gettime-nanoseconds.patch
  update also nanoseconds (bnc#439908 - LTC49499)
* Mon Nov  3 2008 teheo@suse.de
- scripts/vc: s/GIT_COMMITER_EMAIL/GIT_COMMITTER_EMAIL and add
  SUSE_COMMITTER_EMAIL.
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression (bnc#429344).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files: enable more lock debugging,
  latency features, make x86_64 and i386 consistent.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/kprobes_make_pointer_decl_consistent.patch: Make
  kprobe locking consistent with lock-type declarations
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
  Use raw_smp_processor_id in __mem_cgroup_stat_add_safe.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/workqueue-introduce-create_rt_workqueue.patch:
  workqueue: introduce create_rt_workqueue. (from 2.6.28)
  Refresh to eliminate fuzz:
  - patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 sdietrich@suse.de
- Update RT config files:
  - Sync with SLES 11 default/debug configs
  - Limit CPUS to 32
  - Disable CONFIG_RADIX_TREE_CONCURRENT
  - Disable CONFIG_RADIX_TREE_OPTIMISTIC
  - Disable CONFIG_PREEMPT_RCU_BOOST
  - Enable CONFIG_RTMUTEX_CHECK
- Adapt RT patches to changes made by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/mitigate-resched-flood-update.patch: Update
    smp_send_reschedule_allbutself_cpumask mask parameter.
  - patches.rt/x86-nmi-send_IPI_mask-pointer-fix.patch: Update
    smp_send_nmi_allbutself  mask parameter.
  Resolve conflicts introduced by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/nmi-profiling-base.patch
  - patches.rt/send-nmi-all-preempt-disable.patch
  Refresh to eliminate fuzz
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 bwalle@suse.de
- patches.fixes/kdb-fix-stack-overflow.patch:
  kdb: fix stack overflow for large NR_CPUS count (bnc#440361).
* Fri Oct 31 2008 trenn@suse.de
  Fate 304268 and 304266. SGI scir driver (replaces the more intrusive
  leds one) and the rather intrusive x86_64 4096 CPU support patches:
- Update config files.
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
- patches.arch/x86_sgi-uv-scir.patch: SGI X86 UV: Provide a
  System Activity Indicator driver (FATE304268 bnc#426066).
- patches.arch/x86_sgi_cpus4096-01-fix-smp_call_function.patch:
  smp: reduce stack requirements for smp_call_function_mask
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
- patches.arch/x86_sgi_cpus4096-06-optimize-cpumask-in-sched_c.patch:
  Additional cpumask fixups (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-04-add-for_each_cpu_mask_and.patch:
  Add for_each_cpu_mask_and (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-07_pae_compile_fixups.patch:
  more cpumask cleanups for previous (x86_sgi_cpu4096..) patches
  (Additional cpumask fixups).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc8-x86-1 (FATE#303971).
- patches.xen/xen3-patch-2.6.27: Linux: Update to 2.6.27.
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: x86 cpumask xen:
  Updates to support NR_CPUS=4096 (Additional cpumask fixups).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-alc269-dmic: ALSA: hda -
  Add digital-mic for ALC269 auto-probe mode (bnc#440626).
- patches.drivers/alsa-hda-realtek-mic-automute-fix: ALSA: hda -
  Disable broken mic auto-muting in Realtek codes (bnc#440626).
* Fri Oct 31 2008 hare@suse.de
- Update config files.
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3-private-iscsi-ip-addresses: cxgb3 -
  manage private iSCSI IP addresses (FATE#304154,bnc#433500).
- patches.drivers/open-iscsi-offloading-support: support for iscsi
  pdu digest offload and payload DDP. (FATE#304154,bnc#433500).
- patches.fixes/cxgb3-remove-duplicate-tests-in-lro: cxgb3 -
  remove duplicate tests in lro (FATE#304154, bnc#430538).
- supported.conf: Mark cxgb3i as supported.
* Fri Oct 31 2008 bwalle@suse.de
- patches.suse/kdb-resolve-uv-conflict.diff:
  Resolve KDB conflicts with UV (bnc#440376).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-spdif-fix: ALSA: hda -
  Fix SPDIF mute on IDT/STAC codecs.
- patches.drivers/alsa-hda-reboot-notifier: ALSA: hda - Add
  reboot notifier.
* Fri Oct 31 2008 jack@suse.cz
- patches.suse/ocfs2-Fix-mount-cleanup-after-quota-failure.patch:
  ocfs2: Fix mount cleanup after quota failure (fate#302681).
- patches.suse/ocfs2-Fix-oop-in-recovery-without-quotas:
  ocfs2: Fix recovery of nodes when quota feature is disabled
  (fate#302681).
- patches.suse/ocfs2-Fix-grace-time-syncing.patch: ocfs2: Fix
  grace time syncing (fate#302681).
* Fri Oct 31 2008 teheo@suse.de
- patches.drivers/block-del-timer-after-dequeue: blk: move
  blk_delete_timer call in end_that_request_last (bnc#440076
  bnc#440173).
* Thu Oct 30 2008 trenn@suse.de
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Avoid oops
  on G33 in 1MB stolen Mem case (bnc#391261).
* Thu Oct 30 2008 gregkh@suse.de
- patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch:
  agp: Fix stolen memory counting on G4X. (bnc#437618).
* Thu Oct 30 2008 oneukum@suse.de
- patches.fixes/sd_liberal_28_sense_invalid.diff: fix medium
  presence misdetection in usb storage device  (bnc#362850).
* Thu Oct 30 2008 olh@suse.de
- add patches.fixes/scsi-ibmvscsi-show-config.patch
  use 4k buffer to transfer config data (439970 - LTC49349)
* Thu Oct 30 2008 teheo@suse.de
- patches.drivers/block-add-timeout-on-dequeue: block: add timer
  on blkdev_dequeue_request() not elv_next_request() (bnc#440076).
* Wed Oct 29 2008 sdietrich@suse.de
  Refresh RT patches:
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT (debug
  builds).
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/partreadd-lttng-instrumentation-irq.patch: readd
  RT compatible version of lttng-instrumentation-irq.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/start_irq_thread.patch: Linux-RT 2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
* Wed Oct 29 2008 gregkh@suse.de
- s/rtl2860/rt2860/
- remove driver from the Xen build as it's dying for some reason.
- add obsoletes for ralink-rt2860-kmp
* Wed Oct 29 2008 olh@suse.de
- update patches.arch/ppc-oprofile-spu.patch
  add missing ARRAY_SIZE(pm_signal_local)
* Wed Oct 29 2008 hare@suse.de
- patches.arch/s390-symmetrix-ioctl.patch: Add ioctl support
  for EMC Symmetrix Subsystem Control I/O (bnc#439221)
* Wed Oct 29 2008 jbeulich@suse.de
- patches.xen/xen-rtl2860-build: fix issue with Windows-style
  types used in rtl2680.
* Wed Oct 29 2008 olh@suse.de
- build af_packet as a module on powerpc (bnc#433540)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu-mutex-locking.patch
  Fix mutex locking for cell spu-oprofile (bnc#422501 - LTC47617)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu.patch
  fix local array size in activate spu profiling function (bnc#439553 - LTC48925)
* Wed Oct 29 2008 olh@suse.de
- update patches.drivers/ehea.patch
  Add hugepage detection (bnc#439599 - LTC48958)
* Wed Oct 29 2008 gregkh@suse.de
- patches.drivers/staging-add-agnx-wireless-driver.patch: Staging:
  add agnx wireless driver.
- patches.drivers/staging-add-otus-atheros-wireless-network-driver.patch:
  Staging: add otus Atheros wireless network driver.
- patches.drivers/staging-add-rtl2860-wireless-driver.patch:
  Staging: add rtl2860 wireless driver (bnc#437959).
- Update config files.
* Tue Oct 28 2008 jkosina@suse.de
- patches.suse/silent-stack-overflow-2.patch: disabled, as it
  causes kernel hangs triggered by grub (bnc#439448).
* Tue Oct 28 2008 kkeil@suse.de
- update patches.suse/SoN-17-net-ps_rx.patch
  fix i/o corruption on rx in ixgbe (bnc#438929)
* Tue Oct 28 2008 jdelvare@suse.de
- config/powerpc/*: Fixup configuration files after last change.
* Tue Oct 28 2008 jdelvare@suse.de
- config/*: Include many multimedia drivers which has been dropped
  accidentally. This includes the pwc, ivtv, zr36067 drivers and
  many old webcam drivers (bnc#439489).
- supported.conf: Add all these drivers again.
* Tue Oct 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-analog-update,
  patches.drivers/alsa-hda-atihdmi-update,
  patches.drivers/alsa-hda-beep,
  patches.drivers/alsa-hda-hp-mobile-fix,
  patches.drivers/alsa-hda-nvidia-hdmi,
  patches.drivers/alsa-hda-probe-fix,
  patches.drivers/alsa-hda-proc-fix,
  patches.drivers/alsa-hda-realtek-update,
  patches.drivers/alsa-hda-sigmatel-update,
  patches.drivers/alsa-hda-spdif-slave,
  patches.drivers/alsa-hda-via-rec-fix,
  patches.drivers/alsa-hda-via-update:
    ALSA updates, mostly taken from 2.6.28-rc1 patches
- Update config files.
* Tue Oct 28 2008 jdelvare@suse.de
- Actually CONFIG_SND_HDA_HWDEP is a boolean, sorry.
* Tue Oct 28 2008 jdelvare@suse.de
- config/ia64/vanilla, config/x86_64/vanilla: fix configuration
  discrepancy, CONFIG_SND_HDA_HWDEP=m.
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-pcibios_allocate_bus_resources.patch
  add patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix DLPAR on pseries (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-powerpc-fix-pci-unmap-io.patch
  Fix unmapping of IO space on 64-bit (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- update ps3 config, remove unneeded options to reduce vmlinux size
* Tue Oct 28 2008 neilb@suse.de
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped. (fate#303894).
* Tue Oct 28 2008 gregkh@suse.de
- use the panasonic laptop driver that was accepted by upstream, not the
  pcc-acpi driver, which was rejected:
  - patches.drivers/staging-add-pcc-acpi-driver.patch: Delete.
  - patches.drivers/panasonic-laptop-add-panasonic-let-s-note-laptop-extras-driver-v0.94.patch:
    panasonic-laptop: add Panasonic Let's Note laptop extras
    driver v0.94.
- Update config files.
* Mon Oct 27 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Via Framebuffer
  driver.
- Update config files.
* Mon Oct 27 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff:
  Don't change permission of sysfs file (did that accidentally
  when changing the default value).
* Mon Oct 27 2008 trenn@suse.de
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
* Mon Oct 27 2008 tj@suse.de
  Refresh the govault patch.
- patches.drivers/libata-add-waits-for-govault: libata: add
  waits for GoVault (bnc#246451).
* Sun Oct 26 2008 bwalle@suse.de
- patches.fixes/kdb-oops-panic.diff:
  Fix NULL pointer dereference when regs == NULL (bnc#439007).
- patches.fixes/hpwdt-kdump.diff:
  Fix kdump when using hpwdt (bnc#436786).
* Sun Oct 26 2008 gregkh@suse.de
- refresh patches to apply cleanly and properly.
* Sun Oct 26 2008 gregkh@suse.de
- Update to 2.6.27.4
* Sat Oct 25 2008 agruen@suse.de
- Fix the dependencies between the split kernel packages and KMPs
  (FATE 303631).
- Fix for kernel paclages which are not split.
- rpm/kernel-source.spec.in: Update list of scripts to include.
* Sat Oct 25 2008 jjolly@suse.de
- patches.arch/s390-02-02-smp-sysdev.patch: kernel: sysdev class
  file creation (bnc#434333)
- patches.arch/s390-02-03-zfcp.patch: Fix zfcp problems that have
  been found (bnc#434333)
- patches.arch/s390-02-04-qeth-mac.patch: qeth: use firmware
  MAC-address for layer2 hsi-devices (bnc#434333)
- patches.arch/s390-02-05-qeth-recovery.patch: qeth: qeth recovery
  fails (bnc#434333)
- patches.arch/s390-02-06-qeth-offset.patch: qeth: fix offset error
  in non prealloc header path (bnc#434333,LTC#48840)
- patches.arch/s390-02-07-qeth-ipv6check.patch: qeth: remove
  unnecessary support ckeck in sysfs route6 (bnc#434333)
- patches.arch/s390-02-08-qeth-panic.patch: qeth: avoid
  skb_under_panic for malformatted inbound data (bnc#434333)
- patches.arch/s390-02-09-tape-lock.patch: tape device driver:
  improve locking (bnc#434333)
* Sat Oct 25 2008 neilb@suse.de
- patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
  touch_mnt_namespace when the mount flags change (FATE#304218).
* Fri Oct 24 2008 gregkh@suse.de
- Updated to 2.6.27.4-rc3:
  - fixed ath5k suspend/resume regression
  - fixed pvrusb2 so it actually works
* Fri Oct 24 2008 jack@suse.cz
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681). - fixed 64-bit division
* Fri Oct 24 2008 jeffm@suse.de
- Update config files for -rt.
* Fri Oct 24 2008 hare@suse.de
- patches.suse/cgroup-freezer.patch: Add TIF_FREEZE for s390.
* Fri Oct 24 2008 olh@suse.de
- move patches.suse/md-raid-metadata-PAGE_SIZE.patch
  to patches.kernel.org/md-raid-metadata-PAGE_SIZE.patch
  to allow raid0 with 64k PAGE_SIZE
* Fri Oct 24 2008 jack@suse.cz
- Update config files.
- supported.conf: Added new quota module
- patches.suse/xfs-dmapi-enable: Enable XFS DMAPI. - Refreshed
  Quotas for OCFS2:
- patches.suse/quota-Add-callbacks-for-allocating-and-destroying-d.patch:
  quota: Add callbacks for allocating and destroying dquot
  structures (fate#302681).
- patches.suse/quota-Increase-size-of-variables-for-limits-and-ino.patch:
  quota: Increase size of variables for limits and inode usage
  (fate#302681).
- patches.suse/quota-Remove-bogus-optimization-in-check_idq-an.patch:
  quota: Remove bogus 'optimization' in check_idq() and
  check_bdq() (fate#302681).
- patches.suse/quota-Make-_SUSPENDED-just-a-flag.patch: quota:
  Make _SUSPENDED just a flag (fate#302681).
- patches.suse/quota-Allow-to-separately-enable-quota-accounting-a.patch:
  quota: Allow to separately enable quota accounting and enforcing
  limits (fate#302681).
- patches.suse/ext3-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext3: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/ext4-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext4: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/reiserfs-Use-sb_any_quota_loaded-instead-of-sb_an.patch:
  reiserfs: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled(). (fate#302681).
- patches.suse/quota-Remove-compatibility-function-sb_any_quota_en.patch:
  quota: Remove compatibility function sb_any_quota_enabled()
  (fate#302681).
- patches.suse/quota-Introduce-DQUOT_QUOTA_SYS_FILE-flag.patch:
  quota: Introduce DQUOT_QUOTA_SYS_FILE flag (fate#302681).
- patches.suse/quota-Move-quotaio_v-12-.h-from-include-linux-to-f.patch:
  quota: Move quotaio_v[12].h from include/linux/ to fs/
  (fate#302681).
- patches.suse/quota-Split-off-quota-tree-handling-into-a-separate.patch:
  quota: Split off quota tree handling into a separate file
  (fate#302681).
- patches.suse/quota-Convert-union-in-mem_dqinfo-to-a-pointer.patch:
  quota: Convert union in mem_dqinfo to a pointer (fate#302681).
- patches.suse/quota-Allow-negative-usage-of-space-and-inodes.patch:
  quota: Allow negative usage of space and inodes (fate#302681).
- patches.suse/quota-Keep-which-entries-were-set-by-SETQUOTA-quota.patch:
  quota: Keep which entries were set by SETQUOTA quotactl
  (fate#302681).
- patches.suse/quota-Add-helpers-to-allow-ocfs2-specific-quota-ini.patch:
  quota: Add helpers to allow ocfs2 specific quota initialization,
  freeing and recovery (fate#302681).
- patches.suse/quota-Implement-function-for-scanning-active-dquots.patch:
  quota: Implement function for scanning active dquots
  (fate#302681).
- patches.suse/ocfs2-Fix-check-of-return-value-of-ocfs2_start_tran.patch:
  ocfs2: Fix check of return value of ocfs2_start_trans()
  (fate#302681).
- patches.suse/ocfs2-Support-nested-transactions.patch: ocfs2:
  Support nested transactions (fate#302681).
- patches.suse/ocfs2-Fix-checking-of-return-value-of-new_inode.patch:
  ocfs2: Fix checking of return value of new_inode()
  (fate#302681).
- patches.suse/ocfs2-Let-inode-be-really-deleted-when-ocfs2_mknod_.patch:
  ocfs2: Let inode be really deleted when ocfs2_mknod_locked()
  fails (fate#302681).
- patches.suse/ocfs2-Assign-feature-bits-and-system-inodes-to-quot.patch:
  ocfs2: Assign feature bits and system inodes to quota feature
  and quota files (fate#302681).
- patches.suse/ocfs2-Mark-system-files-as-not-subject-to-quota-acc.patch:
  ocfs2: Mark system files as not subject to quota accounting
  (fate#302681).
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681).
- patches.suse/ocfs2-Add-quota-calls-for-allocation-and-freeing-of.patch:
  ocfs2: Add quota calls for allocation and freeing of inodes
  and space (fate#302681).
- patches.suse/ocfs2-Enable-quota-accounting-on-mount-disable-on.patch:
  ocfs2: Enable quota accounting on mount, disable on umount
  (fate#302681).
- patches.suse/ocfs2-Implement-quota-syncing-thread.patch: ocfs2:
  Implement quota syncing thread (fate#302681).
- patches.suse/ocfs2-Implement-quota-recovery.patch: ocfs2:
  Implement quota recovery (fate#302681).
* Fri Oct 24 2008 kkeil@suse.de
- patches.fixes/cxgb3_fix_race_in_EEH: cxgb3: fix race in EEH.
  (bnc#430093)
* Fri Oct 24 2008 jeffm@suse.de
- Refreshed context for -RT patches so they apply again.
* Fri Oct 24 2008 rw@suse.de
- patches.drivers/sgi-ioc4-request-submodules:
  Make ioc4 request dependant modules.  (bnc#429215)
* Fri Oct 24 2008 hare@suse.de
- Update config files: Disable FAIL_MAKE_REQUEST.
* Fri Oct 24 2008 tiwai@suse.de
- patches.drivers/alsa-usb-exclude-1st-slot: Delete this old ugly
  workaround patch.
* Fri Oct 24 2008 hare@suse.de
- Include patches from upstream:
  - patches.fixes/block-use-bio_has_data: Implement bio_has_data().
  - patches.fixes/block-git-fixes: Block layer fixes for 2.6.28.
  - patches.fixes/block-rq-affinity: Implement rq affinity.
  - patches.fixes/dm-mpath-remove-is_active: dm mpath: remove
    is_active from struct dm_path.
  - patches.fixes/block-discard-requests: Implement block discard.
  - patches.drivers/dm-abort-queue-on-failed-paths: dm: Call
    blk_abort_queue on failed paths (bnc#417544).
  - patches.drivers/block-call-sync-on-cleanup: block:
    blk_cleanup_queue() should call blk_sync_queue().
- Refaktor and update request-based multipath patches:
  - patches.drivers/blk-request-based-multipath-update:
    Update request-based multipathing patches to upstream version
    (bnc#434105).
  - patches.suse/rq-based-multipath: Update to latest version
    of request-based multipathing patchset (bnc#434105)
  - patches.drivers/block-abort-request-rq-complete-marking:
    use rq complete marking in blk_abort_request (bnc#434105).
  - patches.fixes/scsi-atomic-blk-timer-deletes: Delete.
  - patches.fixes/dm-mpath-abort-queue: Delete.
  - patches.suse/rq-based-block-layer: Delete.
  - patches.suse/rq-based-dm-interface: Delete.
  - patches.suse/rq-based-multipath-functions: Delete.
  - patches.suse/rq-based-init-crash: Delete.
- Update patches to upstream version:
  - patches.drivers/bdev-resize-check-for-device-resize
  - patches.drivers/bdev-resize-added-flush_disk
  - patches.drivers/bdev-resize-call-flush_disk
  - patches.drivers/bdev-resize-sd-driver-calls
  - patches.drivers/block-timeout-handling
  - patches.drivers/bdev-resize-adjust-block-device-size
  - patches.drivers/bdev-resize-wrapper-for-revalidate_disk
  - patches.drivers/block-abort-queue
  - patches.fixes/scsi-enhance-error-codes
- Rediff patches:
  - patches.fixes/scsi-misc-git-update
  - patches.suse/dm-barrier-single-device
  - patches.suse/kdb-common
  - patches.drivers/lpfc-8.2.8-update
  - patches.drivers/lpfc-8.2.8.3-update
  - patches.drivers/mpt-fusion-4.00.43.00-update
* Fri Oct 24 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch: Add sysctl also
  to kernel/sysctl_check.c.
* Fri Oct 24 2008 bwalle@suse.de
- Obsolete uvcvideo-kmp.
* Fri Oct 24 2008 jbeulich@suse.de
- rpm/kernel-binary.spec.in: Provide 'kernel' also for Xen (bnc#362918).
* Fri Oct 24 2008 jbeulich@suse.de
- patches.arch/x86_64-unwind-annotations: fix unwind annotations.
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind
  annotations.
* Fri Oct 24 2008 jbeulich@suse.de
- Update Xen patches to 2.6.27.3 and c/s 704
- patches.xen/xen3-x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.xen/xen3-x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.xen/xen-kconfig-compat-3.2.0: add 3.2.0-compatibility
  configure option.
- patches.xen/xen-x86-exit-mmap: be more aggressive about
  de-activating mm-s under destruction.
- patches.xen/xen-x86-machphys-prediction: properly predict
  phys<->mach translations.
- patches.xen/xen-x86-mmu-batching: utilize
  arch_{enter,leave}_lazy_cpu_mode().
- patches.xen/xen-x86-no-lazy-tlb: ensure inadvertent uses of
  lazy TLB data are caught during the build.
- Update Xen config files.
* Fri Oct 24 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - do not split kernel-kdump into -base and -extra
  - fix case when a build results in no unsupported modules
* Fri Oct 24 2008 bwalle@suse.de
- patches.fixes/kdb-kdump.diff:
  Fix CONFIG_KDB_KDUMP on xSeries (bnc#436454).
* Fri Oct 24 2008 agruen@suse.de
- supported.conf: Mark dmapi as supported (by SGI).
* Fri Oct 24 2008 olh@suse.de
- disable all unsupported drivers in kernel-kdump
* Fri Oct 24 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap (bnc#44807 bnc#211997).
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc2
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_SYSFS_DEPRECATED_V2 from powerpc/rt config file
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc1
  - lots of bugfixes, and obsoletes some current patches:
  - patches.fixes/ext3-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/ext2-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/wdm_autoload.diff: Delete.
* Fri Oct 24 2008 npiggin@suse.de
- Fix ppc and ps3 configs
* Fri Oct 24 2008 npiggin@suse.de
- Update config files.
- patches.suse/cgroup-freezer.patch: cgroup freezer (bnc#417294,
  fate#304191, fate#201036).
* Fri Oct 24 2008 npiggin@suse.de
- Update config files. Enable cgroups for all archs (bnc#417527)
* Fri Oct 24 2008 npiggin@suse.de
- patches.arch/ppc-gigantic-page-fix2.patch: powerpc gigantic
  pages fix 2 (bnc#434026).
- patches.arch/ppc-gigantic-page-fix3.patch: powerpc gigantic
  pages fix 3 (bnc#434026).
- patches.trace/lttng-instrumentation-hugetlb.patch: de-fuzz
* Fri Oct 24 2008 gregkh@suse.de
- disabled CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64
  vanilla kernel.
* Fri Oct 24 2008 gregkh@suse.de
- patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  cciss: fix procfs firmware regression (bnc435644).
- patches.drivers/cciss-fix-sysfs-symlink.patch: cciss: fix
  sysfs symlink (bnc435644).
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64.  To use
  Calgary iommu systems, you now must manually pass "iommu=calgary" to
  get this hardware support back enabled.  This is the recommended
  proceedure right now, from IBM, otherwise the hardware crashes.
  bnc#436450.
* Fri Oct 24 2008 gregkh@suse.de
- clean up all fuzz in patches to get them to apply cleanly.
* Thu Oct 23 2008 gregkh@suse.de
- delete patches.arch/s390-01-03-cmm2-v2.patch as it touched core
  kernel code and was rejected from upstream.
  - patches.arch/s390-01-03-cmm2-v2.patch: Delete.
  - patches.arch/s390-01-03-cmm2-v2a.patch: Delete.
* Thu Oct 23 2008 gregkh@suse.de
- Update to version 3.4 of squashfs:
  - patches.suse/squashfs3.3-patch: Delete.
  - patches.suse/squashfs-patch-2.6.25: Delete.
  - patches.suse/squashfs-patch-2.6.27: Delete.
  - patches.suse/squashfs-3.4.patch: squashfs v3.4.
* Thu Oct 23 2008 jeffm@suse.de
- patches.fixes/block-sanitize-invalid-partition-table-entries:
  block: sanitize invalid partition table entries (bnc#371657).
* Thu Oct 23 2008 olh@suse.de
- add patches.arch/ppc-pseries_mem-limit-16g.patch
  Don't use a 16G page if beyond mem= limits (bnc#438111 - LTC49329)
* Thu Oct 23 2008 kkeil@suse.de
- Update x86 64bit config files to include WAN support (bnc#437692)
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/cell_edac.patch
  Fix incorrect edac_mode in csrow causing oops (bnc#437757 - LTC49143)
* Thu Oct 23 2008 olh@suse.de
- update patches.suse/nameif-track-rename.patch
  print also application and pid
* Thu Oct 23 2008 jkosina@suse.de
- patches.fixes/hid-rdesc-quirk-for-sony-vaio-VGX-TP1E.patch:
  HID: Fix Sony Vaio VGX report descriptor (bnc#437758).
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch
  reject dynamic memory add/remove (bnc#434651 - LTC48744)
* Thu Oct 23 2008 npiggin@suse.de
- Update config files.
* Thu Oct 23 2008 npiggin@suse.de
- patches.suse/x86-gb-linear-map.patch: Enable GB mapped linear
  KVA on x86 (bnc#437674).
- patches.xen/xen3-patch-2.6.26: merge
* Wed Oct 22 2008 gregkh@suse.de
- update to 2.6.27.3
  - lots of bugfixes
  - CVE-2008-3831 fix
* Wed Oct 22 2008 jeffm@suse.de
- scripts/vc: Handle unset $EDITOR
* Wed Oct 22 2008 jeffm@suse.de
- patches.suse/export-release_open_intent: Export
  release_open_intent for NFS branches with aufs.
* Wed Oct 22 2008 jdelvare@suse.de
- supported.conf: Mark the ibmaem and ibmpex hwmon drivers as
  supported by IBM.
- supported.conf: Mark the i5k_amb hwmon driver as supported.
* Wed Oct 22 2008 olh@suse.de
- add patches.drivers/ehea.patch
  Fix memory hotplug support (436447 - LTC48713)
* Wed Oct 22 2008 olh@suse.de
- add patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  Cleanup hugepage pagetable allocation (bnc# 433503 - LTC48757)
* Wed Oct 22 2008 sassmann@suse.de
  Add PS3 audio patches:
- patches.arch/ppc-ps3-add-passthrough-support-for-non-audio-streams.patch:
  ps3: Add passthrough support for non-audio streams.
- patches.arch/ppc-ps3-add-ps3av-audio-mute-analog.patch:
  ps3: Add ps3av_audio_mute_analog().
- patches.arch/ppc-ps3-add-support-for-SPDIF-HDMI-passthrough.patch:
  ps3: Add support for SPDIF/HDMI passthrough.
* Tue Oct 21 2008 sdietrich@suse.de
- patches.rt/genirq-usb.patch: Make status_cache u32
- patches.rt/genirq-ohci1394.patch: Enable ohci1394 IRQ
  threading.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: rediff.
- patches.fixes/scsi-atomic-blk-timer-deletes: scsi: atomic blk
  timer deletes (LTC#48990, bnc#434105).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  rediff.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/scsi-inquiry-too-short-ratelimit: INQUIRY result
  too short (5) message flood (bnc#432535).
* Tue Oct 21 2008 npiggin@suse.de
- patches.suse/filp-slab-rcu: Delete.
* Tue Oct 21 2008 sdietrich@suse.de
  USB IRQ threading (experimental: guarded by genirq):
- patches.rt/genirq1-make-irqreturn_t-an-enum: genirq: make
  irqreturn_t an enum.
- patches.rt/genirq2-add-quick-check-handler.patch: genirq:
  add a quick check handler.
- patches.rt/genirq3-add-threaded-irq-handler-support: genirq:
  add threaded interrupt handler support.
- patches.rt/genirq4-add-helper-to-check-whether-irq-thread-should-run:
  genirq: add a helper to check whether the irqthread should run.
- patches.rt/genirq5-make-irq-threading-robust: genirq: make
  irq threading robust.
- patches.rt/genirq-usb.patch: genirq threading for ehci, ohci
  and uhci USB hosts..
- patches.rt/genirq-wlan-ng-compat.patch: Remove redundant,
  obsolete 2.4 compatibility code in wlan-ng.
  Ack:
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
* Mon Oct 20 2008 gregkh@suse.de
- patches.arch/x2APIC_PATCH_x86-mach_apicdef.h-need-to-include-before-smp.h.patch:
  x86: mach_apicdef.h need to include before smp.h.
  fixes build error on i386 pae kernels.
* Mon Oct 20 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch:
  Add dump_after_notifier sysctl (bnc#436678).
* Mon Oct 20 2008 gregkh@suse.de
- scripts/wd-functions.sh: reverse git and cvs checks (check for
  cvs before git).  This solves the problem if you are using a cvs
  tree, yet it happens to live in a directory that way up the
  directory chain is in a git tree (like for people who keep portions
  of their $HOME in git).
* Mon Oct 20 2008 gregkh@suse.de
- Update config files: enable CONFIG_GENERICARCH and CONFIG_BIGSMP
  on i386-pae kernels. (bnc#428247)
* Mon Oct 20 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: fix the order of arguments in
  /proc/$pid/syscall on x86_64.
* Mon Oct 20 2008 bwalle@suse.de
- Update config files: Enable CONFIG_KVM_KMP for RT config, run
  oldconfig.
* Mon Oct 20 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff: Correct to reflect mainline
  state.
* Mon Oct 20 2008 hare@suse.de
- Update config files.
- patches.suse/kvm-as-kmp: Allow KVM to be built as KMP
  (FATE#303679).
* Mon Oct 20 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Instrument the kernel
  components such that a kernel message catalog as well as related
  man pages can be automatically generated. (bnc#417300)
- patches.arch/s390-01-06-zfcp-cleanup-v2.patch: Update patch to
  fit on recent kmsg patch changes. (bnc#417550)
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Update patch to fit on recent kmsg patch changes.
- config/s390/{default,s390}: Added CONFIG_KMSG_IDS=y
* Mon Oct 20 2008 bwalle@suse.de
- supported.conf: Mark 'crasher' as supported to avoid installing
  the "extra" package only for that module.
* Mon Oct 20 2008 olh@suse.de
- add patches.arch/ppc-pseries_16g-numa.patch
  fix crash with more 2 numa nodes and 16G hugepage (bnc#436452 - LTC48839)
* Sat Oct 18 2008 gregkh@suse.de
- Update to 2.6.27.2.
  - lots of bugfixes
* Sat Oct 18 2008 tonyj@suse.de
- patches.rt/fix-preempt-none.patch: Fix preempt-none build
  errors
* Fri Oct 17 2008 jeffm@suse.de
- patches.suse/SoN-20-netvm-reserve-inet.patch-fix: SoN: Fix
  initialization of ipv4_route_lock (bnc#435994).
* Fri Oct 17 2008 kkeil@suse.de
- patches.drivers/tg3-Add-57780-ASIC-revision.patch: tg3: Add
  57780 ASIC revision. (bnc#434147)
- patches.drivers/broadcom-Add-support-for-the-57780-integrated-PHY.patch:
  broadcom: Add support for the 57780 integrated PHY. (bnc#434147)
- patches.drivers/bnx2x-eeh.patch: bnx2x: EEH recovery fix.(bnc#433875)
* Fri Oct 17 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: Add the auto-generated (by mkdumprd)
  kdump initrd to %%ghost so that the file gets removed when
  uninstalling the kernel.
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 ACL / security attribute support
  - patches.suse/ocfs2-Remove-unused-function-restore_extent_block.patch
  - patches.suse/ocfs2-Merge-transactions-during-xattr-set.patch
  - patches.suse/ocfs2-xattr.-ch-definition-cleanups.patch
  - patches.suse/ocfs2-Add-security-xattr-support-in-ocfs2.patch
  - patches.suse/ocfs2-Add-POSIX-ACL-support-in-ocfs2.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 fixes / updates from 2.6.28 merge window
  - patches.suse/ocfs2-xattr.c-Fix-a-bug-when-inserting-xattr.patch
  - patches.suse/ocfs2-Add-empty-bucket-support-in-xattr.patch
  - patches.suse/ocfs2-Remove-pointless.patch
  - patches.suse/ocfs2-make-la_debug_mutex-static.patch
  - patches.suse/ocfs2-Documentation-update-for-user_xattr-nouser_.patch
  - patches.suse/ocfs2-use-smaller-counters-in-ocfs2_remove_xattr_cl.patch
  - patches.suse/ocfs2-Don-t-check-for-NULL-before-brelse.patch
  - patches.suse/ocfs2-Uninline-ocfs2_xattr_name_hash.patch
  - patches.suse/ocfs2-Move-trusted-and-user-attribute-support-into.patch
  - patches.suse/ocfs2-Calculate-EA-hash-only-by-its-suffix.patch
  - patches.suse/ocfs2-Refactor-xattr-list-and-remove-ocfs2_xattr_ha.patch
  - patches.suse/ocfs2-Separate-out-sync-reads-from-ocfs2_read_block.patch
  - patches.suse/ocfs2-Require-an-inode-for-ocfs2_read_block-s.patch
  - patches.suse/ocfs2-Simplify-ocfs2_read_block.patch
  - patches.suse/ocfs2-Move-ocfs2_bread-into-dir.c.patch
  - patches.suse/ocfs2-Kill-the-last-naked-wait_on_buffer-for-cach.patch
  - patches.suse/ocfs2-Make-cached-block-reads-the-common-case.patch
  - patches.suse/ocfs2-fix-build-error.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 dynamic local alloc patches
* Thu Oct 16 2008 jslaby@suse.de
- patches.drivers/tpm-bcm0102-workaround.patch: tpm: work around
  bug in Broadcom BCM0102 chipset (bnc#425747 FATE304221).
- patches.drivers/tpm-correct-timeouts.patch: tpm: correct tpm
  timeouts to jiffies conversion (bnc#425747 FATE304221).
* Thu Oct 16 2008 ihno@suse.de
- added patches.arch/s390-01-03-cmm2-v2a.patch
  fix the sequence of initilisations.
* Thu Oct 16 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Make the kernel-$flavor-extra packages
  supplement kernel-$flavor on openSUSE and SLED so that those
  packages will get installed by default, using the product(...)
  dependencies provided by the *-release packages.
* Thu Oct 16 2008 tonyj@suse.de
- Previous checkin was totally broken wrt rt config files.
  Revert to previous versions and incorporate any changes from
  run_oldconfig. Sole changes to previous versions is to remove
  CONFIG_DYNAMIC_FTRACE from rt_debug configs which is consistent
  with change in 2.6.27.1
* Thu Oct 16 2008 gregkh@suse.de
- Update to 2.6.27.1
  - disables a problem config option, only affected the vanilla,
    debug, and rt kernel variants.
* Wed Oct 15 2008 olh@suse.de
- add patches.arch/ppc-pseries_pfn-mem-rm.patch
  fix hotplug memory remove (bnc#435181 - LTC48640)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: run weak-modules, depmod and mkinitrd
  on older distros (bnc#435246)
  Fixed fix for bnc#435104 ("/boot/" was missing in some places)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't recommend the -extra subpackage
  (fate#303631)
- rpm/postun.sh, rpm/post.sh: remove the temporary workaround
* Wed Oct 15 2008 olh@suse.de
- drop patches.arch/ppc-iseries-remove-AVAILABLE_VETH.patch
  not needed anymore
* Wed Oct 15 2008 nfbrown@suse.de
- patches.fixes/nfs-file-cred-context-null: nfs_file_cred should
  cope if 'file' hasn't been opened properly (bnc#431785).
* Wed Oct 15 2008 tonyj@suse.de
- Update RT patches to latest .27 Windriver version (all patches)
- Disable patches.rt/swap-spinlock-fix.patch
- Guard filp-slab-rcu for RT
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: Input:
  Add Acer Aspire 5710 to nomux blacklist (bnc#404881).
* Tue Oct 14 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: Delete.
  in mainline now. done to the right tree.
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/postun.sh, rpm/post.sh: temporarily ignore errors from
  weak-modules2 --{add,remove}-kernel-modules until
  module-init-tools has rebuilt
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Delete.
  The patch is already upstream in 2.6.27
* Tue Oct 14 2008 jeffm@suse.de
- patches.suse/osync-error: Update position after check for -EIO
  (bnc#434910).
* Tue Oct 14 2008 npiggin@suse.de
- patches.suse/rlimit-memlock-64k.patch: Increase default
  RLIMIT_MEMLOCK to 64k (bnc#329675).
* Tue Oct 14 2008 sjayaraman@suse.de
- Update config files: CIFS_EXPERIMENTAL=y and CIFS_DFS_UPCALL=y
  (FATE#303758).
* Tue Oct 14 2008 jbeulich@novell.com
- patches.xen/xen-irq-probe: restrict IRQ probing (bnc#431572).
* Tue Oct 14 2008 ptesarik@suse.cz
- patches.trace/utrace-core: undo overzealous #ifdef's, which
  removed too much code in case UTRACE_CONFIG was unset.
* Tue Oct 14 2008 jbeulich@novell.com
- patches.fixes/reiserfs-commit-ids-unsigned-ints: Remove L suffix
  from constant compared against.
* Tue Oct 14 2008 olh@suse.de
- call bootloader_entry without leading /boot/ (bnc#435104)
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/functions.sh:
  kill functions.sh, put the relink() function to source-post.sh
  directly
- rpm/postun.sh, rpm/pre.sh, rpm/preun.sh, rpm/post.sh,
  rpm/kernel-binary.spec.in: unify generation of the scriptlets,
  switch to the new weak-modules2 script
* Tue Oct 14 2008 olh@suse.de
- disable unused ide_platform driver
* Tue Oct 14 2008 jdelvare@suse.de
- supported.conf: Remove i2c-core and i2c-piix4 from base.
* Tue Oct 14 2008 gregkh@suse.de
- supported.conf: remove ide-core and ide-cdrom from base on request
  from Tejun.
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-pcc-acpi-driver.patch: Staging:
  add pcc-acpi driver.
- rpm/kernel-binary.spec.in: Obsoletes pcc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: it's pcc-acpi and it's not obsolete, yet.
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes at76_usb-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes et131x-kmp, ivtv-kmp, and
  ppc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-at76_usb-wireless-driver.patch: staging:
  at76_usb wireless driver.
* Mon Oct 13 2008 gregkh@suse.de
- refresh all patches (except xen and rt) to apply cleanly
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: add Obsoletes: wlan-ng-kmp as the needed
  driver is now included from the staging tree.
* Mon Oct 13 2008 gregkh@suse.de
- put proper Patch-mainline: markings on staging patches
* Mon Oct 13 2008 gregkh@suse.de
- patches.drivers/staging-workaround-build-system-bug.patch:
  Staging: workaround build system bug.
* Mon Oct 13 2008 aj@suse.de
- rpm/post.sh: Fix typo that breaks script.
* Mon Oct 13 2008 gregkh@suse.de
- disabled staging drivers for -rt trees
* Mon Oct 13 2008 gregkh@suse.de
- Add -staging tree:
  - added TAINT_CRAP flag
  - added eth131x network driver
  - added slicoss network driver
  - added sgx network driver
  - added me4000 data collection driver
  - added go7007 video capture driver
  - added USB/IP host and client driver
  - added w35und wifi network driver
  - added prism2 usb wifi network driver
  - added echo cancellation driver
- only enabled these on x86 platforms
* Mon Oct 13 2008 jjolly@suse.de
- patches.arch/s390-02-01-xpram.patch: xpram: per device block
  request queues (bnc#434333,LTC#49030)
* Mon Oct 13 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Updated supported.conf checker to
  eliminate false positives.
* Mon Oct 13 2008 sjayaraman@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Fix a compiler warning.
* Mon Oct 13 2008 jbenc@suse.cz
- supported.conf: mark drivers/net/wireless/b43* and
  driver/net/wireless/rt2x00/* as unsupported because of known
  problems we cannot fix.
* Mon Oct 13 2008 oneukum@suse.de
- patches.fixes/wdm_autoload.diff:  add MODULE_DEVICE_TABLE to
  cdc-wdm driver to compute a proper alias (bnc#433817).
* Mon Oct 13 2008 ptesarik@suse.cz
- Update config files (CONFIG_UTRACE for rt flavours).
* Mon Oct 13 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27-rc3: Fix uninitialized data issue.
* Mon Oct 13 2008 ptesarik@suse.cz
- patches.trace/utrace-core: utrace core (FATE#304321).
  CONFIG_UTRACE enabled only for kernel-trace.
- Update config files.
* Mon Oct 13 2008 aj@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Add cast to fix compiler warning.
* Mon Oct 13 2008 sjayaraman@suse.de
- Remove another stale swap-over-nfs patch.
  patches.suse/SoN-29-nfs-alloc-recursions.patch: Delete.
* Fri Oct 10 2008 jeffm@suse.de
- Updated to 2.6.27 final.
* Fri Oct 10 2008 tonyj@suse.de
- Update config files
- Fix conflicts, remove most -RT guards added in recent RT update
  patches.rt/apic-dumpstack.patch: refresh
  patches.rt/preempt-irqs-core.patch: refresh
  patches.rt/print-might-sleep-hack.patch: refresh
  patches.rt/partrevert-lttng-instrumentation-irq.patch: add
  patches.rt/partreadd-lttng-instrumentation-irq.patch: add
- Drop unused RT patches
  patches.rt/mips-change-raw-spinlock-type.patch
  patches.rt/nmi-watchdog-disable.patch
  patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
  patches.rt/lockstat-fix-contention-points.patch
  patches.rt/sched-cpupri-priocount.patch
  patches.rt/nmi-watchdog-fix-1.patch
  patches.rt/cache_pci_find_capability.patch
  patches.rt/fix-emac-locking-2.6.16.patch
  patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch
  patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch
  patches.rt/tie-pi-into-task.patch
  patches.rt/idle2-fix.patch
  patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch
  patches.rt/rtmutex-initialize-waiters.patch
  patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch
  patches.rt/add-generalized-pi-interface.patch
  patches.rt/warn-on-rt-scatterlist.patch
  patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch
  patches.rt/trace-eip2ip.patch
  patches.rt/sched_rt-fixup.patch
  patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch
  patches.rt/trace_hist-latediv.patch
  patches.rt/sched-cpupri-hotplug-support.patch
  patches.rt/idle-fix.patch
  patches.rt/ftrace-fix-get-kprobe-wreckage.patch
  patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch
  patches.rt/ftrace-function-record-nop.patch
  patches.rt/ftrace-document-update1.patch
  patches.rt/26-rt1-chirag.patch
  patches.rt/trace_hist-divzero.patch
  patches.rt/latency-tracing-ppc.patch
  patches.rt/rtmutex-defer-pi-until-sleepy.patch
  patches.rt/pmtmr-override.patch
  patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
  patches.rt/rtmutex-use-runtime-init.patch
  patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch
  patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch
  patches.rt/lockdep-lock_set_subclass.patch
  patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch
  patches.rt/rt-mutex-irq-flags-checking.patch
  patches.rt/ftrace-upstream.patch
  patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch
  patches.rt/ftrace-preempt-trace-check.patch
  patches.rt/rtmutex-add_readers.patch
  patches.rt/lockdep-avoid-fork-waring.patch
  patches.rt/arm-omap-02.patch
  patches.rt/fix-acpi-build-weirdness.patch
  patches.rt/cycles-to-ns-trace-fix.patch
  patches.rt/ftrace-compile-fixes.patch
  patches.rt/ftrace-wakeup-rawspinlock.patch
  patches.rt/rtmutex-convert-to-libpi.patch
  patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch
  patches.rt/ftrace-trace-sched.patch
* Fri Oct 10 2008 mfasheh@suse.com
- supported.conf: mark kernel/fs/gfs2 unsupported
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-cs5530 unsupported due
  to sb16 dependancy issues
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/account-reserved-pages: Delete.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Updated to build with
  CONFIG_MODULES=n.
* Thu Oct  9 2008 jeffm@suse.de
- Updated to 2.6.27-rc9, but still disabled:
  - patches.suse/silent-stack-overflow
  - patches.xen/xen3-silent-stack-overflow
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: thermal_sys, not thermal_sysfs.
* Thu Oct  9 2008 jeffm@suse.de
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Updated against
  2.6.27-rc9.
* Thu Oct  9 2008 jdelvare@suse.de
- supported.conf: Fix the name of the thermal_sys module.
- config/x86_64/rt_timing: THERMAL_HWMON is a boolean.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/netfilter-ipv4options: Updated to 2.6.27-rc9,
  enabled, and marked supported (bnc#131728 - FATE#182).
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/serial8250_console_write-ier: Delete.
- patches.fixes/fix-serial-8250-UART_BUG_TXEN-test: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-als4000 unsupported due
  to dependancy on isa sb16 driver.
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/dont-writeback-fd-bdev-inodes.patch: Delete.
- patches.arch/s390-ccwgroup-attribute-ignore-newline: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark drivers/net/wan/hdlc_x25 unsupported due to
  symbol dependancy tree.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/osync-error: make sure O_SYNC writes properly
  return -EIO (bnc#58622).
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff:
  Add additional symbols to /sys/kernel/vmcoreinfo data for
  ppc(64).
* Thu Oct  9 2008 trenn@suse.de
- patches.xen/xen-x2APIC_build_fix.patch: Adopt Xen to x2APIC
  patchset (fate#303984 and fate#303948).
- Update config files.
  Disable interrupt remapping for Xen -> this is something for
  the hypervisor.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y in vanilla configs.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y; is boolean and enables
  functionality in the already modular THERMAL module.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Export supported status
  via sysfs.
* Thu Oct  9 2008 carnold@novell.com
- Update config files.  Disabled the in kernel KVM modules in
  preference to using them as KMPs.  See also brogers@novell.com
* Thu Oct  9 2008 jeffm@suse.de
- Added a -iu|--ignore-unsupported-deps option to allow builds
  with supported.conf problems.
* Thu Oct  9 2008 jdelvare@suse.de
- config/i386/*, config/x86_64/*, config/ia64/*, supported.conf:
  Build hwmon and thermal as modules.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark hdlc_ppp unsupported as syncppp is unsupported.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ubifs as unsupported as it relies on mtd/ubi/
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-dynamic-reconfiguration.diff:
  powerpc: Add support for dynamic reconfiguration memory in
  kexec/kdump kernels (bnc#431492).
* Thu Oct  9 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: package kernel-xen has dependency to
  xen (bnc#431215).
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark TPM drivers a supported, as IBM and others
  rely on them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: fix a dependancy link with the isa sb driver with
  unsupported symbols
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ieee80122 modules as supported, as other
  supported modules need them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark all of the mtd drivers as unsupported to fix
  the build errors (and to reflect our policy here.)
* Thu Oct  9 2008 bwalle@suse.de
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC to 0 (bnc#429910).
* Thu Oct  9 2008 jdelvare@suse.de
- Don't build the tps65010 driver, it's only used on OMAP at the
  moment.
* Thu Oct  9 2008 mmarek@suse.cz
- rpm/built-in-where: make it work with a four-column
  Modules.symvers (bnc#433533)
* Thu Oct  9 2008 bwalle@suse.de
- Update KDB to v4.4-2.6.27-rc8.
* Thu Oct  9 2008 olh@suse.de
- disable legacy iseries (bnc#433685 - LTC48946)
* Thu Oct  9 2008 olh@suse.de
- enable battery_pmu on ppc32
* Thu Oct  9 2008 trenn@suse.de
- supported.conf:
  Marked these unsupported:
  cpufreq-nforce2
  e_powersaver
  gx-suspmod
  longhaul
  longrun
  p4-clockmod
  powernow-k6
  powernow-k7
  speedstep-ich
  speedstep-smi
  Even Via CPUs are exporting cpu freq steps via ACPI and work fine
  with acpi-cpufreq. No need to support the old, some are known
  broken, drivers.
* Thu Oct  9 2008 olh@suse.de
- add patches.suse/md-raid-metadata-PAGE_SIZE.patch
  ignore PAGE_SIZE in md metadata, for raid0 (bnc#429490)
* Thu Oct  9 2008 teheo@suse.de
- patches.xen/xen3-auto-common.diff: minor patch apply fix after
  libata-prefer-over-ide.
* Wed Oct  8 2008 teheo@suse.de
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
* Wed Oct  8 2008 carnold@novell.com
- patches.xen/xen-op-packet: add support for new operation type
  BLKIF_OP_PACKET (fate#300964).
- patches.xen/xen-blkfront-cdrom: implement forwarding of CD-ROM
  specific commands (fate#300964).
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: major update.  Lots of new drivers added as this
  file hadn't been updated for a lot of kernel revisions.
  This should close out a lot of bugs about "unsupported" modules,
  like bnc#433541.
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: sorted the file correctly so we can start determining
  what we are not supporting easier.
* Wed Oct  8 2008 jeffm@suse.de
- Updated -rt for context against -rc9 and the x2APIC patches:
  - patches.rt/new-softirq-code.patch
  - patches.rt/preempt-irqs-core.patch
  - patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch
  - CONFIG_INTR_REMAP=n for now
  - patches.rt/preempt-softirqs-core.patch
  - patches.rt/rt-slab-new.patch
  - patches.rt/slab-irq-nopreempt-fix.patch
  - Update config files: NFS_SWAP=n
* Wed Oct  8 2008 trenn@suse.de
  x2APIC and interrupt remapping enablement.
  Xen needs further work to build again.
  Commit ids are from x86 tip git tree:
- patches.arch/x2APIC_fix_section_mismatch.patch: Fix several
  section mismatches (none).
- patches.arch/x2APIC_PATCH_01_0f4896665a02b465ddca59a560983b24ec28c64b:
  dmar: fix dmar_parse_dev() devices_cnt error condition check
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_01_of_41_e61d98d8dad0048619bb138b0ff996422ffae53b:
  x64, x2apic/intr-remap: Intel vt-d, IOMMU code reorganization
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_228324076234ca6a8cd34be89be78022773459f1:
  dmar: use list_for_each_entry_safe() in dmar_dev_scope_init()
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_of_41_c42d9f32443397aed2d37d37df161392e6a5862f:
  x64, x2apic/intr-remap: fix the need for sequential array
  allocation of iommus (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_03_3f1fdb3673bb5638fa94186dc391cbc4879590bc:
  dmar: initialize the return value in dmar_parse_dev() (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_03_of_41_1886e8a90a580f3ad343f2065c84c1b9e1dac9ef:
  x64, x2apic/intr-remap: code re-structuring, to be used by both
  DMA and Interrupt remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_f12c73e7fa7ebf9ad6defee2c4fb2664e743e970:
  dmar: fix using early fixmap mapping for DMAR table parsing
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_of_41_aaa9d1dd63bf89b62f4ea9f46de376ab1a3fbc6c:
  x64, x2apic/intr-remap: use CONFIG_DMAR for DMA-remapping
  specific code (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_05_7be42004065ce4df193aeef5befd26805267d0d9:
  x86, lguest: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_caf43bf7c6a55e89b6df5179df434d67e24aa32e:
  x86, xen: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_of_41_ad3ad3f6a2caebf56869b83b69e23eb9fa5e0ab6:
  x64, x2apic/intr-remap: parse ioapic scope under vt-d structures
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_511d9d34183662aada3890883e860b151d707e22:
  x86: apic_ops for lguest (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_of_41_cf1337f0447e5be8e66daa944f0ea3bcac2b6179:
  x64, x2apic/intr-remap: move IOMMU_WAIT_OP() macro to
  intel-iommu.h (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_08_of_41_fe962e90cb17a8426e144dee970e77ed789d98ee:
  x64, x2apic/intr-remap: Queued invalidation infrastructure
  (part of VT-d) (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_09_94a8c3c2437c8946f1b6c8e0b2c560a7db8ed3c6:
  x86: let 32bit use apic_ops too - fix (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_09_of_41_2ae21010694e56461a63bfc80e960090ce0a5ed9:
  x64, x2apic/intr-remap: Interrupt remapping infrastructure
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_10_of_41_b6fcb33ad6c05f152a672f7c96c1fab006527b80:
  x64, x2apic/intr-remap: routines managing Interrupt remapping
  table entries. (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_11_of_41_72b1e22dfcad1daca6906148fd956ffe404bb0bc:
  x64, x2apic/intr-remap: generic irq migration support from
  process context (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_12_of_41_d94d93ca5cc36cd78c532def62772c98fe8ba5d7:
  x64, x2apic/intr-remap: 8259 specific mask/unmask routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_13_of_41_4dc2f96cacd1e74c688f94348a3bfd0a980817d5:
  x64, x2apic/intr-remap: ioapic routines which deal with initial
  io-apic RTE setup (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_14_of_41_0c81c746f9bdbfaafe64322d540c8b7b59c27314:
  x64, x2apic/intr-remap: introduce read_apic_id() to genapic
  routines (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_15_of_41_2d7a66d02e11af9ab8e16c76d22767e622b4e3d7:
  x64, x2apic/intr-remap: Interrupt-remapping and x2apic support,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_16_of_41_1b374e4d6f8b3eb2fcd034fcc24ea8ba1dfde7aa:
  x64, x2apic/intr-remap: basic apic ops support (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_17_of_41_32e1d0a0651004f5fe47f85a2a5c725ad579a90c:
  x64, x2apic/intr-remap: cpuid bits for x2apic feature (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_18_of_41_1cb11583a6c4ceda7426eb36f7bf0419da8dfbc2:
  x64, x2apic/intr-remap: disable DMA-remapping if
  Interrupt-remapping is detected (temporary quirk) (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_19_of_41_13c88fb58d0112d47f7839f24a755715c6218822:
  x64, x2apic/intr-remap: x2apic ops for x2apic mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_21_of_41_12a67cf6851871ca8df42025c94f140c303d0f7f:
  x64, x2apic/intr-remap: x2apic cluster mode support (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_22_of_41_5c520a6724e912a7e6153b7597192edad6752750:
  x64, x2apic/intr-remap: setup init_apic_ldr for UV (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_23_of_41_89027d35aa5b8f45ce0f7fa0911db85b46563da0:
  x64, x2apic/intr-remap: IO-APIC support for interrupt-remapping
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_24_of_41_75c46fa61bc5b4ccd20a168ff325c58771248fcd:
  x64, x2apic/intr-remap: MSI and MSI-X support for interrupt
  remapping infrastructure (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_1_of_41_4c9961d56ec20c27ec5d02e49fd7427748312741:
  x86: make read_apic_id return final apicid (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_25_2_of_41_c535b6a1a685eb23f96e2c221777d6c1e05080d5:
  x86: let 32bit use apic_ops too (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_of_41_6e1cb38a2aef7680975e71f23de187859ee8b158:
  x64, x2apic/intr-remap: add x2apic support, including enabling
  interrupt-remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_26_of_41_2d9579a124d746a3e0e0ba45e57d80800ee80807:
  x64, x2apic/intr-remap: support for x2apic physical mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_28_1_of_41_f910a9dc7c865896815e2a95fe33363e9522f277:
  x86: make 64bit have get_apic_id (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_29_of_41_277d1f5846d84e16760131a93b7a67ebfa8eded4:
  x2apic: uninline uv_init_apic_ldr() (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_30_of_41_ad66dd340f561bdde2285992314d9e4fd9b6191e:
  x2apic: xen64 paravirt basic apic ops (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_34_of_41_1b9b89e7f163336ad84200b66a17284dbf26aced:
  x86: add apic probe for genapic 64bit, v2 (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_35_of_41_d25ae38b7e005af03843833bbd811ffe8c5f8cb4:
  x86: add apic probe for genapic 64bit - fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_36_of_41_276605dddb74cbf1b77696e32c4a947e42cec52d:
  x2apic: use x2apic id reported by cpuid during topology
  discovery (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_41_of_41_11c231a962c740b3216eb6565149ae5a7944cba7:
  x86: use x2apic id reported by cpuid during topology discovery,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_42_of_41_77322deb4bc676a5ee645444e7ed1a89f854473d:
  x86: io-apic - interrupt remapping fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_43_of_41_2c72d93f6593f386f5760ca8e7ac7026948c31d7:
  x2apic: fix reserved APIC register accesses in
  print_local_APIC() (fate #303948 and fate #303984).
- patches.drivers/sgi-uv-led: SGI UV: Provide a LED driver and
  some System Activity Indicators (FATE#304268).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc5-x86-1 (FATE#303971).
- patches.xen/xen-x86-no-lapic: Disallow all accesses to the
  local APIC page (191115).
- patches.xen/xen3-auto-arch-x86.diff: xen3 arch-x86.
- patches.xen/xen3-patch-2.6.19: Linux 2.6.19.
- patches.xen/xen3-patch-2.6.26: 2.6.26.
- Update config files:
  Added CONFIG_INTR_REMAP to all x86_64 flavors
* Wed Oct  8 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: added Obsoletes: atl2-kmp as this
  driver is now included in the kernel package.
* Wed Oct  8 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-4-v2.patch: Update for fcpperf-4
  patch to bring in sync with upstream version. (bnc#417243)
- patches.arch/s390-01-04-fcpperf-4.patch: Removed, replaced by
  updated patch
* Wed Oct  8 2008 sjayaraman@suse.de
- Remove stale swap-over-nfs patches.
- patches.suse/SoN-05-page_alloc-reserve.patch: Delete.
- patches.suse/SoN-06-reserve-slub.patch: Delete.
* Wed Oct  8 2008 agruen@suse.de
- No uml patches left, so remove the code referring to
  patches.uml.tar.bz2.
* Wed Oct  8 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
* Wed Oct  8 2008 agruen@suse.de
- Add DMAPI patches (supported by SGI).
- Update config files: enable DMAPI.
* Wed Oct  8 2008 sjayaraman@suse.de
- Doh, forgot to remove stale files from cvs
- Update config files NFS_SWAP=y.
* Wed Oct  8 2008 sjayaraman@suse.de
- Refreshed to -v19 of swap over nfs patchset.
  o netns, ipv6 fixes
  o patch ordering changes due to additional patches
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict.
* Wed Oct  8 2008 bwalle@suse.de
- Enable CONFIG_MFD_SM501_GPIO also for RT.
* Wed Oct  8 2008 bwalle@suse.de
- Refresh patches.rt/mips-remove-duplicate-kconfig.patch.
* Wed Oct  8 2008 bwalle@suse.de
- Update to 2.6.27-rc9.
- Enable new configuration option CONFIG_MFD_SM501_GPIO.
- Drop following patches (mainline):
  o patches.suse/e1000e_debug_contention_on_NVM_SWFLAG
  o patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context
  o patches.suse/e1000e_drop_stats_lock, e1000e_fix_lockdep_issues
  o patches.suse/e1000e_mmap_range_chk,
  o patches.suse/e1000e_reset_swflag_after_resetting_hardware
  o patches.suse/e1000e_update_versione1000e_write_protect_ichx_nvm
- Adjust/refresh following patches:
  o patches.arch/s390-01-03-cmm2-v2.patch
  o patches.drivers/e1000e_add_82574L.patch
  o patches.drivers/e1000e_add_ICH9_BM.patch
  o patches.drivers/e1000e_add_LOM_devices.patch
  o patches.suse/e1000e_allow_bad_checksum
  o patches.suse/e1000e_call_dump_eeprom
  o patches.suse/e1000e_ioremap_sanity_check
  o patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory
* Wed Oct  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: switch KMPs to the new
  weak-modules2 script, which handles running depmod and mkinitrd
* Wed Oct  8 2008 hare@suse.de
- supported.conf: mark igb as supported.
* Wed Oct  8 2008 agruen@suse.de
- kernel-source-rt must not provide a kernel-source symbol: this
  would break dependencies.
* Wed Oct  8 2008 olh@suse.de
- update patches.suse/ppc-no-LDFLAGS_MODULE.patch
  use suggested patch from kernel.org bugzilla
* Wed Oct  8 2008 olh@suse.de
- add patches.arch/ppc-pseries_remove_lmb-PAGE_SHIFTT.patch
  fix oops in pseries_remove_lmb with 64k PAGE_SIZE (bnc#431380)
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: mark efivars.ko as supported
* Wed Oct  8 2008 gregkh@suse.de
- enable yealink driver (bnc#432841)
* Tue Oct  7 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: fix hang in disable_periodic
  (bnc#403346).
* Tue Oct  7 2008 trenn@suse.de
- patches.fixes/fujisu_laptop_fix_section_mismatch.patch: Fix
  section mismatch in fujitsu_laptop driver (none).
* Tue Oct  7 2008 hare@suse.de
- patches.fixes/sd-needs-updating: Driver 'sd' needs updating
  (bnc#406656).
* Tue Oct  7 2008 agruen@suse.de
- rpm/post.sh: Catch mkinitrd error code indicating missing
  required modules. Only add a bootloader entry if an initrd
  could be created, but re-add the bootloader entry even if
  the initrd already existed before (bnc#431703).
* Tue Oct  7 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.4-update: Update lpfc to 8.2.8.4
  (bnc#420767).
- patches.drivers/qla4xxx-sles11-update: qla4xxx driver fixes
  for SLES11 (bnc#432976).
* Tue Oct  7 2008 olh@suse.de
- mark legacy iseries storage as supported
* Mon Oct  6 2008 jdelvare@suse.de
- supported.conf: Add the ad7414, adcxx and ibmaem hwmon drivers as
  unsupported.
* Mon Oct  6 2008 jdelvare@suse.de
- config/ia64/*: Don't built i2c-amd756-s4882 and i2c-nforce2-s4985
  on ia64, these are motherboard-specific drivers for x86_64
  motherboards.
- config/powerpc/*: Don't built i2c-isch on powerpc, it is a driver
  for x86 hardware.
- config/*: Don't built i2c-simtec on i386, x86_64 and ia64, there
  is no Simtec hardware based on these architectures.
* Sun Oct  5 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Fix the logic splitting up the symbols
  defined in vmlinux by subsystem. (Actually, per directory, under
  the assumption that there is enough of a correlation).
* Sun Oct  5 2008 greg@suse.de
- supported.conf: add ohci-hcd to base.  Fix up other USB drivers
  (USB network drivers had moved, others were missing)
* Sun Oct  5 2008 gregkh@suse.de
- patches.drivers/atl2-add-atl2-network-driver.patch: atl2:
  add atl2 network driver.
- Update config files (even the rt ones).
* Fri Oct  3 2008 jkosina@suse.de
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: fix bogus
  WARN_ON() condition, as per upstream commit 95b866d5a
* Fri Oct  3 2008 olh@suse.de
- mark ibmvfc as supported (bnc#417555 - fate#304178 - LTC46935)
* Fri Oct  3 2008 olh@suse.de
- compile windfarm_pm121 into the kernel
* Fri Oct  3 2008 jeffm@suse.de
- doc/README.SUSE, scripts/tar-up_and_run_mbuild.sh,
  scripts/run_oldconfig.sh,
  scripts/sequence-patch.sh: Eliminated defconfig.$flavor
* Fri Oct  3 2008 olh@suse.de
- mark Cell drivers as supported
* Fri Oct  3 2008 tonyj@suse.de
- Update config files
  rt configs not updated for per-module-dynamic-debug-messages.patch
* Fri Oct  3 2008 gregkh@suse.de
- change patches.suse/supported-flag to show which modules are
  unsupported and externally supported in oops messages.  Also change
  the taint values as the documentation was totally wrong.
* Fri Oct  3 2008 tonyj@suse.de
- Reenable RT debug builds, compile tested only
- Update config files
- Fix tracer issues
  patches.rt/event-trace-hrtimer-trace.patch
  patches.rt/trace-events-handle-syscalls.patch
  patches.rt/trace-ktime-scalar.patch
  patches.rt/tracer-event-trace.patch
- patches.rt/kdb-disable-ist.patch: Disable stackfault and debug stacks for kdb
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT
- patches.rt/novfs-rtmisc.patch: Misc NOVFS fixes for RT
* Fri Oct  3 2008 gregkh@suse.de
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  driver core: basic infrastructure for per-module dynamic
  debug messages.
- refresh patches.trace/tracepoints.patch: Kernel Tracepoints.
- Update config files.
* Thu Oct  2 2008 agruen@suse.de
- Introduce kernel-source-rt and kernel-syms-rt packages, needed
  for building real-time KMPs.
* Thu Oct  2 2008 schwab@suse.de
- Don't clean <asm/nr-irqs.h>.
* Thu Oct  2 2008 jblunck@suse.de
- supported.conf: add qeth_l2 and qeth_l3 as supported modules
* Thu Oct  2 2008 jkosina@suse.de
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: update to
  the latest version of the patch as provided by Intel
* Thu Oct  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc8 and c/s 684.
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Replace by ...
- patches.xen/xen3-e1000e_Export_set_memory_ro-rw: this, and put
  in proper place in series.conf.
- patches.xen/xen-rwlocks-enable-interrupts: Replace by ...
- patches.xen/xen3-rwlocks-enable-interrupts: this, and put in
  proper place in series.conf.
* Wed Oct  1 2008 jeffm@suse.de
- scripts/sequence-patch.sh
- scripts/run_oldconfig.sh: x86 defconfigs go under arch/x86.
* Wed Oct  1 2008 olh@suse.de
- enable msi on ppc64 (bnc#430937)
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Remove /lib/modules from file list
  as it's already in filesystem
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Fixed missing endif
* Wed Oct  1 2008 tiwai@suse.de
- Update config files: make floppy module on i386, too
* Wed Oct  1 2008 tiwai@suse.de
- supported.conf: update sound drivers
* Wed Oct  1 2008 tonyj@suse.de
- update RT to 2.6.27-rc8
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
* Wed Oct  1 2008 agruen@suse.de
- Update -rt config files.
* Tue Sep 30 2008 gregkh@suse.de
- update to 2.6.27-rc8
  - obsoletes these patches:
  - patches.arch/ia64-kdump_proc_iomem.diff
  - patches.drivers/qla2xxx-defer-risc-interrupt-enablement
  - patches.fixes/usb-hcd-interrupt-shared.patch
* Tue Sep 30 2008 jkosina@suse.de
- additional patches to track down and fix e1000e NVM corruption
- patches.suse/e1000e_ioremap_sanity_check: ioremap sanity check
  to catch mapping requests exceeding the BAR sizes (bnc#425480).
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: write
  protect ICHx NVM to prevent malicious write/erase (bnc#425480).
* Tue Sep 30 2008 hare@suse.de
- Update config files.
* Tue Sep 30 2008 hare@suse.de
- patches.drivers/mpt-fusion-4.00.43.00-update: Update MPT Fusion
  driver to v4.00.43.00 (bnc#425660).
- patches.kernel.org/gdth-section-conflict: Add missing annotations.
* Tue Sep 30 2008 sassmann@suse.de
- Update config files: Disabled everything unnecessary in
  ps3 config file
* Tue Sep 30 2008 olh@suse.de
- disable ninja32 and ns87415 pata drivers on ppc64
* Tue Sep 30 2008 sdietrich@suse.de
- config.conf: enable rt for i386/x86_64
- Update config files: Preliminary sync with default and debug configs.
- config/x86_64/rt_timing: Delete.
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.27-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.27-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.27-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.27-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.27-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.27-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.27-RT
  Fix a previously reverted "fix".
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.27-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.27-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.27-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.27-RT
  floppy: suspend/resume fix.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT rt: remove call to stop tracer.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: document updates.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.27-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: define function trace nop.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.27-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: only trace preempt off with
  preempt tracer.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.27-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.27-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: trace sched.c.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.27-RT
  ftrace: avoid lockdep recursion.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: user raw spin lock for wakeup
  function trace.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.27-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.27-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.27-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.27-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.27-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT lockdep: lock_set_subclass - reset a held
  lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.27-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.27-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.27-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.27-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.27-RT
  mapping_nrpages-fix.patch.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.27-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT RT: change from raw_spinlock_t to
  __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.27-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.27-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.27-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.27-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.27-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.27-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.27-RT
  nfs: fix missing preemption check.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT x86_64: do not enable the NMI watchdog
  by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.27-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT local_bh_enable() is safe for
  irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.27-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.27-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.27-RT.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT pmtmr: allow command line override of
  ioport.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.27-RT
  powerpc: ftrace stop on crash.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.27-RT
  don't trace early init functions for ppc32.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.27-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.27-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.27-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.27-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.27-RT
  lockdep: add +1 to radix tree array.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.27-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.27-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.27-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.27-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.27-RT
  rt: plist_head_splice.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.27-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.27-RT
  rtmutex-debug-fix.patch.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.27-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.27-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.27-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.27-RT
  rwlocks multi downgrade write.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.27-RT.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.27-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.27-RT
  rwlock: rwlock torture test.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.27-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.27-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.27-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.27-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.27-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.27-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Re: 2.6.25.4-rt4.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.27-RT
  ftrace: print ktime values in readable form.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.27-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.27-RT.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT remove warn on for scatterlist in preempt
  rt.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.27-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/26-rt1-chirag.patch: Linux-RT 2.6.27-RT
  This patch should solve some of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: Linux-RT
  2.6.27-RT
  add generalized priority-inheritance interface.
- patches.rt/rtmutex-add_readers.patch: Linux-RT 2.6.27-RT
  RT: wrap the rt_rwlock "add reader" logic.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: Linux-RT
  2.6.27-RT
  rtmutex: pi-boost locks as late as possible.
- patches.rt/rtmutex-initialize-waiters.patch: Linux-RT 2.6.27-RT
  rtmutex: formally initialize the rt_mutex_waiters.
- patches.rt/rtmutex-use-runtime-init.patch: Linux-RT 2.6.27-RT
  rtmutex: use runtime init for rtmutexes.
- patches.rt/tie-pi-into-task.patch: Linux-RT 2.6.27-RT
  sched: add the basic PI infrastructure to the task_struct.
- patches.rt/rtmutex-convert-to-libpi.patch: Linux-RT 2.6.27-RT
  rtmutex: convert rtmutexes to fully use the PI library.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  Linux-RT 2.6.27-RT
  ftrace: fix elevated preempt_count in wakeup-tracer.
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  Linux-RT 2.6.27-RT
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.27-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.27-RT.
- patches.rt/bit-spinlocks-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/compat_rwsem-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/drivers_base_mutex.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-ppc-define-mcount.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-report-failure.patch: Linux-RT 2.6.27-RT
  ftrace: warn on failure to disable mcount callers.
- patches.rt/ftrace-upstream-temp.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-trivial-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-atomic-fixup.patch: Linux-RT 2.6.27-RT.
- patches.rt/namespace-lock-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-prof-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/plist-fix-static-node-init.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-01-separate-the-irq-radix-tree-insertion.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-02-make-the-irq-reverse-mapping-radix-tree-lockless.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-fix-prev-revert-fix-again.patch: Linux-RT
  2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-apply-rcu_process_callbacks-from-mainline.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-tracing-preempt-disable-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rt-wq-flush_work.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-debug-magic.patch: Linux-RT 2.6.27-RT
  rtmutex: check integrity.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-generic-hide-smp-warning.patch: Linux-RT
  2.6.27-RT
  suppress warning of smp_processor_id use..
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-if-pushable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/seqlock-01-make-sure-that-raw_seqlock-retries.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-02-fix-elevated-preempt-count.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-serialize-against-writers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seqlocks-handle-rwlock-and-spin.patch: Linux-RT
  2.6.27-RT
  seqlock - fix for both PREEMPT_RT and non PREEMPT_RT.
- patches.rt/shorten-posix-cpu-timers-name.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sysctl-compile-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracepoint-backport.patch: Linux-RT 2.6.27-RT.
- patches.rt/x86-tlbstate-lock-raw.patch: Linux-RT 2.6.27-RT.
* Tue Sep 30 2008 olh@suse.de
- enable ipmi message handler on ppc64 (bnc#430705)
* Tue Sep 30 2008 olh@suse.de
- create flavor symlinks unconditionally
  they do not depend on presence of modules
* Mon Sep 29 2008 agruen@suse.de
- Update config files after Swap-over-NFS backout.
* Mon Sep 29 2008 agruen@suse.de
- kernel-vanilla and kernel-p3 are not split into main, -base, and
  - extra packages. Fix the bogus dependencies on those packages.
* Mon Sep 29 2008 jkosina@suse.de
- disabled the following Swap-over-NFS patches, as they cause panic
  in IPv6 code:
  - patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
    gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
    serialize access to min_free_kbytes (FATE#303834).
  - patches.suse/SoN-03-doc.patch: swap over network documentation
    (FATE#303834).
  - patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
    expose gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
    pages (FATE#303834).
  - patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
    of reserve pages (FATE#303834).
  - patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
    kmem_alloc_estimate() (FATE#303834).
  - patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
    PF_MEMALLOC from softirq context (FATE#303834).
  - patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
    pool (FATE#303834).
  - patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
    system wide ALLOC_NO_WATERMARK (FATE#303834).
  - patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
    __GFP_MEMALLOC (FATE#303834).
  - patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
    management (FATE#303834).
  - patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
    tag avc cache alloc as non-critical (FATE#303834).
  - patches.suse/SoN-14-net-backlog.patch: net: wrap
    sk->sk_backlog_rcv() (FATE#303834).
  - patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
    api (FATE#303834).
  - patches.suse/SoN-16-net-sk_allocation.patch: net:
    sk_allocation() - concentrate socket related allocations
    (FATE#303834).
  - patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
    infrastructure (FATE#303834).
  - patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
    reserves. (FATE#303834).
  - patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
    skb allocation to reserves (FATE#303834).
  - patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
    emergency skbs. (FATE#303834).
  - patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
    a stream specific deadlock (FATE#303834).
  - patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
    NF_QUEUE vs emergency skbs (FATE#303834).
  - patches.suse/SoN-23-netvm.patch: netvm: skb processing
    (FATE#303834).
  - patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
    non block device backed swap files (FATE#303834).
  - patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
    for teaching filesystems about PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
    client how to treat PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
    revalidation for swapfiles (FATE#303834).
  - patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
    (FATE#303834).
  - patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
    memory recursions possible with swap over NFS. (FATE#303834).
  - patches.xen/xen3-auto-common.diff: xen3 common.
* Mon Sep 29 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: x86 tracehook (FATE#304321).
  Provide the base infrastructure for utrace on x86.
* Mon Sep 29 2008 schwab@suse.de
- config/powerpc/vanilla: configure to 64bit.
* Mon Sep 29 2008 schwab@suse.de
- rpm/functions.sh: remove readlink emulation.
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.3-update: Update lpfc to 8.2.8.3
  (bnc#420767).
* Mon Sep 29 2008 rw@suse.de
- Update ia64 config files.  (bnc#429881)
* Mon Sep 29 2008 jjolly@suse.de
- patches.drivers/ehca-flush-cqe.patch: adds software flush CQE
  generation (bnc#430344)
* Mon Sep 29 2008 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: fix infinite loop bug in
  e1000_probe() in case the card has invalid EEPROM checksum
* Mon Sep 29 2008 agruen@suse.de
- Do not split kernels which have modules disabled (kernel-ps3)
  or which do not differentiate between supported and unsupported
  modules (kernel-vanilla).
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/open-fcoe-dcb-support: Fix section annotation
  for ixgbe.
- patches.fixes/scsi-enhance-error-codes: Add missing hunk.
- patches.fixes/open-iscsi-git-update: Open-iSCSI updates
  (FATE#304283).
- patches.kernel.org/gdth-section-conflict: Fixup gdth
  section annotations.
* Mon Sep 29 2008 aj@suse.de
- Silence /etc/rpm/macros.kernel-source via rpmlintrc.
* Mon Sep 29 2008 jbeulich@novell.com
- Enable Solarflare driver link and resource driver patches.
- Update x86 config files.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spc.in: Try to get rid of a hack that makes
  uname -r pretend in build environments that the kernel from
  the installed kernel-source package is the running kernel:
  packages assuming this are completely broken ans should really
  be fixed.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spec.in: Prepare for the upcoming introduction
  of kernel-source-rt (and kernel-syms-rt) for producing KMPs for
  real-time kernels.
- rpm/install-configs: Remove; this script didn't improve things.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.rpmlintrc: New file to silence warnings about
  zero size files
- rpm/kernel-source.spec.in: Install it.
- rpm/kernel-source.spec.in: Make /etc/rpm/macros.kernel-source
  a config file to silence rpmlint.
* Sun Sep 28 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-i810, i2c-prosavage and i2c-savage4 are gone.
  - i2c-isch and i2c-nforce2-s4985 are new, mark as supported.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.spec.in: Do not package .gitignore files.
* Sun Sep 28 2008 agruen@suse.de
- Fix CONFIG_MODULES=n case.
- config.conf: Some cleanups.
* Sat Sep 27 2008 agruen@suse.de
- Split the binary kernel packages into three parts:
  + kernel-$flavor-base: very reduced hardware support, intended
  to be used in virtual machine images
  + kernel-$flavor: extends the base package; contains all kernel
  modules we can support
  + kernel-$flavor-extra: all other kernel modules which may be
  useful, but which we cannot support.
* Sat Sep 27 2008 agruen@suse.de
- Hardlink duplicate files automatically: It doesn't save much,
  but it keeps rpmlint from breaking the package build.
* Sat Sep 27 2008 agruen@suse.de
- Add consistency check: supported modules must not depend on
  unsupported ones ... and guess what, there was a large number of
  such modules. Fix this by adding all the dependent modules to
  supported.conf.
* Sat Sep 27 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Implement barrier
  support for single device DM devices (FATE#304489).
* Fri Sep 26 2008 jeffm@suse.de
- scripts/tar-up_and_run_mbuild.sh: Added -xen flavor to default
  mbuild spec list.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls for xen. (bnc#425480).
* Fri Sep 26 2008 kkeil@suse.de
- patches.suse/e1000e_mmap_range_chk:check ranges in pci_mmap
  * updated version with better reporting (bnc#425480)
* Fri Sep 26 2008 kkeil@suse.de
- patches to track down and fix the e1000e NVM corruption
  (bnc#425480)
- patches.suse/e1000e_allow_bad_checksum: e1000e: allow bad
  checksum
- patches.suse/e1000e_call_dump_eeprom: e1000e: dump eeprom to
  dmesg for ich8/9
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: e1000e:
  debug contention on NVM SWFLAG
- patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context:
  e1000e: do not ever sleep in interrupt context
- patches.suse/e1000e_drop_stats_lock: e1000e: drop stats lock
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls
- patches.suse/e1000e_fix_lockdep_issues: e1000e: fix lockdep
  issues
- patches.suse/e1000e_mmap_range_chk: check ranges in pci_mmap
- patches.suse/e1000e_reset_swflag_after_resetting_hardware:
  e1000e: reset swflag after resetting hardware
- patches.suse/e1000e_update_version: update version
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  e1000e: Use set_memory_ro()/set_memory_rw() to protect flash
  memory
-   cleanup old not longer used patches
  * patches.drivers/e1000-7.6.5-napi-tail.patch
  * patches.drivers/e1000-7.6.9.2
  * patches.drivers/e1000-7.6.9.2-napi
* Fri Sep 26 2008 kkeil@suse.de
- Enable CONFIG_SGI_IOC4=m in x86_64 (bnc#430275)
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-export-hotplug_execute: acpi: export
  acpi_os_hotplug_execute.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-rwlocks-enable-interrupts: add missing
  __raw_{read,write}_lock_flags to xen's asm/spinlock.h.
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-bay-remove-from-makefile: acpi: remove bay.c
  from makefile.
* Fri Sep 26 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disabled sparse checking. Too many
  false positives.
* Fri Sep 26 2008 trenn@suse.de
  No functional change:
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
  Dock bug fixes (kacpid runs amok on Dells after suspend):
- patches.arch/acpi-dock-avoid-check-_STA-method.patch: avoid
  check _STA method (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-eject-request-process.patch: fix
  eject request process (fate#304731,bnc#401740).
  More Dock improvements, unrelated to above fixes:
- patches.arch/acpi-bay-remove-useless-code.patch: remove useless
  code (fate#304731,bnc#401740).
- patches.arch/acpi-dock-Fix-duplicate-notification-handler-register.patch:
  Fix duplicate notification handler register
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-_LCK-support-for-dock.patch: add _LCK
  support for dock (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-for-bay-in-a-dock-station.patch:
  fix for bay in a dock station (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-hotplug-race.patch: fix hotplug race
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-introduce-.uevent-for-devices-in-dock.patch:
  introduce .uevent for devices in dock (fate#304731,bnc#401740).
- patches.arch/acpi-libata-hotplug-to-align-with-dock-driver.patch:
  libata hotplug to align with dock driver
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-makeing-dock-driver-supports-bay-and-battery-hotplug.patch:
  makeing dock driver supports bay and battery hotplug
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-add-type-sysfs-file-for-dock.patch:
  add 'type' sysfs file for dock (fate#304731,bnc#401740).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
* Fri Sep 26 2008 jeffm@suse.de
- Update config files: NFS_SWAP=y
* Fri Sep 26 2008 ptesarik@suse.cz
- patches.suse/rwlocks-enable-interrupts: Allow rwlocks to
  re-enable interrupts (bnc#387784).
- patches.arch/ia64-rwlocks-enable-interrupts: ia64: re-enable
  interrupts when waiting for a rwlock (bnc#387784).
* Fri Sep 26 2008 sjayaraman@suse.de
- Add Swap over NFS patchset.
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict on skbuff.h
  as both xen and swap-over-nfs want to add some bits to the skbuff structure.
- patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
  gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
  serialize access to min_free_kbytes (FATE#303834).
- patches.suse/SoN-03-doc.patch: swap over network documentation
  (FATE#303834).
- patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
  expose gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
  pages (FATE#303834).
- patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
  of reserve pages (FATE#303834).
- patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
  kmem_alloc_estimate() (FATE#303834).
- patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
  PF_MEMALLOC from softirq context (FATE#303834).
- patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
  pool (FATE#303834).
- patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
  system wide ALLOC_NO_WATERMARK (FATE#303834).
- patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
  __GFP_MEMALLOC (FATE#303834).
- patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
  management (FATE#303834).
- patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
  tag avc cache alloc as non-critical (FATE#303834).
- patches.suse/SoN-14-net-backlog.patch: net: wrap
  sk->sk_backlog_rcv() (FATE#303834).
- patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
  api (FATE#303834).
- patches.suse/SoN-16-net-sk_allocation.patch: net:
  sk_allocation() - concentrate socket related allocations
  (FATE#303834).
- patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
  infrastructure (FATE#303834).
- patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
  reserves. (FATE#303834).
- patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
  skb allocation to reserves (FATE#303834).
- patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
  emergency skbs. (FATE#303834).
- patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
  a stream specific deadlock (FATE#303834).
- patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
  NF_QUEUE vs emergency skbs (FATE#303834).
- patches.suse/SoN-23-netvm.patch: netvm: skb processing
  (FATE#303834).
- patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
  non block device backed swap files (FATE#303834).
- patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
  for teaching filesystems about PG_swapcache pages (FATE#303834).
- patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
  client how to treat PG_swapcache pages (FATE#303834).
- patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
  revalidation for swapfiles (FATE#303834).
- patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
  (FATE#303834).
- patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
  memory recursions possible with swap over NFS. (FATE#303834).
- patches.xen/xen3-auto-common.diff: xen3 common.
* Fri Sep 26 2008 ptesarik@suse.cz
- split patches.arch/s390-01-01-self-ptrace-v3.patch to make it
  more obvious that the patch is not constrained to s390.
  The new series is:
    patches.suse/self-ptrace.patch: the generic pieces
    patches.arch/x86-self-ptrace.patch: implementation for x86
    patches.arch/s390-01-01-self-ptrace-v3.patch: dtto for s390
* Thu Sep 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc7 and c/s 676.
* Thu Sep 25 2008 olh@suse.de
- add patches.arch/ppc64-rpanote-relocate-firmware.patch
  update RPA note for firmware relocation (bnc#427960 - LTC48297)
* Wed Sep 24 2008 jblunck@suse.de
  This adds some tracepoint instrumentation taken from the LTTng patch
  series. Tracepoints are enabled for kernel-debug and kernel-trace only. I
  disabled ftrace for all flavors except kernel-debug and kernel-trace as well.
- Update config files.
- rpm/kernel-source.spec.in,kernel-binary.spec.in, config.conf: Add trace
  flavor
- patches.fixes/ia64-sparse-fixes.diff: ia64-kvm: fix sparse
  warnings.
- patches.xen/xen3-fixup-common: rediff
- patches.xen/xen3-auto-common.diff: rediff
- patches.xen/xen3-patch-2.6.21: rediff
- patches.xen/xen3-patch-2.6.26: rediff
- patches.trace/rcu-read-sched.patch
- patches.trace/markers-use-rcu-read-lock-sched.patch
- patches.trace/tracepoints.patch
- patches.trace/tracepoints-use-table-size-macro.patch
- patches.trace/tracepoints-documentation.patch
- patches.trace/tracepoints-tracepoint-synchronize-unregister.patch
- patches.trace/tracepoints-documentation-fix-teardown.patch
- patches.trace/tracepoints-samples.patch
- patches.trace/tracepoints-samples-fix-teardown.patch
- patches.trace/lttng-instrumentation-irq.patch
- patches.trace/lttng-instrumentation-scheduler.patch
- patches.trace/lttng-instrumentation-timer.patch
- patches.trace/lttng-instrumentation-kernel.patch
- patches.trace/lttng-instrumentation-filemap.patch
- patches.trace/lttng-instrumentation-swap.patch
- patches.trace/lttng-instrumentation-memory.patch
- patches.trace/lttng-instrumentation-page_alloc.patch
- patches.trace/lttng-instrumentation-hugetlb.patch
- patches.trace/lttng-instrumentation-net.patch
- patches.trace/lttng-instrumentation-ipv4.patch
- patches.trace/lttng-instrumentation-ipv6.patch
- patches.trace/lttng-instrumentation-socket.patch
- patches.trace/lttng-instrumentation-fs.patch
- patches.trace/lttng-instrumentation-ipc.patch
- patches.trace/ftrace-port-to-tracepoints.patch
- patches.trace/ftrace-framepointer.diff
* Tue Sep 23 2008 jjolly@suse.de
- patches.arch/s390-01-03-cmm2-v2.patch: kernel (new function):
  Collaborative Memory Management Stage II (bnc#417244)
- patches.xen/xen3-auto-common.diff: Modified patch to allow for
  the new patch
* Tue Sep 23 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Enable sparse checking and section
  mismatch checking.
* Tue Sep 23 2008 jeffm@suse.de
- patches.kernel.org/arch-include-asm-fixes: kbuild: Properly
  handle arch/$arch/include/asm (bnc#427473).
* Mon Sep 22 2008 jeffm@suse.de
- patches.fixes/ext2-avoid-printk-flood-with-dir-corruption:
  ext2: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
- patches.fixes/ext3-avoid-printk-flood-with-dir-corruption:
  ext3: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
* Mon Sep 22 2008 jeffm@suse.de
- Update to 2.6.27-rc7.
  - Eliminated 2 patches.
  - patches.arch/s390-01-04-fcpperf-4.patch: Fixed up context.
* Mon Sep 22 2008 trenn@suse.de
  Workaround for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
  Commented out for now, possibly to be included later
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  cpufreq: Add a cpu parameter to __cpufreq_driver_getavg()..
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  cpufreq,ondemand: Use get_cpu_idle_time_us() to get
  micro-accounted idle information.
- patches.drivers/cpufreq_change_load_calculation_2.patch:
  cpufreq, ondemand: Change the load calculation, optimizing
  for dependent cpus.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  export get_cpu_idle_time_us() .
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  cpufreq,ondemand: Prepare changes for doing micro-accounting.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  cpufreq, ondemand: Use a parameter for down differential.
  Added CONFIG_PCIEASPM for rt, xen, powerpc and IA64 to be more
  consistent across different kernel flavors as suggested on the
  kernel list:
- Update config files.
* Mon Sep 22 2008 hare@suse.de
- patches.drivers/open-fcoe-libfc: Fix build error on IA64.
- patches.fixes/scsi-terminate-target-reset: Target reset hangs
  (bnc#427267).
- supported.conf: Update to include supported SCSI adapters.
* Fri Sep 19 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Re-enable after removing FTRACE
  related change.
- Update x86 non-debug config files: Turn off FRAME_POINTER and FTRACE.
* Fri Sep 19 2008 nfbrown@suse.de
- patches.fixes/md-Allow-metadata_version-to-be-updated-for-externa.patch:
  md: Allow metadata_version to be updated for externally managed
  metadata. (FATE#304218).
- patches.fixes/md-Don-t-try-to-set-an-array-to-read-auto-if-it-i.patch:
  md: Don't try to set an array to 'read-auto' if it is already
  in that state. (FATE#304218).
* Thu Sep 18 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Disable.
- Re-enable CONFIG_FRAME_POINTER in x86 config files.
* Thu Sep 18 2008 jbeulich@novell.com
- Update i386 and x86-64 config files (disable CONFIG_FRAME_POINTER in
  non-debug configs).
- patches.suse/stack-unwind: Add missing put_cpu()-s for x86-64.
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
* Thu Sep 18 2008 hare@suse.de
- Update config files.
- patches.drivers/open-fcoe-driver: fcoe: Fibre Channel over
  Ethernet driver (FATE#303913).
- patches.drivers/open-fcoe-libfc: libfc: a modular software
  Fibre Channel implementation (FATE#303913).
- patches.drivers/open-fcoe-header-files: FC protocol definition
  header files (FATE#303913).
- patches.drivers/open-fcoe-dcb-support: FCoE: Add DCB support
  (FATE#303913).
- patches.drivers/ixgbe-fcoe-bugfixes: ixgbe: Bugfixes for FCoE.
- patches.fixes/vlan-gso-size-fix: vlan: device not reading gso
  max size of parent. (FATE#303913).
- patches.fixes/pkt_action-skbedit: pkt_action: add new action
  skbedit.
- patches.fixes/pkt_sched_multiq_support: pkt_sched: Add
  multiqueue scheduler support (FATE#303913).
- supported.conf: Update to include FCoE and device_handler
  modules
* Wed Sep 17 2008 jbeulich@novell.com
- supported.conf: adjust name of ide-cd (is now ide-cd_mod).
* Wed Sep 17 2008 hare@suse.de
- patches.drivers/qla2xxx-defer-risc-interrupt-enablement:
  qla2xxx: Defer enablement of RISC interrupts until ISP
  initialization completes (FATE#304113).
- patches.drivers/qla2xxx-8.02.01-k8-update: Update qla2xxx to
  8.02.01-k8 (FATE#304113).
* Wed Sep 17 2008 hare@suse.de
- patches.fixes/scsi-retry-hardware-error: make scsi_check_sense
  HARDWARE_ERROR return ADD_TO_MLQUEUE on retry (FATE#304042)
* Tue Sep 16 2008 olh@suse.de
- disable CONFIG_SPARSEMEM_VMEMMAP on ppc64 to allow memory remove
  (bnc#417537)
* Mon Sep 15 2008 jkosina@suse.de
- Update config files (build elousb driver as module)
- patches.drivers/elousb.patch: Elo USB touchscreen driver
  (FATE#304972).
* Mon Sep 15 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: Abort queued requests for
  multipath (FATE#304151).
* Mon Sep 15 2008 hare@suse.de
- Update config files: Disable CONFIG_OCFS2_COMPAT_JBD
* Mon Sep 15 2008 hare@suse.de
- patches.xen/xen-scsifront-block-timeout-update: Update XEN
  scsifront driver to request timeouts.
* Mon Sep 15 2008 sdietrich@suse.de
- Update config files: Enable GROUP_SCHED, FAIR_GROUP_SCHED,
  RT_GROUP_SCHED, CGROUP_SCHED
* Mon Sep 15 2008 hare@suse.de
- patches.drivers/block-timeout-handling: Fix typo.
* Fri Sep 12 2008 duwe@suse.de
- Add LED driver for SGI "UV" systems (FATE#304268)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/bdev-resize-added-flush_disk: Added
  flush_disk to factor out common buffer cache flushing code
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-adjust-block-device-size:
  Adjust block device size after an online resize of a
  disk. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-call-flush_disk: Call flush_disk()
  after detecting an online resize. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-check-for-device-resize:
  Check for device resize when rescanning partitions
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-sd-driver-calls: SCSI sd driver
  calls revalidate_disk wrapper (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-wrapper-for-revalidate_disk:
  Wrapper for lower-level revalidate_disk
  routines. (FATE#302348,FATE#303786).
- patches.drivers/block-timeout-handling: block: unify request
  timeout handling (FATE#304151,bnc#417544).
- patches.fixes/scsi-misc-git-update: SCSI misc fixes
  (FATE#303485,FATE#303484).
- patches.fixes/scsi-enhance-error-codes: Separate failfast into
  multiple bits (FATE#303485,FATE#303484).
- patches.suse/rq-based-block-layer: rediff.
- patches.suse/rq-based-multipath-functions: rediff.
- patches.suse/no-partition-scan: rediff.
* Fri Sep 12 2008 hare@suse.de
- patches.fixes/scsi-misc-git-update: SCSI misc fixes,
  required by the driver updates (FATE#303485,FATE#303484)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.1-update: Update lpfc to 8.2.8.1
  (bnc#420767).
- patches.drivers/lpfc-8.2.8-update: Emulex lpfc driver update
  to 8.2.8 (FATE#303485,bnc#420767).
* Fri Sep 12 2008 bwalle@suse.de
- patches.arch/ia64-kdump_proc_iomem.diff:
  IA64: assign a distinguishable label to uncached memory in
  /proc/iomem (to fix MCA on kdump boot).
* Thu Sep 11 2008 jack@suse.cz
  Latest ext4 fixes from ext4 patch queue:
- patches.fixes/ext4-Add-inode-to-journal-handle-after-block-alloca.patch:
  ext4: Don't add the inode to journal handle until after the
  block is allocated (fate#303783).
- patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors:
  ext4: add missing unlock in ext4_check_descriptors() on error
  path (fate#303783).
- patches.fixes/ext4-Add-percpu-dirty-block-accounting.patch:
  ext4: Add percpu dirty block accounting. (fate#303783).
- patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully:
  ext4: fix #11321: create /proc/ext4/*/stats more carefully
  (fate#303783).
- patches.fixes/ext4_fix_longlong_checkpatch_issues: ext4:
  Fix long long checkpatch warnings (fate#303783).
- patches.fixes/ext4_fix_printk_checkpatch_issues: ext4:
  Add printk priority levels to clean up checkpatch warnings
  (fate#303783).
- patches.fixes/ext4_fix_whitespace_checkpatch_issues: ext4:
  Fix whitespace checkpatch warnings/errors (fate#303783).
- patches.fixes/ext4_i_disksize_lock_race_fix.patch: ext4:
  Properly update i_disksize. (fate#303783).
- patches.fixes/ext4_invalidate_pages_when_delalloc_alloc_fail.patch:
  ext4: invalidate pages if delalloc block allocation
  fails. (fate#303783).
- patches.fixes/ext4-Make-sure-all-the-block-allocation-paths-reser.patch:
  ext4: Make sure all the block allocation paths reserve blocks
  (fate#303783).
- patches.fixes/ext4_nonmballoc_reservation_ENOSPC_fix.patch:
  ext4: Fix ext4 nomballoc allocator for ENOSPC (fate#303783).
- patches.fixes/ext4-Retry-block-allocation-if-we-have-free-blocks.patch:
  ext4: Retry block allocation if we have free blocks left
  (fate#303783).
- patches.fixes/ext4-Retry-block-reservation.patch: ext4: Retry
  block reservation (fate#303783).
- patches.fixes/ext4-Signed-arithematic-fix.patch: ext4: Signed
  arithematic fix (fate#303783).
- patches.fixes/ext4-Switch-to-non-delalloc-mode-when-we-are-low-on.patch:
  ext4: Switch to non delalloc mode when we are low on free
  blocks count. (fate#303783).
- patches.fixes/ext4_truncate_block_allocated_on_a_failed_ext4_write_begin.patch:
  ext4: truncate block allocated on a failed ext4_write_begin
  (fate#303783).
- patches.fixes/ext4_update-flex-bg-counters-when-resizing:
  Update flex_bg free blocks and free inodes counters when
  resizing. (fate#303783).
- patches.fixes/percpu_counter_sum_cleanup.patch: percpu counter:
  clean up percpu_counter_sum_and_set() (fate#303783).
* Thu Sep 11 2008 bwalle@suse.de
- Enable KDB for i386 and x86_64 in "default" and "pae"
  configuration with CONFIG_KDB_OFF set to "y" (FATE#303971).
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC=2 in all configurations
  that have KDB enabled.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  enable PID_NS and USER_NS
  (FATE#303785, FATE#304371)
* Thu Sep 11 2008 jeffm@suse.de
- Update config files.
  - Enabled CONFIG_XFRM_SUB_POLICY (FATE#303781)
* Thu Sep 11 2008 mfasheh@suse.com
- Added POSIX File Locks support for Ocfs2  (FATE#110294)
  - patches.suse/ocfs2-POSIX-file-locks-support.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 JBD2 Support  (FATE#302877)
  - patches.suse/ocfs2-Limit-inode-allocation-to-32bits.patch
  - patches.suse/ocfs2-Add-the-inode64-mount-option.patch
  - patches.suse/ocfs2-Switch-over-to-JBD2.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 Extended Attributes Support (FATE#302067)
  - patches.suse/ocfs2-Modify-ocfs2_num_free_extents-f.patch
  - patches.suse/ocfs2-Use-ocfs2_extent_list-instead-o.patch
  - patches.suse/ocfs2-Abstract-ocfs2_extent_tree-in-b.patch
  - patches.suse/ocfs2-Make-high-level-btree-extend-co.patch
  - patches.suse/ocfs2-Add-the-basic-xattr-disk-layout-in-ocf.patch
  - patches.suse/ocfs2-Add-helper-function-in-uptodate.patch
  - patches.suse/ocfs2-Add-extent-tree-operation-for-x.patch
  - patches.suse/ocfs2-reserve-inline-space-for-extend.patch
  - patches.suse/ocfs2-Add-extended-attribute-support.patch
  - patches.suse/ocfs2-Add-xattr-index-tree-operations.patch
  - patches.suse/ocfs2-Add-xattr-bucket-iteration-for.patch
  - patches.suse/ocfs2-Add-xattr-lookup-code-xattr-btr.patch
  - patches.suse/ocfs2-Optionally-limit-extent-size-in.patch
  - patches.suse/ocfs2-Enable-xattr-set-in-index-btree.patch
  - patches.suse/ocfs2-Delete-all-xattr-buckets-during.patch
  - patches.suse/ocfs2-Add-incompatible-flag-for-exten.patch
  - patches.suse/ocfs2-fix-printk-format-warnings.patch
  - patches.suse/ocfs2-Prefix-the-extent-tree-operations-structure.patch
  - patches.suse/ocfs2-Prefix-the-ocfs2_extent_tree-structure.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-get-put-instead-of-all.patch
  - patches.suse/ocfs2-Make-private-into-object-on-ocfs2_extent_.patch
  - patches.suse/ocfs2-Provide-the-get_root_el-method-to-ocfs2_ext.patch
  - patches.suse/ocfs2-Use-struct-ocfs2_extent_tree-in-ocfs2_num_fre.patch
  - patches.suse/ocfs2-Determine-an-extent-tree-s-max_leaf_clusters.patch
  - patches.suse/ocfs2-Create-specific-get_extent_tree-functions.patch
  - patches.suse/ocfs2-Add-an-insertion-check-to-ocfs2_extent_tree_o.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-the-first-class-repres.patch
  - patches.suse/ocfs2-Comment-struct-ocfs2_extent_tree_operations.patch
  - patches.suse/ocfs2-Change-ocfs2_get_-_extent_tree-to-ocfs2_ini.patch
  - patches.suse/ocfs2-bug-fix-for-journal-extend-in-xattr.patch
  - patches.suse/ocfs2-Resolve-deadlock-in-ocfs2_xattr_free_.patch
  - patches.suse/ocfs2-Add-xattr-mount-option-in-ocfs2_show_options.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/jbd2-create-proc-entry-fix.patch
  jbd2: Create proc entry with bdevname+i_ino.
  (FATE#302877)
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/dlm-allow-multiple-lockspaces.patch
  dlm: allow multiple lockspace creates
  (FATE#110294)
* Thu Sep 11 2008 schwab@suse.de
- Update kdb patches.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  change CONFIG_NODES_SHIFT from 6 to 9
  (FATE#304261)
* Wed Sep 10 2008 trenn@suse.de
- Update config files.
  Added: CONFIG_PCIEASPM
* Wed Sep 10 2008 kkeil@suse.de
- patches.drivers/e1000e_add_82574L.patch: e1000e: add support
  for new 82574L part.
- patches.drivers/e1000e_add_ICH9_BM.patch: e1000e: add support
  for the 82567LM-4 device.
- patches.drivers/e1000e_add_LOM_devices.patch: e1000e: add
  support for 82567LM-3 and 82567LF-3 (ICH10D).
  (FATE#303916)
* Wed Sep 10 2008 hare@suse.de
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697)
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/ipmi-section-conflict.diff: ipmi: Fix
  section type conflicts.
- patches.kernel.org/psmouse-section-conflict.diff: psmouse:
  fix section type conflict.
- patches.kernel.org/carmine-section-mismatch: video: Fix section
  mismatch in carminefb.
- patches.kernel.org/md-section-conflict: md: Fix section
  conflicts.
- patches.kernel.org/setup_APIC_timer-section-mismatch: x86:
  Fix section conflict with kvm_setup_secondary_clock.
* Wed Sep 10 2008 trenn@suse.de
- patches.arch/thinkpad_fingers_off_backlight_igd.patch:
  Serve ThinkPad IGD devices backlight functionality through
  thinkpad_acpi (fate #302883).
- supported.conf: Add most important laptop drivers as supported:
    kernel/drivers/misc/asus_laptop
    kernel/drivers/misc/eeepc-laptop
    kernel/drivers/misc/msi-laptop
    kernel/drivers/misc/fujitsu-laptop
    kernel/drivers/acpi/wmi
    kernel/drivers/misc/hp-wmi
* Wed Sep 10 2008 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Fixed up
  some section conflicts.
* Wed Sep 10 2008 jeffm@suse.de
- Update to 2.6.27-rc6.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Added missing netfilter modules.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Updated netfilter module names.
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: Updated header.
* Wed Sep 10 2008 jkosina@suse.de
- Update config files: support more than 4 serial ports
  (FATE#303314)
* Wed Sep 10 2008 olh@suse.de
- set CONFIG_CMM=y instead of =m to simplify virtual partition memory
  (bnc#417554)
* Tue Sep  9 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: add Recommends: kerneloops
* Tue Sep  9 2008 olh@suse.de
- Updated to 2.6.27-rc5-git10
* Mon Sep  8 2008 olh@suse.de
- Updated to 2.6.27-rc5-git9
* Fri Sep  5 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: system call
  notification with self_ptrace (bnc#417299)
- patches.arch/s390-01-02-dcss-64-v2.patch: dcssblk (new function):
  Add support for >2G DCSS and stacked contiguous DCSS support.
  (bnc#417246)
- patches.arch/s390-01-04-fcpperf-{1-4}.patch: (kernel):FCP -
  Performance Data colletion & analysis (bnc#417243)
* Fri Sep  5 2008 olh@suse.de
- add patches.fixes/usb-hcd-interrupt-shared.patch
  fix interrupt handling for shared irqs, for PS3 (bnc#409961)
* Fri Sep  5 2008 olh@suse.de
- Updated to 2.6.27-rc5-git7
* Thu Sep  4 2008 olh@suse.de
- build with CONFIG_POWER4_ONLY (bnc#417566)
  this disables support for POWER3 and RS64 cpus
* Thu Sep  4 2008 jkosina@suse.de
- switch from Reno to Cubic as default TCP congestion algorithm
  (bnc#422825)
* Thu Sep  4 2008 bwalle@suse.de
- Update KDB patches. Fix build on x86_64-debug.
* Wed Sep  3 2008 jeffm@suse.de
- mark crc-t10dif as supported
* Wed Sep  3 2008 olh@suse.de
- mark pata_pdc2027x as supported
* Wed Sep  3 2008 olh@suse.de
- mark spidernet as supported
* Wed Sep  3 2008 olh@suse.de
- mark ehea as supported
* Wed Sep  3 2008 trenn@suse.de
- supported.conf:
  Mark dock (libata depends on it), bay, acpi_memhotplug, hpilo
  as supported
  Remove or adjust supported laptop drivers that went from
  drivers/acpi to drivers/misc
* Wed Sep  3 2008 hare@suse.de
- supported.conf: Mark virtio modules as supported.
* Tue Sep  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc5 and c/s 651.
* Tue Sep  2 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v2.patch: kernel
  (new function): System call notification with self_ptrace
  (bnc#417299,FATE#304021)
* Mon Sep  1 2008 agruen@suse.de
- File capabilities: replace our no_file_caps patch with what is
  supposed to end up in 2.6.28.
* Mon Sep  1 2008 bwalle@suse.de
- patches.arch/ia64-node_mem_map-node_start_pfn.diff:
  Fix memory map for ia64/discontmem for kdump.
* Mon Sep  1 2008 olh@suse.de
- Updated to 2.6.27-rc5-git2
* Fri Aug 29 2008 jeffm@suse.de
- Updated to 2.6.27-rc5.
  - Eliminated 2 patches.
  - KDB has an incompatible change on x86_64, so kernel-debug
    will fail there.
* Fri Aug 29 2008 olh@suse.de
- update message in post.sh to display also the rpm FLAVOR
* Thu Aug 28 2008 olh@suse.de
- update patches.suse/dm-raid45-2.6.25-rc2_20080221.patch
  rename rh_init to region_hash_init to avoid conflict
  with existing powerpc symbol on powerpc
* Thu Aug 28 2008 olh@suse.de
- disable musb, not useful, does not compile
* Tue Aug 26 2008 trenn@suse.de
  Vendor specific drivers vs generic video driver.
  Distinguish which ACPI driver should do backlight switching.
  This patch series is queued up for 2.6.28 in the ACPI branch:
- patches.arch/0000-ACPI-video-Ignore-devices-not-present.patch:
  ACPI: video: Ignore devices that aren't present in hardware.
- patches.arch/0001-Check-for-ACPI-backlight-support.patch: Check
  for ACPI backlight support otherwise use vendor ACPI drivers.
- patches.arch/0002-Acer-WMI-fingers-off-backlight-video.ko.patch:
  Acer-WMI: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0003-Asus-acpi-fingers-off-backlight.patch:
  asus-acpi: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0004-Compal-fingers-off-backlight.patch: compal:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0005-eeepc-laptop-fingers-off.patch: eeepc-laptop:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0006-fujitsu-laptop-fingers-off-backlight.patch:
  fujitsu-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0007-msi-laptop-fingers-off-backlight.patch:
  msi-laptop: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0009-thinkpad_acpi-fingers-off-backlight.patch:
  thinkpad_acpi: fingers off backlight if video.ko is serving
  this functionality.
  I had to refresh these. While one patch was broken,
  two lines were missing, "patch" from 11.0 still worked, while
  "patch" from 10.3 did not:
- patches.xen/add-console-use-vt: add console_use_vt.
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  kexec: Move asm segment handling code to the assembly file
  (i386).
* Mon Aug 25 2008 jeffm@suse.de
- Disabled patches.kernel.org/ia64-asm-nr-irqs
* Mon Aug 25 2008 jeffm@suse.de
- patches.fixes/pseries-compile-fix: pseries: compile fix.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/musb-powerpc-conflict: musb: compile fix
  for powerpc.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/ia64-asm-nr-irqs: ia64: nr-irqs.h generation
  should place it in arch/../asm.
* Mon Aug 25 2008 jeffm@suse.de
- Update config files.
* Mon Aug 25 2008 jeffm@suse.de
- Updated to 2.6.27-rc4.
  - Refreshed context.
* Mon Aug 25 2008 trenn@suse.de
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch:
  x86, pci: introduce pci=noioapicquirk kernel cmdline option.
  Mysterious patch problem in include/asm-x86/pci.h
- patches.fixes/acpi-clear-wake-status.patch: Clear wak_sts
  register on resume.
* Mon Aug 25 2008 trenn@suse.de
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  Delete.
* Mon Aug 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc4.
- patches.xen/xen-x86_64-dump-user-pgt: dump the correct page
  tables for user mode faults.
- patches.xen/xen-x86_64-pgd-alloc-order: don't require order-1
  allocations for pgd-s.
- patches.xen/xen-x86_64-pgd-pin: make pinning of pgd pairs
  transparent to callers.
- patches.xen/xen-blktap-write-barriers: blktap: Write Barriers.
- patches.xen/xen-x86-pmd-handling: consolidate pmd/pud/pgd entry
  handling.
- patches.xen/xen-x86-bigmem: fix issues with the assignment of
  huge amounts of memory.
- patches.xen/xen-msix-restore: print at least a message if MSI-X
  restore failed.
- config.conf: Re-enable Xen.
- patches.xen/sfc-i2c: Delete.
- Update config files.
* Fri Aug 22 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Adjust and re-enable.
- Update config files.
* Tue Aug 19 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: Delete.
* Tue Aug 19 2008 jeffm@suse.de
- Removed unused patches.
* Tue Aug 19 2008 tiwai@suse.de
- Update config files: Use CONFIG_INPUT_PCSPKR=m (bnc#225221)
* Mon Aug 18 2008 schwab@suse.de
- Update config files.
* Mon Aug 18 2008 schwab@suse.de
- Update kdb patches.
* Fri Aug 15 2008 tiwai@suse.de
- patches.arch/ppc-ipic-suspend-without-83xx-fix: Fix build_error
  without CONFIG_PPC_83xx.
- Update config files.
* Fri Aug 15 2008 tiwai@suse.de
- Update config files: disable CONFIG_IPIC for ppc/default and
  vanilla again to fix build
* Fri Aug 15 2008 tiwai@suse.de
- rpm/kernel-binary.spec.in: fix build without firmware files
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/no-include-asm: kbuild: correctly link
  include/asm in external builds.
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/ath9k-workaround-gcc-ICE-again-on-powerpc:
  ath9k: work around gcc ICE again.
* Thu Aug 14 2008 jeffm@suse.de
- patches.suse/novfs-gregorian-day-fix: novfs: Fix GregorianDay
  conflict.
* Thu Aug 14 2008 jeffm@suse.de
- Enabled patches.kernel.org/firmware-path
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Fixed duplicate
  export of security_inode_permission.
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Add missing
  stub for security_path_permission when CONFIG_SECURITY_APPARMOR=n
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: firmware: Allow
  release-specific firmware dir.
- rpm/kernel-binary.spec.in: Add firmware files.
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/ia64-export-cpu_core_map: ia64: Export
  cpu_core_map for topology_core_siblings.
* Thu Aug 14 2008 jeffm@suse.de
- Updated to 2.6.27-rc3.
  - AppArmor mostly merged. There may be some hiccups.
  - Xen and RT temporarily disabled for merging.
  - 17 patches eliminated.
* Thu Aug 14 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  ftrace: fix elevated preempt_count in wakeup-tracer.
* Fri Aug  8 2008 hare@suse.de
- Update config files for RT kernel to activate SCSI
  device handler.
* Fri Aug  8 2008 jbeulich@novell.com
- patches.xen/xen3-fixup-common, patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.24, patches.xen/xen3-patch-2.6.25: Fix
  a couple of bugs and inconsistencies.
* Fri Aug  8 2008 schwab@suse.de
- Fix reference to $RPM_BUILD_ROOT in makefiles.
* Fri Aug  8 2008 hare@suse.de
- patches.fixes/dm-mpath-hp-sw.patch: Delete.
- Update config files.
- patches.fixes/dm-2.6.27-update: Upstream device-mapper patches
  (FATE#302108).
- patches.fixes/scsi_dh-2.6.27-update: SCSI device handler update
  (FATE#302269,FATE#303696,FATE#303754,FATE#304125).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  block layer changes (FATE#302108).
- patches.suse/rq-based-dm-interface: rq-based multipathing:
  device-mapper interface (FATE#302108).
- patches.suse/rq-based-multipath-functions: rq-based
  multipathing: request-based functions to multipath
  (FATE#302108).
* Thu Aug  7 2008 jbeulich@novell.com
- Update Xen patches to c/s 623.
- patches.xen/sfc-network-driver: Delete.
- patches.xen/xen-balloon-hvm-min: Delete.
- patches.xen/xen-netfront-flip-prod: Delete.
- patches.xen/xen-x86_64-init-cleanup: Delete.
- patches.xen/sfc-i2c: sfc: Use kernel I2C system and i2c-algo-bit
  driver (disabled).
- patches.xen/sfc-driverlink: Solarflare: Resource driver (disabled).
- Update Xen config files.
* Wed Aug  6 2008 olh@suse.de
- add patches.suse/ppc-no-LDFLAGS_MODULE.patch
  do not link external modules against arch/powerpc/lib/crtsavres.o
* Tue Aug  5 2008 jeffm@suse.de
- patches.fixes/reiserfs-commit-ids-unsigned-ints: reiserfs:
  audit transaction ids to always be unsigned ints (bnc#410847).
* Tue Aug  5 2008 jeffm@suse.de
- README.BRANCH: Took ownership of 11.1 tree.
* Tue Aug  5 2008 jeffm@suse.de
- README: Changed w3d links to wiki links.
* Tue Aug  5 2008 ghaskins@suse.de
  Fixed misnamed rt_trace to rt_timing
- config/x86_64/rt_trace: Delete.
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Added x86_64/rt_trace kernel flavor (based on ftrace)
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Fix rtmutex-tester build problem with rt_debug
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Remove version.patch to stop build breakage
* Tue Aug  5 2008 jjohansen@suse.de
- update apparmor patches with fixes for
  - broken getcwd (bnc#413915)
  - ref counting bug in getcwd and d_namespace_path when used
    on disconnected paths (bnc#414607)
  - typeo in patches that keep selinux from compiling (bnc#414609)
  - incorporate smack patch into base apparmor patches, so
    that smack can be built (bnc#414610)
* Tue Aug  5 2008 jslaby@suse.de
- patches.fixes/ath5k-fix-memory-corruption.patch: Ath5k: fix
  memory corruption (bnc#414635).
- patches.fixes/ath5k-kill-tasklets-on-shutdown.patch: Ath5k:
  kill tasklets on shutdown (bnc#414638).
* Mon Aug  4 2008 gregkh@suse.de
- README.BRANCH: added file.
* Mon Aug  4 2008 olh@suse.de
- disable CONFIG_SECURITY_ROOTPLUG because /init in initrd will
  not run if USB is compiled in and a specific USB device is not
  present
* Mon Aug  4 2008 jslaby@suse.de
- patches.fixes/tpm-write-data-types.patch: tpm: Use correct
  data types for sizes in tpm_write() and tpm_read() (bnc#400211).
* Fri Aug  1 2008 ghaskins@suse.de
  PI rework v0.5 and a fix from upstream for 26-rt1
- patches.rt/26-rt1-chirag.patch: This patch should solve some
  of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: add generalized
  priority-inheritance interface.
- patches.rt/tie-pi-into-task.patch: sched: add the basic PI
  infrastructure to the task_struct.
- patches.rt/rtmutex-initialize-waiters.patch: rtmutex: formally
  initialize the rt_mutex_waiters.
- patches.rt/rtmutex-add_readers.patch: RT: wrap the rt_rwlock
  "add reader" logic.
- patches.rt/rtmutex-use-runtime-init.patch: rtmutex: use runtime
  init for rtmutexes.
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: rtmutex:
  pi-boost locks as late as possible.
* Fri Aug  1 2008 schwab@suse.de
- Reenable EFI_RTC.
* Fri Aug  1 2008 trenn@suse.de
- Update config files.
  Unset on forgotten archs:
  CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS
* Fri Aug  1 2008 trenn@suse.de
- patches.fixes/x86_hpet_amd_quirk.patch: Workaround a hpet BIOS
  bug which is common on latest AMD driven boards (bnc#387053).
* Fri Aug  1 2008 sassmann@suse.de
  Add boot interrupt patches from linux-2.6-tip
- patches.arch/x86-acpi-reroute-PCI-interrupt-to-legacy-boot-interrupt.patch
- patches.arch/x86-add-PCI-IDs-for-devices-that-need-boot-irq-quirk.patch
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch
- patches.arch/x86-disable-broadcomm-boot-interrupt-generation.patch
- patches.arch/x86-disable-intel-boot-interrupt-generation.patch
- patches.arch/x86-introduce-config-option-for-pci-reroute-quirks.patch
- patches.arch/x86-introduce-pci-ioapicreroute-kernel-cmdline.patch
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch
- Update config files.
  * reroute of boot interrupts is enabled for RT only!
* Thu Jul 31 2008 sdietrich@suse.de
  Update to 2.6.26-rt1:
- config.conf: Enable i386/x86_64 - RT / RT_debug
- Update config files:
  * Sync to default config.
  * Disable (broken):
  - Novell Netware Filesystem support (novfs) (EXPERIMENTAL) (NOVFS)
  - ISP 1760 HCD support (USB_ISP1760_HCD)
  - KDB
  - QLogic InfiniPath Driver (INFINIBAND_IPATH)
  Remove obsolete patches:
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-omap-03.patch: Delete.
- patches.rt/arm-omap-04.patch: Delete.
- patches.rt/disable-sched-rt-groups.patch: Delete.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch: Delete.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Delete.
- patches.rt/drivers-edac-new-amd64.patch: Delete.
- patches.rt/drivers-edac-new-k8-rev-f.patch: Delete.
- patches.rt/drivers-edac-prevent-potential-printk-storm: Delete.
- patches.rt/drivers-edac-test_device.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/fix-alternate_node_alloc.patch: Delete.
- patches.rt/fix-irq-flags-size.patch: Delete.
- patches.rt/foo.patch: Delete.
- patches.rt/ftrace-add-nr_syscalls.patch: Delete.
- patches.rt/ftrace-alloc-pages.patch: Delete.
- patches.rt/ftrace-cpu-clock-update.patch: Delete.
- patches.rt/ftrace-debug-use-preempt-disable-notrace.patch:
  Delete.
- patches.rt/ftrace-direct-calls.patch: Delete.
- patches.rt/ftrace-disable-daemon.patch: Delete.
- patches.rt/ftrace-dont-use-raw-irq-save.patch: Delete.
- patches.rt/ftrace-eventtrace-fixup.patch: Delete.
- patches.rt/ftrace-filter-functions.patch: Delete.
- patches.rt/ftrace-fix-ip.patch: Delete.
- patches.rt/ftrace-flip-fix.patch: Delete.
- patches.rt/ftrace-handle-time-outside-of-lockdep.patch: Delete.
- patches.rt/ftrace-irqsoff-smp-processor-id-fix.patch: Delete.
- patches.rt/ftrace-lockdep-notrace-annotations.patch: Delete.
- patches.rt/ftrace-max-update-fixes.patch: Delete.
- patches.rt/ftrace-move-memory-management-to-generic.patch:
  Delete.
- patches.rt/ftrace-nop-calls.patch: Delete.
- patches.rt/ftrace-peterz-cpu_clock.patch: Delete.
- patches.rt/ftrace-remove-max-printks.patch: Delete.
- patches.rt/ftrace-safe-traversal-hlist.patch: Delete.
- patches.rt/ftrace-stop-function-trace-fix.patch: Delete.
- patches.rt/ftrace-unlock-mutex-in-output.patch: Delete.
- patches.rt/ftrace-update-cnt-stat-fix.patch: Delete.
- patches.rt/ftracer-build-fix.patch: Delete.
- patches.rt/futex-performance-hack-sysctl-fix.patch: Delete.
- patches.rt/futex-performance-hack.patch: Delete.
- patches.rt/git-ignore-module-markers.patch: Delete.
- patches.rt/irq-flags-unsigned-long.patch: Delete.
- patches.rt/kernel-bug-after-entering-something-from-login.patch:
  Delete.
- patches.rt/kthread-cpus-allowed-init.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/netfilter-more-debugging.patch: Delete.
- patches.rt/page-alloc-use-real-time-pcp-locking-for-page-draining.patch:
  Delete.
- patches.rt/pcounter-percpu-protect.patch: Delete.
- patches.rt/percpu-locked-powerpc-fixups-a6.patch: Delete.
- patches.rt/powerpc-rearrange-thread-flags-to-work-with-andi-instruction.patch:
  Delete.
- patches.rt/ppc-add-mcount.patch: Delete.
- patches.rt/ppc-add-ppc32-mcount.patch: Delete.
- patches.rt/ppc-mark-notrace-mainline.patch: Delete.
- patches.rt/ppc-mcount-dummy-functions.patch: Delete.
- patches.rt/ppc-rename-xmon-mcount.patch: Delete.
- patches.rt/ppc-select-mcount.patch: Delete.
- patches.rt/preempt-irqs-ppc-celleb-beatic-eoi.patch: Delete.
- patches.rt/preempt-irqs-softirq-in-hardirq.patch: Delete.
- patches.rt/preempt-realtime-powerpc-a7.patch: Delete.
- patches.rt/preempt-realtime-ppc-more-resched-fixups.patch:
  Delete.
- patches.rt/preempt-realtime-ppc-need-resched-delayed.patch:
  Delete.
- patches.rt/preempt-realtime-sh.patch: Delete.
- patches.rt/preempt-realtime-supress-cpulock-warning.patch:
  Delete.
- patches.rt/rcu-preempt-trace-markers-1.patch: Delete.
- patches.rt/rcu-preempt-trace-markers-2.patch: Delete.
- patches.rt/rcu-various-fixups.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-delayed-resched.patch: Delete.
- patches.rt/rt-mutex-drop-generic-TIF_NEED_RESCHED_DELAYED.patch:
  Delete.
- patches.rt/rt-time-starvation-fix.patch: Delete.
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/sched-fix-rt-task-wakeup.patch: Delete.
- patches.rt/sched-fix-sched-fair-wakeup.patch: Delete.
- patches.rt/sched-rt-push-only-new.patch: Delete.
- patches.rt/schedule_on_each_cpu-enhance-rt.patch: Delete.
- patches.rt/tasklet-fix-preemption-race.patch: Delete.
- patches.rt/tasklet-more-fixes.patch: Delete.
- patches.rt/time-gcc-linker-error.patch: Delete.
- patches.rt/tracer-use-sched-clock.patch: Delete.
- patches.rt/write-try-lock-irqsave.patch: Delete.
- patches.rt/x86-delay-enable-preempt-tglx.patch: Delete.
  Introduce 2.6.26-RT1:
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.26-RT
  radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.26-RT
  mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.26-RT
  mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.26-RT
  mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.26-RT
  mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.26-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.26-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.26-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.26-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.26-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.26-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.26-RT
  Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.26-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.26-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.26-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.26-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.26-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.26-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.26-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.26-RT.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.26-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.26-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.26-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.26-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.26-RT
  floppy: suspend/resume fix.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.26-RT
  rt: remove call to stop tracer.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.26-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.26-RT
  ftrace: define function trace nop.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.26-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.26-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.26-RT
  ftrace: trace sched.c.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.26-RT
  ftrace: avoid lockdep recursion.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.26-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.26-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.26-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.26-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.26-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.26-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.26-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.26-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.26-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.26-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.26-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.26-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.26-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.26-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.26-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.26-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.26-RT
  ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.26-RT
  lockdep: lock_set_subclass - reset a held lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.26-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.26-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.26-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.26-RT
  lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.26-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.26-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.26-RT
  RT: change from raw_spinlock_t to __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.26-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.26-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.26-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.26-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.26-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.26-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.26-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.26-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.26-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.26-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.26-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.26-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.26-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.26-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.26-RT
  x86_64: do not enable the NMI watchdog by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.26-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.26-RT
  local_bh_enable() is safe for irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.26-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.26-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.26-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.26-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.26-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.26-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.26-RT.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.26-RT
  don't trace early init functions for ppc32.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.26-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.26-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.26-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.26-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.26-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.26-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.26-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.26-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.26-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.26-RT
  radix-tree: optimistic locking.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.26-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.26-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.26-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.26-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.26-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.26-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.26-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.26-RT
  rt: plist_head_splice.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.26-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.26-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.26-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.26-RT
  rwlocks multi downgrade write.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.26-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.26-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.26-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.26-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.26-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.26-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.26-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.26-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.26-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.26-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.26-RT.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.26-RT
  trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.26-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.26-RT.
- patches.rt/version.patch: Linux-RT 2.6.26-RT
  add -rt extra-version.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.26-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.26-RT
  event-tracer: add clockevent trace.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.26-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.26-RT
  ftrace: user raw spin lock for wakeup function trace.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.26-RT
  lockdep: add +1 to radix tree array.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.26-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.26-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.26-RT
  rwlock: rwlock torture test.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.26-RT
  Re: 2.6.25.4-rt4.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.26-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.26-RT
  Fix a previously reverted "fix".
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.26-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.26-RT
  ftrace: document updates.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.26-RT
  ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.26-RT
  ftrace: only trace preempt off with preempt tracer.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.26-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.26-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.26-RT
  mapping_nrpages-fix.patch.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.26-RT
  nfs: fix missing preemption check.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.26-RT
  pmtmr: allow command line override of ioport.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.26-RT
  powerpc: ftrace stop on crash.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch~: Linux-RT 2.6.26-RT.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.26-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.26-RT
  rtmutex-debug-fix.patch.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.26-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.26-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.26-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.26-RT.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.26-RT
  sched-fix-dequeued-race.patch.
- patches.rt/serial-locking-rt-cleanup.patch~: Linux-RT 2.6.26-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.26-RT
  rt: dont disable irqs in usb.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.26-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.26-RT
  ftrace: print ktime values in readable form.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.26-RT
  remove warn on for scatterlist in preempt rt.
* Tue Jul 29 2008 trenn@suse.de
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  ACPI: Provide a spec conform OSI interface to the BIOS.
* Mon Jul 28 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: uvcvideo merged.  Add Obsoletes.
* Fri Jul 25 2008 mszeredi@suse.cz
- supported.conf: Mark fuse as supported.
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_MARKERS
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_SECURITY_SELINUX
* Thu Jul 24 2008 agruen@suse.de
- Fix for using relative paths in /usr/src/linux-obj/$arch/
  $flavor/Makefile (bnc#409982).
* Fri Jul 18 2008 hare@suse.de
- Update config files for S/390.
* Thu Jul 17 2008 bwalle@suse.de
- patches.fixes/show-OSRELEASE-in-VMCOREINFO.diff:
  kdump: Report actual value of VMCOREINFO_OSRELEASE in VMCOREINFO
* Thu Jul 17 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Removed Supplements handling
  entirely. Use preamble instead.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.26: Fix 32-bit build.
* Thu Jul 17 2008 jbeulich@novell.com
- Update Xen patches for 2.6.26.
- patches.xen/540-blkif-nr-segments-check.patch: Delete.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: Delete.
- patches.xen/xen3-patch-2.6.25.1: Delete.
- Update i386 and x86-64 config files.
- config.conf: Re-enable Xen configs.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.fixes/seccomp-disable-tsc-option: Also handle x86-64 (191123).
- Update x86-64 config files.
- patches.suse/raw_device_max_minors_param.diff: Fix uninitialized
  return value.
- patches.apparmor/remove_suid.diff: Also handle fuse.
- supported.conf: Add e1000e, rtc-core, rtc-lib, and rtc-cmos.
* Mon Jul 14 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: Delete.
* Mon Jul 14 2008 olh@suse.de
- disable unused fsl-diu-fb driver
* Mon Jul 14 2008 jeffm@suse.de
- Updated to 2.6.26-final.
* Mon Jul 14 2008 bwalle@suse.de
- patches.fixes/move-crashkernel-reservation.diff:
  x86: Move crashkernel reservation before dma32_reserve_bootmem().
* Mon Jul 14 2008 rgoldwyn@suse.de
- Enable patches.suse/convert-novfs-to-open-soure-coding-standards.patch
  Fix oops in novfs_daemon_lib_ioctl
* Fri Jul 11 2008 jeffm@suse.de
- Updated squashfs to v3.3. (bnc#373285)
* Thu Jul 10 2008 jeffm@suse.de
- Update config files: Enable raw devices on s390.
* Thu Jul 10 2008 jack@suse.cz
- patches.suse/raw_device_max_minors_param.diff: Allow setting
  of number of raw devices as a module parameter (FATE 302178).
* Thu Jul 10 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: fsl-diu-fb:
  compile fix.
* Wed Jul  9 2008 jeffm@suse.de
- patches.suse/kdb-common: Removed obsolete file_lock_operations
  printing.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: Upstreamed with
  - git5.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: reiserfs:
  discard prealloc in reiserfs_delete_inode (bnc#389656).
* Wed Jul  9 2008 jeffm@suse.de
- Updated to 2.6.26-rc9-git5.
  - Eliminated 2 patches.
* Wed Jul  9 2008 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ip_conntrack_slp.patch: connection
  tracking helper for SLP (fate#301134).
* Wed Jul  9 2008 olh@suse.de
- enable PHYP-assisted OS dump (fate#304131)
* Mon Jul  7 2008 trenn@suse.de
- patches.fixes/acpi_thermal_passive_cleanup.patch: Delete.
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-gericom-bellagio-to-nomux.patch: Input:
  add Gericom Bellagio to nomux blacklist (bnc#404892).
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-1360-to-nomux.patch: Input:
  add Acer Aspire 1360 to nomux blacklist (bnc#216857).
* Wed Jul  2 2008 jeffm@suse.de
- patches.apparmor/__d_path-keep-connected.diff
  patches.apparmor/mount-consistent-__d_path.diff
  patches.suse/kdb-ia64: Edited to apply with --fuzz=0
- Added --fuzz=0 (-F0) to sequence-patch.sh and spec files
* Fri Jun 27 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: don't generate the makedumpfile.config
  any more, the new kernel, kexec-tools and makedumpfile is able to
  extract that information from the running kernel and pass it
  as ELF NOTE (in /proc/vmcore)
* Thu Jun 26 2008 olh@suse.de
- add patches.arch/ppc-ibmebus-modalias.patch
  autoload ehea and ehca (bnc#394602 - LTC44938)
* Thu Jun 26 2008 sdietrich@suse.de
- RT:  Update config files - enable CONFIG_CGROUPS
* Thu Jun 26 2008 sdietrich@suse.de
- Update config files - enable CPUSETs support:
  CONFIG_CGROUPS, CONFIG_CGROUP_NS, CONFIG_CGROUP_DEVICE,
  CONFIG_CPUSET, CONFIG_CGROUP_CPUACCT,
  CONFIG_RESOURCE_COUNTERS, CONFIG_MM_OWNER,
  CONFIG_CGROUP_MEM_RES_CTLR, CONFIG_PROC_PID_CPUSET
- debug only: CONFIG_CGROUP_DEBUG
* Wed Jun 25 2008 jeffm@suse.de
- Updated to 2.6.26-rc8
  - Eliminated 1 patch.
* Wed Jun 25 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Added Supplements tag copying and added
    coreutils and grep to Requires
- rpm/macros.kernel-source: Added kernel-syms to BuildRequires
* Wed Jun 25 2008 olh@suse.de
- enable 64K pages in config ppc64 (fate#304100)
- enable up to 1024 cpus in config ppc64 (fate#304180)
- enable up to 4 cpus in config kdump
- enable powermanagement in config ppc64
- enable cell be cpufreq
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-isa is gone.
  - i2c-i810, i2c-prosavage and i2c-savage4 are deprecated and will
    be removed soon, mark as unsupported.
  - i2c-voodoo3 has very limited usefulness, mark as unsupported.
  - i2c-powermac is new, mark as supported.
- supported.conf: Update the list of i2c chip drivers.
  - ds1337, ds1374, rtc8564 and x1205 are gone (RTC drivers, moved
    to drivers/rtc).
  - pca9539, pcf8574 and pcf8575 are deprecated (new GPIO drivers
    exist in drivers/gpio), mark as unsupported.
  - ds1682, max6875 and tsl2550 are new, mark as supported.
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Add two new hwmon drivers (dme1737 and thmc50,
  both unsupported.)
- supported.conf: Mark hwmon and hwmon-vid as supported. These are
  simple, software-only utility modules, it makes little sense
  to taint the kernel just because they are loaded.
* Mon Jun 23 2008 tiwai@suse.de
- disable CONFIG_SND_PCSP as it conflicts with input pcspkr and
  disturbs the order of sound devices
* Mon Jun 23 2008 agruen@suse.de
- genksyms: add support for checking against a reference ABI.
* Wed Jun 18 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git5.
  - Eliminated 2 patches.
* Fri Jun 13 2008 jeffm@suse.de
- Removed kABI reference symbols
- Restored make-symsets check for ignoring/tolerating kABI changes.
* Fri Jun 13 2008 jeffm@suse.de
- Update config files (vanilla).
* Fri Jun 13 2008 jeffm@suse.de
- Update config files.
* Fri Jun 13 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git1.
  - Eliminated 2 patches.
* Thu Jun 12 2008 sdietrich@suse.de
- config.conf: Suppress RT until forward-port is complete
* Thu Jun 12 2008 jeffm@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: Delete.
* Thu Jun 12 2008 olh@suse.de
- update ps3 config, disable unused drivers
- disable patches.arch/ppc-efika-slowdown.patch
* Thu Jun 12 2008 jeffm@suse.de
- Updated to 2.6.26-rc5-git5.
  - Eliminated 91 patches.
  - Disabled OCFS2 userspace heartbeat.
  - Disabled Xen.
* Thu Jun 12 2008 sdietrich@suse.de
  Build fix: drop patches merged into 2.6.25.5
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: Delete.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  Delete.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: Delete.
  Update to 2.6.25-RT6:
- Update config files: enable (M) CONFIG_RWLOCK_TORTURE_TEST
  Resolve conflicts:
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.25.4-RT.
  Add:
- patches.rt/trace-eip2ip.patch: Re: 2.6.25.4-rt4 Compile Fix.
- patches.rt/rwlock-prio-fix.patch: rwlock: reset prio on unlocks
  and wakeups.
- patches.rt/rwlock-fixes.patch: rwlock: fix pi_list race
  conditions.
- patches.rt/event-trace-hrtimer-trace.patch: event-tracer:
  add clockevent trace.
- patches.rt/rwlock-torture.patch: rwlock: rwlock torture test.
- patches.rt/ftrace-wakeup-rawspinlock.patch: ftrace: user raw
  spin lock for wakeup function trace.
- patches.rt/radix-tree-lockdep-plus1.patch: lockdep: add +1 to
  radix tree array.
- patches.rt/sched-cpupri-hotplug-support.patch: sched: fix
  cpupri hotplug support.
- patches.rt/sched-cpupri-priocount.patch: sched: fix cpupri
  priocount.
- patches.rt/ftrace-hotplug-fix.patch: ftrace: cpu hotplug fix.
* Wed Jun 11 2008 agruen@suse.de
- rpm/make-symsets: update to the latest version which will ignore
  symset changes if the symset includes a symbol marked to be
  ignored.
* Wed Jun 11 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: only generate symsets for kernels
  with CONFIG_MODULES=y.
- rpm/macros.kernel-source: remove the ps3 specific check: we
  really want to check whether the kernel mas modules enabled,
  which is covered by the symsets check already now.
* Wed Jun 11 2008 gregkh@suse.de
- patches.drivers/usb-don-t-use-reset-resume-if-drivers-don-t-support-it.patch:
  USB: don't use reset-resume if drivers don't support it.
* Wed Jun 11 2008 gregkh@suse.de
- comment out
  patches.suse/convert-novfs-to-open-soure-coding-standards.patch in the
  series file as it is reported to fail some regression tests.
* Wed Jun 11 2008 gregkh@suse.de
- patches.suse/convert-novfs-to-open-soure-coding-standards.patch:
  Convert novfs to open soure coding standards.
* Mon Jun  9 2008 gregkh@suse.de
- patches.fixes/mptbase-vmware-fix: Delete as it's not needed anymore
* Mon Jun  9 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Mon Jun  9 2008 gregkh@suse.de
- Update to 2.6.25.6
  - loads of bugfixes
  - remove the following patches that were already included in this release:
  - patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch
  - patches.drivers/libata-force-hardreset-if-link-pm
  - patches.fixes/input-hid-apple-numlock-emulation.patch
  - patches.arch/check-for-acpi-resource-conflicts-in-i2c-bus-drivers.patch
* Mon Jun  9 2008 gregkh@suse.de
- patches.drivers/usb-sierra-option.patch: USB: update sierra
  and option device ids (bnc#374637).
* Mon Jun  9 2008 teheo@suse.de
- patches.drivers/libata-ahci-mcp65-workarounds: ahci: workarounds
  for mcp65 (bnc#398573).
* Mon Jun  9 2008 jkosina@suse.de
- patches.fixes/input-i8042-add-ctr-resume-timeout.patch: Input:
  add retry logic to resume with respect to CTR (bnc#351119).
* Sat Jun  7 2008 gregkh@suse.de
- Update to 2.6.25.5.
  - fixes CVE-2008-1673
* Fri Jun  6 2008 tiwai@suse.de
- add missing patches.rt/ftrace-add-nr_syscalls.patch for fixing
  i386-rt_debug
* Thu Jun  5 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25: netfront (bnc#394575) and page table
  handling (bnc#396858) fixes.
- patches.xen/540-blkif-nr-segments-check.patch: Avoid theoretical
  TOCTTOU bug in block backend nr_segments checking.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: x86_64:
  Remove warning message about 'Breaking affinity for irq'.
- patches.xen/xen-netfront-flip-prod: fix updating of req_prod_pvt
  in the receive ring for the flipping case.
* Wed Jun  4 2008 jblunck@suse.de
- patches.drivers/libata-acpi-fix-hotplug: Don't call ata_port_freeze()
  in ata_acpi_detach_device().
* Wed Jun  4 2008 schwab@suse.de
- Don't clean asm-offsets.h.
* Wed Jun  4 2008 jjohanse@suse.de
- patches.apparmor/apparmor-module_interface.diff: AppArmor:
  Update patch to properly set profile name_table size (bnc#396993)
* Tue Jun  3 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Add
  Fujitsu-Siemens Amilo Pro 2010 and 2030 to nomux list
  (bnc#345699 bnc#389169)
* Tue Jun  3 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-auto-resume-fix: hda - Fix
  resume of auto-config mode with Realtek codecs (bnc#385473).
* Tue Jun  3 2008 bphilips@suse.de
  Backport: e1000e for montevina systems
- patches.drivers/e1000e-backport-0001-remove-no-longer-used-e1000e_read_nvm_spi.patch:
  e1000e: remove no longer used e1000e_read_nvm_spi.
- patches.drivers/e1000e-backport-0002-remove-irq_sem.patch:
  e1000e: remove irq_sem.
- patches.drivers/e1000e-backport-0003-rename-mc_addr_list_update.patch:
  e1000e: rename mc_addr_list_update.
- patches.drivers/e1000e-backport-0004-reorganize-PHY-and-flow-control-interface.patch:
  e1000e: reorganize PHY and flow control interface.
- patches.drivers/e1000e-backport-0005-Make-arrays-out-of-these-Rx-Tx-registers.patch:
  e1000e: Make arrays out of these Rx/Tx registers.
- patches.drivers/e1000e-backport-0006-rename-a-few-functions.patch:
  e1000e: rename a few functions.
- patches.drivers/e1000e-backport-0007-cleanup-several-stats-issues.patch:
  e1000e: cleanup several stats issues.
- patches.drivers/e1000e-backport-0008-Fix-HW-Error-on-es2lan-ARP-capture-issue-by.patch:
  e1000e: Fix HW Error on es2lan, ARP capture issue by BMC.
- patches.drivers/e1000e-backport-0009-Add-support-for-BM-PHYs-on-ICH9.patch:
  e1000e: Add support for BM PHYs on ICH9.
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: Delete.
- patches.drivers/alsa-hda-backport-2.6.26-rc4: Backport ALSA
  HDA-Intel patches from 2.6.26-rc4 (bnc#390473).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-asus-a9t-fix: ac97 - Fix ASUS A9T laptop
  output (bnc#363987).
* Mon Jun  2 2008 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: reiserfs: Use list_del_init
  in use_preallocated_list_if_available (bnc#378095).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hp2133-mic-fix: hda - Fix mic input on
  HP2133 (bnc#388540).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy2-digital-fix: emu10k1 - Fix
  inverted Analog/Digital mixer switch on Audigy2 (bnc#396204).
* Sat May 31 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt4 (refreshed patches suppressed)
- Update config files.
  Added:
- patches.rt/adapt-remove-extra-try-to-lock.patch
- patches.rt/adaptive-adjust-pi-wakeup.patch
- patches.rt/adaptive-earlybreak-on-steal.patch
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch
- patches.rt/adaptive-task-oncpu.patch
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch
- patches.rt/arm-omap-02.patch
- patches.rt/arm-omap-03.patch
- patches.rt/arm-omap-04.patch
- patches.rt/arm-omap-05.patch
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch
- patches.rt/ftrace-compile-fixes.patch
- patches.rt/ftrace-disable-daemon.patch
- patches.rt/ftrace-dont-trace-markers.patch
- patches.rt/ftrace-fix-header.patch
- patches.rt/ftrace-function-record-nop.patch
- patches.rt/ftrace-print-missing-cmdline.patch
- patches.rt/ftrace-record-comm-on-ctrl.patch
- patches.rt/ftrace-safe-traversal-hlist.patch
- patches.rt/ftrace-trace-sched.patch
- patches.rt/ftrace-update-cnt-stat-fix.patch
- patches.rt/git-ignore-module-markers.patch
- patches.rt/git-ignore-script-lpp.patch
- patches.rt/lockdep-avoid-fork-waring.patch
- patches.rt/lockstat-fix-contention-points.patch
- patches.rt/lockstat-output.patch
- patches.rt/nmi-show-regs-fix.patch
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch
- patches.rt/realtime-preempt-warn-about-tracing.patch
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch
- patches.rt/rwlock-implement-downgrade-write.patch
- patches.rt/rwlocks-fix-no-preempt-rt.patch
- patches.rt/sched-fix-rt-task-wakeup.patch
- patches.rt/sched-fix-sched-fair-wakeup.patch
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
- patches.rt/sched-wake_up_idle_cpu-rt.patch
- patches.rt/trace_hist-divzero.patch
- patches.rt/trace_hist-latediv.patch
- patches.rt/x86-delay-enable-preempt-tglx.patch
  Removed:
- patches.rt/rtmutex-optimize-wakeup.patch
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch
- patches.rt/rtmutex-remove-extra-try.patch
- patches.rt/ftrace-remove-print-of-max.patch
* Thu May 29 2008 sdietrich@suse.de
  RT: Update IBM EDAC and PRTM
- Update config files.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Add support for HS21XM SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Add support for HS21/LS21 SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Turn off unsupported EDAC check on the i5000 controller.
- patches.rt/drivers-edac-prevent-potential-printk-storm:
  Prevent potential EDAC printk storm.
- patches.rt/drivers-edac-test_device.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-k8-rev-f.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-amd64.patch:
  drivers-edac-new-amd64.patch (revision 108).
  Obsolete:
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: Delete.
- patches.rt/add-support-for-HS21XM-SMI-remediation: Delete.
- patches.rt/prevent-potential-EDAC-printk-storm: Delete.
* Thu May 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: ata_piix: fix
  macbook ich8m problems (bnc#395407).
* Thu May 29 2008 agruen@suse.de
- Obsolete some KMPs which have been integrated into mainline
  meanwhile (bnc#357799).
* Thu May 29 2008 jbeulich@novell.com
- supported.conf: Mark 8250_pnp as supported.
* Wed May 28 2008 teheo@suse.de
- patches.drivers/libata-acpi-fix-hotplug: libata: Handle bay
  devices in dock stations (bnc#390822 bnc#395082).
* Wed May 28 2008 jkosina@suse.de
- patches.fixes/input-add-i8042-nopnp-for-D845PESV.patch: Input:
  Add i8042.nopnp for Intel D845PESV (bnc#386952).
* Mon May 26 2008 sdietrich@suse.de
  RT: Update to 2.6.25.4-rt3 - add RWSEM / RWLOCK patches:
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.25.4-RT3.
- patches.rt/multi-reader-account.patch: map tasks to reader
  locks held.
- patches.rt/multi-reader-limit.patch: implement reader limit
  on read write locks.
- patches.rt/multi-reader-lock-account.patch: map read/write
  locks back to their readers.
- patches.rt/multi-reader-pi.patch: read lock Priority Inheritance
  implementation.
- patches.rt/native-sched-clock-booboo.patch: Re: 2.6.25.4-rt2
  (native_sched_clock() booboo).
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch:
- patches.rt/rwlocks-multiple-readers.patch: implement rwlocks
  management.
- patches.rt/rwsems-multiple-readers.patch: add framework for
  multi readers on rwsems.
* Mon May 26 2008 olh@suse.de
- add patches.arch/ppc-efika-slowdown.patch
  slow down hot code paths to avoid hangs during install (bnc#374309)
* Sun May 25 2008 tiwai@suse.de
- Update config files: forgot to update vanilla kernel configs
* Sat May 24 2008 tiwai@suse.de
- Update config files: disable group scheduler for normal kernels
  for openSUSE 11.0, too (this should be enabled again later for
  11.1 once after the bugs get fixed...)
* Fri May 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dma-pos-fix: hda - Fix DMA position
  inaccuracy (bnc#362775, bnc#364421).
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: hda - Fix noise
  on VT1708 codec (bnc#390473).
* Fri May 23 2008 sdietrich@suse.de
  RT: Update config files: Disable Group Scheduler
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-simg3726-nosrst: libata: SRST can't
  be trusted on PMP sil3726 (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: update config files: Disable SYSFS_DEPRECATED
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).  series.conf not
  updated.  Fix it.
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: build fix
- suppress adaptive locking patches that are not upstream.
- Update config files.
* Wed May 21 2008 jblunck@suse.de
- patches.fixes/acpi-bay-cleanup-and-exit.patch: bay: Exit if
  notify handler cannot be installed (bnc#390822).
* Wed May 21 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.25: Fix DomU boot issue.
* Wed May 21 2008 oneukum@suse.de
- patches.drivers/ehci_fix_remote_wakeup_regression.diff: EHCI:
  fix remote-wakeup regression. (bnc#373128)
* Tue May 20 2008 jblunck@suse.de
- doc/novell-kmp/novell-example-1.1.tar.bz2,
  doc/novell-kmp/novell-example.spec: Fix example spec and Kbuild
  because EXTRA_CFLAGS isn't taken from the environment anymore.
* Tue May 20 2008 sdietrich@suse.de
- Update config files: SLERT compatibility: SYSFS_DEPRECATED
* Tue May 20 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt2 (refreshed patches suppressed)
  Add:
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: x86: disable TSC
  for sched_clock() when calibration failed
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: x86: fix setup of cyc2ns
  in tsc_64.c.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  x86: distangle user disabled TSC from unstable
- patches.rt/adaptive-spinlock-lite-v2.patch: adaptive spinlocks
  lite.
- patches.rt/rtmutex-remove-xchg.patch: rtmutex - remove double
  xchg.
  Update:
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
  Resolve Conflicts:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- Update config files.
* Mon May 19 2008 sdietrich@suse.de
  RT: Adaptive locking patches:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/rtmutex-adaptive-timeout.patch: add a timeout
  mechanism to adaptive-locking.
- patches.rt/rtmutex-optimize-wakeup.patch: optimize rt lock
  wakeup.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch:
  adjust pi_lock usage in wakeup.
- patches.rt/rtmutex-remove-extra-try.patch: remove the extra
  call to try_to_take_lock.
- Update config files:
  CONFIG_RTLOCK_LATERAL_STEAL=y
  CONFIG_ADAPTIVE_RTLOCK=y
  CONFIG_IBM_RTL (disable temporarily to address build error)
* Mon May 19 2008 tiwai@suse.de
- Update config files (missing for rt*).
* Mon May 19 2008 tiwai@suse.de
- patches.drivers/alsa-hda-backport-2.6.25-rc3: Backport ALSA
  HDA-Intel patches from 2.6.25-rc3 (bnc#390473, bnc#386422,
  bnc#385473).
- patches.drivers/alsa-intel8x0-8ch: intel8x0 - Add support of
  8 channel sound.
- patches.drivers/alsa-mixer-oss-map-fix: Add more fallbacks to
  OSS PHONEOUT mixer map.
- patches.drivers/alsa-usb-audio-disconnect-oops-fix: Fix Oops
  with usb-audio reconnection.
- patches.drivers/alsa-hda-intel-new-ati-id: Delete.
- patches.drivers/alsa-hda-intel-new-nvidia-id: Delete.
- patches.drivers/alsa-hda-intel-use-PCI_DEVICE: Delete.
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Delete.
- Update config files.
* Mon May 19 2008 jbeulich@novell.com
- Update Xen patches to c/s 524 and 2.6.25.4.
- patches.xen/xen-balloon-hvm-min: don't allow ballooning down
  a HVM domain below a reasonable limit (172482).
- patches.xen/xen-swiotlb-heuristics: adjust Xen's swiotlb
  default size setting.
* Mon May 19 2008 jbeulich@novell.com
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Add missing list terminator for acpi_rsdt_dmi_table[] and move to
  __initdata.
* Mon May 19 2008 sdietrich@suse.de
  RT: SMI latency fixes from IBM.
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: [PATCH
  1/3] Add support for HS21/LS21 SMI Remediation.
- patches.rt/add-support-for-HS21XM-SMI-remediation: [PATCH 2/3]
  Add support for HS21XM SMI Remediation .
- patches.rt/prevent-potential-EDAC-printk-storm: [PATCH 3/3]
  Prevent potential EDAC printk storm.
- RT: Update config files.
* Mon May 19 2008 agruen@suse.de
- patches.suse/nfs4acl-ext3.diff: Fix compilation error when
  CONFIG_EXT3_FS_NFS4ACL is off.
* Mon May 19 2008 sdietrich@suse.de
- RT: Update config files.
* Mon May 19 2008 trenn@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: ACPI:
  initramfs DSDT override support.
  - > Did not make it into 2.6.25 again...
- Update config files.
* Sun May 18 2008 agruen@suse.de
- Update the nfs4acl patches (and split them out more explicitly).
  Export all new symbols als GPL only.
- patches.apparmor/parent-permission.diff: Rediff.
* Sun May 18 2008 sdietrich@suse.de
- RT: Update config files.
* Sun May 18 2008 sdietrich@suse.de
  RT: update to 2.6.25.4-rt1 patch queue.
* Sun May 18 2008 sdietrich@suse.de
  RT cleanup: Remove unused/obsolete RT patches.
* Sun May 18 2008 sdietrich@suse.de
- Update config files: update RT debug configs.
- config.conf: enable DEBUG flavors.
* Sat May 17 2008 sdietrich@suse.de
  Linux-RT 2.6.25-RT:
- Updated RT patch queue (not individually enumerated here)
- Update config files: RT
- config.conf: RT
* Fri May 16 2008 gregkh@suse.de
- Update config files.
- patches.drivers/usb-add-option-hso-driver.patch: USB: add
  option hso driver.
* Fri May 16 2008 gregkh@suse.de
- refresh patches due to fuzz
* Fri May 16 2008 gregkh@suse.de
- patches.fixes/bluetooth-wake-up-properly-after-ide-timeout-expires.patch:
  bluetooth: wake up properly after ide timeout expires
  (bnc#390839).
* Fri May 16 2008 olh@suse.de
- update patches.fixes/tg3-flowctrl.patch
  do not compare flow control settings in parallel detect mode
* Fri May 16 2008 trenn@suse.de
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Introduce acpi_root_table=rsdt boot param and dmi list to
  force rsdt (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_introduce_acpica_rsdt_global_variable.patch:
  ACPICA: Add acpi_gbl_force_rsdt variable
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_remove_R40e_c-state_blacklist.patch:
  Remove R40e c-state blacklist
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch:
  CPUFREQ: Check against freq changes from the BIOS.
* Fri May 16 2008 jblunck@suse.de
- patches.fixes/vfs-2.6.git-9bc300eae0400efdfae3fec3352896e10468a78f.patch:
  return to old errno choice for fix mkdir -p with ro-bind mounts
* Fri May 16 2008 jblunck@suse.de
- rpm/kernel-{binary,source}.spec.in: use localversion and set
  KBUILD_BUILD_VERSION (used for Kernel:Vanilla)
* Thu May 15 2008 gregkh@suse.de
- Update to final version of 2.6.25.4
* Thu May 15 2008 jblunck@suse.de
- rpm/macros.kernel-source: Let KMPs fail when flavors_to_build is empty
- rpm/kernel-{dummy,source,syms,binary}.spec.in, scripts/tar-up.sh:
  fix release number changes introduced by bnc#271712 for OBS (bnc#378933)
* Thu May 15 2008 olh@suse.de
- add patches.fixes/tg3-flowctrl.patch
  revert 'Fix supporting flowctrl code' to fix JS21 (bnc#390314)
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 teheo@suse.de
- patches.drivers/libata-force-hardreset-if-link-pm: libata:
  force hardreset if link is in powersave mode (bnc#381795).
- patches.drivers/libata-ahci-sb600-no-msi: ahci: SB600 ahci
  can't do MSI, blacklist that capability (bnc#384559).
* Tue May 13 2008 gregkh@suse.de
- Update config files for vanilla targets
* Tue May 13 2008 gregkh@suse.de
- Update to 2.6.25.4-rc1
  - lots of bug fixes
* Mon May 12 2008 sdietrich@suse.de
  Cleanup RT:
- patches.rt/*: Delete.
* Mon May 12 2008 jkosina@suse.de
- patches.fixes/input-hid-apple-numlock-emulation.patch:
  HID: split Numlock emulation quirk from
  HID_QUIRK_APPLE_HAS_FN. (bnc#381764).
* Sat May 10 2008 gregkh@suse.de
- Update to 2.6.25.3
  - fixes 2 security issues (one networking, one sparc, no CVE
    numbers issued just yet)
* Fri May  9 2008 jeffm@suse.de
- patches.apparmor/fsetattr-restore-ia_file: vfs: restore ia_file
  for compatibility with external modules. (bnc#381259)
* Fri May  9 2008 hare@suse.de
- patches.drivers/open-iscsi-git-update: Delete.
- patches.fixes/open-iscsi-nop-fixes: NOP timeout fixes.
* Thu May  8 2008 gregkh@suse.de
- patches.kernel.org/v4l-dvb-patch-for-various-dibcom-based-devices.patch:
  V4L/DVB (7473): PATCH for various Dibcom based devices
  (bnc#381632).
* Thu May  8 2008 gregkh@suse.de
- comment out vmware patch as it should no longer be needed
* Thu May  8 2008 gregkh@suse.de
- rediff patches to apply cleanly.
* Thu May  8 2008 gregkh@suse.de
- Update to 2.6.25.3-rc1
  - potential fix for increased power consumption and other bugs
* Thu May  8 2008 sassmann@suse.de
- Update config file ppc64.
- patches.arch/ppc-ps3-ps3vram-mtd.patch: ps3vram driver that
  allows you to access the extra ~240MB of DDR video.
* Wed May  7 2008 gregkh@suse.de
- patches.kernel.org/patch-2.6.25.1-2: Linux 2.6.25.2.
  - fixes CVE-2008-1669
* Tue May  6 2008 schwab@suse.de
- suse-ppc32-mol-semaphore: fix mol for 2.6.26-rc1.
* Mon May  5 2008 jack@suse.cz
  Bring UDF to state in 2.6.26-rc1 to support UDF 2.50.
- patches.suse/udf-10-simple-cleanup-of-truncate.c.patch: udf:
  simple cleanup of truncate.c (fate#303336).
- patches.suse/udf-11-truncate-create-function-for-updating-of-Alloc.patch:
  udf: truncate: create function for updating of Allocation Ext
  Descriptor (fate#303336).
- patches.suse/udf-12-replace-all-adds-to-little-endians-variables-wi.patch:
  udf: replace all adds to little endians variables with
  le*_add_cpu (fate#303336).
- patches.suse/udf-13-simplify-__udf_read_inode.patch: udf:
  simplify __udf_read_inode (fate#303336).
- patches.suse/udf-14-replace-udf_-_offset-macros-with-functions.patch:
  udf: replace udf_*_offset macros with functions (fate#303336).
- patches.suse/udf-15-convert-udf_count_free_bitmap-to-use-bitmap_wei.patch:
  udf: convert udf_count_free_bitmap to use bitmap_weight
  (fate#303336).
- patches.suse/udf-16-udf_get_block-inode_bmap-remove-unneeded-che.patch:
  udf: udf_get_block, inode_bmap - remove unneeded checks
  (fate#303336).
- patches.suse/udf-17-create-function-for-conversion-from-timestamp-t.patch:
  udf: create function for conversion from timestamp to timespec
  (fate#303336).
- patches.suse/udf-18-convert-udf_stamp_to_time-to-return-struct-time.patch:
  udf: convert udf_stamp_to_time to return struct timespec
  (fate#303336).
- patches.suse/udf-19-convert-udf_stamp_to_time-and-udf_time_to_stamp.patch:
  udf: convert udf_stamp_to_time and udf_time_to_stamp to use
  timestamps (fate#303336).
- patches.suse/udf-1-kill-udf_set_blocksize.patch: udf: kill
  udf_set_blocksize (fate#303336).
- patches.suse/udf-20-remove-unneeded-kernel_timestamp-type.patch:
  udf: remove unneeded kernel_timestamp type (fate#303336).
- patches.suse/udf-21-super.c-reorganization.patch: udf: super.c
  reorganization (fate#303336).
- patches.suse/udf-22-Mark-udf_process_sequence-as-noinline.patch:
  udf: Mark udf_process_sequence() as noinline (fate#303336).
- patches.suse/udf-23-Remove-checking-of-existence-of-filename-in-udf.patch:
  udf: Remove checking of existence of filename in udf_add_entry()
  (fate#303336).
- patches.suse/udf-24-Remove-declarations-of-arrays-of-size-UDF_NAME_.patch:
  udf: Remove declarations of arrays of size UDF_NAME_LEN (256
  bytes) (fate#303336).
- patches.suse/udf-25-fix-anchor-point-detection.patch: udf:
  fix anchor point detection (fate#303336).
- patches.suse/udf-26-Cleanup-volume-descriptor-sequence-processing.patch:
  udf: Cleanup volume descriptor sequence processing
  (fate#303336).
- patches.suse/udf-27-Improve-error-recovery-on-mount.patch:
  udf: Improve error recovery on mount (fate#303336).
- patches.suse/udf-28-Move-filling-of-partition-descriptor-info-into.patch:
  udf: Move filling of partition descriptor info into a separate
  function (fate#303336).
- patches.suse/udf-29-Move-processing-of-virtual-partitions.patch:
  udf: Move processing of virtual partitions (fate#303336).
- patches.suse/udf-2-kill-useless-file-header-comments-for-vfs-metho.patch:
  udf: kill useless file header comments for vfs method
  implementations (fate#303336).
- patches.suse/udf-30-Cleanup-anchor-block-detection.patch: udf:
  Cleanup anchor block detection. (fate#303336).
- patches.suse/udf-31-Improve-anchor-block-detection.patch: udf:
  Improve anchor block detection (fate#303336).
- patches.suse/udf-32-Silence-warning-about-accesses-beyond-end-of-de.patch:
  udf: Silence warning about accesses beyond end of device
  (fate#303336).
- patches.suse/udf-33-Fix-detection-of-VAT-version.patch: udf:
  Fix detection of VAT version (fate#303336).
- patches.suse/udf-34-Allow-loading-of-VAT-inode.patch: udf:
  Allow loading of VAT inode (fate#303336).
- patches.suse/udf-35-Handle-VAT-packed-inside-inode-properly.patch:
  udf: Handle VAT packed inside inode properly (fate#303336).
- patches.suse/udf-36-Mount-filesystem-read-only-if-it-has-pseudoover.patch:
  udf: Mount filesystem read-only if it has pseudooverwrite
  partition (fate#303336).
- patches.suse/udf-37-Fix-handling-of-multisession-media.patch:
  udf: Fix handling of multisession media (fate#303336).
- patches.suse/udf-38-Add-read-only-support-for-2.50-UDF-media.patch:
  udf: Add read-only support for 2.50 UDF media (fate#303336).
- patches.suse/udf-39-Fix-bug-in-VAT-mapping-code.patch: udf:
  Fix bug in VAT mapping code (fate#303336).
- patches.suse/udf-3-move-headers-out-include-linux.patch: udf:
  move headers out include/linux/ (fate#303336).
- patches.suse/udf-40-Fix-compilation-warnings-when-UDF-debug-is-on.patch:
  udf: Fix compilation warnings when UDF debug is on
  (fate#303336).
- patches.suse/udf-41-use-crc_itu_t-from-lib-instead-of-udf_crc.patch:
  udf: use crc_itu_t from lib instead of udf_crc (fate#303336).
- patches.suse/udf-42-fs-udf-partition.c-udf_get_pblock-mustn-t-be.patch:
  udf: fs/udf/partition.c:udf_get_pblock() mustn't be inline
  (fate#303336).
- patches.suse/udf-4-Use-DIV_ROUND_UP.patch: fs/udf: Use
  DIV_ROUND_UP (fate#303336).
- patches.suse/udf-5--udf_error-static.patch: make udf_error()
  static (fate#303336).
- patches.suse/udf-6-udf_CS0toUTF8-cleanup.patch: udf:
  udf_CS0toUTF8 cleanup (fate#303336).
- patches.suse/udf-7-fix-udf_build_ustr.patch: udf: fix
  udf_build_ustr (fate#303336).
- patches.suse/udf-8-udf_CS0toNLS-cleanup.patch: udf: udf_CS0toNLS
  cleanup (fate#303336).
- patches.suse/udf-9-constify-crc.patch: udf: constify crc
  (fate#303336).
* Fri May  2 2008 teheo@suse.de
- patches.drivers/libata-sata_inic162x-update-to-0.4:
  sata_inic162x: update to 0.4 (bnc#385599).
* Thu May  1 2008 gregkh@suse.de
- update to 2.6.25.1:
  - fixes CVE-2008-1375 and CVE-2008-1675
  - lots of other minor bugfixes
* Thu May  1 2008 agruen@suse.de
- Provide "kernel(flavor:symset) = version" instead of
  "kernel(symset) = version". This disambiguates the case where
  several kernel flavors end up with the same modver checksums
  (bnc#190163, bnc#355628).
* Thu May  1 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-verify-sidpr: ata_piix: verify
  SIDPR access before enabling it (bnc#385535).
* Wed Apr 30 2008 gregkh@suse.de
- novfs: fixes needed due to apparmor vfs core changes
  (extended attributes probably do not work now...)
* Wed Apr 30 2008 gregkh@suse.de
- patches.suse/novfs-add-the-novell-filesystem-client-kernel-module.patch:
  novfs: Add the Novell filesystem client kernel module.
- Update config files.
* Wed Apr 30 2008 jeffm@suse.de
- patches.suse/reiserfs-simplify-xattr-internal-file-lookups-opens.diff:
  removed fs.h changes, they weren't used.
* Mon Apr 28 2008 gregkh@suse.de
- Update config files.
  hopefully the build system is happy now
* Mon Apr 28 2008 gregkh@suse.de
- rpm/config-subst: add #!/bin/sh at start of script to keep future
  build issues (like bnc#382214) from causing problems.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete patches: ARM-ep93xx-timer, latency-tracing,
  RCU, KVM, mcount, PPC-gtod
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/kvm-fix-preemption-bug.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch: Delete.
- patches.rt/remove-unused-var-warning.patch: Delete.
- patches.rt/latency-tracing.patch: Delete.
- patches.rt/latency-tracing-remove-trace-array.patch: Delete.
- patches.rt/latency-tracer-disable-across-trace-cmdline.patch:
  Delete.
- patches.rt/latency-tracing-i386-paravirt-fastcall.patch: Delete.
- patches.rt/latency-tracing-i386.patch: Delete.
- patches.rt/latency-tracing-x86_64.patch: Delete.
- patches.rt/latency-tracing-ppc.patch: Delete.
- patches.rt/latency-tracer-printk-fix.patch: Delete.
- patches.rt/latency-tracing-exclude-printk.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/latency-tracer-one-off-fix.patch: Delete.
- patches.rt/smaller-trace.patch: Delete.
- patches.rt/trace-name-plus.patch: Delete.
- patches.rt/trace-with-caller-addr.patch: Delete.
- patches.rt/trace-sti-mwait.patch: Delete.
- patches.rt/latency-tracer-optimize-a-bit.patch: Delete.
- patches.rt/idle-stop-critical-timing.patch: Delete.
- patches.rt/latency-tracer-variable-threshold.patch: Delete.
- patches.rt/reset-latency-histogram.patch: Delete.
- patches.rt/undo-latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/random-driver-latency-fix.patch: Delete.
- patches.rt/latency-tracing-use-now.patch: Delete.
- patches.rt/preempt_max_latency-in-all-modes.patch: Delete.
- patches.rt/latency-hist-add-resetting-for-all-timing-options.patch:
  Delete.
- patches.rt/latency-trace-sysctl-config-fix.patch: Delete.
- patches.rt/latency-trace-convert-back-to-ms.patch: Delete.
- patches.rt/latency-trace-fix.patch: Delete.
- patches.rt/trace-cpuidle.patch: Delete.
- patches.rt/lockdep-show-held-locks.patch: Delete.
- patches.rt/lockdep-lock_set_subclass.patch: Delete.
- patches.rt/lockdep-prettify.patch: Delete.
- patches.rt/lockdep-more-entries.patch: Delete.
- patches.rt/latency-tracer-arch-low-address.patch: Delete.
- patches.rt/latency-tracer-dont-panic-on-failed-bootmem-alloc.patch:
  Delete.
- patches.rt/mcount-add-x86_64-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-x86-vdso-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-nmi-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-time-notrace-annotations.patch: Delete.
- patches.rt/mcount-lockdep-notrace-annotations.patch: Delete.
- patches.rt/mcount-preemptcount-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-fault-notrace-annotations.patch: Delete.
- patches.rt/mcount-irqs-notrace-annotations.patch: Delete.
- patches.rt/mcount-rcu-notrace-annotations.patch: Delete.
- patches.rt/latency-measurement-drivers-fix.patch: Delete.
- patches.rt/latency-measurement-drivers.patch: Delete.
- patches.rt/redo-regparm-option.patch: Delete.
- patches.rt/nmi-profiling-base.patch: Delete.
- patches.rt/ppc-gtod-notrace-fix.patch: Delete.
- patches.rt/ppc-gtod-support.patch: Delete.
- patches.rt/ppc-gtod-support-fix.patch: Delete.
- patches.rt/ppc-a-2.patch: Delete.
- patches.rt/ppc-fix-clocksource-timebase-shift.patch: Delete.
- patches.rt/ppc-remove-broken-vsyscall.patch: Delete.
- patches.rt/ppc-read-persistent-clock.patch: Delete.
- patches.rt/ppc-clockevents.patch: Delete.
- patches.rt/ppc-clockevents-fix.patch: Delete.
- patches.rt/ppc-highres-dyntick.patch: Delete.
- patches.rt/inet-hash-bits-ipv6-fix.patch: Delete.
- patches.rt/inet_hash_bits.patch: Delete.
- patches.rt/rcu-1.patch: Delete.
- patches.rt/rcu-2.patch: Delete.
- patches.rt/rcu-3.patch: Delete.
- patches.rt/rcu-4.patch: Delete.
- patches.rt/rcu-preempt-fix-nmi-watchdog.patch: Delete.
- patches.rt/rcu-preempt-fix-rcu-torture.patch: Delete.
- patches.rt/dynticks-rcu-rt-fixlet.patch: Delete.
- patches.rt/rcu-tasklet-softirq.patch: Delete.
- patches.rt/rcu-classic-fixup.patch: Delete.
- patches.rt/rcu-warn-underflow.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete Adaptive-locking patches
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
- patches.rt/rtmutex-lateral-steal.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/rtmutex-optimize-wakeup.patch: Delete.
- patches.rt/rtmutex-rearrange.patch: Delete.
- patches.rt/rtmutex-remove-extra-try.patch: Delete.
- patches.rt/x86-ticket-lock.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove ARM and MIPS RT patches
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-compile-fix.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-latency-tracer-support.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-preempt-config.patch: Delete.
- patches.rt/arm-trace-preempt-idle.patch: Delete.
- patches.rt/latency-tracing-arm.patch: Delete.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Delete.
- patches.rt/preempt-irqs-arm.patch: Delete.
- patches.rt/preempt-realtime-arm-bagde4.patch: Delete.
- patches.rt/preempt-realtime-arm-footbridge.patch: Delete.
- patches.rt/preempt-realtime-arm-integrator.patch: Delete.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Delete.
- patches.rt/preempt-realtime-arm-pxa.patch: Delete.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Delete.
- patches.rt/preempt-realtime-arm-shark.patch: Delete.
- patches.rt/preempt-realtime-arm.patch: Delete.
- patches.rt/preempt-irqs-mips.patch: Delete.
- patches.rt/preempt-realtime-mips.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-arm.patch: Delete.
- patches.rt/rt-mutex-mips.patch: Delete.
- patches.rt/mips-change-raw-spinlock-type.patch: Delete.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Delete.
- patches.rt/mips-remove-duplicate-kconfig.patch: Delete.
- patches.rt/mips-remove-finish-arch-switch.patch: Delete.
* Fri Apr 25 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: kernel-xen does not obsolete/provide
  kernel-xenpae (bnc#382309)
* Fri Apr 25 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  create /builtin/sound/cell-index, content == 1
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add newline to devspec files
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add devspec file for mac-io, it was created as a side effect
  in of/platform.c (bnc#374693)
* Thu Apr 24 2008 olh@suse.de
- use bzip2 instead of lzma as rpm compression method for vanilla
* Thu Apr 24 2008 olh@suse.de
- relax Conflicts for kernel-vanilla
  no version check for lvm, udev and apparmor
* Wed Apr 23 2008 olh@suse.de
- readd patches.arch/ppc-pegasos-console-autodetection.patch
  force speed 115200, device-tree has no current-speed property
* Wed Apr 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-intel-new-ati-id,
  patches.drivers/alsa-hda-intel-use-PCI_DEVICE,
  patches.drivers/alsa-hda-intel-new-nvidia-id: Add missing PCI
  ids for new ATI/Nvidia devices (bnc#370775)
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Fix Dell XPS M1330
  outputs
* Tue Apr 22 2008 jack@suse.cz
- patches.fixes/quota_reiserfs_tail_fix.diff: reiserfs: Unpack
  tails on quota files (375179).
* Tue Apr 22 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  fixes for 2.6.25
* Sat Apr 19 2008 schwab@suse.de
- Add compat handler for PTRACE_GETSIGINFO.
* Sat Apr 19 2008 aj@suse.de
- Conflict with apparmor-parser < 2.3 (not <=) in kernel-binary
  spec files.
* Fri Apr 18 2008 jeffm@suse.de
- Re-synced reiserfs patch set due to broken local repo.
* Fri Apr 18 2008 jeffm@suse.de
- Updated reiserfs patch set
  - Eliminated xattr interaction with AppArmor
  - Eliminated xattr deadlock under load between journal lock and
    xattr dir i_mutex
  - Properly annotated xattr i_mutex locking for lockdep
  - Code cleanup
* Fri Apr 18 2008 jjohanse@suse.de
- Update fsetattr.diff to EXPORT_SYMBOL_GPL(fnotify_change)
* Fri Apr 18 2008 jjohanse@suse.de
- patches.apparmor/__d_path-keep-connected.diff: Fix __d_path
  to allow for old and new behavior bnc#380763.
* Thu Apr 17 2008 gregkh@suse.de
- refresh patches to apply without fuzz
* Thu Apr 17 2008 gregkh@suse.de
- Update to 2.6.25-final
* Wed Apr 16 2008 jjohanse@suse.de
- Update to AppArmor 2.3 patch series
* Wed Apr 16 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Fixed accidental
  passing of -ENODATA to userspace during chown, and messages during
  chown and delete.
* Tue Apr 15 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc9 and c/s 517.
* Fri Apr 11 2008 gregkh@suse.de
- refresh patches to clean up fuzz
* Fri Apr 11 2008 gregkh@suse.de
- Update config files.
* Fri Apr 11 2008 gregkh@suse.de
- updat to 2.6.25-rc9
* Thu Apr 10 2008 gregkh@suse.de
- update to 2.6.25-rc8-git8
* Tue Apr  8 2008 gregkh@suse.de
- update to 2.6.25-rc8-git7
* Mon Apr  7 2008 gregkh@suse.de
- patches.kernel.org/pvrusb2-fix-broken-build-due-to-patch-order-dependency.patch:
  pvrusb2: fix broken build due to patch order dependency.
* Mon Apr  7 2008 gregkh@suse.de
- update to 2.6.25-rc8-git5
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Removed struct
  file use entirely.
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Eliminated use
  of vfsmount-less dentry_open().
* Thu Apr  3 2008 teheo@suse.de
- patches.drivers/libata-pata_ali-disable-ATAPI_DMA: pata_ali:
  disable ATAPI DMA (332588).
* Wed Apr  2 2008 gregkh@suse.de
- Update to 2.6.25-rc8
* Tue Apr  1 2008 jblunck@suse.de
- rpm/kernel-source.spec.in,kernel-binary.spec.in: Cleanup Requires
* Mon Mar 31 2008 jdelvare@suse.de
- supported.conf: Add new hwmon drivers, all unsupported.
* Thu Mar 27 2008 jeffm@suse.de
- Fixed up the rest of the reiserfs patch queue.
* Thu Mar 27 2008 jeffm@suse.de
- Updated reiserfs xattr patches.
* Thu Mar 27 2008 gregkh@suse.de
- fix merge error in patches.suse/supported-flag caused by me...
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7-git2
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7
  - note that reiserfs xattr patches are now disabled due to merge
    issues...
* Sun Mar 23 2008 teheo@suse.de
- patches.drivers/libata-improve-hpa-error-handling: libata:
  improve HPA error handling (365534).
* Thu Mar 20 2008 gregkh@suse.de
- fix up some EXPORT_SYMBOL() markings to be EXPORT_SYMBOL_GPL() as the
  code is not upstream and we aren't allowed to add non-GPL exports to
  our kernel tree.
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git5
- refresh patches to apply cleanly
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git4
- refresh patches to apply cleanly
* Thu Mar 20 2008 agruen@suse.de
- scripts/tar-up.sh: Rename --kbuild option to --source-timestamp.
  For generating the source timestamp, use HEAD as the branch
  name.
- rpm/get_release_number.sh.in: Don't try to synchronize release
  numbers with kernel-dummy if the release number has been
  specified explicitly (tar-up with --release-string, --timestamp,
  or --source-timestamp).
* Thu Mar 20 2008 olh@suse.de
- remove patches.kernel.org/powerpc-needs-uboot
  not needed without mpc51xx support
* Thu Mar 20 2008 olh@suse.de
- disable gianfar network driver and unused freescale drivers
* Wed Mar 19 2008 gregkh@suse.de
- patch refreshes due to version update
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6-git3
- Update config files.
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6
  - which deleted the following patches:
  - patches.fixes/hibernation-snapshot-numa-workaround.patch
  - patches.fixes/acpi-fix-double-log-level.patch
  - patches.fixes/acpi_fix_mem_corruption.patch
  - patches.kernel.org/patch-2.6.25-rc5
  - patches.kernel.org/patch-2.6.25-rc5-git3
- Update config files.
- delete patches.arch/x86-nvidia-timer-quirk as it is not being used.
* Wed Mar 19 2008 olh@suse.de
- remove patches.arch/ppc-efika-ipic.patch
  disable mpc51xx support instead
* Tue Mar 18 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Changed to just match %%ix86
* Mon Mar 17 2008 olh@suse.de
- add patches.arch/ppc-efika-ipic.patch
  fix a crash in init_ipic_sysfs on efika
* Mon Mar 17 2008 agruen@suse.de
- post.sh: Fix a syntax error when creating the initrd.
* Mon Mar 17 2008 jbeulich@novell.com
- patches.xen/xen-quicklist.patch: Delete.
- Update i386 Xen config file.
- patches.xen/xen3-patch-2.6.25-rc5-rc6: 2.6.25-rc6.
- patches.xen/xen3-auto-xen-kconfig.diff,
  patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.19,
  patches.xen/xen3-patch-2.6.20,
  patches.xen/xen3-patch-2.6.21,
  patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25-rc5,
  patches.xen/xen-x86-no-lapic,
  patches.xen/xen-x86-panic-no-reboot: Various adjustments.
* Sun Mar 16 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added an RPM conflict for 32-bit
  kernels and 64-bit glibc to avoid installing a 32-bit kernel
  with 64-bit userspace. (364433, et al)
* Fri Mar 14 2008 jeffm@suse.de
- scripts/tar-up.sh: Added --kbuild option to autogenerate
  release number based on branch and timestamp.
* Fri Mar 14 2008 jeffm@suse.de
- patches.apparmor/export-security_inode_permission-for-aufs:
  LSM: Export security_inode_permission for aufs (356902).
* Fri Mar 14 2008 agruen@suse.de
- Boot loader: do the same during initial installation as when
  updating a kernel package (FATE 302660).
* Thu Mar 13 2008 gregkh@suse.de
- Update to 2.6.25-rc5-git3
* Thu Mar 13 2008 olh@suse.de
- disable unuses pata platform and ibm newemac driver on powerpc
* Thu Mar 13 2008 olh@suse.de
- add patches.xen/xen-quicklist.patch
  fix kernel-xen compile, readd CONFIG_QUICKLIST for xen
* Wed Mar 12 2008 gregkh@suse.de
- remove alpha configs as they are no longer used
* Wed Mar 12 2008 gregkh@suse.de
- Enabled CONFIG_UNUSED_SYMBOLS for now.  It will be disabled
  after the next openSUSE alpha release.  It is being enabled
  for now to let some kmp packages still work while their
  maintainers are working to update them with the 2.6.25
  kernel changes.
* Wed Mar 12 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Wed Mar 12 2008 gregkh@suse.de
- update to 2.6.25-rc5-git2
* Wed Mar 12 2008 sassmann@suse.de
- patches.arch/ppc-ps3-rename-wireless-interface.patch:
  rename ps3 wireless interface from eth? to wlan? for better
  handling in udev
* Wed Mar 12 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc5 and c/s 471.
- patches.xen/xen3-aslr-i386-and-x86_64-randomize-brk.patch:
  Delete.
- patches.xen/xen3-aslr-pie-executable-randomization.patch:
  Delete.
- patches.xen/xen3-early-firewire.diff: Delete.
- Update x86 config files.
- config.conf: Re-enable Xen configs.
* Tue Mar 11 2008 gregkh@suse.de
- add usb persist for storage devices across suspend to ram.  This is going to
  be in 2.6.26, just missed the .25 merge window.
* Tue Mar 11 2008 gregkh@suse.de
- Update to 2.6.26-rc5-git1
- Update config files.
* Tue Mar 11 2008 gregkh@suse.de
- update to 2.6.25-rc5
* Mon Mar 10 2008 agruen@suse.de
- scripts/tar-up.sh: Don't lose the EXTRAVERSION when overriding
  the release number with --release-string or --timestamp.
* Sun Mar  9 2008 jeffm@suse.de
- patches.fixes/hibernation-snapshot-numa-workaround.patch:
  swsusp: workaround for crash on NUMA (kernel.org#9966).
* Sat Mar  8 2008 agruen@suse.de
- Encode the EXTRAVERSION part of kernel release numbers in the
  RPM release instead of in the version. This resolves the problem
  that kernel releases like 2.6.25-rc4 would result in a package
  with a higher version than 2.6.25 according to RPM's versioning
  scheme (bug 271712).
* Fri Mar  7 2008 schwab@suse.de
- Update kdb patches.
* Thu Mar  6 2008 trenn@suse.de
- patches.fixes/acpi_fix_mem_corruption.patch: ACPI: Fix mem
  corruption (350017).
- patches.fixes/acpi_thermal_passive_cleanup.patch: Warn user
  about a BIOS bug in asus boards (350017).
* Thu Mar  6 2008 gregkh@suse.de
- Update s390 config files.
* Thu Mar  6 2008 gregkh@suse.de
- update to 2.6.24-rc5-git1
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_GROUP_SCHED
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_HIGH_RES_TIMERS on i386
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_USB_PERSIST for vanilla config files
* Wed Mar  5 2008 gregkh@suse.de
- refresh patches to apply cleanly with no fuzz
- enable CONFIG_USB_PERSIST so that users can enable this if they want
* Wed Mar  5 2008 gregkh@suse.de
- update the vanilla config files for CONFIG_DEBUG_RODATA
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_DEBUG_RODATA (Not really a debug option, something
  we need in all of our kernels.)
* Wed Mar  5 2008 gregkh@suse.de
- Update vanilla config files.
* Wed Mar  5 2008 jbeulich@novell.com
- patches.fixes/parport-mutex,
  patches.suse/stack-unwind: Fix merge mistakes.
- Update i386 config files.
* Wed Mar  5 2008 gregkh@suse.de
- Update tree to 2.6.25-rc4
* Wed Mar  5 2008 fseidel@suse.de
- add patches.fixes/fat_detect_media_wo_parttable.patch and
  patches.fixes/fat_valid_media.patch:
  detect FAT formated medias without partition table correctly
  (bnc 364365)
* Tue Mar  4 2008 olh@suse.de
- add patches.kernel.org/s390-defkeymap.patch
  Build fix for drivers/s390/char/defkeymap.c
* Tue Mar  4 2008 olh@suse.de
- enable ext2/3 acl support in ps3 kernel
* Tue Mar  4 2008 olh@suse.de
- Update to 2.6.25-rc3-git5
* Tue Mar  4 2008 olh@suse.de
- use suffix -ps3 for PS3 kernel, it is only used in otheros.bld
* Mon Mar  3 2008 lmb@suse.de
- rpm/kernel-binary.spec.in: Require udev >= 118.
* Mon Mar  3 2008 ak@suse.de
- patches.arch/x86-nvidia-timer-quirk: Delete.
  PCI device ID list still not complete and let's have the same
  crap as mainline for now. It would be better to fix the PCI
  ID lists (#302327)
* Sun Mar  2 2008 olh@suse.de
- add patches.fixes/ibmvstgt-fixes.patch
  fix oops in ibmvstgt init function
* Fri Feb 29 2008 olh@suse.de
- add patches.arch/ppc-pci-bogus-resources.patch
  fix bogus test for unassigned resources
* Thu Feb 28 2008 olh@suse.de
- disable CONFIG_CRYPTO_DEV_HIFN_795X on ppc32 due to __divdi3 usage
- update patches.kernel.org/powerpc-needs-uboot
  disable mkimage call in arch/powerpc/boot/wrapper
* Thu Feb 28 2008 olh@suse.de
- update patches.kernel.org/fixed-phy-select
  add dependency on libphy=y
* Wed Feb 27 2008 jdelvare@suse.de
- patches.fixes/acpi-fix-double-log-level.patch: ACPI: Fix a
  duplicate log level.
* Wed Feb 27 2008 trenn@suse.de
- patches.fixes/acpi_force-fan-active.patch: Delete.
* Tue Feb 26 2008 sdietrich@suse.de
- remove obsolete adaptive-locks patches
  patches.rt/rtmutex-adaptive-locks.patch: Delete.
  patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
  patches.rt/rtmutex-optimize-wakeup.patch: Delete.
  patches.rt/rtmutex-rearrange.patch: Delete.
  patches.rt/rtmutex-remove-extra-try.patch: Delete.
  patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
  patches.rt/rtmutex-adaptive-timeout.patch: Delete.
  patches.rt/rtmutex-lateral-steal.patch: Delete.
  patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
* Tue Feb 26 2008 sassmann@suse.de
- remove patches included upstream
  patches.arch/ppc-ps3-gelic-cleanup.patch
  patches.arch/ppc-ps3-gelic-endianness.patch
  patches.arch/ppc-ps3-gelic-ethernet-linkstatus.patch
  patches.arch/ppc-ps3-gelic-fix-fallback.diff
  patches.arch/ppc-ps3-gelic-multiple-interface.patch
  patches.arch/ppc-ps3-gelic-remove-duplicate-ethtool-handlers.patch
  patches.arch/ppc-ps3-gelic-wireless-v2.patch
* Tue Feb 26 2008 jeffm@suse.de
- Update config files: Disabled CONFIG_INPUT_YEALINK per an old
  request from AJ.
* Tue Feb 26 2008 jeffm@suse.de
- Update to 2.6.25-rc3.
* Sun Feb 24 2008 sdietrich@suse.de
- patches.rt/0001-sched-count-of-queued-RT-tasks.patch: Delete.
- patches.rt/0002-sched-track-highest-prio-task-queued.patch:
  Delete.
- patches.rt/0003-sched-add-RT-task-pushing.patch: Delete.
- patches.rt/0004-sched-add-rt-overload-tracking.patch: Delete.
- patches.rt/0005-sched-pull-RT-tasks-from-overloaded-runqueues.patch:
  Delete.
- patches.rt/0006-sched-push-RT-tasks-from-overloaded-CPUs.patch:
  Delete.
- patches.rt/0007-sched-disable-standard-balancer-for-RT-tasks.patch:
  Delete.
- patches.rt/0008-sched-add-RT-balance-cpu-weight.patch: Delete.
- patches.rt/0009-sched-clean-up-this_rq-use-in-kernel-sched_rt.c.patch:
  Delete.
- patches.rt/0010-sched-de-SCHED_OTHER-ize-the-RT-path.patch:
  Delete.
- patches.rt/0011-sched-break-out-search-for-RT-tasks.patch:
  Delete.
- patches.rt/0012-sched-RT-balancing-include-current-CPU.patch:
  Delete.
- patches.rt/0013-sched-pre-route-RT-tasks-on-wakeup.patch:
  Delete.
- patches.rt/0014-sched-optimize-RT-affinity.patch: Delete.
- patches.rt/0015-sched-wake-balance-fixes.patch: Delete.
- patches.rt/0016-sched-RT-balance-avoid-overloading.patch:
  Delete.
- patches.rt/0017-sched-break-out-early-if-RT-task-cannot-be-migrated.patch:
  Delete.
- patches.rt/0018-sched-RT-balance-optimize.patch: Delete.
- patches.rt/0019-sched-RT-balance-optimize-cpu-search.patch:
  Delete.
- patches.rt/0020-sched-RT-balance-on-new-task.patch: Delete.
- patches.rt/0021-sched-clean-up-pick_next_highest_task_rt.patch:
  Delete.
- patches.rt/0022-sched-clean-up-find_lock_lowest_rq.patch:
  Delete.
- patches.rt/0023-sched-clean-up-overlong-line-in-kernel-sched_debug.patch:
  Delete.
- patches.rt/0024-sched-clean-up-kernel-sched_rt.c.patch: Delete.
- patches.rt/0025-sched-remove-rt_overload.patch: Delete.
- patches.rt/0026-sched-remove-leftover-debugging.patch: Delete.
- patches.rt/0027-sched-clean-up-pull_rt_task.patch: Delete.
- patches.rt/0028-sched-clean-up-schedule_balance_rt.patch:
  Delete.
- patches.rt/0029-sched-add-sched-domain-roots.patch: Delete.
- patches.rt/0030-sched-update-root-domain-spans-upon-departure.patch:
  Delete.
- patches.rt/0031-Subject-SCHED-Only-balance-our-RT-tasks-within-ou.patch:
  Delete.
- patches.rt/0032-sched-fix-sched_rt.c-join-leave_domain.patch:
  Delete.
- patches.rt/0033-sched-remove-unused-JIFFIES_TO_NS-macro.patch:
  Delete.
- patches.rt/0034-sched-style-cleanup-2.patch: Delete.
- patches.rt/0035-sched-add-credits-for-RT-balancing-improvements.patch:
  Delete.
- patches.rt/0036-sched-reactivate-fork-balancing.patch: Delete.
- patches.rt/0037-sched-whitespace-cleanups-in-topology.h.patch:
  Delete.
- patches.rt/0038-sched-no-need-for-affine-wakeup-balancing-in.patch:
  Delete.
- patches.rt/0039-sched-get-rid-of-new_cpu-in-try_to_wake_up.patch:
  Delete.
- patches.rt/0040-sched-remove-do_div-from-__sched_slice.patch:
  Delete.
- patches.rt/0041-sched-RT-balance-replace-hooks-with-pre-post-sched.patch:
  Delete.
- patches.rt/0042-sched-RT-balance-add-new-methods-to-sched_class.patch:
  Delete.
- patches.rt/0043-sched-RT-balance-only-adjust-overload-state-when-c.patch:
  Delete.
- patches.rt/0044-sched-remove-some-old-cpuset-logic.patch:
  Delete.
- Remove scheduler patches already upstream in 2.6.25-rc1
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/libertas-section-conflict: libertas: fix
  section conflict.
* Sat Feb 23 2008 jeffm@suse.de
- Enabled patches.kernel.org/ps3-lpm-include
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/spu_profiler-include: powerpc: spu_profiler
  build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: ps3: lpm build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/fixed-phy-select: powerpc: FSL_SOC requires
  FIXED_PHY.
- patches.kernel.org/lguest-fixups: lguest: Fix asm-offsets_32
  with correct config option.
* Sat Feb 23 2008 jeffm@suse.de
- Build fixes for ia64 and i386.
* Sat Feb 23 2008 jeffm@suse.de
- Update to 2.6.25-rc2-git6.
  - Removed:
  - patches.arch/ppc-pegasos-pata_via-fixup.patch: Delete.
  - patches.arch/ppc-pegasos-console-autodetection.patch: Delete.
  - patches.arch/ppc-ps3-make-dev_id-and-bus_id-u64.diff: Delete.
  - patches.arch/acpi_autoload_bay.patch: Delete.
  - patches.arch/small-acpica-extension-to-be-able-to-store-the-name-of.patch:
    Delete.
  - patches.arch/export-acpi_check_resource_conflict.patch: Delete.
  - patches.drivers/early-firewire.diff: Delete.
  - patches.drivers/scsi-throttle-SG_DXFER_TO_FROM_DEV-warning-better:
    Delete.
  - patches.drivers/libata-implement-force-parameter: Delete.
  - patches.drivers/igb-1.0.8-k2: Delete.
  - patches.drivers/always-announce-new-usb-devices.patch: Delete.
  - patches.drivers/nozomi.patch: Delete.
  - patches.drivers/libata-quirk_amd_ide_mode: Delete.
  - patches.fixes/acpi_autoload_baydock.patch: Delete.
  - patches.fixes/bluetooth_hci_dev_put.patch: Delete.
  - patches.fixes/bluetooth_hci_conn_childs.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan1.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan2.patch: Delete.
  - patches.fixes/libiscsi-missing-semicolon.diff: Delete.
  - patches.fixes/pci-quirk-enable-smbus-on-hp-xw4100.patch: Delete.
  - patches.kernel.org/patch-2.6.24.1: Delete.
  - patches.suse/acpi_dsdt_ssdt_initrd_initramfs.patch: Delete.
  - patches.suse/squashfs.patch.fixup: Delete.
  - patches.suse/aslr-pie-executable-randomization.patch: Delete.
  - patches.suse/aslr-i386-and-x86_64-randomize-brk.patch: Delete.
  - Xen and RT currently disabled.
  - SquashFS may not work.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: fixed and renabled check
* Fri Feb 22 2008 sdietrich@suse.de
- embargoed-patches: eliminate embargoed patches abuse.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: Disable check for non-existant patches.
* Fri Feb 22 2008 schwab@suse.de
- Update kdb patches.
* Fri Feb 22 2008 jbeulich@novell.com
- config/i386/xenpae: Rename to config/i386/xen.
- config.conf: Delete i386/xenpae.
* Thu Feb 21 2008 sdietrich@suse.de
- Update config files: update RT options for adaptive RT locks
* Thu Feb 21 2008 sdietrich@suse.de
- patches.rt/rtmutex-adaptive-mutexes.patch: cleanup.
- patches.rt/rtmutex-adaptive-timeout.patch: cleanup.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
* Thu Feb 21 2008 jbeulich@novell.com
- Update Xen patches to c/s 425.
- patches.xen/sfc-network-driver: Solarflare: Standard network driver
  (disabled until status clarified).
- patches.xen/sfc-resource-driver: Solarflare: Resource driver
  (disabled until status clarified).
- Update Xen config files.
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v20
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v19
* Wed Feb 20 2008 jeffm@suse.de
- Update config files for dmraid45.
* Wed Feb 20 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: add PAGESIZE detection for
  makedumpfile.config from the .config file also for PPC64
* Wed Feb 20 2008 fseidel@suse.de
- patches.fixes/bluetooth_hci_dev_put.patch,
  patches.fixes/bluetooth_hci_conn_childs.patch,
  patches.fixes/bluetooth_hci_unregister_sysfs.patch:
  fix kernel crash after removing bluetooth adapter (bnc 359546)
* Tue Feb 19 2008 jeffm@suse.de
- patches.suse/dm-raid45-2.6.24-20080602a.patch: DMRAID45 module.
* Fri Feb 15 2008 sdietrich@suse.de
- Update to latest patch set:
- patches.rt/rearrange_rtspinlock_sleep:
  [PATCH 02/10] rearrange rtspinlock sleep
- patches.rt/optimize_rtspinlock_wakeup:
  [PATCH 03/10] optimize rtspinlock wakeup
- patches.rt/adaptive_RT_spinlock_support:
  [PATCH 04/10] Adaptive RT spinlock support
- patches.rt/add_timeout_mechanism: [PATCH 05/10]
  add a loop counter based timeoutmechanism
- patches.rt/adaptive_mutexes: [PATCH 06/10] adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  [PATCH 07/10] Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: [PATCH 08/10]
  optimize the !printk fastpath throughthe lock acquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  [PATCH 09/10] remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: [PATCH 10/10] allow
  rt-mutex lock-stealing toinclude lateral priority
* Fri Feb 15 2008 sdietrich@suse.de
- embargoed-patches: (embargo development RT throughput patches)
- Update config files (RT config options)
- patches.rt/optimize_rtspinlock_wakeup: optimize rtspinlock
  wakeup.
- patches.rt/adaptive_RT_spinlock_support: Adaptive RT spinlock
  support.
- patches.rt/add_timeout_mechanism: add
  a loop counter based timeout mechanism
- patches.rt/adaptive_mutexes: adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: optimize
  the !printk fastpath through the lockacquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: allow rt-mutex
  lock-stealing to include lateralpriority
- patches.rt/rearrange_rtspinlock_sleep: cleanup rtspinlock sleep
* Thu Feb 14 2008 jeffm@suse.de
- Removed unused OCFS2 patches.
* Thu Feb 14 2008 jeffm@suse.de
- Removed old commented out ocfs2 patchset.
* Thu Feb 14 2008 teheo@suse.de
- patches.drivers/libata-quirk_amd_ide_mode: PCI: modify SATA
  IDE mode quirk (345124).
* Wed Feb 13 2008 jeffm@suse.de
- patches.suse/ocfs2-03-split-disk-heartbeat-out.diff: Fixed
  section conflict.
* Wed Feb 13 2008 jeffm@suse.de
- Update config files.
* Wed Feb 13 2008 jeffm@suse.de
- Merged and re-enabled OCFS2 userspace clustering
* Wed Feb 13 2008 jdelvare@suse.de
- config/*: Don't build i2c algorithm drivers that we do not use.
- supported.conf: Drop i2c-elektor and i2c-algo-pcf, we don't ship
  them.
* Tue Feb 12 2008 teheo@suse.de
  Build fix for section mismatch check.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Mon Feb 11 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: Delete.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Fri Feb  8 2008 gregkh@suse.de
- Update to 2.6.24.1
  - fixes CVE-2008-0007, CVE-2008-0009, CVE-2008-0010
  - lots of USB device ids updated
  - lots of other bugfixes
  - removed patches.fixes/bootstrap-memoryless-node.patch as it is now
    contained within.
* Fri Feb  8 2008 gregkh@suse.de
- Move ipv6-no-autoconf to xen directory as it is a Xen bugfix
* Fri Feb  8 2008 bwalle@suse.de
- patches.arch/ppc-fix-prpmc2800: remove patch since it's not needed
  with current binutils any more
* Fri Feb  8 2008 bwalle@suse.de
- patches.drivers/igb-2007-12-11: Delete.
- patches.drivers/igb-1.0.8-k2: Update to latest version which is
  also upstream now in the 2.6.25 tree.
* Fri Feb  8 2008 gregkh@suse.de
- Remove NO_BRP_NOEXECSTACK from the .spec files as it is obsolete
  and doesn't do anything anymore.
* Fri Feb  8 2008 jbeulich@novell.com
- patches.xen/xen3-auto-common.diff,
  patches.xen/xen3-patch-2.6.23: fix merge mistake.
* Fri Feb  8 2008 jbenc@suse.cz
- Update config files: disabled CONFIG_BCM43XX.
* Wed Feb  6 2008 jeffm@suse.de
- patches.apparmor/vfs-mkdir.diff: Added missing case in
  kernel/cgroup.c
* Wed Feb  6 2008 fseidel@suse.de
- updated patches.drivers/nozomi.patch: mainline info
* Wed Feb  6 2008 sdietrich@suse.de
- Update config files: RT@1KHz, sched groups & cpusets enabled.
* Wed Feb  6 2008 olh@suse.de
- enable bnx2 on ppc64 (bnc 359114 - LTC42106)
* Wed Feb  6 2008 gregkh@suse.de
- remove unused lockd patches:
  - patches.suse/lockd-switchable-statd
  - patches.suse/lockd-kernel-statd
  - patches.suse/lockd-suse-config
  - patches.suse/lockd-max-hosts-dynamic
* Tue Feb  5 2008 oneukum@suse.de
- patches.suse/usb_printer_no_auto.diff: Delete.
  Obsoleted by mainline change
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547) for RT kernels
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547)
* Thu Jan 31 2008 sdietrich@suse.de
- patches.rt/megasas_IRQF_NODELAY.patch: Convert megaraid sas
  IRQ to non-threaded IRQ.
- patches.rt/version.patch: Delete (unused).
* Thu Jan 31 2008 jbenc@suse.cz
- patches.fixes/mac80211-fix-hw-scan1.patch,
  patches.fixes/mac80211-fix-hw-scan2.patch: mac80211: hardware
  scan rework (bnc#307050).
* Thu Jan 31 2008 sdietrich@suse.de
- Remove a legacy tweak carried over from the 10.3 Kernel,
  enable the affinity load-balancing sysctl.
* Wed Jan 30 2008 sdietrich@suse.de
- patches.rt/x86-ticket-lock.patch: FIFO ticket lock spinlocks
  for x86 (RT).
- patches.rt/rt-mutex-i386.patch: Resolve conflicts.
* Tue Jan 29 2008 olh@suse.de
- really skip kernel-ps3 in suse_kernel_module_package rpm macro
* Tue Jan 29 2008 jbeulich@novell.com
- Update Xen patches to 2.6.24 final and c/s 399.
- patches.xen/xen3-seccomp-disable-tsc-option: [PATCH seccomp:
  make tsc disabling optional (191123).
* Sat Jan 26 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rt1 (many patches in patches.rt refreshed).
- patches.rt/series: Delete (unused).
* Sat Jan 26 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  use struct device_attribute to fix oops on boot
* Fri Jan 25 2008 jeffm@suse.de
- scripts/sequence-patch.sh: Updated to include $EXTRA_SYMBOLS in
  $PATCH_DIR (e.g.: --symbol=RT creates linux-2.6.24-RT)
* Fri Jan 25 2008 jeffm@suse.de
- patches.rt/rcu-new-1.patch: Updated context against 2.6.24.
* Fri Jan 25 2008 olh@suse.de
- add patches.fixes/bootstrap-memoryless-node.patch
  slab: fix bootstrap on memoryless node
* Fri Jan 25 2008 gregkh@suse.de
- refresh allmost all patches to apply cleanly and have a proper
  diffstat (except for the xen patches, they were left alone...)
* Fri Jan 25 2008 gregkh@suse.de
- Update to 2.6.24
* Thu Jan 24 2008 olh@suse.de
- always skip kernel-ps3 in suse_kernel_module_package rpm macro
* Thu Jan 24 2008 sdietrich@suse.de
- Update config files: set SYSFS_DEPRECATED for reverse
  compatibility with SLERT
* Tue Jan 22 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  simplify patch
* Tue Jan 22 2008 agruen@suse.de
- patches.rpmify/cloneconfig.diff: Adjust to upstream i386 + x86_64
  merge (347712).
* Tue Jan 22 2008 sassmann@suse.de
- add defconfig for ps3 kernel
- add entry for ps3 defconfig in config.conf
- add support for kernels without loadable modules to rpm/kernel-binary.spec.in
- include ps3 target in scripts/tar-up_and_run_mbuild.sh
* Mon Jan 21 2008 sdietrich@suse.de
- Update config files (RT)
* Mon Jan 21 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rc8-rt1
* Mon Jan 21 2008 olh@suse.de
- add patches.arch/ppc-pegasos-pata_via-fixup.patch
  call chrp_pci_fixup_vt8231_ata() later to allow pata_via usage
* Mon Jan 21 2008 aj@suse.de
- Remove unused config/s390/rt.
* Fri Jan 18 2008 jeffm@suse.de
- patches.rt/irq-flags-unsigned-long.patch: Delete.
* Fri Jan 18 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git2.
* Fri Jan 18 2008 jeffm@suse.de
- Enabled 2.6.24-rc8-git1.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: Delete. The patch
  is not correct, there exist two cards with different chipsets but
  the same USB ID.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: rt2x00: remove
  duplicate USB ID (350956).
* Fri Jan 18 2008 olh@suse.de
- sync powerpc vanilla with default .config to enable libata
* Fri Jan 18 2008 olh@suse.de
- add patches.arch/ppc-pegasos-mv643xx_eth-modalias.patch
  provide module alias platform:mv643xx_eth
* Thu Jan 17 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git1.
* Wed Jan 16 2008 jeffm@suse.de
- Update to 2.6.24-rc8.
* Sun Jan 13 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git5.
* Fri Jan 11 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git3.
* Fri Jan 11 2008 jbeulich@novell.com
- Update Xen patches to c/s 372 and 2.6.24-rc7.
- patches.xen/xen3-aux-at_vector_size.patch: Delete.
- Update Xen config files.
* Thu Jan 10 2008 olh@suse.de
- update patches.arch/ppc-efika-ethernet-phy.patch
  move Forth code to fixup_device_tree_efika
* Wed Jan  9 2008 schwab@suse.de
- Fix debug package build.
* Wed Jan  9 2008 oneukum@suse.de
- Update config files. CONFIG_USB_SUSPEND default
* Wed Jan  9 2008 schwab@suse.de
- Update kdb patches.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Another try...
* Wed Jan  9 2008 jeffm@suse.de
- Update config files: Enabled CONFIG_SCSI_SAS_ATA. (346990)
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Fix CONFIG_FRAME_POINTER build.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- patches.xen/xen3-stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- Update config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: Fixed so it only applies
  to i386, and updated config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: [PATCH] seccomp:
  make tsc disabling optional (191123).
* Tue Jan  8 2008 olh@suse.de
- add patches.arch/ppc-efika-ethernet-phy.patch
  drop patches.arch/ppc-efika-bestcomm-ethernet.patch
  provide phy-handle property for fec_mpc52xx (347234)
* Tue Jan  8 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: libata: implement
  libata.force_cbl parameter (337610).
* Mon Jan  7 2008 jeffm@suse.de
- Update to 2.6.24-rc7.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-disable-ADMA: sata_nv: disable
  ADMA by default (346508).
* Mon Jan  7 2008 teheo@suse.de
  Bug 347708.  port_info for vmw was being assigned to the wrong index.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Mon Jan  7 2008 teheo@suse.de
  As the rest of kernel has caught up now, this one is no longer
  necessary.
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Fri Jan  4 2008 jeffm@suse.de
- Update config files for -vanilla.
* Fri Jan  4 2008 jeffm@suse.de
- patches.rt/timer-freq-tweaks.patch: Adjusted context.
* Fri Jan  4 2008 jeffm@suse.de
- Update config files.
* Fri Jan  4 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git11.
* Wed Jan  2 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Copy debug sources to a proper location.
* Tue Jan  1 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git7.
* Tue Jan  1 2008 jeffm@suse.de
- scripts/run_oldconfig.sh: Removed RT symbol from EXTRA_SYMBOLS.
  We add it manually when building the patch list. This allows
  the script to work with the RT kernel without having to remove
  all the other configs from config.conf first.
